@@ -17,12 +17,12 @@ from typeguard import check_type
 
 from .._jsii import *
 
-import cdktf
-import constructs
+import cdktf as _cdktf_9a9027ec
+import constructs as _constructs_77d1e7e8
 
 
 class AzureAdlsGen1Mount(
-    cdktf.TerraformResource,
+    _cdktf_9a9027ec.TerraformResource,
     metaclass=jsii.JSIIMeta,
     jsii_type="@cdktf/provider-databricks.azureAdlsGen1Mount.AzureAdlsGen1Mount",
 ):
@@ -30,7 +30,7 @@ class AzureAdlsGen1Mount(
 
     def __init__(
         self,
-        scope: constructs.Construct,
+        scope: _constructs_77d1e7e8.Construct,
         id_: builtins.str,
         *,
         client_id: builtins.str,
@@ -43,13 +43,13 @@ class AzureAdlsGen1Mount(
         directory: typing.Optional[builtins.str] = None,
         id: typing.Optional[builtins.str] = None,
         spark_conf_prefix: typing.Optional[builtins.str] = None,
-        connection: typing.Optional[typing.Union[typing.Union[cdktf.SSHProvisionerConnection, typing.Dict[str, typing.Any]], typing.Union[cdktf.WinrmProvisionerConnection, typing.Dict[str, typing.Any]]]] = None,
+        connection: typing.Optional[typing.Union[typing.Union[_cdktf_9a9027ec.SSHProvisionerConnection, typing.Dict[builtins.str, typing.Any]], typing.Union[_cdktf_9a9027ec.WinrmProvisionerConnection, typing.Dict[builtins.str, typing.Any]]]] = None,
         count: typing.Optional[jsii.Number] = None,
-        depends_on: typing.Optional[typing.Sequence[cdktf.ITerraformDependable]] = None,
-        for_each: typing.Optional[cdktf.ITerraformIterator] = None,
-        lifecycle: typing.Optional[typing.Union[cdktf.TerraformResourceLifecycle, typing.Dict[str, typing.Any]]] = None,
-        provider: typing.Optional[cdktf.TerraformProvider] = None,
-        provisioners: typing.Optional[typing.Sequence[typing.Union[typing.Union[cdktf.FileProvisioner, typing.Dict[str, typing.Any]], typing.Union[cdktf.LocalExecProvisioner, typing.Dict[str, typing.Any]], typing.Union[cdktf.RemoteExecProvisioner, typing.Dict[str, typing.Any]]]]] = None,
+        depends_on: typing.Optional[typing.Sequence[_cdktf_9a9027ec.ITerraformDependable]] = None,
+        for_each: typing.Optional[_cdktf_9a9027ec.ITerraformIterator] = None,
+        lifecycle: typing.Optional[typing.Union[_cdktf_9a9027ec.TerraformResourceLifecycle, typing.Dict[builtins.str, typing.Any]]] = None,
+        provider: typing.Optional[_cdktf_9a9027ec.TerraformProvider] = None,
+        provisioners: typing.Optional[typing.Sequence[typing.Union[typing.Union[_cdktf_9a9027ec.FileProvisioner, typing.Dict[builtins.str, typing.Any]], typing.Union[_cdktf_9a9027ec.LocalExecProvisioner, typing.Dict[builtins.str, typing.Any]], typing.Union[_cdktf_9a9027ec.RemoteExecProvisioner, typing.Dict[builtins.str, typing.Any]]]]] = None,
     ) -> None:
         '''Create a new {@link https://www.terraform.io/docs/providers/databricks/r/azure_adls_gen1_mount databricks_azure_adls_gen1_mount} Resource.
 
@@ -74,7 +74,7 @@ class AzureAdlsGen1Mount(
         :param provisioners: 
         '''
         if __debug__:
-            type_hints = typing.get_type_hints(AzureAdlsGen1Mount.__init__)
+            type_hints = typing.get_type_hints(_typecheckingstub__b2b3fb7f406a079f2539aeef2de50959cb6d7151861a8b3392d84e2705f86543)
             check_type(argname="argument scope", value=scope, expected_type=type_hints["scope"])
             check_type(argname="argument id_", value=id_, expected_type=type_hints["id_"])
         config = AzureAdlsGen1MountConfig(
@@ -187,7 +187,7 @@ class AzureAdlsGen1Mount(
     @client_id.setter
     def client_id(self, value: builtins.str) -> None:
         if __debug__:
-            type_hints = typing.get_type_hints(getattr(AzureAdlsGen1Mount, "client_id").fset)
+            type_hints = typing.get_type_hints(_typecheckingstub__508f5327c105673e4f4599071b0fab1fec452fd47440bf1553c76bf4c8677727)
             check_type(argname="argument value", value=value, expected_type=type_hints["value"])
         jsii.set(self, "clientId", value)
 
@@ -199,7 +199,7 @@ class AzureAdlsGen1Mount(
     @client_secret_key.setter
     def client_secret_key(self, value: builtins.str) -> None:
         if __debug__:
-            type_hints = typing.get_type_hints(getattr(AzureAdlsGen1Mount, "client_secret_key").fset)
+            type_hints = typing.get_type_hints(_typecheckingstub__7881e9f4321c06ef039a0b657bc3bdaf51d1dd3437ddacdd176a417325ca3f61)
             check_type(argname="argument value", value=value, expected_type=type_hints["value"])
         jsii.set(self, "clientSecretKey", value)
 
@@ -211,7 +211,7 @@ class AzureAdlsGen1Mount(
     @client_secret_scope.setter
     def client_secret_scope(self, value: builtins.str) -> None:
         if __debug__:
-            type_hints = typing.get_type_hints(getattr(AzureAdlsGen1Mount, "client_secret_scope").fset)
+            type_hints = typing.get_type_hints(_typecheckingstub__ce9ab94dddcac9c891821b0b6d6ce8546ddb039939829a72fcddbfeed9ff1c5e)
             check_type(argname="argument value", value=value, expected_type=type_hints["value"])
         jsii.set(self, "clientSecretScope", value)
 
@@ -223,7 +223,7 @@ class AzureAdlsGen1Mount(
     @cluster_id.setter
     def cluster_id(self, value: builtins.str) -> None:
         if __debug__:
-            type_hints = typing.get_type_hints(getattr(AzureAdlsGen1Mount, "cluster_id").fset)
+            type_hints = typing.get_type_hints(_typecheckingstub__94d9e870d952a2f7c4ecd246253378baa67ad01da76641bb97739b208f10108f)
             check_type(argname="argument value", value=value, expected_type=type_hints["value"])
         jsii.set(self, "clusterId", value)
 
@@ -235,7 +235,7 @@ class AzureAdlsGen1Mount(
     @directory.setter
     def directory(self, value: builtins.str) -> None:
         if __debug__:
-            type_hints = typing.get_type_hints(getattr(AzureAdlsGen1Mount, "directory").fset)
+            type_hints = typing.get_type_hints(_typecheckingstub__cdd00666c6e40263d4a222bba0847ca1cb7a4f027517262a74f547881e42a86c)
             check_type(argname="argument value", value=value, expected_type=type_hints["value"])
         jsii.set(self, "directory", value)
 
@@ -247,7 +247,7 @@ class AzureAdlsGen1Mount(
     @id.setter
     def id(self, value: builtins.str) -> None:
         if __debug__:
-            type_hints = typing.get_type_hints(getattr(AzureAdlsGen1Mount, "id").fset)
+            type_hints = typing.get_type_hints(_typecheckingstub__bb7554e5dc27f4f220b0ff485257f78c75817dc99788f9aa7e64a687ec7724a4)
             check_type(argname="argument value", value=value, expected_type=type_hints["value"])
         jsii.set(self, "id", value)
 
@@ -259,7 +259,7 @@ class AzureAdlsGen1Mount(
     @mount_name.setter
     def mount_name(self, value: builtins.str) -> None:
         if __debug__:
-            type_hints = typing.get_type_hints(getattr(AzureAdlsGen1Mount, "mount_name").fset)
+            type_hints = typing.get_type_hints(_typecheckingstub__5d35f9a72b5be2bef7880266be99adc853530533457d9aa82b7f1a6519c6465b)
             check_type(argname="argument value", value=value, expected_type=type_hints["value"])
         jsii.set(self, "mountName", value)
 
@@ -271,7 +271,7 @@ class AzureAdlsGen1Mount(
     @spark_conf_prefix.setter
     def spark_conf_prefix(self, value: builtins.str) -> None:
         if __debug__:
-            type_hints = typing.get_type_hints(getattr(AzureAdlsGen1Mount, "spark_conf_prefix").fset)
+            type_hints = typing.get_type_hints(_typecheckingstub__037378a96cf24ee4b6cf810b57003ed5f7daf32ce48128475acfedf21e020cc2)
             check_type(argname="argument value", value=value, expected_type=type_hints["value"])
         jsii.set(self, "sparkConfPrefix", value)
 
@@ -283,7 +283,7 @@ class AzureAdlsGen1Mount(
     @storage_resource_name.setter
     def storage_resource_name(self, value: builtins.str) -> None:
         if __debug__:
-            type_hints = typing.get_type_hints(getattr(AzureAdlsGen1Mount, "storage_resource_name").fset)
+            type_hints = typing.get_type_hints(_typecheckingstub__56802d8e237fc818bda410bad103cdd70d13f3426ac4e7282d1f39dcfb3b5440)
             check_type(argname="argument value", value=value, expected_type=type_hints["value"])
         jsii.set(self, "storageResourceName", value)
 
@@ -295,14 +295,14 @@ class AzureAdlsGen1Mount(
     @tenant_id.setter
     def tenant_id(self, value: builtins.str) -> None:
         if __debug__:
-            type_hints = typing.get_type_hints(getattr(AzureAdlsGen1Mount, "tenant_id").fset)
+            type_hints = typing.get_type_hints(_typecheckingstub__ac379f318274055733ed7ee873b6b45ea4bbd466202776819c02e4355cc94afa)
             check_type(argname="argument value", value=value, expected_type=type_hints["value"])
         jsii.set(self, "tenantId", value)
 
 
 @jsii.data_type(
     jsii_type="@cdktf/provider-databricks.azureAdlsGen1Mount.AzureAdlsGen1MountConfig",
-    jsii_struct_bases=[cdktf.TerraformMetaArguments],
+    jsii_struct_bases=[_cdktf_9a9027ec.TerraformMetaArguments],
     name_mapping={
         "connection": "connection",
         "count": "count",
@@ -323,17 +323,17 @@ class AzureAdlsGen1Mount(
         "spark_conf_prefix": "sparkConfPrefix",
     },
 )
-class AzureAdlsGen1MountConfig(cdktf.TerraformMetaArguments):
+class AzureAdlsGen1MountConfig(_cdktf_9a9027ec.TerraformMetaArguments):
     def __init__(
         self,
         *,
-        connection: typing.Optional[typing.Union[typing.Union[cdktf.SSHProvisionerConnection, typing.Dict[str, typing.Any]], typing.Union[cdktf.WinrmProvisionerConnection, typing.Dict[str, typing.Any]]]] = None,
+        connection: typing.Optional[typing.Union[typing.Union[_cdktf_9a9027ec.SSHProvisionerConnection, typing.Dict[builtins.str, typing.Any]], typing.Union[_cdktf_9a9027ec.WinrmProvisionerConnection, typing.Dict[builtins.str, typing.Any]]]] = None,
         count: typing.Optional[jsii.Number] = None,
-        depends_on: typing.Optional[typing.Sequence[cdktf.ITerraformDependable]] = None,
-        for_each: typing.Optional[cdktf.ITerraformIterator] = None,
-        lifecycle: typing.Optional[typing.Union[cdktf.TerraformResourceLifecycle, typing.Dict[str, typing.Any]]] = None,
-        provider: typing.Optional[cdktf.TerraformProvider] = None,
-        provisioners: typing.Optional[typing.Sequence[typing.Union[typing.Union[cdktf.FileProvisioner, typing.Dict[str, typing.Any]], typing.Union[cdktf.LocalExecProvisioner, typing.Dict[str, typing.Any]], typing.Union[cdktf.RemoteExecProvisioner, typing.Dict[str, typing.Any]]]]] = None,
+        depends_on: typing.Optional[typing.Sequence[_cdktf_9a9027ec.ITerraformDependable]] = None,
+        for_each: typing.Optional[_cdktf_9a9027ec.ITerraformIterator] = None,
+        lifecycle: typing.Optional[typing.Union[_cdktf_9a9027ec.TerraformResourceLifecycle, typing.Dict[builtins.str, typing.Any]]] = None,
+        provider: typing.Optional[_cdktf_9a9027ec.TerraformProvider] = None,
+        provisioners: typing.Optional[typing.Sequence[typing.Union[typing.Union[_cdktf_9a9027ec.FileProvisioner, typing.Dict[builtins.str, typing.Any]], typing.Union[_cdktf_9a9027ec.LocalExecProvisioner, typing.Dict[builtins.str, typing.Any]], typing.Union[_cdktf_9a9027ec.RemoteExecProvisioner, typing.Dict[builtins.str, typing.Any]]]]] = None,
         client_id: builtins.str,
         client_secret_key: builtins.str,
         client_secret_scope: builtins.str,
@@ -365,9 +365,9 @@ class AzureAdlsGen1MountConfig(cdktf.TerraformMetaArguments):
         :param spark_conf_prefix: Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/databricks/r/azure_adls_gen1_mount#spark_conf_prefix AzureAdlsGen1Mount#spark_conf_prefix}.
         '''
         if isinstance(lifecycle, dict):
-            lifecycle = cdktf.TerraformResourceLifecycle(**lifecycle)
+            lifecycle = _cdktf_9a9027ec.TerraformResourceLifecycle(**lifecycle)
         if __debug__:
-            type_hints = typing.get_type_hints(AzureAdlsGen1MountConfig.__init__)
+            type_hints = typing.get_type_hints(_typecheckingstub__f52732c7ae7ffeb20c743ec5aa58e5b485f3770ea6ecf90be836fbee63f878ae)
             check_type(argname="argument connection", value=connection, expected_type=type_hints["connection"])
             check_type(argname="argument count", value=count, expected_type=type_hints["count"])
             check_type(argname="argument depends_on", value=depends_on, expected_type=type_hints["depends_on"])
@@ -385,7 +385,7 @@ class AzureAdlsGen1MountConfig(cdktf.TerraformMetaArguments):
             check_type(argname="argument directory", value=directory, expected_type=type_hints["directory"])
             check_type(argname="argument id", value=id, expected_type=type_hints["id"])
             check_type(argname="argument spark_conf_prefix", value=spark_conf_prefix, expected_type=type_hints["spark_conf_prefix"])
-        self._values: typing.Dict[str, typing.Any] = {
+        self._values: typing.Dict[builtins.str, typing.Any] = {
             "client_id": client_id,
             "client_secret_key": client_secret_key,
             "client_secret_scope": client_secret_scope,
@@ -419,12 +419,12 @@ class AzureAdlsGen1MountConfig(cdktf.TerraformMetaArguments):
     @builtins.property
     def connection(
         self,
-    ) -> typing.Optional[typing.Union[cdktf.SSHProvisionerConnection, cdktf.WinrmProvisionerConnection]]:
+    ) -> typing.Optional[typing.Union[_cdktf_9a9027ec.SSHProvisionerConnection, _cdktf_9a9027ec.WinrmProvisionerConnection]]:
         '''
         :stability: experimental
         '''
         result = self._values.get("connection")
-        return typing.cast(typing.Optional[typing.Union[cdktf.SSHProvisionerConnection, cdktf.WinrmProvisionerConnection]], result)
+        return typing.cast(typing.Optional[typing.Union[_cdktf_9a9027ec.SSHProvisionerConnection, _cdktf_9a9027ec.WinrmProvisionerConnection]], result)
 
     @builtins.property
     def count(self) -> typing.Optional[jsii.Number]:
@@ -435,46 +435,48 @@ class AzureAdlsGen1MountConfig(cdktf.TerraformMetaArguments):
         return typing.cast(typing.Optional[jsii.Number], result)
 
     @builtins.property
-    def depends_on(self) -> typing.Optional[typing.List[cdktf.ITerraformDependable]]:
+    def depends_on(
+        self,
+    ) -> typing.Optional[typing.List[_cdktf_9a9027ec.ITerraformDependable]]:
         '''
         :stability: experimental
         '''
         result = self._values.get("depends_on")
-        return typing.cast(typing.Optional[typing.List[cdktf.ITerraformDependable]], result)
+        return typing.cast(typing.Optional[typing.List[_cdktf_9a9027ec.ITerraformDependable]], result)
 
     @builtins.property
-    def for_each(self) -> typing.Optional[cdktf.ITerraformIterator]:
+    def for_each(self) -> typing.Optional[_cdktf_9a9027ec.ITerraformIterator]:
         '''
         :stability: experimental
         '''
         result = self._values.get("for_each")
-        return typing.cast(typing.Optional[cdktf.ITerraformIterator], result)
+        return typing.cast(typing.Optional[_cdktf_9a9027ec.ITerraformIterator], result)
 
     @builtins.property
-    def lifecycle(self) -> typing.Optional[cdktf.TerraformResourceLifecycle]:
+    def lifecycle(self) -> typing.Optional[_cdktf_9a9027ec.TerraformResourceLifecycle]:
         '''
         :stability: experimental
         '''
         result = self._values.get("lifecycle")
-        return typing.cast(typing.Optional[cdktf.TerraformResourceLifecycle], result)
+        return typing.cast(typing.Optional[_cdktf_9a9027ec.TerraformResourceLifecycle], result)
 
     @builtins.property
-    def provider(self) -> typing.Optional[cdktf.TerraformProvider]:
+    def provider(self) -> typing.Optional[_cdktf_9a9027ec.TerraformProvider]:
         '''
         :stability: experimental
         '''
         result = self._values.get("provider")
-        return typing.cast(typing.Optional[cdktf.TerraformProvider], result)
+        return typing.cast(typing.Optional[_cdktf_9a9027ec.TerraformProvider], result)
 
     @builtins.property
     def provisioners(
         self,
-    ) -> typing.Optional[typing.List[typing.Union[cdktf.FileProvisioner, cdktf.LocalExecProvisioner, cdktf.RemoteExecProvisioner]]]:
+    ) -> typing.Optional[typing.List[typing.Union[_cdktf_9a9027ec.FileProvisioner, _cdktf_9a9027ec.LocalExecProvisioner, _cdktf_9a9027ec.RemoteExecProvisioner]]]:
         '''
         :stability: experimental
         '''
         result = self._values.get("provisioners")
-        return typing.cast(typing.Optional[typing.List[typing.Union[cdktf.FileProvisioner, cdktf.LocalExecProvisioner, cdktf.RemoteExecProvisioner]]], result)
+        return typing.cast(typing.Optional[typing.List[typing.Union[_cdktf_9a9027ec.FileProvisioner, _cdktf_9a9027ec.LocalExecProvisioner, _cdktf_9a9027ec.RemoteExecProvisioner]]], result)
 
     @builtins.property
     def client_id(self) -> builtins.str:
@@ -564,3 +566,111 @@ __all__ = [
 ]
 
 publication.publish()
+
+def _typecheckingstub__b2b3fb7f406a079f2539aeef2de50959cb6d7151861a8b3392d84e2705f86543(
+    scope: _constructs_77d1e7e8.Construct,
+    id_: builtins.str,
+    *,
+    client_id: builtins.str,
+    client_secret_key: builtins.str,
+    client_secret_scope: builtins.str,
+    mount_name: builtins.str,
+    storage_resource_name: builtins.str,
+    tenant_id: builtins.str,
+    cluster_id: typing.Optional[builtins.str] = None,
+    directory: typing.Optional[builtins.str] = None,
+    id: typing.Optional[builtins.str] = None,
+    spark_conf_prefix: typing.Optional[builtins.str] = None,
+    connection: typing.Optional[typing.Union[typing.Union[_cdktf_9a9027ec.SSHProvisionerConnection, typing.Dict[builtins.str, typing.Any]], typing.Union[_cdktf_9a9027ec.WinrmProvisionerConnection, typing.Dict[builtins.str, typing.Any]]]] = None,
+    count: typing.Optional[jsii.Number] = None,
+    depends_on: typing.Optional[typing.Sequence[_cdktf_9a9027ec.ITerraformDependable]] = None,
+    for_each: typing.Optional[_cdktf_9a9027ec.ITerraformIterator] = None,
+    lifecycle: typing.Optional[typing.Union[_cdktf_9a9027ec.TerraformResourceLifecycle, typing.Dict[builtins.str, typing.Any]]] = None,
+    provider: typing.Optional[_cdktf_9a9027ec.TerraformProvider] = None,
+    provisioners: typing.Optional[typing.Sequence[typing.Union[typing.Union[_cdktf_9a9027ec.FileProvisioner, typing.Dict[builtins.str, typing.Any]], typing.Union[_cdktf_9a9027ec.LocalExecProvisioner, typing.Dict[builtins.str, typing.Any]], typing.Union[_cdktf_9a9027ec.RemoteExecProvisioner, typing.Dict[builtins.str, typing.Any]]]]] = None,
+) -> None:
+    """Type checking stubs"""
+    pass
+
+def _typecheckingstub__508f5327c105673e4f4599071b0fab1fec452fd47440bf1553c76bf4c8677727(
+    value: builtins.str,
+) -> None:
+    """Type checking stubs"""
+    pass
+
+def _typecheckingstub__7881e9f4321c06ef039a0b657bc3bdaf51d1dd3437ddacdd176a417325ca3f61(
+    value: builtins.str,
+) -> None:
+    """Type checking stubs"""
+    pass
+
+def _typecheckingstub__ce9ab94dddcac9c891821b0b6d6ce8546ddb039939829a72fcddbfeed9ff1c5e(
+    value: builtins.str,
+) -> None:
+    """Type checking stubs"""
+    pass
+
+def _typecheckingstub__94d9e870d952a2f7c4ecd246253378baa67ad01da76641bb97739b208f10108f(
+    value: builtins.str,
+) -> None:
+    """Type checking stubs"""
+    pass
+
+def _typecheckingstub__cdd00666c6e40263d4a222bba0847ca1cb7a4f027517262a74f547881e42a86c(
+    value: builtins.str,
+) -> None:
+    """Type checking stubs"""
+    pass
+
+def _typecheckingstub__bb7554e5dc27f4f220b0ff485257f78c75817dc99788f9aa7e64a687ec7724a4(
+    value: builtins.str,
+) -> None:
+    """Type checking stubs"""
+    pass
+
+def _typecheckingstub__5d35f9a72b5be2bef7880266be99adc853530533457d9aa82b7f1a6519c6465b(
+    value: builtins.str,
+) -> None:
+    """Type checking stubs"""
+    pass
+
+def _typecheckingstub__037378a96cf24ee4b6cf810b57003ed5f7daf32ce48128475acfedf21e020cc2(
+    value: builtins.str,
+) -> None:
+    """Type checking stubs"""
+    pass
+
+def _typecheckingstub__56802d8e237fc818bda410bad103cdd70d13f3426ac4e7282d1f39dcfb3b5440(
+    value: builtins.str,
+) -> None:
+    """Type checking stubs"""
+    pass
+
+def _typecheckingstub__ac379f318274055733ed7ee873b6b45ea4bbd466202776819c02e4355cc94afa(
+    value: builtins.str,
+) -> None:
+    """Type checking stubs"""
+    pass
+
+def _typecheckingstub__f52732c7ae7ffeb20c743ec5aa58e5b485f3770ea6ecf90be836fbee63f878ae(
+    *,
+    connection: typing.Optional[typing.Union[typing.Union[_cdktf_9a9027ec.SSHProvisionerConnection, typing.Dict[builtins.str, typing.Any]], typing.Union[_cdktf_9a9027ec.WinrmProvisionerConnection, typing.Dict[builtins.str, typing.Any]]]] = None,
+    count: typing.Optional[jsii.Number] = None,
+    depends_on: typing.Optional[typing.Sequence[_cdktf_9a9027ec.ITerraformDependable]] = None,
+    for_each: typing.Optional[_cdktf_9a9027ec.ITerraformIterator] = None,
+    lifecycle: typing.Optional[typing.Union[_cdktf_9a9027ec.TerraformResourceLifecycle, typing.Dict[builtins.str, typing.Any]]] = None,
+    provider: typing.Optional[_cdktf_9a9027ec.TerraformProvider] = None,
+    provisioners: typing.Optional[typing.Sequence[typing.Union[typing.Union[_cdktf_9a9027ec.FileProvisioner, typing.Dict[builtins.str, typing.Any]], typing.Union[_cdktf_9a9027ec.LocalExecProvisioner, typing.Dict[builtins.str, typing.Any]], typing.Union[_cdktf_9a9027ec.RemoteExecProvisioner, typing.Dict[builtins.str, typing.Any]]]]] = None,
+    client_id: builtins.str,
+    client_secret_key: builtins.str,
+    client_secret_scope: builtins.str,
+    mount_name: builtins.str,
+    storage_resource_name: builtins.str,
+    tenant_id: builtins.str,
+    cluster_id: typing.Optional[builtins.str] = None,
+    directory: typing.Optional[builtins.str] = None,
+    id: typing.Optional[builtins.str] = None,
+    spark_conf_prefix: typing.Optional[builtins.str] = None,
+) -> None:
+    """Type checking stubs"""
+    pass
