@@ -17,12 +17,12 @@ from typeguard import check_type
 
 from .._jsii import *
 
-import cdktf
-import constructs
+import cdktf as _cdktf_9a9027ec
+import constructs as _constructs_77d1e7e8
 
 
 class AzureAdlsGen2Mount(
-    cdktf.TerraformResource,
+    _cdktf_9a9027ec.TerraformResource,
     metaclass=jsii.JSIIMeta,
     jsii_type="@cdktf/provider-databricks.azureAdlsGen2Mount.AzureAdlsGen2Mount",
 ):
@@ -30,27 +30,27 @@ class AzureAdlsGen2Mount(
 
     def __init__(
         self,
-        scope: constructs.Construct,
+        scope: _constructs_77d1e7e8.Construct,
         id_: builtins.str,
         *,
         client_id: builtins.str,
         client_secret_key: builtins.str,
         client_secret_scope: builtins.str,
         container_name: builtins.str,
-        initialize_file_system: typing.Union[builtins.bool, cdktf.IResolvable],
+        initialize_file_system: typing.Union[builtins.bool, _cdktf_9a9027ec.IResolvable],
         mount_name: builtins.str,
         storage_account_name: builtins.str,
         tenant_id: builtins.str,
         cluster_id: typing.Optional[builtins.str] = None,
         directory: typing.Optional[builtins.str] = None,
         id: typing.Optional[builtins.str] = None,
-        connection: typing.Optional[typing.Union[typing.Union[cdktf.SSHProvisionerConnection, typing.Dict[str, typing.Any]], typing.Union[cdktf.WinrmProvisionerConnection, typing.Dict[str, typing.Any]]]] = None,
+        connection: typing.Optional[typing.Union[typing.Union[_cdktf_9a9027ec.SSHProvisionerConnection, typing.Dict[builtins.str, typing.Any]], typing.Union[_cdktf_9a9027ec.WinrmProvisionerConnection, typing.Dict[builtins.str, typing.Any]]]] = None,
         count: typing.Optional[jsii.Number] = None,
-        depends_on: typing.Optional[typing.Sequence[cdktf.ITerraformDependable]] = None,
-        for_each: typing.Optional[cdktf.ITerraformIterator] = None,
-        lifecycle: typing.Optional[typing.Union[cdktf.TerraformResourceLifecycle, typing.Dict[str, typing.Any]]] = None,
-        provider: typing.Optional[cdktf.TerraformProvider] = None,
-        provisioners: typing.Optional[typing.Sequence[typing.Union[typing.Union[cdktf.FileProvisioner, typing.Dict[str, typing.Any]], typing.Union[cdktf.LocalExecProvisioner, typing.Dict[str, typing.Any]], typing.Union[cdktf.RemoteExecProvisioner, typing.Dict[str, typing.Any]]]]] = None,
+        depends_on: typing.Optional[typing.Sequence[_cdktf_9a9027ec.ITerraformDependable]] = None,
+        for_each: typing.Optional[_cdktf_9a9027ec.ITerraformIterator] = None,
+        lifecycle: typing.Optional[typing.Union[_cdktf_9a9027ec.TerraformResourceLifecycle, typing.Dict[builtins.str, typing.Any]]] = None,
+        provider: typing.Optional[_cdktf_9a9027ec.TerraformProvider] = None,
+        provisioners: typing.Optional[typing.Sequence[typing.Union[typing.Union[_cdktf_9a9027ec.FileProvisioner, typing.Dict[builtins.str, typing.Any]], typing.Union[_cdktf_9a9027ec.LocalExecProvisioner, typing.Dict[builtins.str, typing.Any]], typing.Union[_cdktf_9a9027ec.RemoteExecProvisioner, typing.Dict[builtins.str, typing.Any]]]]] = None,
     ) -> None:
         '''Create a new {@link https://www.terraform.io/docs/providers/databricks/r/azure_adls_gen2_mount databricks_azure_adls_gen2_mount} Resource.
 
@@ -76,7 +76,7 @@ class AzureAdlsGen2Mount(
         :param provisioners: 
         '''
         if __debug__:
-            type_hints = typing.get_type_hints(AzureAdlsGen2Mount.__init__)
+            type_hints = typing.get_type_hints(_typecheckingstub__5930b7e193b7f085588e840d9e30a84ffc7372e1ba964c043c9cdafd2376d1a7)
             check_type(argname="argument scope", value=scope, expected_type=type_hints["scope"])
             check_type(argname="argument id_", value=id_, expected_type=type_hints["id_"])
         config = AzureAdlsGen2MountConfig(
@@ -167,8 +167,8 @@ class AzureAdlsGen2Mount(
     @jsii.member(jsii_name="initializeFileSystemInput")
     def initialize_file_system_input(
         self,
-    ) -> typing.Optional[typing.Union[builtins.bool, cdktf.IResolvable]]:
-        return typing.cast(typing.Optional[typing.Union[builtins.bool, cdktf.IResolvable]], jsii.get(self, "initializeFileSystemInput"))
+    ) -> typing.Optional[typing.Union[builtins.bool, _cdktf_9a9027ec.IResolvable]]:
+        return typing.cast(typing.Optional[typing.Union[builtins.bool, _cdktf_9a9027ec.IResolvable]], jsii.get(self, "initializeFileSystemInput"))
 
     @builtins.property
     @jsii.member(jsii_name="mountNameInput")
@@ -193,7 +193,7 @@ class AzureAdlsGen2Mount(
     @client_id.setter
     def client_id(self, value: builtins.str) -> None:
         if __debug__:
-            type_hints = typing.get_type_hints(getattr(AzureAdlsGen2Mount, "client_id").fset)
+            type_hints = typing.get_type_hints(_typecheckingstub__f7188dd9c92ade6c14152682d68357ef121a11d615743bb258b1ab47783a3722)
             check_type(argname="argument value", value=value, expected_type=type_hints["value"])
         jsii.set(self, "clientId", value)
 
@@ -205,7 +205,7 @@ class AzureAdlsGen2Mount(
     @client_secret_key.setter
     def client_secret_key(self, value: builtins.str) -> None:
         if __debug__:
-            type_hints = typing.get_type_hints(getattr(AzureAdlsGen2Mount, "client_secret_key").fset)
+            type_hints = typing.get_type_hints(_typecheckingstub__9291828e1bba518fa0fe3638c58fbf7a1a1536d7760b8d42937fc34d8c2988f6)
             check_type(argname="argument value", value=value, expected_type=type_hints["value"])
         jsii.set(self, "clientSecretKey", value)
 
@@ -217,7 +217,7 @@ class AzureAdlsGen2Mount(
     @client_secret_scope.setter
     def client_secret_scope(self, value: builtins.str) -> None:
         if __debug__:
-            type_hints = typing.get_type_hints(getattr(AzureAdlsGen2Mount, "client_secret_scope").fset)
+            type_hints = typing.get_type_hints(_typecheckingstub__d9de83285a3695591d82af4a54ca5ee46b3df2855fa9a76a1a859066654a200d)
             check_type(argname="argument value", value=value, expected_type=type_hints["value"])
         jsii.set(self, "clientSecretScope", value)
 
@@ -229,7 +229,7 @@ class AzureAdlsGen2Mount(
     @cluster_id.setter
     def cluster_id(self, value: builtins.str) -> None:
         if __debug__:
-            type_hints = typing.get_type_hints(getattr(AzureAdlsGen2Mount, "cluster_id").fset)
+            type_hints = typing.get_type_hints(_typecheckingstub__dd814b3c61d999c3b97eeab42df56f2c71b9d7b7ba5387bd73c260c665b149a2)
             check_type(argname="argument value", value=value, expected_type=type_hints["value"])
         jsii.set(self, "clusterId", value)
 
@@ -241,7 +241,7 @@ class AzureAdlsGen2Mount(
     @container_name.setter
     def container_name(self, value: builtins.str) -> None:
         if __debug__:
-            type_hints = typing.get_type_hints(getattr(AzureAdlsGen2Mount, "container_name").fset)
+            type_hints = typing.get_type_hints(_typecheckingstub__653f40f2bcd1cf43d1b1d2edf764bbd0b7a0a7c1ab54483ad2709e2bb06cbcac)
             check_type(argname="argument value", value=value, expected_type=type_hints["value"])
         jsii.set(self, "containerName", value)
 
@@ -253,7 +253,7 @@ class AzureAdlsGen2Mount(
     @directory.setter
     def directory(self, value: builtins.str) -> None:
         if __debug__:
-            type_hints = typing.get_type_hints(getattr(AzureAdlsGen2Mount, "directory").fset)
+            type_hints = typing.get_type_hints(_typecheckingstub__d9118db818d94a01387dac5df0b93472acdf5bd6ab8dd13620e9c4f2e16b1bd4)
             check_type(argname="argument value", value=value, expected_type=type_hints["value"])
         jsii.set(self, "directory", value)
 
@@ -265,22 +265,24 @@ class AzureAdlsGen2Mount(
     @id.setter
     def id(self, value: builtins.str) -> None:
         if __debug__:
-            type_hints = typing.get_type_hints(getattr(AzureAdlsGen2Mount, "id").fset)
+            type_hints = typing.get_type_hints(_typecheckingstub__82ea94dd06e21725e44b8a8457f774017e9defe86418f38a079a4d7e1ba1ed19)
             check_type(argname="argument value", value=value, expected_type=type_hints["value"])
         jsii.set(self, "id", value)
 
     @builtins.property
     @jsii.member(jsii_name="initializeFileSystem")
-    def initialize_file_system(self) -> typing.Union[builtins.bool, cdktf.IResolvable]:
-        return typing.cast(typing.Union[builtins.bool, cdktf.IResolvable], jsii.get(self, "initializeFileSystem"))
+    def initialize_file_system(
+        self,
+    ) -> typing.Union[builtins.bool, _cdktf_9a9027ec.IResolvable]:
+        return typing.cast(typing.Union[builtins.bool, _cdktf_9a9027ec.IResolvable], jsii.get(self, "initializeFileSystem"))
 
     @initialize_file_system.setter
     def initialize_file_system(
         self,
-        value: typing.Union[builtins.bool, cdktf.IResolvable],
+        value: typing.Union[builtins.bool, _cdktf_9a9027ec.IResolvable],
     ) -> None:
         if __debug__:
-            type_hints = typing.get_type_hints(getattr(AzureAdlsGen2Mount, "initialize_file_system").fset)
+            type_hints = typing.get_type_hints(_typecheckingstub__f0f2e66de1947413cf10ea5f51817ce5892c38c4a03b5c82138430f379a10439)
             check_type(argname="argument value", value=value, expected_type=type_hints["value"])
         jsii.set(self, "initializeFileSystem", value)
 
@@ -292,7 +294,7 @@ class AzureAdlsGen2Mount(
     @mount_name.setter
     def mount_name(self, value: builtins.str) -> None:
         if __debug__:
-            type_hints = typing.get_type_hints(getattr(AzureAdlsGen2Mount, "mount_name").fset)
+            type_hints = typing.get_type_hints(_typecheckingstub__d9112f9bbe27ff779d11cf8f8d2d033567aed5350020576aaafc5c56c5710750)
             check_type(argname="argument value", value=value, expected_type=type_hints["value"])
         jsii.set(self, "mountName", value)
 
@@ -304,7 +306,7 @@ class AzureAdlsGen2Mount(
     @storage_account_name.setter
     def storage_account_name(self, value: builtins.str) -> None:
         if __debug__:
-            type_hints = typing.get_type_hints(getattr(AzureAdlsGen2Mount, "storage_account_name").fset)
+            type_hints = typing.get_type_hints(_typecheckingstub__5334f3e6a10247d8d2e6a3f85134df35a03a7571a286887939a2eca0ea4ad1da)
             check_type(argname="argument value", value=value, expected_type=type_hints["value"])
         jsii.set(self, "storageAccountName", value)
 
@@ -316,14 +318,14 @@ class AzureAdlsGen2Mount(
     @tenant_id.setter
     def tenant_id(self, value: builtins.str) -> None:
         if __debug__:
-            type_hints = typing.get_type_hints(getattr(AzureAdlsGen2Mount, "tenant_id").fset)
+            type_hints = typing.get_type_hints(_typecheckingstub__26216601682b712f35889bc00cc4965fe56f7b95335c5fd454983ac8f2e6ce4b)
             check_type(argname="argument value", value=value, expected_type=type_hints["value"])
         jsii.set(self, "tenantId", value)
 
 
 @jsii.data_type(
     jsii_type="@cdktf/provider-databricks.azureAdlsGen2Mount.AzureAdlsGen2MountConfig",
-    jsii_struct_bases=[cdktf.TerraformMetaArguments],
+    jsii_struct_bases=[_cdktf_9a9027ec.TerraformMetaArguments],
     name_mapping={
         "connection": "connection",
         "count": "count",
@@ -345,22 +347,22 @@ class AzureAdlsGen2Mount(
         "id": "id",
     },
 )
-class AzureAdlsGen2MountConfig(cdktf.TerraformMetaArguments):
+class AzureAdlsGen2MountConfig(_cdktf_9a9027ec.TerraformMetaArguments):
     def __init__(
         self,
         *,
-        connection: typing.Optional[typing.Union[typing.Union[cdktf.SSHProvisionerConnection, typing.Dict[str, typing.Any]], typing.Union[cdktf.WinrmProvisionerConnection, typing.Dict[str, typing.Any]]]] = None,
+        connection: typing.Optional[typing.Union[typing.Union[_cdktf_9a9027ec.SSHProvisionerConnection, typing.Dict[builtins.str, typing.Any]], typing.Union[_cdktf_9a9027ec.WinrmProvisionerConnection, typing.Dict[builtins.str, typing.Any]]]] = None,
         count: typing.Optional[jsii.Number] = None,
-        depends_on: typing.Optional[typing.Sequence[cdktf.ITerraformDependable]] = None,
-        for_each: typing.Optional[cdktf.ITerraformIterator] = None,
-        lifecycle: typing.Optional[typing.Union[cdktf.TerraformResourceLifecycle, typing.Dict[str, typing.Any]]] = None,
-        provider: typing.Optional[cdktf.TerraformProvider] = None,
-        provisioners: typing.Optional[typing.Sequence[typing.Union[typing.Union[cdktf.FileProvisioner, typing.Dict[str, typing.Any]], typing.Union[cdktf.LocalExecProvisioner, typing.Dict[str, typing.Any]], typing.Union[cdktf.RemoteExecProvisioner, typing.Dict[str, typing.Any]]]]] = None,
+        depends_on: typing.Optional[typing.Sequence[_cdktf_9a9027ec.ITerraformDependable]] = None,
+        for_each: typing.Optional[_cdktf_9a9027ec.ITerraformIterator] = None,
+        lifecycle: typing.Optional[typing.Union[_cdktf_9a9027ec.TerraformResourceLifecycle, typing.Dict[builtins.str, typing.Any]]] = None,
+        provider: typing.Optional[_cdktf_9a9027ec.TerraformProvider] = None,
+        provisioners: typing.Optional[typing.Sequence[typing.Union[typing.Union[_cdktf_9a9027ec.FileProvisioner, typing.Dict[builtins.str, typing.Any]], typing.Union[_cdktf_9a9027ec.LocalExecProvisioner, typing.Dict[builtins.str, typing.Any]], typing.Union[_cdktf_9a9027ec.RemoteExecProvisioner, typing.Dict[builtins.str, typing.Any]]]]] = None,
         client_id: builtins.str,
         client_secret_key: builtins.str,
         client_secret_scope: builtins.str,
         container_name: builtins.str,
-        initialize_file_system: typing.Union[builtins.bool, cdktf.IResolvable],
+        initialize_file_system: typing.Union[builtins.bool, _cdktf_9a9027ec.IResolvable],
         mount_name: builtins.str,
         storage_account_name: builtins.str,
         tenant_id: builtins.str,
@@ -389,9 +391,9 @@ class AzureAdlsGen2MountConfig(cdktf.TerraformMetaArguments):
         :param id: Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/databricks/r/azure_adls_gen2_mount#id AzureAdlsGen2Mount#id}. Please be aware that the id field is automatically added to all resources in Terraform providers using a Terraform provider SDK version below 2. If you experience problems setting this value it might not be settable. Please take a look at the provider documentation to ensure it should be settable.
         '''
         if isinstance(lifecycle, dict):
-            lifecycle = cdktf.TerraformResourceLifecycle(**lifecycle)
+            lifecycle = _cdktf_9a9027ec.TerraformResourceLifecycle(**lifecycle)
         if __debug__:
-            type_hints = typing.get_type_hints(AzureAdlsGen2MountConfig.__init__)
+            type_hints = typing.get_type_hints(_typecheckingstub__6423d1c3da487275147899fe59f13710722aec3e5048f5d712c57e71f7449059)
             check_type(argname="argument connection", value=connection, expected_type=type_hints["connection"])
             check_type(argname="argument count", value=count, expected_type=type_hints["count"])
             check_type(argname="argument depends_on", value=depends_on, expected_type=type_hints["depends_on"])
@@ -410,7 +412,7 @@ class AzureAdlsGen2MountConfig(cdktf.TerraformMetaArguments):
             check_type(argname="argument cluster_id", value=cluster_id, expected_type=type_hints["cluster_id"])
             check_type(argname="argument directory", value=directory, expected_type=type_hints["directory"])
             check_type(argname="argument id", value=id, expected_type=type_hints["id"])
-        self._values: typing.Dict[str, typing.Any] = {
+        self._values: typing.Dict[builtins.str, typing.Any] = {
             "client_id": client_id,
             "client_secret_key": client_secret_key,
             "client_secret_scope": client_secret_scope,
@@ -444,12 +446,12 @@ class AzureAdlsGen2MountConfig(cdktf.TerraformMetaArguments):
     @builtins.property
     def connection(
         self,
-    ) -> typing.Optional[typing.Union[cdktf.SSHProvisionerConnection, cdktf.WinrmProvisionerConnection]]:
+    ) -> typing.Optional[typing.Union[_cdktf_9a9027ec.SSHProvisionerConnection, _cdktf_9a9027ec.WinrmProvisionerConnection]]:
         '''
         :stability: experimental
         '''
         result = self._values.get("connection")
-        return typing.cast(typing.Optional[typing.Union[cdktf.SSHProvisionerConnection, cdktf.WinrmProvisionerConnection]], result)
+        return typing.cast(typing.Optional[typing.Union[_cdktf_9a9027ec.SSHProvisionerConnection, _cdktf_9a9027ec.WinrmProvisionerConnection]], result)
 
     @builtins.property
     def count(self) -> typing.Optional[jsii.Number]:
@@ -460,46 +462,48 @@ class AzureAdlsGen2MountConfig(cdktf.TerraformMetaArguments):
         return typing.cast(typing.Optional[jsii.Number], result)
 
     @builtins.property
-    def depends_on(self) -> typing.Optional[typing.List[cdktf.ITerraformDependable]]:
+    def depends_on(
+        self,
+    ) -> typing.Optional[typing.List[_cdktf_9a9027ec.ITerraformDependable]]:
         '''
         :stability: experimental
         '''
         result = self._values.get("depends_on")
-        return typing.cast(typing.Optional[typing.List[cdktf.ITerraformDependable]], result)
+        return typing.cast(typing.Optional[typing.List[_cdktf_9a9027ec.ITerraformDependable]], result)
 
     @builtins.property
-    def for_each(self) -> typing.Optional[cdktf.ITerraformIterator]:
+    def for_each(self) -> typing.Optional[_cdktf_9a9027ec.ITerraformIterator]:
         '''
         :stability: experimental
         '''
         result = self._values.get("for_each")
-        return typing.cast(typing.Optional[cdktf.ITerraformIterator], result)
+        return typing.cast(typing.Optional[_cdktf_9a9027ec.ITerraformIterator], result)
 
     @builtins.property
-    def lifecycle(self) -> typing.Optional[cdktf.TerraformResourceLifecycle]:
+    def lifecycle(self) -> typing.Optional[_cdktf_9a9027ec.TerraformResourceLifecycle]:
         '''
         :stability: experimental
         '''
         result = self._values.get("lifecycle")
-        return typing.cast(typing.Optional[cdktf.TerraformResourceLifecycle], result)
+        return typing.cast(typing.Optional[_cdktf_9a9027ec.TerraformResourceLifecycle], result)
 
     @builtins.property
-    def provider(self) -> typing.Optional[cdktf.TerraformProvider]:
+    def provider(self) -> typing.Optional[_cdktf_9a9027ec.TerraformProvider]:
         '''
         :stability: experimental
         '''
         result = self._values.get("provider")
-        return typing.cast(typing.Optional[cdktf.TerraformProvider], result)
+        return typing.cast(typing.Optional[_cdktf_9a9027ec.TerraformProvider], result)
 
     @builtins.property
     def provisioners(
         self,
-    ) -> typing.Optional[typing.List[typing.Union[cdktf.FileProvisioner, cdktf.LocalExecProvisioner, cdktf.RemoteExecProvisioner]]]:
+    ) -> typing.Optional[typing.List[typing.Union[_cdktf_9a9027ec.FileProvisioner, _cdktf_9a9027ec.LocalExecProvisioner, _cdktf_9a9027ec.RemoteExecProvisioner]]]:
         '''
         :stability: experimental
         '''
         result = self._values.get("provisioners")
-        return typing.cast(typing.Optional[typing.List[typing.Union[cdktf.FileProvisioner, cdktf.LocalExecProvisioner, cdktf.RemoteExecProvisioner]]], result)
+        return typing.cast(typing.Optional[typing.List[typing.Union[_cdktf_9a9027ec.FileProvisioner, _cdktf_9a9027ec.LocalExecProvisioner, _cdktf_9a9027ec.RemoteExecProvisioner]]], result)
 
     @builtins.property
     def client_id(self) -> builtins.str:
@@ -530,11 +534,13 @@ class AzureAdlsGen2MountConfig(cdktf.TerraformMetaArguments):
         return typing.cast(builtins.str, result)
 
     @builtins.property
-    def initialize_file_system(self) -> typing.Union[builtins.bool, cdktf.IResolvable]:
+    def initialize_file_system(
+        self,
+    ) -> typing.Union[builtins.bool, _cdktf_9a9027ec.IResolvable]:
         '''Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/databricks/r/azure_adls_gen2_mount#initialize_file_system AzureAdlsGen2Mount#initialize_file_system}.'''
         result = self._values.get("initialize_file_system")
         assert result is not None, "Required property 'initialize_file_system' is missing"
-        return typing.cast(typing.Union[builtins.bool, cdktf.IResolvable], result)
+        return typing.cast(typing.Union[builtins.bool, _cdktf_9a9027ec.IResolvable], result)
 
     @builtins.property
     def mount_name(self) -> builtins.str:
@@ -597,3 +603,119 @@ __all__ = [
 ]
 
 publication.publish()
+
+def _typecheckingstub__5930b7e193b7f085588e840d9e30a84ffc7372e1ba964c043c9cdafd2376d1a7(
+    scope: _constructs_77d1e7e8.Construct,
+    id_: builtins.str,
+    *,
+    client_id: builtins.str,
+    client_secret_key: builtins.str,
+    client_secret_scope: builtins.str,
+    container_name: builtins.str,
+    initialize_file_system: typing.Union[builtins.bool, _cdktf_9a9027ec.IResolvable],
+    mount_name: builtins.str,
+    storage_account_name: builtins.str,
+    tenant_id: builtins.str,
+    cluster_id: typing.Optional[builtins.str] = None,
+    directory: typing.Optional[builtins.str] = None,
+    id: typing.Optional[builtins.str] = None,
+    connection: typing.Optional[typing.Union[typing.Union[_cdktf_9a9027ec.SSHProvisionerConnection, typing.Dict[builtins.str, typing.Any]], typing.Union[_cdktf_9a9027ec.WinrmProvisionerConnection, typing.Dict[builtins.str, typing.Any]]]] = None,
+    count: typing.Optional[jsii.Number] = None,
+    depends_on: typing.Optional[typing.Sequence[_cdktf_9a9027ec.ITerraformDependable]] = None,
+    for_each: typing.Optional[_cdktf_9a9027ec.ITerraformIterator] = None,
+    lifecycle: typing.Optional[typing.Union[_cdktf_9a9027ec.TerraformResourceLifecycle, typing.Dict[builtins.str, typing.Any]]] = None,
+    provider: typing.Optional[_cdktf_9a9027ec.TerraformProvider] = None,
+    provisioners: typing.Optional[typing.Sequence[typing.Union[typing.Union[_cdktf_9a9027ec.FileProvisioner, typing.Dict[builtins.str, typing.Any]], typing.Union[_cdktf_9a9027ec.LocalExecProvisioner, typing.Dict[builtins.str, typing.Any]], typing.Union[_cdktf_9a9027ec.RemoteExecProvisioner, typing.Dict[builtins.str, typing.Any]]]]] = None,
+) -> None:
+    """Type checking stubs"""
+    pass
+
+def _typecheckingstub__f7188dd9c92ade6c14152682d68357ef121a11d615743bb258b1ab47783a3722(
+    value: builtins.str,
+) -> None:
+    """Type checking stubs"""
+    pass
+
+def _typecheckingstub__9291828e1bba518fa0fe3638c58fbf7a1a1536d7760b8d42937fc34d8c2988f6(
+    value: builtins.str,
+) -> None:
+    """Type checking stubs"""
+    pass
+
+def _typecheckingstub__d9de83285a3695591d82af4a54ca5ee46b3df2855fa9a76a1a859066654a200d(
+    value: builtins.str,
+) -> None:
+    """Type checking stubs"""
+    pass
+
+def _typecheckingstub__dd814b3c61d999c3b97eeab42df56f2c71b9d7b7ba5387bd73c260c665b149a2(
+    value: builtins.str,
+) -> None:
+    """Type checking stubs"""
+    pass
+
+def _typecheckingstub__653f40f2bcd1cf43d1b1d2edf764bbd0b7a0a7c1ab54483ad2709e2bb06cbcac(
+    value: builtins.str,
+) -> None:
+    """Type checking stubs"""
+    pass
+
+def _typecheckingstub__d9118db818d94a01387dac5df0b93472acdf5bd6ab8dd13620e9c4f2e16b1bd4(
+    value: builtins.str,
+) -> None:
+    """Type checking stubs"""
+    pass
+
+def _typecheckingstub__82ea94dd06e21725e44b8a8457f774017e9defe86418f38a079a4d7e1ba1ed19(
+    value: builtins.str,
+) -> None:
+    """Type checking stubs"""
+    pass
+
+def _typecheckingstub__f0f2e66de1947413cf10ea5f51817ce5892c38c4a03b5c82138430f379a10439(
+    value: typing.Union[builtins.bool, _cdktf_9a9027ec.IResolvable],
+) -> None:
+    """Type checking stubs"""
+    pass
+
+def _typecheckingstub__d9112f9bbe27ff779d11cf8f8d2d033567aed5350020576aaafc5c56c5710750(
+    value: builtins.str,
+) -> None:
+    """Type checking stubs"""
+    pass
+
+def _typecheckingstub__5334f3e6a10247d8d2e6a3f85134df35a03a7571a286887939a2eca0ea4ad1da(
+    value: builtins.str,
+) -> None:
+    """Type checking stubs"""
+    pass
+
+def _typecheckingstub__26216601682b712f35889bc00cc4965fe56f7b95335c5fd454983ac8f2e6ce4b(
+    value: builtins.str,
+) -> None:
+    """Type checking stubs"""
+    pass
+
+def _typecheckingstub__6423d1c3da487275147899fe59f13710722aec3e5048f5d712c57e71f7449059(
+    *,
+    connection: typing.Optional[typing.Union[typing.Union[_cdktf_9a9027ec.SSHProvisionerConnection, typing.Dict[builtins.str, typing.Any]], typing.Union[_cdktf_9a9027ec.WinrmProvisionerConnection, typing.Dict[builtins.str, typing.Any]]]] = None,
+    count: typing.Optional[jsii.Number] = None,
+    depends_on: typing.Optional[typing.Sequence[_cdktf_9a9027ec.ITerraformDependable]] = None,
+    for_each: typing.Optional[_cdktf_9a9027ec.ITerraformIterator] = None,
+    lifecycle: typing.Optional[typing.Union[_cdktf_9a9027ec.TerraformResourceLifecycle, typing.Dict[builtins.str, typing.Any]]] = None,
+    provider: typing.Optional[_cdktf_9a9027ec.TerraformProvider] = None,
+    provisioners: typing.Optional[typing.Sequence[typing.Union[typing.Union[_cdktf_9a9027ec.FileProvisioner, typing.Dict[builtins.str, typing.Any]], typing.Union[_cdktf_9a9027ec.LocalExecProvisioner, typing.Dict[builtins.str, typing.Any]], typing.Union[_cdktf_9a9027ec.RemoteExecProvisioner, typing.Dict[builtins.str, typing.Any]]]]] = None,
+    client_id: builtins.str,
+    client_secret_key: builtins.str,
+    client_secret_scope: builtins.str,
+    container_name: builtins.str,
+    initialize_file_system: typing.Union[builtins.bool, _cdktf_9a9027ec.IResolvable],
+    mount_name: builtins.str,
+    storage_account_name: builtins.str,
+    tenant_id: builtins.str,
+    cluster_id: typing.Optional[builtins.str] = None,
+    directory: typing.Optional[builtins.str] = None,
+    id: typing.Optional[builtins.str] = None,
+) -> None:
+    """Type checking stubs"""
+    pass
