@@ -17,12 +17,12 @@ from typeguard import check_type
 
 from .._jsii import *
 
-import cdktf
-import constructs
+import cdktf as _cdktf_9a9027ec
+import constructs as _constructs_77d1e7e8
 
 
 class Catalog(
-    cdktf.TerraformResource,
+    _cdktf_9a9027ec.TerraformResource,
     metaclass=jsii.JSIIMeta,
     jsii_type="@cdktf/provider-databricks.catalog.Catalog",
 ):
@@ -30,23 +30,26 @@ class Catalog(
 
     def __init__(
         self,
-        scope: constructs.Construct,
+        scope: _constructs_77d1e7e8.Construct,
         id_: builtins.str,
         *,
         name: builtins.str,
         comment: typing.Optional[builtins.str] = None,
-        force_destroy: typing.Optional[typing.Union[builtins.bool, cdktf.IResolvable]] = None,
+        force_destroy: typing.Optional[typing.Union[builtins.bool, _cdktf_9a9027ec.IResolvable]] = None,
         id: typing.Optional[builtins.str] = None,
         metastore_id: typing.Optional[builtins.str] = None,
         owner: typing.Optional[builtins.str] = None,
         properties: typing.Optional[typing.Mapping[builtins.str, builtins.str]] = None,
-        connection: typing.Optional[typing.Union[typing.Union[cdktf.SSHProvisionerConnection, typing.Dict[str, typing.Any]], typing.Union[cdktf.WinrmProvisionerConnection, typing.Dict[str, typing.Any]]]] = None,
+        provider_name: typing.Optional[builtins.str] = None,
+        share_name: typing.Optional[builtins.str] = None,
+        storage_root: typing.Optional[builtins.str] = None,
+        connection: typing.Optional[typing.Union[typing.Union[_cdktf_9a9027ec.SSHProvisionerConnection, typing.Dict[builtins.str, typing.Any]], typing.Union[_cdktf_9a9027ec.WinrmProvisionerConnection, typing.Dict[builtins.str, typing.Any]]]] = None,
         count: typing.Optional[jsii.Number] = None,
-        depends_on: typing.Optional[typing.Sequence[cdktf.ITerraformDependable]] = None,
-        for_each: typing.Optional[cdktf.ITerraformIterator] = None,
-        lifecycle: typing.Optional[typing.Union[cdktf.TerraformResourceLifecycle, typing.Dict[str, typing.Any]]] = None,
-        provider: typing.Optional[cdktf.TerraformProvider] = None,
-        provisioners: typing.Optional[typing.Sequence[typing.Union[typing.Union[cdktf.FileProvisioner, typing.Dict[str, typing.Any]], typing.Union[cdktf.LocalExecProvisioner, typing.Dict[str, typing.Any]], typing.Union[cdktf.RemoteExecProvisioner, typing.Dict[str, typing.Any]]]]] = None,
+        depends_on: typing.Optional[typing.Sequence[_cdktf_9a9027ec.ITerraformDependable]] = None,
+        for_each: typing.Optional[_cdktf_9a9027ec.ITerraformIterator] = None,
+        lifecycle: typing.Optional[typing.Union[_cdktf_9a9027ec.TerraformResourceLifecycle, typing.Dict[builtins.str, typing.Any]]] = None,
+        provider: typing.Optional[_cdktf_9a9027ec.TerraformProvider] = None,
+        provisioners: typing.Optional[typing.Sequence[typing.Union[typing.Union[_cdktf_9a9027ec.FileProvisioner, typing.Dict[builtins.str, typing.Any]], typing.Union[_cdktf_9a9027ec.LocalExecProvisioner, typing.Dict[builtins.str, typing.Any]], typing.Union[_cdktf_9a9027ec.RemoteExecProvisioner, typing.Dict[builtins.str, typing.Any]]]]] = None,
     ) -> None:
         '''Create a new {@link https://www.terraform.io/docs/providers/databricks/r/catalog databricks_catalog} Resource.
 
@@ -59,6 +62,9 @@ class Catalog(
         :param metastore_id: Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/databricks/r/catalog#metastore_id Catalog#metastore_id}.
         :param owner: Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/databricks/r/catalog#owner Catalog#owner}.
         :param properties: Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/databricks/r/catalog#properties Catalog#properties}.
+        :param provider_name: Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/databricks/r/catalog#provider_name Catalog#provider_name}.
+        :param share_name: Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/databricks/r/catalog#share_name Catalog#share_name}.
+        :param storage_root: Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/databricks/r/catalog#storage_root Catalog#storage_root}.
         :param connection: 
         :param count: 
         :param depends_on: 
@@ -68,7 +74,7 @@ class Catalog(
         :param provisioners: 
         '''
         if __debug__:
-            type_hints = typing.get_type_hints(Catalog.__init__)
+            type_hints = typing.get_type_hints(_typecheckingstub__bec76dad9b6660a555a5c1c5cf4b775e9867abaf432627a2b13467bb30de533d)
             check_type(argname="argument scope", value=scope, expected_type=type_hints["scope"])
             check_type(argname="argument id_", value=id_, expected_type=type_hints["id_"])
         config = CatalogConfig(
@@ -79,6 +85,9 @@ class Catalog(
             metastore_id=metastore_id,
             owner=owner,
             properties=properties,
+            provider_name=provider_name,
+            share_name=share_name,
+            storage_root=storage_root,
             connection=connection,
             count=count,
             depends_on=depends_on,
@@ -114,6 +123,18 @@ class Catalog(
     def reset_properties(self) -> None:
         return typing.cast(None, jsii.invoke(self, "resetProperties", []))
 
+    @jsii.member(jsii_name="resetProviderName")
+    def reset_provider_name(self) -> None:
+        return typing.cast(None, jsii.invoke(self, "resetProviderName", []))
+
+    @jsii.member(jsii_name="resetShareName")
+    def reset_share_name(self) -> None:
+        return typing.cast(None, jsii.invoke(self, "resetShareName", []))
+
+    @jsii.member(jsii_name="resetStorageRoot")
+    def reset_storage_root(self) -> None:
+        return typing.cast(None, jsii.invoke(self, "resetStorageRoot", []))
+
     @jsii.member(jsii_name="synthesizeAttributes")
     def _synthesize_attributes(self) -> typing.Mapping[builtins.str, typing.Any]:
         return typing.cast(typing.Mapping[builtins.str, typing.Any], jsii.invoke(self, "synthesizeAttributes", []))
@@ -132,8 +153,8 @@ class Catalog(
     @jsii.member(jsii_name="forceDestroyInput")
     def force_destroy_input(
         self,
-    ) -> typing.Optional[typing.Union[builtins.bool, cdktf.IResolvable]]:
-        return typing.cast(typing.Optional[typing.Union[builtins.bool, cdktf.IResolvable]], jsii.get(self, "forceDestroyInput"))
+    ) -> typing.Optional[typing.Union[builtins.bool, _cdktf_9a9027ec.IResolvable]]:
+        return typing.cast(typing.Optional[typing.Union[builtins.bool, _cdktf_9a9027ec.IResolvable]], jsii.get(self, "forceDestroyInput"))
 
     @builtins.property
     @jsii.member(jsii_name="idInput")
@@ -162,6 +183,21 @@ class Catalog(
     ) -> typing.Optional[typing.Mapping[builtins.str, builtins.str]]:
         return typing.cast(typing.Optional[typing.Mapping[builtins.str, builtins.str]], jsii.get(self, "propertiesInput"))
 
+    @builtins.property
+    @jsii.member(jsii_name="providerNameInput")
+    def provider_name_input(self) -> typing.Optional[builtins.str]:
+        return typing.cast(typing.Optional[builtins.str], jsii.get(self, "providerNameInput"))
+
+    @builtins.property
+    @jsii.member(jsii_name="shareNameInput")
+    def share_name_input(self) -> typing.Optional[builtins.str]:
+        return typing.cast(typing.Optional[builtins.str], jsii.get(self, "shareNameInput"))
+
+    @builtins.property
+    @jsii.member(jsii_name="storageRootInput")
+    def storage_root_input(self) -> typing.Optional[builtins.str]:
+        return typing.cast(typing.Optional[builtins.str], jsii.get(self, "storageRootInput"))
+
     @builtins.property
     @jsii.member(jsii_name="comment")
     def comment(self) -> builtins.str:
@@ -170,22 +206,22 @@ class Catalog(
     @comment.setter
     def comment(self, value: builtins.str) -> None:
         if __debug__:
-            type_hints = typing.get_type_hints(getattr(Catalog, "comment").fset)
+            type_hints = typing.get_type_hints(_typecheckingstub__5f0635fc0db5677d73e90054ab1f59eef2df49eebdaf3bd4e0b0aba354125868)
             check_type(argname="argument value", value=value, expected_type=type_hints["value"])
         jsii.set(self, "comment", value)
 
     @builtins.property
     @jsii.member(jsii_name="forceDestroy")
-    def force_destroy(self) -> typing.Union[builtins.bool, cdktf.IResolvable]:
-        return typing.cast(typing.Union[builtins.bool, cdktf.IResolvable], jsii.get(self, "forceDestroy"))
+    def force_destroy(self) -> typing.Union[builtins.bool, _cdktf_9a9027ec.IResolvable]:
+        return typing.cast(typing.Union[builtins.bool, _cdktf_9a9027ec.IResolvable], jsii.get(self, "forceDestroy"))
 
     @force_destroy.setter
     def force_destroy(
         self,
-        value: typing.Union[builtins.bool, cdktf.IResolvable],
+        value: typing.Union[builtins.bool, _cdktf_9a9027ec.IResolvable],
     ) -> None:
         if __debug__:
-            type_hints = typing.get_type_hints(getattr(Catalog, "force_destroy").fset)
+            type_hints = typing.get_type_hints(_typecheckingstub__c812ceaa2f0ccf7affe5b9b0969732725444cbff657b67d3204e8a4075fe532b)
             check_type(argname="argument value", value=value, expected_type=type_hints["value"])
         jsii.set(self, "forceDestroy", value)
 
@@ -197,7 +233,7 @@ class Catalog(
     @id.setter
     def id(self, value: builtins.str) -> None:
         if __debug__:
-            type_hints = typing.get_type_hints(getattr(Catalog, "id").fset)
+            type_hints = typing.get_type_hints(_typecheckingstub__b5c97a945de54aafa18314b21c9a0972ee0ce663ef159ba33e3d43a43d287576)
             check_type(argname="argument value", value=value, expected_type=type_hints["value"])
         jsii.set(self, "id", value)
 
@@ -209,7 +245,7 @@ class Catalog(
     @metastore_id.setter
     def metastore_id(self, value: builtins.str) -> None:
         if __debug__:
-            type_hints = typing.get_type_hints(getattr(Catalog, "metastore_id").fset)
+            type_hints = typing.get_type_hints(_typecheckingstub__c397fe0dc0c9dddb4af31dd051b3d2a68889e12a0a1da28b33652e7b19e535aa)
             check_type(argname="argument value", value=value, expected_type=type_hints["value"])
         jsii.set(self, "metastoreId", value)
 
@@ -221,7 +257,7 @@ class Catalog(
     @name.setter
     def name(self, value: builtins.str) -> None:
         if __debug__:
-            type_hints = typing.get_type_hints(getattr(Catalog, "name").fset)
+            type_hints = typing.get_type_hints(_typecheckingstub__1faf6e3867769e014c3150b118e19dc42cf80bce7cebb2e6893c1a5e6f967cec)
             check_type(argname="argument value", value=value, expected_type=type_hints["value"])
         jsii.set(self, "name", value)
 
@@ -233,7 +269,7 @@ class Catalog(
     @owner.setter
     def owner(self, value: builtins.str) -> None:
         if __debug__:
-            type_hints = typing.get_type_hints(getattr(Catalog, "owner").fset)
+            type_hints = typing.get_type_hints(_typecheckingstub__922e3d93baa5faa53623ffe8f4991290d806d1a3ff0afd5fb00ffaabba9188de)
             check_type(argname="argument value", value=value, expected_type=type_hints["value"])
         jsii.set(self, "owner", value)
 
@@ -245,14 +281,50 @@ class Catalog(
     @properties.setter
     def properties(self, value: typing.Mapping[builtins.str, builtins.str]) -> None:
         if __debug__:
-            type_hints = typing.get_type_hints(getattr(Catalog, "properties").fset)
+            type_hints = typing.get_type_hints(_typecheckingstub__e4b5b3976629ea39c8a45c63e1017a49b9241380a9bd290d27a51353a2811e91)
             check_type(argname="argument value", value=value, expected_type=type_hints["value"])
         jsii.set(self, "properties", value)
 
+    @builtins.property
+    @jsii.member(jsii_name="providerName")
+    def provider_name(self) -> builtins.str:
+        return typing.cast(builtins.str, jsii.get(self, "providerName"))
+
+    @provider_name.setter
+    def provider_name(self, value: builtins.str) -> None:
+        if __debug__:
+            type_hints = typing.get_type_hints(_typecheckingstub__fddcc7e2c4c264bcca513fff8c9beed481487cf6fddcabcd7692461dfb23f9bd)
+            check_type(argname="argument value", value=value, expected_type=type_hints["value"])
+        jsii.set(self, "providerName", value)
+
+    @builtins.property
+    @jsii.member(jsii_name="shareName")
+    def share_name(self) -> builtins.str:
+        return typing.cast(builtins.str, jsii.get(self, "shareName"))
+
+    @share_name.setter
+    def share_name(self, value: builtins.str) -> None:
+        if __debug__:
+            type_hints = typing.get_type_hints(_typecheckingstub__1ae37df227a4c5710cfaa8a845fd31ebbdc031d8f7bb86419dfc6328bad9a2e3)
+            check_type(argname="argument value", value=value, expected_type=type_hints["value"])
+        jsii.set(self, "shareName", value)
+
+    @builtins.property
+    @jsii.member(jsii_name="storageRoot")
+    def storage_root(self) -> builtins.str:
+        return typing.cast(builtins.str, jsii.get(self, "storageRoot"))
+
+    @storage_root.setter
+    def storage_root(self, value: builtins.str) -> None:
+        if __debug__:
+            type_hints = typing.get_type_hints(_typecheckingstub__7116d3d0dee3ead4f09d5f679b08f9df5f34b3b8bbfb0eb584b0d8f3a170d381)
+            check_type(argname="argument value", value=value, expected_type=type_hints["value"])
+        jsii.set(self, "storageRoot", value)
+
 
 @jsii.data_type(
     jsii_type="@cdktf/provider-databricks.catalog.CatalogConfig",
-    jsii_struct_bases=[cdktf.TerraformMetaArguments],
+    jsii_struct_bases=[_cdktf_9a9027ec.TerraformMetaArguments],
     name_mapping={
         "connection": "connection",
         "count": "count",
@@ -268,26 +340,32 @@ class Catalog(
         "metastore_id": "metastoreId",
         "owner": "owner",
         "properties": "properties",
+        "provider_name": "providerName",
+        "share_name": "shareName",
+        "storage_root": "storageRoot",
     },
 )
-class CatalogConfig(cdktf.TerraformMetaArguments):
+class CatalogConfig(_cdktf_9a9027ec.TerraformMetaArguments):
     def __init__(
         self,
         *,
-        connection: typing.Optional[typing.Union[typing.Union[cdktf.SSHProvisionerConnection, typing.Dict[str, typing.Any]], typing.Union[cdktf.WinrmProvisionerConnection, typing.Dict[str, typing.Any]]]] = None,
+        connection: typing.Optional[typing.Union[typing.Union[_cdktf_9a9027ec.SSHProvisionerConnection, typing.Dict[builtins.str, typing.Any]], typing.Union[_cdktf_9a9027ec.WinrmProvisionerConnection, typing.Dict[builtins.str, typing.Any]]]] = None,
         count: typing.Optional[jsii.Number] = None,
-        depends_on: typing.Optional[typing.Sequence[cdktf.ITerraformDependable]] = None,
-        for_each: typing.Optional[cdktf.ITerraformIterator] = None,
-        lifecycle: typing.Optional[typing.Union[cdktf.TerraformResourceLifecycle, typing.Dict[str, typing.Any]]] = None,
-        provider: typing.Optional[cdktf.TerraformProvider] = None,
-        provisioners: typing.Optional[typing.Sequence[typing.Union[typing.Union[cdktf.FileProvisioner, typing.Dict[str, typing.Any]], typing.Union[cdktf.LocalExecProvisioner, typing.Dict[str, typing.Any]], typing.Union[cdktf.RemoteExecProvisioner, typing.Dict[str, typing.Any]]]]] = None,
+        depends_on: typing.Optional[typing.Sequence[_cdktf_9a9027ec.ITerraformDependable]] = None,
+        for_each: typing.Optional[_cdktf_9a9027ec.ITerraformIterator] = None,
+        lifecycle: typing.Optional[typing.Union[_cdktf_9a9027ec.TerraformResourceLifecycle, typing.Dict[builtins.str, typing.Any]]] = None,
+        provider: typing.Optional[_cdktf_9a9027ec.TerraformProvider] = None,
+        provisioners: typing.Optional[typing.Sequence[typing.Union[typing.Union[_cdktf_9a9027ec.FileProvisioner, typing.Dict[builtins.str, typing.Any]], typing.Union[_cdktf_9a9027ec.LocalExecProvisioner, typing.Dict[builtins.str, typing.Any]], typing.Union[_cdktf_9a9027ec.RemoteExecProvisioner, typing.Dict[builtins.str, typing.Any]]]]] = None,
         name: builtins.str,
         comment: typing.Optional[builtins.str] = None,
-        force_destroy: typing.Optional[typing.Union[builtins.bool, cdktf.IResolvable]] = None,
+        force_destroy: typing.Optional[typing.Union[builtins.bool, _cdktf_9a9027ec.IResolvable]] = None,
         id: typing.Optional[builtins.str] = None,
         metastore_id: typing.Optional[builtins.str] = None,
         owner: typing.Optional[builtins.str] = None,
         properties: typing.Optional[typing.Mapping[builtins.str, builtins.str]] = None,
+        provider_name: typing.Optional[builtins.str] = None,
+        share_name: typing.Optional[builtins.str] = None,
+        storage_root: typing.Optional[builtins.str] = None,
     ) -> None:
         '''
         :param connection: 
@@ -304,11 +382,14 @@ class CatalogConfig(cdktf.TerraformMetaArguments):
         :param metastore_id: Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/databricks/r/catalog#metastore_id Catalog#metastore_id}.
         :param owner: Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/databricks/r/catalog#owner Catalog#owner}.
         :param properties: Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/databricks/r/catalog#properties Catalog#properties}.
+        :param provider_name: Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/databricks/r/catalog#provider_name Catalog#provider_name}.
+        :param share_name: Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/databricks/r/catalog#share_name Catalog#share_name}.
+        :param storage_root: Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/databricks/r/catalog#storage_root Catalog#storage_root}.
         '''
         if isinstance(lifecycle, dict):
-            lifecycle = cdktf.TerraformResourceLifecycle(**lifecycle)
+            lifecycle = _cdktf_9a9027ec.TerraformResourceLifecycle(**lifecycle)
         if __debug__:
-            type_hints = typing.get_type_hints(CatalogConfig.__init__)
+            type_hints = typing.get_type_hints(_typecheckingstub__fb70163508455f7297c22f7e9811d7ac44f916e2df8ee1ea8b58a4ea7acaefb8)
             check_type(argname="argument connection", value=connection, expected_type=type_hints["connection"])
             check_type(argname="argument count", value=count, expected_type=type_hints["count"])
             check_type(argname="argument depends_on", value=depends_on, expected_type=type_hints["depends_on"])
@@ -323,7 +404,10 @@ class CatalogConfig(cdktf.TerraformMetaArguments):
             check_type(argname="argument metastore_id", value=metastore_id, expected_type=type_hints["metastore_id"])
             check_type(argname="argument owner", value=owner, expected_type=type_hints["owner"])
             check_type(argname="argument properties", value=properties, expected_type=type_hints["properties"])
-        self._values: typing.Dict[str, typing.Any] = {
+            check_type(argname="argument provider_name", value=provider_name, expected_type=type_hints["provider_name"])
+            check_type(argname="argument share_name", value=share_name, expected_type=type_hints["share_name"])
+            check_type(argname="argument storage_root", value=storage_root, expected_type=type_hints["storage_root"])
+        self._values: typing.Dict[builtins.str, typing.Any] = {
             "name": name,
         }
         if connection is not None:
@@ -352,16 +436,22 @@ class CatalogConfig(cdktf.TerraformMetaArguments):
             self._values["owner"] = owner
         if properties is not None:
             self._values["properties"] = properties
+        if provider_name is not None:
+            self._values["provider_name"] = provider_name
+        if share_name is not None:
+            self._values["share_name"] = share_name
+        if storage_root is not None:
+            self._values["storage_root"] = storage_root
 
     @builtins.property
     def connection(
         self,
-    ) -> typing.Optional[typing.Union[cdktf.SSHProvisionerConnection, cdktf.WinrmProvisionerConnection]]:
+    ) -> typing.Optional[typing.Union[_cdktf_9a9027ec.SSHProvisionerConnection, _cdktf_9a9027ec.WinrmProvisionerConnection]]:
         '''
         :stability: experimental
         '''
         result = self._values.get("connection")
-        return typing.cast(typing.Optional[typing.Union[cdktf.SSHProvisionerConnection, cdktf.WinrmProvisionerConnection]], result)
+        return typing.cast(typing.Optional[typing.Union[_cdktf_9a9027ec.SSHProvisionerConnection, _cdktf_9a9027ec.WinrmProvisionerConnection]], result)
 
     @builtins.property
     def count(self) -> typing.Optional[jsii.Number]:
@@ -372,46 +462,48 @@ class CatalogConfig(cdktf.TerraformMetaArguments):
         return typing.cast(typing.Optional[jsii.Number], result)
 
     @builtins.property
-    def depends_on(self) -> typing.Optional[typing.List[cdktf.ITerraformDependable]]:
+    def depends_on(
+        self,
+    ) -> typing.Optional[typing.List[_cdktf_9a9027ec.ITerraformDependable]]:
         '''
         :stability: experimental
         '''
         result = self._values.get("depends_on")
-        return typing.cast(typing.Optional[typing.List[cdktf.ITerraformDependable]], result)
+        return typing.cast(typing.Optional[typing.List[_cdktf_9a9027ec.ITerraformDependable]], result)
 
     @builtins.property
-    def for_each(self) -> typing.Optional[cdktf.ITerraformIterator]:
+    def for_each(self) -> typing.Optional[_cdktf_9a9027ec.ITerraformIterator]:
         '''
         :stability: experimental
         '''
         result = self._values.get("for_each")
-        return typing.cast(typing.Optional[cdktf.ITerraformIterator], result)
+        return typing.cast(typing.Optional[_cdktf_9a9027ec.ITerraformIterator], result)
 
     @builtins.property
-    def lifecycle(self) -> typing.Optional[cdktf.TerraformResourceLifecycle]:
+    def lifecycle(self) -> typing.Optional[_cdktf_9a9027ec.TerraformResourceLifecycle]:
         '''
         :stability: experimental
         '''
         result = self._values.get("lifecycle")
-        return typing.cast(typing.Optional[cdktf.TerraformResourceLifecycle], result)
+        return typing.cast(typing.Optional[_cdktf_9a9027ec.TerraformResourceLifecycle], result)
 
     @builtins.property
-    def provider(self) -> typing.Optional[cdktf.TerraformProvider]:
+    def provider(self) -> typing.Optional[_cdktf_9a9027ec.TerraformProvider]:
         '''
         :stability: experimental
         '''
         result = self._values.get("provider")
-        return typing.cast(typing.Optional[cdktf.TerraformProvider], result)
+        return typing.cast(typing.Optional[_cdktf_9a9027ec.TerraformProvider], result)
 
     @builtins.property
     def provisioners(
         self,
-    ) -> typing.Optional[typing.List[typing.Union[cdktf.FileProvisioner, cdktf.LocalExecProvisioner, cdktf.RemoteExecProvisioner]]]:
+    ) -> typing.Optional[typing.List[typing.Union[_cdktf_9a9027ec.FileProvisioner, _cdktf_9a9027ec.LocalExecProvisioner, _cdktf_9a9027ec.RemoteExecProvisioner]]]:
         '''
         :stability: experimental
         '''
         result = self._values.get("provisioners")
-        return typing.cast(typing.Optional[typing.List[typing.Union[cdktf.FileProvisioner, cdktf.LocalExecProvisioner, cdktf.RemoteExecProvisioner]]], result)
+        return typing.cast(typing.Optional[typing.List[typing.Union[_cdktf_9a9027ec.FileProvisioner, _cdktf_9a9027ec.LocalExecProvisioner, _cdktf_9a9027ec.RemoteExecProvisioner]]], result)
 
     @builtins.property
     def name(self) -> builtins.str:
@@ -429,10 +521,10 @@ class CatalogConfig(cdktf.TerraformMetaArguments):
     @builtins.property
     def force_destroy(
         self,
-    ) -> typing.Optional[typing.Union[builtins.bool, cdktf.IResolvable]]:
+    ) -> typing.Optional[typing.Union[builtins.bool, _cdktf_9a9027ec.IResolvable]]:
         '''Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/databricks/r/catalog#force_destroy Catalog#force_destroy}.'''
         result = self._values.get("force_destroy")
-        return typing.cast(typing.Optional[typing.Union[builtins.bool, cdktf.IResolvable]], result)
+        return typing.cast(typing.Optional[typing.Union[builtins.bool, _cdktf_9a9027ec.IResolvable]], result)
 
     @builtins.property
     def id(self) -> typing.Optional[builtins.str]:
@@ -462,6 +554,24 @@ class CatalogConfig(cdktf.TerraformMetaArguments):
         result = self._values.get("properties")
         return typing.cast(typing.Optional[typing.Mapping[builtins.str, builtins.str]], result)
 
+    @builtins.property
+    def provider_name(self) -> typing.Optional[builtins.str]:
+        '''Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/databricks/r/catalog#provider_name Catalog#provider_name}.'''
+        result = self._values.get("provider_name")
+        return typing.cast(typing.Optional[builtins.str], result)
+
+    @builtins.property
+    def share_name(self) -> typing.Optional[builtins.str]:
+        '''Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/databricks/r/catalog#share_name Catalog#share_name}.'''
+        result = self._values.get("share_name")
+        return typing.cast(typing.Optional[builtins.str], result)
+
+    @builtins.property
+    def storage_root(self) -> typing.Optional[builtins.str]:
+        '''Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/databricks/r/catalog#storage_root Catalog#storage_root}.'''
+        result = self._values.get("storage_root")
+        return typing.cast(typing.Optional[builtins.str], result)
+
     def __eq__(self, rhs: typing.Any) -> builtins.bool:
         return isinstance(rhs, self.__class__) and rhs._values == self._values
 
@@ -480,3 +590,111 @@ __all__ = [
 ]
 
 publication.publish()
+
+def _typecheckingstub__bec76dad9b6660a555a5c1c5cf4b775e9867abaf432627a2b13467bb30de533d(
+    scope: _constructs_77d1e7e8.Construct,
+    id_: builtins.str,
+    *,
+    name: builtins.str,
+    comment: typing.Optional[builtins.str] = None,
+    force_destroy: typing.Optional[typing.Union[builtins.bool, _cdktf_9a9027ec.IResolvable]] = None,
+    id: typing.Optional[builtins.str] = None,
+    metastore_id: typing.Optional[builtins.str] = None,
+    owner: typing.Optional[builtins.str] = None,
+    properties: typing.Optional[typing.Mapping[builtins.str, builtins.str]] = None,
+    provider_name: typing.Optional[builtins.str] = None,
+    share_name: typing.Optional[builtins.str] = None,
+    storage_root: typing.Optional[builtins.str] = None,
+    connection: typing.Optional[typing.Union[typing.Union[_cdktf_9a9027ec.SSHProvisionerConnection, typing.Dict[builtins.str, typing.Any]], typing.Union[_cdktf_9a9027ec.WinrmProvisionerConnection, typing.Dict[builtins.str, typing.Any]]]] = None,
+    count: typing.Optional[jsii.Number] = None,
+    depends_on: typing.Optional[typing.Sequence[_cdktf_9a9027ec.ITerraformDependable]] = None,
+    for_each: typing.Optional[_cdktf_9a9027ec.ITerraformIterator] = None,
+    lifecycle: typing.Optional[typing.Union[_cdktf_9a9027ec.TerraformResourceLifecycle, typing.Dict[builtins.str, typing.Any]]] = None,
+    provider: typing.Optional[_cdktf_9a9027ec.TerraformProvider] = None,
+    provisioners: typing.Optional[typing.Sequence[typing.Union[typing.Union[_cdktf_9a9027ec.FileProvisioner, typing.Dict[builtins.str, typing.Any]], typing.Union[_cdktf_9a9027ec.LocalExecProvisioner, typing.Dict[builtins.str, typing.Any]], typing.Union[_cdktf_9a9027ec.RemoteExecProvisioner, typing.Dict[builtins.str, typing.Any]]]]] = None,
+) -> None:
+    """Type checking stubs"""
+    pass
+
+def _typecheckingstub__5f0635fc0db5677d73e90054ab1f59eef2df49eebdaf3bd4e0b0aba354125868(
+    value: builtins.str,
+) -> None:
+    """Type checking stubs"""
+    pass
+
+def _typecheckingstub__c812ceaa2f0ccf7affe5b9b0969732725444cbff657b67d3204e8a4075fe532b(
+    value: typing.Union[builtins.bool, _cdktf_9a9027ec.IResolvable],
+) -> None:
+    """Type checking stubs"""
+    pass
+
+def _typecheckingstub__b5c97a945de54aafa18314b21c9a0972ee0ce663ef159ba33e3d43a43d287576(
+    value: builtins.str,
+) -> None:
+    """Type checking stubs"""
+    pass
+
+def _typecheckingstub__c397fe0dc0c9dddb4af31dd051b3d2a68889e12a0a1da28b33652e7b19e535aa(
+    value: builtins.str,
+) -> None:
+    """Type checking stubs"""
+    pass
+
+def _typecheckingstub__1faf6e3867769e014c3150b118e19dc42cf80bce7cebb2e6893c1a5e6f967cec(
+    value: builtins.str,
+) -> None:
+    """Type checking stubs"""
+    pass
+
+def _typecheckingstub__922e3d93baa5faa53623ffe8f4991290d806d1a3ff0afd5fb00ffaabba9188de(
+    value: builtins.str,
+) -> None:
+    """Type checking stubs"""
+    pass
+
+def _typecheckingstub__e4b5b3976629ea39c8a45c63e1017a49b9241380a9bd290d27a51353a2811e91(
+    value: typing.Mapping[builtins.str, builtins.str],
+) -> None:
+    """Type checking stubs"""
+    pass
+
+def _typecheckingstub__fddcc7e2c4c264bcca513fff8c9beed481487cf6fddcabcd7692461dfb23f9bd(
+    value: builtins.str,
+) -> None:
+    """Type checking stubs"""
+    pass
+
+def _typecheckingstub__1ae37df227a4c5710cfaa8a845fd31ebbdc031d8f7bb86419dfc6328bad9a2e3(
+    value: builtins.str,
+) -> None:
+    """Type checking stubs"""
+    pass
+
+def _typecheckingstub__7116d3d0dee3ead4f09d5f679b08f9df5f34b3b8bbfb0eb584b0d8f3a170d381(
+    value: builtins.str,
+) -> None:
+    """Type checking stubs"""
+    pass
+
+def _typecheckingstub__fb70163508455f7297c22f7e9811d7ac44f916e2df8ee1ea8b58a4ea7acaefb8(
+    *,
+    connection: typing.Optional[typing.Union[typing.Union[_cdktf_9a9027ec.SSHProvisionerConnection, typing.Dict[builtins.str, typing.Any]], typing.Union[_cdktf_9a9027ec.WinrmProvisionerConnection, typing.Dict[builtins.str, typing.Any]]]] = None,
+    count: typing.Optional[jsii.Number] = None,
+    depends_on: typing.Optional[typing.Sequence[_cdktf_9a9027ec.ITerraformDependable]] = None,
+    for_each: typing.Optional[_cdktf_9a9027ec.ITerraformIterator] = None,
+    lifecycle: typing.Optional[typing.Union[_cdktf_9a9027ec.TerraformResourceLifecycle, typing.Dict[builtins.str, typing.Any]]] = None,
+    provider: typing.Optional[_cdktf_9a9027ec.TerraformProvider] = None,
+    provisioners: typing.Optional[typing.Sequence[typing.Union[typing.Union[_cdktf_9a9027ec.FileProvisioner, typing.Dict[builtins.str, typing.Any]], typing.Union[_cdktf_9a9027ec.LocalExecProvisioner, typing.Dict[builtins.str, typing.Any]], typing.Union[_cdktf_9a9027ec.RemoteExecProvisioner, typing.Dict[builtins.str, typing.Any]]]]] = None,
+    name: builtins.str,
+    comment: typing.Optional[builtins.str] = None,
+    force_destroy: typing.Optional[typing.Union[builtins.bool, _cdktf_9a9027ec.IResolvable]] = None,
+    id: typing.Optional[builtins.str] = None,
+    metastore_id: typing.Optional[builtins.str] = None,
+    owner: typing.Optional[builtins.str] = None,
+    properties: typing.Optional[typing.Mapping[builtins.str, builtins.str]] = None,
+    provider_name: typing.Optional[builtins.str] = None,
+    share_name: typing.Optional[builtins.str] = None,
+    storage_root: typing.Optional[builtins.str] = None,
+) -> None:
+    """Type checking stubs"""
+    pass
