@@ -17,12 +17,12 @@ from typeguard import check_type
 
 from .._jsii import *
 
-import cdktf
-import constructs
+import cdktf as _cdktf_9a9027ec
+import constructs as _constructs_77d1e7e8
 
 
 class DataDatabricksAwsBucketPolicy(
-    cdktf.TerraformDataSource,
+    _cdktf_9a9027ec.TerraformDataSource,
     metaclass=jsii.JSIIMeta,
     jsii_type="@cdktf/provider-databricks.dataDatabricksAwsBucketPolicy.DataDatabricksAwsBucketPolicy",
 ):
@@ -30,20 +30,21 @@ class DataDatabricksAwsBucketPolicy(
 
     def __init__(
         self,
-        scope: constructs.Construct,
+        scope: _constructs_77d1e7e8.Construct,
         id_: builtins.str,
         *,
         bucket: builtins.str,
         databricks_account_id: typing.Optional[builtins.str] = None,
+        databricks_e2_account_id: typing.Optional[builtins.str] = None,
         full_access_role: typing.Optional[builtins.str] = None,
         id: typing.Optional[builtins.str] = None,
-        connection: typing.Optional[typing.Union[typing.Union[cdktf.SSHProvisionerConnection, typing.Dict[str, typing.Any]], typing.Union[cdktf.WinrmProvisionerConnection, typing.Dict[str, typing.Any]]]] = None,
+        connection: typing.Optional[typing.Union[typing.Union[_cdktf_9a9027ec.SSHProvisionerConnection, typing.Dict[builtins.str, typing.Any]], typing.Union[_cdktf_9a9027ec.WinrmProvisionerConnection, typing.Dict[builtins.str, typing.Any]]]] = None,
         count: typing.Optional[jsii.Number] = None,
-        depends_on: typing.Optional[typing.Sequence[cdktf.ITerraformDependable]] = None,
-        for_each: typing.Optional[cdktf.ITerraformIterator] = None,
-        lifecycle: typing.Optional[typing.Union[cdktf.TerraformResourceLifecycle, typing.Dict[str, typing.Any]]] = None,
-        provider: typing.Optional[cdktf.TerraformProvider] = None,
-        provisioners: typing.Optional[typing.Sequence[typing.Union[typing.Union[cdktf.FileProvisioner, typing.Dict[str, typing.Any]], typing.Union[cdktf.LocalExecProvisioner, typing.Dict[str, typing.Any]], typing.Union[cdktf.RemoteExecProvisioner, typing.Dict[str, typing.Any]]]]] = None,
+        depends_on: typing.Optional[typing.Sequence[_cdktf_9a9027ec.ITerraformDependable]] = None,
+        for_each: typing.Optional[_cdktf_9a9027ec.ITerraformIterator] = None,
+        lifecycle: typing.Optional[typing.Union[_cdktf_9a9027ec.TerraformResourceLifecycle, typing.Dict[builtins.str, typing.Any]]] = None,
+        provider: typing.Optional[_cdktf_9a9027ec.TerraformProvider] = None,
+        provisioners: typing.Optional[typing.Sequence[typing.Union[typing.Union[_cdktf_9a9027ec.FileProvisioner, typing.Dict[builtins.str, typing.Any]], typing.Union[_cdktf_9a9027ec.LocalExecProvisioner, typing.Dict[builtins.str, typing.Any]], typing.Union[_cdktf_9a9027ec.RemoteExecProvisioner, typing.Dict[builtins.str, typing.Any]]]]] = None,
     ) -> None:
         '''Create a new {@link https://www.terraform.io/docs/providers/databricks/d/aws_bucket_policy databricks_aws_bucket_policy} Data Source.
 
@@ -51,6 +52,7 @@ class DataDatabricksAwsBucketPolicy(
         :param id_: The scoped construct ID. Must be unique amongst siblings in the same scope
         :param bucket: Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/databricks/d/aws_bucket_policy#bucket DataDatabricksAwsBucketPolicy#bucket}.
         :param databricks_account_id: Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/databricks/d/aws_bucket_policy#databricks_account_id DataDatabricksAwsBucketPolicy#databricks_account_id}.
+        :param databricks_e2_account_id: Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/databricks/d/aws_bucket_policy#databricks_e2_account_id DataDatabricksAwsBucketPolicy#databricks_e2_account_id}.
         :param full_access_role: Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/databricks/d/aws_bucket_policy#full_access_role DataDatabricksAwsBucketPolicy#full_access_role}.
         :param id: Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/databricks/d/aws_bucket_policy#id DataDatabricksAwsBucketPolicy#id}. Please be aware that the id field is automatically added to all resources in Terraform providers using a Terraform provider SDK version below 2. If you experience problems setting this value it might not be settable. Please take a look at the provider documentation to ensure it should be settable.
         :param connection: 
@@ -62,12 +64,13 @@ class DataDatabricksAwsBucketPolicy(
         :param provisioners: 
         '''
         if __debug__:
-            type_hints = typing.get_type_hints(DataDatabricksAwsBucketPolicy.__init__)
+            type_hints = typing.get_type_hints(_typecheckingstub__ada72c7b1f92eb4c82a8804b3c109651f919c90edfa9714738d0c688ef927efc)
             check_type(argname="argument scope", value=scope, expected_type=type_hints["scope"])
             check_type(argname="argument id_", value=id_, expected_type=type_hints["id_"])
         config = DataDatabricksAwsBucketPolicyConfig(
             bucket=bucket,
             databricks_account_id=databricks_account_id,
+            databricks_e2_account_id=databricks_e2_account_id,
             full_access_role=full_access_role,
             id=id,
             connection=connection,
@@ -85,6 +88,10 @@ class DataDatabricksAwsBucketPolicy(
     def reset_databricks_account_id(self) -> None:
         return typing.cast(None, jsii.invoke(self, "resetDatabricksAccountId", []))
 
+    @jsii.member(jsii_name="resetDatabricksE2AccountId")
+    def reset_databricks_e2_account_id(self) -> None:
+        return typing.cast(None, jsii.invoke(self, "resetDatabricksE2AccountId", []))
+
     @jsii.member(jsii_name="resetFullAccessRole")
     def reset_full_access_role(self) -> None:
         return typing.cast(None, jsii.invoke(self, "resetFullAccessRole", []))
@@ -117,6 +124,11 @@ class DataDatabricksAwsBucketPolicy(
     def databricks_account_id_input(self) -> typing.Optional[builtins.str]:
         return typing.cast(typing.Optional[builtins.str], jsii.get(self, "databricksAccountIdInput"))
 
+    @builtins.property
+    @jsii.member(jsii_name="databricksE2AccountIdInput")
+    def databricks_e2_account_id_input(self) -> typing.Optional[builtins.str]:
+        return typing.cast(typing.Optional[builtins.str], jsii.get(self, "databricksE2AccountIdInput"))
+
     @builtins.property
     @jsii.member(jsii_name="fullAccessRoleInput")
     def full_access_role_input(self) -> typing.Optional[builtins.str]:
@@ -135,7 +147,7 @@ class DataDatabricksAwsBucketPolicy(
     @bucket.setter
     def bucket(self, value: builtins.str) -> None:
         if __debug__:
-            type_hints = typing.get_type_hints(getattr(DataDatabricksAwsBucketPolicy, "bucket").fset)
+            type_hints = typing.get_type_hints(_typecheckingstub__40f824749348c90de70b36ff7abd45ba2efbdff079d6cbee8167c83308ad0f17)
             check_type(argname="argument value", value=value, expected_type=type_hints["value"])
         jsii.set(self, "bucket", value)
 
@@ -147,10 +159,22 @@ class DataDatabricksAwsBucketPolicy(
     @databricks_account_id.setter
     def databricks_account_id(self, value: builtins.str) -> None:
         if __debug__:
-            type_hints = typing.get_type_hints(getattr(DataDatabricksAwsBucketPolicy, "databricks_account_id").fset)
+            type_hints = typing.get_type_hints(_typecheckingstub__2ed0e3dc4bb96e6c9d18cb67630cb9ad6b97b92533a0f448db2064d5348c62be)
             check_type(argname="argument value", value=value, expected_type=type_hints["value"])
         jsii.set(self, "databricksAccountId", value)
 
+    @builtins.property
+    @jsii.member(jsii_name="databricksE2AccountId")
+    def databricks_e2_account_id(self) -> builtins.str:
+        return typing.cast(builtins.str, jsii.get(self, "databricksE2AccountId"))
+
+    @databricks_e2_account_id.setter
+    def databricks_e2_account_id(self, value: builtins.str) -> None:
+        if __debug__:
+            type_hints = typing.get_type_hints(_typecheckingstub__737ad6a37631d85b564a85ab16af3b80224124347477c524187a9bdf1c22c2c7)
+            check_type(argname="argument value", value=value, expected_type=type_hints["value"])
+        jsii.set(self, "databricksE2AccountId", value)
+
     @builtins.property
     @jsii.member(jsii_name="fullAccessRole")
     def full_access_role(self) -> builtins.str:
@@ -159,7 +183,7 @@ class DataDatabricksAwsBucketPolicy(
     @full_access_role.setter
     def full_access_role(self, value: builtins.str) -> None:
         if __debug__:
-            type_hints = typing.get_type_hints(getattr(DataDatabricksAwsBucketPolicy, "full_access_role").fset)
+            type_hints = typing.get_type_hints(_typecheckingstub__24a293b5790a32c741275f04ce08771eb691ddcde567c2798c6e3b067d1a1ba0)
             check_type(argname="argument value", value=value, expected_type=type_hints["value"])
         jsii.set(self, "fullAccessRole", value)
 
@@ -171,14 +195,14 @@ class DataDatabricksAwsBucketPolicy(
     @id.setter
     def id(self, value: builtins.str) -> None:
         if __debug__:
-            type_hints = typing.get_type_hints(getattr(DataDatabricksAwsBucketPolicy, "id").fset)
+            type_hints = typing.get_type_hints(_typecheckingstub__21e26b1b122f7f9a6ebfb3447e7b485c5a7c674d92e9d704919addfa2232dcec)
             check_type(argname="argument value", value=value, expected_type=type_hints["value"])
         jsii.set(self, "id", value)
 
 
 @jsii.data_type(
     jsii_type="@cdktf/provider-databricks.dataDatabricksAwsBucketPolicy.DataDatabricksAwsBucketPolicyConfig",
-    jsii_struct_bases=[cdktf.TerraformMetaArguments],
+    jsii_struct_bases=[_cdktf_9a9027ec.TerraformMetaArguments],
     name_mapping={
         "connection": "connection",
         "count": "count",
@@ -189,23 +213,25 @@ class DataDatabricksAwsBucketPolicy(
         "provisioners": "provisioners",
         "bucket": "bucket",
         "databricks_account_id": "databricksAccountId",
+        "databricks_e2_account_id": "databricksE2AccountId",
         "full_access_role": "fullAccessRole",
         "id": "id",
     },
 )
-class DataDatabricksAwsBucketPolicyConfig(cdktf.TerraformMetaArguments):
+class DataDatabricksAwsBucketPolicyConfig(_cdktf_9a9027ec.TerraformMetaArguments):
     def __init__(
         self,
         *,
-        connection: typing.Optional[typing.Union[typing.Union[cdktf.SSHProvisionerConnection, typing.Dict[str, typing.Any]], typing.Union[cdktf.WinrmProvisionerConnection, typing.Dict[str, typing.Any]]]] = None,
+        connection: typing.Optional[typing.Union[typing.Union[_cdktf_9a9027ec.SSHProvisionerConnection, typing.Dict[builtins.str, typing.Any]], typing.Union[_cdktf_9a9027ec.WinrmProvisionerConnection, typing.Dict[builtins.str, typing.Any]]]] = None,
         count: typing.Optional[jsii.Number] = None,
-        depends_on: typing.Optional[typing.Sequence[cdktf.ITerraformDependable]] = None,
-        for_each: typing.Optional[cdktf.ITerraformIterator] = None,
-        lifecycle: typing.Optional[typing.Union[cdktf.TerraformResourceLifecycle, typing.Dict[str, typing.Any]]] = None,
-        provider: typing.Optional[cdktf.TerraformProvider] = None,
-        provisioners: typing.Optional[typing.Sequence[typing.Union[typing.Union[cdktf.FileProvisioner, typing.Dict[str, typing.Any]], typing.Union[cdktf.LocalExecProvisioner, typing.Dict[str, typing.Any]], typing.Union[cdktf.RemoteExecProvisioner, typing.Dict[str, typing.Any]]]]] = None,
+        depends_on: typing.Optional[typing.Sequence[_cdktf_9a9027ec.ITerraformDependable]] = None,
+        for_each: typing.Optional[_cdktf_9a9027ec.ITerraformIterator] = None,
+        lifecycle: typing.Optional[typing.Union[_cdktf_9a9027ec.TerraformResourceLifecycle, typing.Dict[builtins.str, typing.Any]]] = None,
+        provider: typing.Optional[_cdktf_9a9027ec.TerraformProvider] = None,
+        provisioners: typing.Optional[typing.Sequence[typing.Union[typing.Union[_cdktf_9a9027ec.FileProvisioner, typing.Dict[builtins.str, typing.Any]], typing.Union[_cdktf_9a9027ec.LocalExecProvisioner, typing.Dict[builtins.str, typing.Any]], typing.Union[_cdktf_9a9027ec.RemoteExecProvisioner, typing.Dict[builtins.str, typing.Any]]]]] = None,
         bucket: builtins.str,
         databricks_account_id: typing.Optional[builtins.str] = None,
+        databricks_e2_account_id: typing.Optional[builtins.str] = None,
         full_access_role: typing.Optional[builtins.str] = None,
         id: typing.Optional[builtins.str] = None,
     ) -> None:
@@ -219,13 +245,14 @@ class DataDatabricksAwsBucketPolicyConfig(cdktf.TerraformMetaArguments):
         :param provisioners: 
         :param bucket: Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/databricks/d/aws_bucket_policy#bucket DataDatabricksAwsBucketPolicy#bucket}.
         :param databricks_account_id: Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/databricks/d/aws_bucket_policy#databricks_account_id DataDatabricksAwsBucketPolicy#databricks_account_id}.
+        :param databricks_e2_account_id: Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/databricks/d/aws_bucket_policy#databricks_e2_account_id DataDatabricksAwsBucketPolicy#databricks_e2_account_id}.
         :param full_access_role: Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/databricks/d/aws_bucket_policy#full_access_role DataDatabricksAwsBucketPolicy#full_access_role}.
         :param id: Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/databricks/d/aws_bucket_policy#id DataDatabricksAwsBucketPolicy#id}. Please be aware that the id field is automatically added to all resources in Terraform providers using a Terraform provider SDK version below 2. If you experience problems setting this value it might not be settable. Please take a look at the provider documentation to ensure it should be settable.
         '''
         if isinstance(lifecycle, dict):
-            lifecycle = cdktf.TerraformResourceLifecycle(**lifecycle)
+            lifecycle = _cdktf_9a9027ec.TerraformResourceLifecycle(**lifecycle)
         if __debug__:
-            type_hints = typing.get_type_hints(DataDatabricksAwsBucketPolicyConfig.__init__)
+            type_hints = typing.get_type_hints(_typecheckingstub__cf49caca092096ee1294a5118fd796597a0dc43b92450c6a37f466d966b72ca3)
             check_type(argname="argument connection", value=connection, expected_type=type_hints["connection"])
             check_type(argname="argument count", value=count, expected_type=type_hints["count"])
             check_type(argname="argument depends_on", value=depends_on, expected_type=type_hints["depends_on"])
@@ -235,9 +262,10 @@ class DataDatabricksAwsBucketPolicyConfig(cdktf.TerraformMetaArguments):
             check_type(argname="argument provisioners", value=provisioners, expected_type=type_hints["provisioners"])
             check_type(argname="argument bucket", value=bucket, expected_type=type_hints["bucket"])
             check_type(argname="argument databricks_account_id", value=databricks_account_id, expected_type=type_hints["databricks_account_id"])
+            check_type(argname="argument databricks_e2_account_id", value=databricks_e2_account_id, expected_type=type_hints["databricks_e2_account_id"])
             check_type(argname="argument full_access_role", value=full_access_role, expected_type=type_hints["full_access_role"])
             check_type(argname="argument id", value=id, expected_type=type_hints["id"])
-        self._values: typing.Dict[str, typing.Any] = {
+        self._values: typing.Dict[builtins.str, typing.Any] = {
             "bucket": bucket,
         }
         if connection is not None:
@@ -256,6 +284,8 @@ class DataDatabricksAwsBucketPolicyConfig(cdktf.TerraformMetaArguments):
             self._values["provisioners"] = provisioners
         if databricks_account_id is not None:
             self._values["databricks_account_id"] = databricks_account_id
+        if databricks_e2_account_id is not None:
+            self._values["databricks_e2_account_id"] = databricks_e2_account_id
         if full_access_role is not None:
             self._values["full_access_role"] = full_access_role
         if id is not None:
@@ -264,12 +294,12 @@ class DataDatabricksAwsBucketPolicyConfig(cdktf.TerraformMetaArguments):
     @builtins.property
     def connection(
         self,
-    ) -> typing.Optional[typing.Union[cdktf.SSHProvisionerConnection, cdktf.WinrmProvisionerConnection]]:
+    ) -> typing.Optional[typing.Union[_cdktf_9a9027ec.SSHProvisionerConnection, _cdktf_9a9027ec.WinrmProvisionerConnection]]:
         '''
         :stability: experimental
         '''
         result = self._values.get("connection")
-        return typing.cast(typing.Optional[typing.Union[cdktf.SSHProvisionerConnection, cdktf.WinrmProvisionerConnection]], result)
+        return typing.cast(typing.Optional[typing.Union[_cdktf_9a9027ec.SSHProvisionerConnection, _cdktf_9a9027ec.WinrmProvisionerConnection]], result)
 
     @builtins.property
     def count(self) -> typing.Optional[jsii.Number]:
@@ -280,46 +310,48 @@ class DataDatabricksAwsBucketPolicyConfig(cdktf.TerraformMetaArguments):
         return typing.cast(typing.Optional[jsii.Number], result)
 
     @builtins.property
-    def depends_on(self) -> typing.Optional[typing.List[cdktf.ITerraformDependable]]:
+    def depends_on(
+        self,
+    ) -> typing.Optional[typing.List[_cdktf_9a9027ec.ITerraformDependable]]:
         '''
         :stability: experimental
         '''
         result = self._values.get("depends_on")
-        return typing.cast(typing.Optional[typing.List[cdktf.ITerraformDependable]], result)
+        return typing.cast(typing.Optional[typing.List[_cdktf_9a9027ec.ITerraformDependable]], result)
 
     @builtins.property
-    def for_each(self) -> typing.Optional[cdktf.ITerraformIterator]:
+    def for_each(self) -> typing.Optional[_cdktf_9a9027ec.ITerraformIterator]:
         '''
         :stability: experimental
         '''
         result = self._values.get("for_each")
-        return typing.cast(typing.Optional[cdktf.ITerraformIterator], result)
+        return typing.cast(typing.Optional[_cdktf_9a9027ec.ITerraformIterator], result)
 
     @builtins.property
-    def lifecycle(self) -> typing.Optional[cdktf.TerraformResourceLifecycle]:
+    def lifecycle(self) -> typing.Optional[_cdktf_9a9027ec.TerraformResourceLifecycle]:
         '''
         :stability: experimental
         '''
         result = self._values.get("lifecycle")
-        return typing.cast(typing.Optional[cdktf.TerraformResourceLifecycle], result)
+        return typing.cast(typing.Optional[_cdktf_9a9027ec.TerraformResourceLifecycle], result)
 
     @builtins.property
-    def provider(self) -> typing.Optional[cdktf.TerraformProvider]:
+    def provider(self) -> typing.Optional[_cdktf_9a9027ec.TerraformProvider]:
         '''
         :stability: experimental
         '''
         result = self._values.get("provider")
-        return typing.cast(typing.Optional[cdktf.TerraformProvider], result)
+        return typing.cast(typing.Optional[_cdktf_9a9027ec.TerraformProvider], result)
 
     @builtins.property
     def provisioners(
         self,
-    ) -> typing.Optional[typing.List[typing.Union[cdktf.FileProvisioner, cdktf.LocalExecProvisioner, cdktf.RemoteExecProvisioner]]]:
+    ) -> typing.Optional[typing.List[typing.Union[_cdktf_9a9027ec.FileProvisioner, _cdktf_9a9027ec.LocalExecProvisioner, _cdktf_9a9027ec.RemoteExecProvisioner]]]:
         '''
         :stability: experimental
         '''
         result = self._values.get("provisioners")
-        return typing.cast(typing.Optional[typing.List[typing.Union[cdktf.FileProvisioner, cdktf.LocalExecProvisioner, cdktf.RemoteExecProvisioner]]], result)
+        return typing.cast(typing.Optional[typing.List[typing.Union[_cdktf_9a9027ec.FileProvisioner, _cdktf_9a9027ec.LocalExecProvisioner, _cdktf_9a9027ec.RemoteExecProvisioner]]], result)
 
     @builtins.property
     def bucket(self) -> builtins.str:
@@ -334,6 +366,12 @@ class DataDatabricksAwsBucketPolicyConfig(cdktf.TerraformMetaArguments):
         result = self._values.get("databricks_account_id")
         return typing.cast(typing.Optional[builtins.str], result)
 
+    @builtins.property
+    def databricks_e2_account_id(self) -> typing.Optional[builtins.str]:
+        '''Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/databricks/d/aws_bucket_policy#databricks_e2_account_id DataDatabricksAwsBucketPolicy#databricks_e2_account_id}.'''
+        result = self._values.get("databricks_e2_account_id")
+        return typing.cast(typing.Optional[builtins.str], result)
+
     @builtins.property
     def full_access_role(self) -> typing.Optional[builtins.str]:
         '''Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/databricks/d/aws_bucket_policy#full_access_role DataDatabricksAwsBucketPolicy#full_access_role}.'''
@@ -368,3 +406,71 @@ __all__ = [
 ]
 
 publication.publish()
+
+def _typecheckingstub__ada72c7b1f92eb4c82a8804b3c109651f919c90edfa9714738d0c688ef927efc(
+    scope: _constructs_77d1e7e8.Construct,
+    id_: builtins.str,
+    *,
+    bucket: builtins.str,
+    databricks_account_id: typing.Optional[builtins.str] = None,
+    databricks_e2_account_id: typing.Optional[builtins.str] = None,
+    full_access_role: typing.Optional[builtins.str] = None,
+    id: typing.Optional[builtins.str] = None,
+    connection: typing.Optional[typing.Union[typing.Union[_cdktf_9a9027ec.SSHProvisionerConnection, typing.Dict[builtins.str, typing.Any]], typing.Union[_cdktf_9a9027ec.WinrmProvisionerConnection, typing.Dict[builtins.str, typing.Any]]]] = None,
+    count: typing.Optional[jsii.Number] = None,
+    depends_on: typing.Optional[typing.Sequence[_cdktf_9a9027ec.ITerraformDependable]] = None,
+    for_each: typing.Optional[_cdktf_9a9027ec.ITerraformIterator] = None,
+    lifecycle: typing.Optional[typing.Union[_cdktf_9a9027ec.TerraformResourceLifecycle, typing.Dict[builtins.str, typing.Any]]] = None,
+    provider: typing.Optional[_cdktf_9a9027ec.TerraformProvider] = None,
+    provisioners: typing.Optional[typing.Sequence[typing.Union[typing.Union[_cdktf_9a9027ec.FileProvisioner, typing.Dict[builtins.str, typing.Any]], typing.Union[_cdktf_9a9027ec.LocalExecProvisioner, typing.Dict[builtins.str, typing.Any]], typing.Union[_cdktf_9a9027ec.RemoteExecProvisioner, typing.Dict[builtins.str, typing.Any]]]]] = None,
+) -> None:
+    """Type checking stubs"""
+    pass
+
+def _typecheckingstub__40f824749348c90de70b36ff7abd45ba2efbdff079d6cbee8167c83308ad0f17(
+    value: builtins.str,
+) -> None:
+    """Type checking stubs"""
+    pass
+
+def _typecheckingstub__2ed0e3dc4bb96e6c9d18cb67630cb9ad6b97b92533a0f448db2064d5348c62be(
+    value: builtins.str,
+) -> None:
+    """Type checking stubs"""
+    pass
+
+def _typecheckingstub__737ad6a37631d85b564a85ab16af3b80224124347477c524187a9bdf1c22c2c7(
+    value: builtins.str,
+) -> None:
+    """Type checking stubs"""
+    pass
+
+def _typecheckingstub__24a293b5790a32c741275f04ce08771eb691ddcde567c2798c6e3b067d1a1ba0(
+    value: builtins.str,
+) -> None:
+    """Type checking stubs"""
+    pass
+
+def _typecheckingstub__21e26b1b122f7f9a6ebfb3447e7b485c5a7c674d92e9d704919addfa2232dcec(
+    value: builtins.str,
+) -> None:
+    """Type checking stubs"""
+    pass
+
+def _typecheckingstub__cf49caca092096ee1294a5118fd796597a0dc43b92450c6a37f466d966b72ca3(
+    *,
+    connection: typing.Optional[typing.Union[typing.Union[_cdktf_9a9027ec.SSHProvisionerConnection, typing.Dict[builtins.str, typing.Any]], typing.Union[_cdktf_9a9027ec.WinrmProvisionerConnection, typing.Dict[builtins.str, typing.Any]]]] = None,
+    count: typing.Optional[jsii.Number] = None,
+    depends_on: typing.Optional[typing.Sequence[_cdktf_9a9027ec.ITerraformDependable]] = None,
+    for_each: typing.Optional[_cdktf_9a9027ec.ITerraformIterator] = None,
+    lifecycle: typing.Optional[typing.Union[_cdktf_9a9027ec.TerraformResourceLifecycle, typing.Dict[builtins.str, typing.Any]]] = None,
+    provider: typing.Optional[_cdktf_9a9027ec.TerraformProvider] = None,
+    provisioners: typing.Optional[typing.Sequence[typing.Union[typing.Union[_cdktf_9a9027ec.FileProvisioner, typing.Dict[builtins.str, typing.Any]], typing.Union[_cdktf_9a9027ec.LocalExecProvisioner, typing.Dict[builtins.str, typing.Any]], typing.Union[_cdktf_9a9027ec.RemoteExecProvisioner, typing.Dict[builtins.str, typing.Any]]]]] = None,
+    bucket: builtins.str,
+    databricks_account_id: typing.Optional[builtins.str] = None,
+    databricks_e2_account_id: typing.Optional[builtins.str] = None,
+    full_access_role: typing.Optional[builtins.str] = None,
+    id: typing.Optional[builtins.str] = None,
+) -> None:
+    """Type checking stubs"""
+    pass
