@@ -17,12 +17,12 @@ from typeguard import check_type
 
 from .._jsii import *
 
-import cdktf
-import constructs
+import cdktf as _cdktf_9a9027ec
+import constructs as _constructs_77d1e7e8
 
 
 class DataDatabricksGroup(
-    cdktf.TerraformDataSource,
+    _cdktf_9a9027ec.TerraformDataSource,
     metaclass=jsii.JSIIMeta,
     jsii_type="@cdktf/provider-databricks.dataDatabricksGroup.DataDatabricksGroup",
 ):
@@ -30,30 +30,30 @@ class DataDatabricksGroup(
 
     def __init__(
         self,
-        scope: constructs.Construct,
+        scope: _constructs_77d1e7e8.Construct,
         id_: builtins.str,
         *,
         display_name: builtins.str,
-        allow_cluster_create: typing.Optional[typing.Union[builtins.bool, cdktf.IResolvable]] = None,
-        allow_instance_pool_create: typing.Optional[typing.Union[builtins.bool, cdktf.IResolvable]] = None,
+        allow_cluster_create: typing.Optional[typing.Union[builtins.bool, _cdktf_9a9027ec.IResolvable]] = None,
+        allow_instance_pool_create: typing.Optional[typing.Union[builtins.bool, _cdktf_9a9027ec.IResolvable]] = None,
         child_groups: typing.Optional[typing.Sequence[builtins.str]] = None,
-        databricks_sql_access: typing.Optional[typing.Union[builtins.bool, cdktf.IResolvable]] = None,
+        databricks_sql_access: typing.Optional[typing.Union[builtins.bool, _cdktf_9a9027ec.IResolvable]] = None,
         external_id: typing.Optional[builtins.str] = None,
         groups: typing.Optional[typing.Sequence[builtins.str]] = None,
         id: typing.Optional[builtins.str] = None,
         instance_profiles: typing.Optional[typing.Sequence[builtins.str]] = None,
         members: typing.Optional[typing.Sequence[builtins.str]] = None,
-        recursive: typing.Optional[typing.Union[builtins.bool, cdktf.IResolvable]] = None,
+        recursive: typing.Optional[typing.Union[builtins.bool, _cdktf_9a9027ec.IResolvable]] = None,
         service_principals: typing.Optional[typing.Sequence[builtins.str]] = None,
         users: typing.Optional[typing.Sequence[builtins.str]] = None,
-        workspace_access: typing.Optional[typing.Union[builtins.bool, cdktf.IResolvable]] = None,
-        connection: typing.Optional[typing.Union[typing.Union[cdktf.SSHProvisionerConnection, typing.Dict[str, typing.Any]], typing.Union[cdktf.WinrmProvisionerConnection, typing.Dict[str, typing.Any]]]] = None,
+        workspace_access: typing.Optional[typing.Union[builtins.bool, _cdktf_9a9027ec.IResolvable]] = None,
+        connection: typing.Optional[typing.Union[typing.Union[_cdktf_9a9027ec.SSHProvisionerConnection, typing.Dict[builtins.str, typing.Any]], typing.Union[_cdktf_9a9027ec.WinrmProvisionerConnection, typing.Dict[builtins.str, typing.Any]]]] = None,
         count: typing.Optional[jsii.Number] = None,
-        depends_on: typing.Optional[typing.Sequence[cdktf.ITerraformDependable]] = None,
-        for_each: typing.Optional[cdktf.ITerraformIterator] = None,
-        lifecycle: typing.Optional[typing.Union[cdktf.TerraformResourceLifecycle, typing.Dict[str, typing.Any]]] = None,
-        provider: typing.Optional[cdktf.TerraformProvider] = None,
-        provisioners: typing.Optional[typing.Sequence[typing.Union[typing.Union[cdktf.FileProvisioner, typing.Dict[str, typing.Any]], typing.Union[cdktf.LocalExecProvisioner, typing.Dict[str, typing.Any]], typing.Union[cdktf.RemoteExecProvisioner, typing.Dict[str, typing.Any]]]]] = None,
+        depends_on: typing.Optional[typing.Sequence[_cdktf_9a9027ec.ITerraformDependable]] = None,
+        for_each: typing.Optional[_cdktf_9a9027ec.ITerraformIterator] = None,
+        lifecycle: typing.Optional[typing.Union[_cdktf_9a9027ec.TerraformResourceLifecycle, typing.Dict[builtins.str, typing.Any]]] = None,
+        provider: typing.Optional[_cdktf_9a9027ec.TerraformProvider] = None,
+        provisioners: typing.Optional[typing.Sequence[typing.Union[typing.Union[_cdktf_9a9027ec.FileProvisioner, typing.Dict[builtins.str, typing.Any]], typing.Union[_cdktf_9a9027ec.LocalExecProvisioner, typing.Dict[builtins.str, typing.Any]], typing.Union[_cdktf_9a9027ec.RemoteExecProvisioner, typing.Dict[builtins.str, typing.Any]]]]] = None,
     ) -> None:
         '''Create a new {@link https://www.terraform.io/docs/providers/databricks/d/group databricks_group} Data Source.
 
@@ -82,7 +82,7 @@ class DataDatabricksGroup(
         :param provisioners: 
         '''
         if __debug__:
-            type_hints = typing.get_type_hints(DataDatabricksGroup.__init__)
+            type_hints = typing.get_type_hints(_typecheckingstub__b95100a949934e64884ec68eac4c9d5149860ad636e55fda46b8bd9c4c2f68d8)
             check_type(argname="argument scope", value=scope, expected_type=type_hints["scope"])
             check_type(argname="argument id_", value=id_, expected_type=type_hints["id_"])
         config = DataDatabricksGroupConfig(
@@ -176,15 +176,15 @@ class DataDatabricksGroup(
     @jsii.member(jsii_name="allowClusterCreateInput")
     def allow_cluster_create_input(
         self,
-    ) -> typing.Optional[typing.Union[builtins.bool, cdktf.IResolvable]]:
-        return typing.cast(typing.Optional[typing.Union[builtins.bool, cdktf.IResolvable]], jsii.get(self, "allowClusterCreateInput"))
+    ) -> typing.Optional[typing.Union[builtins.bool, _cdktf_9a9027ec.IResolvable]]:
+        return typing.cast(typing.Optional[typing.Union[builtins.bool, _cdktf_9a9027ec.IResolvable]], jsii.get(self, "allowClusterCreateInput"))
 
     @builtins.property
     @jsii.member(jsii_name="allowInstancePoolCreateInput")
     def allow_instance_pool_create_input(
         self,
-    ) -> typing.Optional[typing.Union[builtins.bool, cdktf.IResolvable]]:
-        return typing.cast(typing.Optional[typing.Union[builtins.bool, cdktf.IResolvable]], jsii.get(self, "allowInstancePoolCreateInput"))
+    ) -> typing.Optional[typing.Union[builtins.bool, _cdktf_9a9027ec.IResolvable]]:
+        return typing.cast(typing.Optional[typing.Union[builtins.bool, _cdktf_9a9027ec.IResolvable]], jsii.get(self, "allowInstancePoolCreateInput"))
 
     @builtins.property
     @jsii.member(jsii_name="childGroupsInput")
@@ -195,8 +195,8 @@ class DataDatabricksGroup(
     @jsii.member(jsii_name="databricksSqlAccessInput")
     def databricks_sql_access_input(
         self,
-    ) -> typing.Optional[typing.Union[builtins.bool, cdktf.IResolvable]]:
-        return typing.cast(typing.Optional[typing.Union[builtins.bool, cdktf.IResolvable]], jsii.get(self, "databricksSqlAccessInput"))
+    ) -> typing.Optional[typing.Union[builtins.bool, _cdktf_9a9027ec.IResolvable]]:
+        return typing.cast(typing.Optional[typing.Union[builtins.bool, _cdktf_9a9027ec.IResolvable]], jsii.get(self, "databricksSqlAccessInput"))
 
     @builtins.property
     @jsii.member(jsii_name="displayNameInput")
@@ -232,8 +232,8 @@ class DataDatabricksGroup(
     @jsii.member(jsii_name="recursiveInput")
     def recursive_input(
         self,
-    ) -> typing.Optional[typing.Union[builtins.bool, cdktf.IResolvable]]:
-        return typing.cast(typing.Optional[typing.Union[builtins.bool, cdktf.IResolvable]], jsii.get(self, "recursiveInput"))
+    ) -> typing.Optional[typing.Union[builtins.bool, _cdktf_9a9027ec.IResolvable]]:
+        return typing.cast(typing.Optional[typing.Union[builtins.bool, _cdktf_9a9027ec.IResolvable]], jsii.get(self, "recursiveInput"))
 
     @builtins.property
     @jsii.member(jsii_name="servicePrincipalsInput")
@@ -249,21 +249,23 @@ class DataDatabricksGroup(
     @jsii.member(jsii_name="workspaceAccessInput")
     def workspace_access_input(
         self,
-    ) -> typing.Optional[typing.Union[builtins.bool, cdktf.IResolvable]]:
-        return typing.cast(typing.Optional[typing.Union[builtins.bool, cdktf.IResolvable]], jsii.get(self, "workspaceAccessInput"))
+    ) -> typing.Optional[typing.Union[builtins.bool, _cdktf_9a9027ec.IResolvable]]:
+        return typing.cast(typing.Optional[typing.Union[builtins.bool, _cdktf_9a9027ec.IResolvable]], jsii.get(self, "workspaceAccessInput"))
 
     @builtins.property
     @jsii.member(jsii_name="allowClusterCreate")
-    def allow_cluster_create(self) -> typing.Union[builtins.bool, cdktf.IResolvable]:
-        return typing.cast(typing.Union[builtins.bool, cdktf.IResolvable], jsii.get(self, "allowClusterCreate"))
+    def allow_cluster_create(
+        self,
+    ) -> typing.Union[builtins.bool, _cdktf_9a9027ec.IResolvable]:
+        return typing.cast(typing.Union[builtins.bool, _cdktf_9a9027ec.IResolvable], jsii.get(self, "allowClusterCreate"))
 
     @allow_cluster_create.setter
     def allow_cluster_create(
         self,
-        value: typing.Union[builtins.bool, cdktf.IResolvable],
+        value: typing.Union[builtins.bool, _cdktf_9a9027ec.IResolvable],
     ) -> None:
         if __debug__:
-            type_hints = typing.get_type_hints(getattr(DataDatabricksGroup, "allow_cluster_create").fset)
+            type_hints = typing.get_type_hints(_typecheckingstub__7e8277af0b47300b1ef748a7a82512431013e5f6283b9f3523768652e408ec8d)
             check_type(argname="argument value", value=value, expected_type=type_hints["value"])
         jsii.set(self, "allowClusterCreate", value)
 
@@ -271,16 +273,16 @@ class DataDatabricksGroup(
     @jsii.member(jsii_name="allowInstancePoolCreate")
     def allow_instance_pool_create(
         self,
-    ) -> typing.Union[builtins.bool, cdktf.IResolvable]:
-        return typing.cast(typing.Union[builtins.bool, cdktf.IResolvable], jsii.get(self, "allowInstancePoolCreate"))
+    ) -> typing.Union[builtins.bool, _cdktf_9a9027ec.IResolvable]:
+        return typing.cast(typing.Union[builtins.bool, _cdktf_9a9027ec.IResolvable], jsii.get(self, "allowInstancePoolCreate"))
 
     @allow_instance_pool_create.setter
     def allow_instance_pool_create(
         self,
-        value: typing.Union[builtins.bool, cdktf.IResolvable],
+        value: typing.Union[builtins.bool, _cdktf_9a9027ec.IResolvable],
     ) -> None:
         if __debug__:
-            type_hints = typing.get_type_hints(getattr(DataDatabricksGroup, "allow_instance_pool_create").fset)
+            type_hints = typing.get_type_hints(_typecheckingstub__78c8e959496c61967a1fd92ce17cf3ef1803f06166b40519f4df1d462392cba0)
             check_type(argname="argument value", value=value, expected_type=type_hints["value"])
         jsii.set(self, "allowInstancePoolCreate", value)
 
@@ -292,22 +294,24 @@ class DataDatabricksGroup(
     @child_groups.setter
     def child_groups(self, value: typing.List[builtins.str]) -> None:
         if __debug__:
-            type_hints = typing.get_type_hints(getattr(DataDatabricksGroup, "child_groups").fset)
+            type_hints = typing.get_type_hints(_typecheckingstub__4052c6bec703b3fb2658814a19fa8a6c161a943f9a0cfa1e451fb8ceff70a0a2)
             check_type(argname="argument value", value=value, expected_type=type_hints["value"])
         jsii.set(self, "childGroups", value)
 
     @builtins.property
     @jsii.member(jsii_name="databricksSqlAccess")
-    def databricks_sql_access(self) -> typing.Union[builtins.bool, cdktf.IResolvable]:
-        return typing.cast(typing.Union[builtins.bool, cdktf.IResolvable], jsii.get(self, "databricksSqlAccess"))
+    def databricks_sql_access(
+        self,
+    ) -> typing.Union[builtins.bool, _cdktf_9a9027ec.IResolvable]:
+        return typing.cast(typing.Union[builtins.bool, _cdktf_9a9027ec.IResolvable], jsii.get(self, "databricksSqlAccess"))
 
     @databricks_sql_access.setter
     def databricks_sql_access(
         self,
-        value: typing.Union[builtins.bool, cdktf.IResolvable],
+        value: typing.Union[builtins.bool, _cdktf_9a9027ec.IResolvable],
     ) -> None:
         if __debug__:
-            type_hints = typing.get_type_hints(getattr(DataDatabricksGroup, "databricks_sql_access").fset)
+            type_hints = typing.get_type_hints(_typecheckingstub__bb2f0c5fb64f7952cfbce899c64bae167e0bf9478408f94165c3d4d5def75745)
             check_type(argname="argument value", value=value, expected_type=type_hints["value"])
         jsii.set(self, "databricksSqlAccess", value)
 
@@ -319,7 +323,7 @@ class DataDatabricksGroup(
     @display_name.setter
     def display_name(self, value: builtins.str) -> None:
         if __debug__:
-            type_hints = typing.get_type_hints(getattr(DataDatabricksGroup, "display_name").fset)
+            type_hints = typing.get_type_hints(_typecheckingstub__6f127edaffb7b058d7ab86e38662006b6e4f96654c522be2971f5f4dd0e7c1a9)
             check_type(argname="argument value", value=value, expected_type=type_hints["value"])
         jsii.set(self, "displayName", value)
 
@@ -331,7 +335,7 @@ class DataDatabricksGroup(
     @external_id.setter
     def external_id(self, value: builtins.str) -> None:
         if __debug__:
-            type_hints = typing.get_type_hints(getattr(DataDatabricksGroup, "external_id").fset)
+            type_hints = typing.get_type_hints(_typecheckingstub__5b32d417c06ef723e38334eb05cc06078bbb52a4e74d18b30459b0b5ee064103)
             check_type(argname="argument value", value=value, expected_type=type_hints["value"])
         jsii.set(self, "externalId", value)
 
@@ -343,7 +347,7 @@ class DataDatabricksGroup(
     @groups.setter
     def groups(self, value: typing.List[builtins.str]) -> None:
         if __debug__:
-            type_hints = typing.get_type_hints(getattr(DataDatabricksGroup, "groups").fset)
+            type_hints = typing.get_type_hints(_typecheckingstub__6999e678f8de11a03846d048666f0e85a586553c4eb97d2fc784569c3ce8d624)
             check_type(argname="argument value", value=value, expected_type=type_hints["value"])
         jsii.set(self, "groups", value)
 
@@ -355,7 +359,7 @@ class DataDatabricksGroup(
     @id.setter
     def id(self, value: builtins.str) -> None:
         if __debug__:
-            type_hints = typing.get_type_hints(getattr(DataDatabricksGroup, "id").fset)
+            type_hints = typing.get_type_hints(_typecheckingstub__4405fb10c17e82b26af1fdade43b18687a9193226f32f2bf1b8ec3dadd209dd8)
             check_type(argname="argument value", value=value, expected_type=type_hints["value"])
         jsii.set(self, "id", value)
 
@@ -367,7 +371,7 @@ class DataDatabricksGroup(
     @instance_profiles.setter
     def instance_profiles(self, value: typing.List[builtins.str]) -> None:
         if __debug__:
-            type_hints = typing.get_type_hints(getattr(DataDatabricksGroup, "instance_profiles").fset)
+            type_hints = typing.get_type_hints(_typecheckingstub__e3f0eb694fe900f193dc63b2f0a03daa17e34a90f38659002bc6a1a9e43d70f8)
             check_type(argname="argument value", value=value, expected_type=type_hints["value"])
         jsii.set(self, "instanceProfiles", value)
 
@@ -379,19 +383,22 @@ class DataDatabricksGroup(
     @members.setter
     def members(self, value: typing.List[builtins.str]) -> None:
         if __debug__:
-            type_hints = typing.get_type_hints(getattr(DataDatabricksGroup, "members").fset)
+            type_hints = typing.get_type_hints(_typecheckingstub__a58ff5cd981c893fd910b98de3e264af6e3c2f0a76049ec2494a0b8f9d3ab2f2)
             check_type(argname="argument value", value=value, expected_type=type_hints["value"])
         jsii.set(self, "members", value)
 
     @builtins.property
     @jsii.member(jsii_name="recursive")
-    def recursive(self) -> typing.Union[builtins.bool, cdktf.IResolvable]:
-        return typing.cast(typing.Union[builtins.bool, cdktf.IResolvable], jsii.get(self, "recursive"))
+    def recursive(self) -> typing.Union[builtins.bool, _cdktf_9a9027ec.IResolvable]:
+        return typing.cast(typing.Union[builtins.bool, _cdktf_9a9027ec.IResolvable], jsii.get(self, "recursive"))
 
     @recursive.setter
-    def recursive(self, value: typing.Union[builtins.bool, cdktf.IResolvable]) -> None:
+    def recursive(
+        self,
+        value: typing.Union[builtins.bool, _cdktf_9a9027ec.IResolvable],
+    ) -> None:
         if __debug__:
-            type_hints = typing.get_type_hints(getattr(DataDatabricksGroup, "recursive").fset)
+            type_hints = typing.get_type_hints(_typecheckingstub__d40eb7d1161f86b134bba86c637e6c4e6b4b1e4bdce56d5fb18718bf5fbc222c)
             check_type(argname="argument value", value=value, expected_type=type_hints["value"])
         jsii.set(self, "recursive", value)
 
@@ -403,7 +410,7 @@ class DataDatabricksGroup(
     @service_principals.setter
     def service_principals(self, value: typing.List[builtins.str]) -> None:
         if __debug__:
-            type_hints = typing.get_type_hints(getattr(DataDatabricksGroup, "service_principals").fset)
+            type_hints = typing.get_type_hints(_typecheckingstub__26ebdf1e622220a4694208865f8ad2a635573740b82ffd0179cc13ba7f90f91f)
             check_type(argname="argument value", value=value, expected_type=type_hints["value"])
         jsii.set(self, "servicePrincipals", value)
 
@@ -415,29 +422,31 @@ class DataDatabricksGroup(
     @users.setter
     def users(self, value: typing.List[builtins.str]) -> None:
         if __debug__:
-            type_hints = typing.get_type_hints(getattr(DataDatabricksGroup, "users").fset)
+            type_hints = typing.get_type_hints(_typecheckingstub__b92f2d82d1abe140016af3bc9d2bcb5ce79f3b3839e457d2e9104dde5518d79a)
             check_type(argname="argument value", value=value, expected_type=type_hints["value"])
         jsii.set(self, "users", value)
 
     @builtins.property
     @jsii.member(jsii_name="workspaceAccess")
-    def workspace_access(self) -> typing.Union[builtins.bool, cdktf.IResolvable]:
-        return typing.cast(typing.Union[builtins.bool, cdktf.IResolvable], jsii.get(self, "workspaceAccess"))
+    def workspace_access(
+        self,
+    ) -> typing.Union[builtins.bool, _cdktf_9a9027ec.IResolvable]:
+        return typing.cast(typing.Union[builtins.bool, _cdktf_9a9027ec.IResolvable], jsii.get(self, "workspaceAccess"))
 
     @workspace_access.setter
     def workspace_access(
         self,
-        value: typing.Union[builtins.bool, cdktf.IResolvable],
+        value: typing.Union[builtins.bool, _cdktf_9a9027ec.IResolvable],
     ) -> None:
         if __debug__:
-            type_hints = typing.get_type_hints(getattr(DataDatabricksGroup, "workspace_access").fset)
+            type_hints = typing.get_type_hints(_typecheckingstub__aba28d84e00e0004baa6304a943f9676fee1f47b77e2e9a9d03c5a941027a1c9)
             check_type(argname="argument value", value=value, expected_type=type_hints["value"])
         jsii.set(self, "workspaceAccess", value)
 
 
 @jsii.data_type(
     jsii_type="@cdktf/provider-databricks.dataDatabricksGroup.DataDatabricksGroupConfig",
-    jsii_struct_bases=[cdktf.TerraformMetaArguments],
+    jsii_struct_bases=[_cdktf_9a9027ec.TerraformMetaArguments],
     name_mapping={
         "connection": "connection",
         "count": "count",
@@ -462,31 +471,31 @@ class DataDatabricksGroup(
         "workspace_access": "workspaceAccess",
     },
 )
-class DataDatabricksGroupConfig(cdktf.TerraformMetaArguments):
+class DataDatabricksGroupConfig(_cdktf_9a9027ec.TerraformMetaArguments):
     def __init__(
         self,
         *,
-        connection: typing.Optional[typing.Union[typing.Union[cdktf.SSHProvisionerConnection, typing.Dict[str, typing.Any]], typing.Union[cdktf.WinrmProvisionerConnection, typing.Dict[str, typing.Any]]]] = None,
+        connection: typing.Optional[typing.Union[typing.Union[_cdktf_9a9027ec.SSHProvisionerConnection, typing.Dict[builtins.str, typing.Any]], typing.Union[_cdktf_9a9027ec.WinrmProvisionerConnection, typing.Dict[builtins.str, typing.Any]]]] = None,
         count: typing.Optional[jsii.Number] = None,
-        depends_on: typing.Optional[typing.Sequence[cdktf.ITerraformDependable]] = None,
-        for_each: typing.Optional[cdktf.ITerraformIterator] = None,
-        lifecycle: typing.Optional[typing.Union[cdktf.TerraformResourceLifecycle, typing.Dict[str, typing.Any]]] = None,
-        provider: typing.Optional[cdktf.TerraformProvider] = None,
-        provisioners: typing.Optional[typing.Sequence[typing.Union[typing.Union[cdktf.FileProvisioner, typing.Dict[str, typing.Any]], typing.Union[cdktf.LocalExecProvisioner, typing.Dict[str, typing.Any]], typing.Union[cdktf.RemoteExecProvisioner, typing.Dict[str, typing.Any]]]]] = None,
+        depends_on: typing.Optional[typing.Sequence[_cdktf_9a9027ec.ITerraformDependable]] = None,
+        for_each: typing.Optional[_cdktf_9a9027ec.ITerraformIterator] = None,
+        lifecycle: typing.Optional[typing.Union[_cdktf_9a9027ec.TerraformResourceLifecycle, typing.Dict[builtins.str, typing.Any]]] = None,
+        provider: typing.Optional[_cdktf_9a9027ec.TerraformProvider] = None,
+        provisioners: typing.Optional[typing.Sequence[typing.Union[typing.Union[_cdktf_9a9027ec.FileProvisioner, typing.Dict[builtins.str, typing.Any]], typing.Union[_cdktf_9a9027ec.LocalExecProvisioner, typing.Dict[builtins.str, typing.Any]], typing.Union[_cdktf_9a9027ec.RemoteExecProvisioner, typing.Dict[builtins.str, typing.Any]]]]] = None,
         display_name: builtins.str,
-        allow_cluster_create: typing.Optional[typing.Union[builtins.bool, cdktf.IResolvable]] = None,
-        allow_instance_pool_create: typing.Optional[typing.Union[builtins.bool, cdktf.IResolvable]] = None,
+        allow_cluster_create: typing.Optional[typing.Union[builtins.bool, _cdktf_9a9027ec.IResolvable]] = None,
+        allow_instance_pool_create: typing.Optional[typing.Union[builtins.bool, _cdktf_9a9027ec.IResolvable]] = None,
         child_groups: typing.Optional[typing.Sequence[builtins.str]] = None,
-        databricks_sql_access: typing.Optional[typing.Union[builtins.bool, cdktf.IResolvable]] = None,
+        databricks_sql_access: typing.Optional[typing.Union[builtins.bool, _cdktf_9a9027ec.IResolvable]] = None,
         external_id: typing.Optional[builtins.str] = None,
         groups: typing.Optional[typing.Sequence[builtins.str]] = None,
         id: typing.Optional[builtins.str] = None,
         instance_profiles: typing.Optional[typing.Sequence[builtins.str]] = None,
         members: typing.Optional[typing.Sequence[builtins.str]] = None,
-        recursive: typing.Optional[typing.Union[builtins.bool, cdktf.IResolvable]] = None,
+        recursive: typing.Optional[typing.Union[builtins.bool, _cdktf_9a9027ec.IResolvable]] = None,
         service_principals: typing.Optional[typing.Sequence[builtins.str]] = None,
         users: typing.Optional[typing.Sequence[builtins.str]] = None,
-        workspace_access: typing.Optional[typing.Union[builtins.bool, cdktf.IResolvable]] = None,
+        workspace_access: typing.Optional[typing.Union[builtins.bool, _cdktf_9a9027ec.IResolvable]] = None,
     ) -> None:
         '''
         :param connection: 
@@ -512,9 +521,9 @@ class DataDatabricksGroupConfig(cdktf.TerraformMetaArguments):
         :param workspace_access: Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/databricks/d/group#workspace_access DataDatabricksGroup#workspace_access}.
         '''
         if isinstance(lifecycle, dict):
-            lifecycle = cdktf.TerraformResourceLifecycle(**lifecycle)
+            lifecycle = _cdktf_9a9027ec.TerraformResourceLifecycle(**lifecycle)
         if __debug__:
-            type_hints = typing.get_type_hints(DataDatabricksGroupConfig.__init__)
+            type_hints = typing.get_type_hints(_typecheckingstub__4aa1be14635d5d509e23297f1b0b99b0976749dedd1367f16987e2bc77333232)
             check_type(argname="argument connection", value=connection, expected_type=type_hints["connection"])
             check_type(argname="argument count", value=count, expected_type=type_hints["count"])
             check_type(argname="argument depends_on", value=depends_on, expected_type=type_hints["depends_on"])
@@ -536,7 +545,7 @@ class DataDatabricksGroupConfig(cdktf.TerraformMetaArguments):
             check_type(argname="argument service_principals", value=service_principals, expected_type=type_hints["service_principals"])
             check_type(argname="argument users", value=users, expected_type=type_hints["users"])
             check_type(argname="argument workspace_access", value=workspace_access, expected_type=type_hints["workspace_access"])
-        self._values: typing.Dict[str, typing.Any] = {
+        self._values: typing.Dict[builtins.str, typing.Any] = {
             "display_name": display_name,
         }
         if connection is not None:
@@ -583,12 +592,12 @@ class DataDatabricksGroupConfig(cdktf.TerraformMetaArguments):
     @builtins.property
     def connection(
         self,
-    ) -> typing.Optional[typing.Union[cdktf.SSHProvisionerConnection, cdktf.WinrmProvisionerConnection]]:
+    ) -> typing.Optional[typing.Union[_cdktf_9a9027ec.SSHProvisionerConnection, _cdktf_9a9027ec.WinrmProvisionerConnection]]:
         '''
         :stability: experimental
         '''
         result = self._values.get("connection")
-        return typing.cast(typing.Optional[typing.Union[cdktf.SSHProvisionerConnection, cdktf.WinrmProvisionerConnection]], result)
+        return typing.cast(typing.Optional[typing.Union[_cdktf_9a9027ec.SSHProvisionerConnection, _cdktf_9a9027ec.WinrmProvisionerConnection]], result)
 
     @builtins.property
     def count(self) -> typing.Optional[jsii.Number]:
@@ -599,46 +608,48 @@ class DataDatabricksGroupConfig(cdktf.TerraformMetaArguments):
         return typing.cast(typing.Optional[jsii.Number], result)
 
     @builtins.property
-    def depends_on(self) -> typing.Optional[typing.List[cdktf.ITerraformDependable]]:
+    def depends_on(
+        self,
+    ) -> typing.Optional[typing.List[_cdktf_9a9027ec.ITerraformDependable]]:
         '''
         :stability: experimental
         '''
         result = self._values.get("depends_on")
-        return typing.cast(typing.Optional[typing.List[cdktf.ITerraformDependable]], result)
+        return typing.cast(typing.Optional[typing.List[_cdktf_9a9027ec.ITerraformDependable]], result)
 
     @builtins.property
-    def for_each(self) -> typing.Optional[cdktf.ITerraformIterator]:
+    def for_each(self) -> typing.Optional[_cdktf_9a9027ec.ITerraformIterator]:
         '''
         :stability: experimental
         '''
         result = self._values.get("for_each")
-        return typing.cast(typing.Optional[cdktf.ITerraformIterator], result)
+        return typing.cast(typing.Optional[_cdktf_9a9027ec.ITerraformIterator], result)
 
     @builtins.property
-    def lifecycle(self) -> typing.Optional[cdktf.TerraformResourceLifecycle]:
+    def lifecycle(self) -> typing.Optional[_cdktf_9a9027ec.TerraformResourceLifecycle]:
         '''
         :stability: experimental
         '''
         result = self._values.get("lifecycle")
-        return typing.cast(typing.Optional[cdktf.TerraformResourceLifecycle], result)
+        return typing.cast(typing.Optional[_cdktf_9a9027ec.TerraformResourceLifecycle], result)
 
     @builtins.property
-    def provider(self) -> typing.Optional[cdktf.TerraformProvider]:
+    def provider(self) -> typing.Optional[_cdktf_9a9027ec.TerraformProvider]:
         '''
         :stability: experimental
         '''
         result = self._values.get("provider")
-        return typing.cast(typing.Optional[cdktf.TerraformProvider], result)
+        return typing.cast(typing.Optional[_cdktf_9a9027ec.TerraformProvider], result)
 
     @builtins.property
     def provisioners(
         self,
-    ) -> typing.Optional[typing.List[typing.Union[cdktf.FileProvisioner, cdktf.LocalExecProvisioner, cdktf.RemoteExecProvisioner]]]:
+    ) -> typing.Optional[typing.List[typing.Union[_cdktf_9a9027ec.FileProvisioner, _cdktf_9a9027ec.LocalExecProvisioner, _cdktf_9a9027ec.RemoteExecProvisioner]]]:
         '''
         :stability: experimental
         '''
         result = self._values.get("provisioners")
-        return typing.cast(typing.Optional[typing.List[typing.Union[cdktf.FileProvisioner, cdktf.LocalExecProvisioner, cdktf.RemoteExecProvisioner]]], result)
+        return typing.cast(typing.Optional[typing.List[typing.Union[_cdktf_9a9027ec.FileProvisioner, _cdktf_9a9027ec.LocalExecProvisioner, _cdktf_9a9027ec.RemoteExecProvisioner]]], result)
 
     @builtins.property
     def display_name(self) -> builtins.str:
@@ -650,18 +661,18 @@ class DataDatabricksGroupConfig(cdktf.TerraformMetaArguments):
     @builtins.property
     def allow_cluster_create(
         self,
-    ) -> typing.Optional[typing.Union[builtins.bool, cdktf.IResolvable]]:
+    ) -> typing.Optional[typing.Union[builtins.bool, _cdktf_9a9027ec.IResolvable]]:
         '''Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/databricks/d/group#allow_cluster_create DataDatabricksGroup#allow_cluster_create}.'''
         result = self._values.get("allow_cluster_create")
-        return typing.cast(typing.Optional[typing.Union[builtins.bool, cdktf.IResolvable]], result)
+        return typing.cast(typing.Optional[typing.Union[builtins.bool, _cdktf_9a9027ec.IResolvable]], result)
 
     @builtins.property
     def allow_instance_pool_create(
         self,
-    ) -> typing.Optional[typing.Union[builtins.bool, cdktf.IResolvable]]:
+    ) -> typing.Optional[typing.Union[builtins.bool, _cdktf_9a9027ec.IResolvable]]:
         '''Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/databricks/d/group#allow_instance_pool_create DataDatabricksGroup#allow_instance_pool_create}.'''
         result = self._values.get("allow_instance_pool_create")
-        return typing.cast(typing.Optional[typing.Union[builtins.bool, cdktf.IResolvable]], result)
+        return typing.cast(typing.Optional[typing.Union[builtins.bool, _cdktf_9a9027ec.IResolvable]], result)
 
     @builtins.property
     def child_groups(self) -> typing.Optional[typing.List[builtins.str]]:
@@ -672,10 +683,10 @@ class DataDatabricksGroupConfig(cdktf.TerraformMetaArguments):
     @builtins.property
     def databricks_sql_access(
         self,
-    ) -> typing.Optional[typing.Union[builtins.bool, cdktf.IResolvable]]:
+    ) -> typing.Optional[typing.Union[builtins.bool, _cdktf_9a9027ec.IResolvable]]:
         '''Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/databricks/d/group#databricks_sql_access DataDatabricksGroup#databricks_sql_access}.'''
         result = self._values.get("databricks_sql_access")
-        return typing.cast(typing.Optional[typing.Union[builtins.bool, cdktf.IResolvable]], result)
+        return typing.cast(typing.Optional[typing.Union[builtins.bool, _cdktf_9a9027ec.IResolvable]], result)
 
     @builtins.property
     def external_id(self) -> typing.Optional[builtins.str]:
@@ -714,10 +725,10 @@ class DataDatabricksGroupConfig(cdktf.TerraformMetaArguments):
     @builtins.property
     def recursive(
         self,
-    ) -> typing.Optional[typing.Union[builtins.bool, cdktf.IResolvable]]:
+    ) -> typing.Optional[typing.Union[builtins.bool, _cdktf_9a9027ec.IResolvable]]:
         '''Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/databricks/d/group#recursive DataDatabricksGroup#recursive}.'''
         result = self._values.get("recursive")
-        return typing.cast(typing.Optional[typing.Union[builtins.bool, cdktf.IResolvable]], result)
+        return typing.cast(typing.Optional[typing.Union[builtins.bool, _cdktf_9a9027ec.IResolvable]], result)
 
     @builtins.property
     def service_principals(self) -> typing.Optional[typing.List[builtins.str]]:
@@ -734,10 +745,10 @@ class DataDatabricksGroupConfig(cdktf.TerraformMetaArguments):
     @builtins.property
     def workspace_access(
         self,
-    ) -> typing.Optional[typing.Union[builtins.bool, cdktf.IResolvable]]:
+    ) -> typing.Optional[typing.Union[builtins.bool, _cdktf_9a9027ec.IResolvable]]:
         '''Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/databricks/d/group#workspace_access DataDatabricksGroup#workspace_access}.'''
         result = self._values.get("workspace_access")
-        return typing.cast(typing.Optional[typing.Union[builtins.bool, cdktf.IResolvable]], result)
+        return typing.cast(typing.Optional[typing.Union[builtins.bool, _cdktf_9a9027ec.IResolvable]], result)
 
     def __eq__(self, rhs: typing.Any) -> builtins.bool:
         return isinstance(rhs, self.__class__) and rhs._values == self._values
@@ -757,3 +768,143 @@ __all__ = [
 ]
 
 publication.publish()
+
+def _typecheckingstub__b95100a949934e64884ec68eac4c9d5149860ad636e55fda46b8bd9c4c2f68d8(
+    scope: _constructs_77d1e7e8.Construct,
+    id_: builtins.str,
+    *,
+    display_name: builtins.str,
+    allow_cluster_create: typing.Optional[typing.Union[builtins.bool, _cdktf_9a9027ec.IResolvable]] = None,
+    allow_instance_pool_create: typing.Optional[typing.Union[builtins.bool, _cdktf_9a9027ec.IResolvable]] = None,
+    child_groups: typing.Optional[typing.Sequence[builtins.str]] = None,
+    databricks_sql_access: typing.Optional[typing.Union[builtins.bool, _cdktf_9a9027ec.IResolvable]] = None,
+    external_id: typing.Optional[builtins.str] = None,
+    groups: typing.Optional[typing.Sequence[builtins.str]] = None,
+    id: typing.Optional[builtins.str] = None,
+    instance_profiles: typing.Optional[typing.Sequence[builtins.str]] = None,
+    members: typing.Optional[typing.Sequence[builtins.str]] = None,
+    recursive: typing.Optional[typing.Union[builtins.bool, _cdktf_9a9027ec.IResolvable]] = None,
+    service_principals: typing.Optional[typing.Sequence[builtins.str]] = None,
+    users: typing.Optional[typing.Sequence[builtins.str]] = None,
+    workspace_access: typing.Optional[typing.Union[builtins.bool, _cdktf_9a9027ec.IResolvable]] = None,
+    connection: typing.Optional[typing.Union[typing.Union[_cdktf_9a9027ec.SSHProvisionerConnection, typing.Dict[builtins.str, typing.Any]], typing.Union[_cdktf_9a9027ec.WinrmProvisionerConnection, typing.Dict[builtins.str, typing.Any]]]] = None,
+    count: typing.Optional[jsii.Number] = None,
+    depends_on: typing.Optional[typing.Sequence[_cdktf_9a9027ec.ITerraformDependable]] = None,
+    for_each: typing.Optional[_cdktf_9a9027ec.ITerraformIterator] = None,
+    lifecycle: typing.Optional[typing.Union[_cdktf_9a9027ec.TerraformResourceLifecycle, typing.Dict[builtins.str, typing.Any]]] = None,
+    provider: typing.Optional[_cdktf_9a9027ec.TerraformProvider] = None,
+    provisioners: typing.Optional[typing.Sequence[typing.Union[typing.Union[_cdktf_9a9027ec.FileProvisioner, typing.Dict[builtins.str, typing.Any]], typing.Union[_cdktf_9a9027ec.LocalExecProvisioner, typing.Dict[builtins.str, typing.Any]], typing.Union[_cdktf_9a9027ec.RemoteExecProvisioner, typing.Dict[builtins.str, typing.Any]]]]] = None,
+) -> None:
+    """Type checking stubs"""
+    pass
+
+def _typecheckingstub__7e8277af0b47300b1ef748a7a82512431013e5f6283b9f3523768652e408ec8d(
+    value: typing.Union[builtins.bool, _cdktf_9a9027ec.IResolvable],
+) -> None:
+    """Type checking stubs"""
+    pass
+
+def _typecheckingstub__78c8e959496c61967a1fd92ce17cf3ef1803f06166b40519f4df1d462392cba0(
+    value: typing.Union[builtins.bool, _cdktf_9a9027ec.IResolvable],
+) -> None:
+    """Type checking stubs"""
+    pass
+
+def _typecheckingstub__4052c6bec703b3fb2658814a19fa8a6c161a943f9a0cfa1e451fb8ceff70a0a2(
+    value: typing.List[builtins.str],
+) -> None:
+    """Type checking stubs"""
+    pass
+
+def _typecheckingstub__bb2f0c5fb64f7952cfbce899c64bae167e0bf9478408f94165c3d4d5def75745(
+    value: typing.Union[builtins.bool, _cdktf_9a9027ec.IResolvable],
+) -> None:
+    """Type checking stubs"""
+    pass
+
+def _typecheckingstub__6f127edaffb7b058d7ab86e38662006b6e4f96654c522be2971f5f4dd0e7c1a9(
+    value: builtins.str,
+) -> None:
+    """Type checking stubs"""
+    pass
+
+def _typecheckingstub__5b32d417c06ef723e38334eb05cc06078bbb52a4e74d18b30459b0b5ee064103(
+    value: builtins.str,
+) -> None:
+    """Type checking stubs"""
+    pass
+
+def _typecheckingstub__6999e678f8de11a03846d048666f0e85a586553c4eb97d2fc784569c3ce8d624(
+    value: typing.List[builtins.str],
+) -> None:
+    """Type checking stubs"""
+    pass
+
+def _typecheckingstub__4405fb10c17e82b26af1fdade43b18687a9193226f32f2bf1b8ec3dadd209dd8(
+    value: builtins.str,
+) -> None:
+    """Type checking stubs"""
+    pass
+
+def _typecheckingstub__e3f0eb694fe900f193dc63b2f0a03daa17e34a90f38659002bc6a1a9e43d70f8(
+    value: typing.List[builtins.str],
+) -> None:
+    """Type checking stubs"""
+    pass
+
+def _typecheckingstub__a58ff5cd981c893fd910b98de3e264af6e3c2f0a76049ec2494a0b8f9d3ab2f2(
+    value: typing.List[builtins.str],
+) -> None:
+    """Type checking stubs"""
+    pass
+
+def _typecheckingstub__d40eb7d1161f86b134bba86c637e6c4e6b4b1e4bdce56d5fb18718bf5fbc222c(
+    value: typing.Union[builtins.bool, _cdktf_9a9027ec.IResolvable],
+) -> None:
+    """Type checking stubs"""
+    pass
+
+def _typecheckingstub__26ebdf1e622220a4694208865f8ad2a635573740b82ffd0179cc13ba7f90f91f(
+    value: typing.List[builtins.str],
+) -> None:
+    """Type checking stubs"""
+    pass
+
+def _typecheckingstub__b92f2d82d1abe140016af3bc9d2bcb5ce79f3b3839e457d2e9104dde5518d79a(
+    value: typing.List[builtins.str],
+) -> None:
+    """Type checking stubs"""
+    pass
+
+def _typecheckingstub__aba28d84e00e0004baa6304a943f9676fee1f47b77e2e9a9d03c5a941027a1c9(
+    value: typing.Union[builtins.bool, _cdktf_9a9027ec.IResolvable],
+) -> None:
+    """Type checking stubs"""
+    pass
+
+def _typecheckingstub__4aa1be14635d5d509e23297f1b0b99b0976749dedd1367f16987e2bc77333232(
+    *,
+    connection: typing.Optional[typing.Union[typing.Union[_cdktf_9a9027ec.SSHProvisionerConnection, typing.Dict[builtins.str, typing.Any]], typing.Union[_cdktf_9a9027ec.WinrmProvisionerConnection, typing.Dict[builtins.str, typing.Any]]]] = None,
+    count: typing.Optional[jsii.Number] = None,
+    depends_on: typing.Optional[typing.Sequence[_cdktf_9a9027ec.ITerraformDependable]] = None,
+    for_each: typing.Optional[_cdktf_9a9027ec.ITerraformIterator] = None,
+    lifecycle: typing.Optional[typing.Union[_cdktf_9a9027ec.TerraformResourceLifecycle, typing.Dict[builtins.str, typing.Any]]] = None,
+    provider: typing.Optional[_cdktf_9a9027ec.TerraformProvider] = None,
+    provisioners: typing.Optional[typing.Sequence[typing.Union[typing.Union[_cdktf_9a9027ec.FileProvisioner, typing.Dict[builtins.str, typing.Any]], typing.Union[_cdktf_9a9027ec.LocalExecProvisioner, typing.Dict[builtins.str, typing.Any]], typing.Union[_cdktf_9a9027ec.RemoteExecProvisioner, typing.Dict[builtins.str, typing.Any]]]]] = None,
+    display_name: builtins.str,
+    allow_cluster_create: typing.Optional[typing.Union[builtins.bool, _cdktf_9a9027ec.IResolvable]] = None,
+    allow_instance_pool_create: typing.Optional[typing.Union[builtins.bool, _cdktf_9a9027ec.IResolvable]] = None,
+    child_groups: typing.Optional[typing.Sequence[builtins.str]] = None,
+    databricks_sql_access: typing.Optional[typing.Union[builtins.bool, _cdktf_9a9027ec.IResolvable]] = None,
+    external_id: typing.Optional[builtins.str] = None,
+    groups: typing.Optional[typing.Sequence[builtins.str]] = None,
+    id: typing.Optional[builtins.str] = None,
+    instance_profiles: typing.Optional[typing.Sequence[builtins.str]] = None,
+    members: typing.Optional[typing.Sequence[builtins.str]] = None,
+    recursive: typing.Optional[typing.Union[builtins.bool, _cdktf_9a9027ec.IResolvable]] = None,
+    service_principals: typing.Optional[typing.Sequence[builtins.str]] = None,
+    users: typing.Optional[typing.Sequence[builtins.str]] = None,
+    workspace_access: typing.Optional[typing.Union[builtins.bool, _cdktf_9a9027ec.IResolvable]] = None,
+) -> None:
+    """Type checking stubs"""
+    pass
