@@ -17,12 +17,12 @@ from typeguard import check_type
 
 from .._jsii import *
 
-import cdktf
-import constructs
+import cdktf as _cdktf_9a9027ec
+import constructs as _constructs_77d1e7e8
 
 
 class DataDatabricksNotebookPaths(
-    cdktf.TerraformDataSource,
+    _cdktf_9a9027ec.TerraformDataSource,
     metaclass=jsii.JSIIMeta,
     jsii_type="@cdktf/provider-databricks.dataDatabricksNotebookPaths.DataDatabricksNotebookPaths",
 ):
@@ -30,19 +30,19 @@ class DataDatabricksNotebookPaths(
 
     def __init__(
         self,
-        scope: constructs.Construct,
+        scope: _constructs_77d1e7e8.Construct,
         id_: builtins.str,
         *,
         path: builtins.str,
-        recursive: typing.Union[builtins.bool, cdktf.IResolvable],
+        recursive: typing.Union[builtins.bool, _cdktf_9a9027ec.IResolvable],
         id: typing.Optional[builtins.str] = None,
-        connection: typing.Optional[typing.Union[typing.Union[cdktf.SSHProvisionerConnection, typing.Dict[str, typing.Any]], typing.Union[cdktf.WinrmProvisionerConnection, typing.Dict[str, typing.Any]]]] = None,
+        connection: typing.Optional[typing.Union[typing.Union[_cdktf_9a9027ec.SSHProvisionerConnection, typing.Dict[builtins.str, typing.Any]], typing.Union[_cdktf_9a9027ec.WinrmProvisionerConnection, typing.Dict[builtins.str, typing.Any]]]] = None,
         count: typing.Optional[jsii.Number] = None,
-        depends_on: typing.Optional[typing.Sequence[cdktf.ITerraformDependable]] = None,
-        for_each: typing.Optional[cdktf.ITerraformIterator] = None,
-        lifecycle: typing.Optional[typing.Union[cdktf.TerraformResourceLifecycle, typing.Dict[str, typing.Any]]] = None,
-        provider: typing.Optional[cdktf.TerraformProvider] = None,
-        provisioners: typing.Optional[typing.Sequence[typing.Union[typing.Union[cdktf.FileProvisioner, typing.Dict[str, typing.Any]], typing.Union[cdktf.LocalExecProvisioner, typing.Dict[str, typing.Any]], typing.Union[cdktf.RemoteExecProvisioner, typing.Dict[str, typing.Any]]]]] = None,
+        depends_on: typing.Optional[typing.Sequence[_cdktf_9a9027ec.ITerraformDependable]] = None,
+        for_each: typing.Optional[_cdktf_9a9027ec.ITerraformIterator] = None,
+        lifecycle: typing.Optional[typing.Union[_cdktf_9a9027ec.TerraformResourceLifecycle, typing.Dict[builtins.str, typing.Any]]] = None,
+        provider: typing.Optional[_cdktf_9a9027ec.TerraformProvider] = None,
+        provisioners: typing.Optional[typing.Sequence[typing.Union[typing.Union[_cdktf_9a9027ec.FileProvisioner, typing.Dict[builtins.str, typing.Any]], typing.Union[_cdktf_9a9027ec.LocalExecProvisioner, typing.Dict[builtins.str, typing.Any]], typing.Union[_cdktf_9a9027ec.RemoteExecProvisioner, typing.Dict[builtins.str, typing.Any]]]]] = None,
     ) -> None:
         '''Create a new {@link https://www.terraform.io/docs/providers/databricks/d/notebook_paths databricks_notebook_paths} Data Source.
 
@@ -60,7 +60,7 @@ class DataDatabricksNotebookPaths(
         :param provisioners: 
         '''
         if __debug__:
-            type_hints = typing.get_type_hints(DataDatabricksNotebookPaths.__init__)
+            type_hints = typing.get_type_hints(_typecheckingstub__7793b8c43803333b2e9af6a2da8935a777f875a2754bc1e8d00c1a67f78cd7e9)
             check_type(argname="argument scope", value=scope, expected_type=type_hints["scope"])
             check_type(argname="argument id_", value=id_, expected_type=type_hints["id_"])
         config = DataDatabricksNotebookPathsConfig(
@@ -110,8 +110,8 @@ class DataDatabricksNotebookPaths(
     @jsii.member(jsii_name="recursiveInput")
     def recursive_input(
         self,
-    ) -> typing.Optional[typing.Union[builtins.bool, cdktf.IResolvable]]:
-        return typing.cast(typing.Optional[typing.Union[builtins.bool, cdktf.IResolvable]], jsii.get(self, "recursiveInput"))
+    ) -> typing.Optional[typing.Union[builtins.bool, _cdktf_9a9027ec.IResolvable]]:
+        return typing.cast(typing.Optional[typing.Union[builtins.bool, _cdktf_9a9027ec.IResolvable]], jsii.get(self, "recursiveInput"))
 
     @builtins.property
     @jsii.member(jsii_name="id")
@@ -121,7 +121,7 @@ class DataDatabricksNotebookPaths(
     @id.setter
     def id(self, value: builtins.str) -> None:
         if __debug__:
-            type_hints = typing.get_type_hints(getattr(DataDatabricksNotebookPaths, "id").fset)
+            type_hints = typing.get_type_hints(_typecheckingstub__e0137d7e8221ef72b9f6a440571645f5c2f307647fd5bd37f07f56c374eb5efb)
             check_type(argname="argument value", value=value, expected_type=type_hints["value"])
         jsii.set(self, "id", value)
 
@@ -133,26 +133,29 @@ class DataDatabricksNotebookPaths(
     @path.setter
     def path(self, value: builtins.str) -> None:
         if __debug__:
-            type_hints = typing.get_type_hints(getattr(DataDatabricksNotebookPaths, "path").fset)
+            type_hints = typing.get_type_hints(_typecheckingstub__5c4a2e0888d95830e098b2c3f6cec118332d4ba2ee1c41d8eb1abca713dbb06f)
             check_type(argname="argument value", value=value, expected_type=type_hints["value"])
         jsii.set(self, "path", value)
 
     @builtins.property
     @jsii.member(jsii_name="recursive")
-    def recursive(self) -> typing.Union[builtins.bool, cdktf.IResolvable]:
-        return typing.cast(typing.Union[builtins.bool, cdktf.IResolvable], jsii.get(self, "recursive"))
+    def recursive(self) -> typing.Union[builtins.bool, _cdktf_9a9027ec.IResolvable]:
+        return typing.cast(typing.Union[builtins.bool, _cdktf_9a9027ec.IResolvable], jsii.get(self, "recursive"))
 
     @recursive.setter
-    def recursive(self, value: typing.Union[builtins.bool, cdktf.IResolvable]) -> None:
+    def recursive(
+        self,
+        value: typing.Union[builtins.bool, _cdktf_9a9027ec.IResolvable],
+    ) -> None:
         if __debug__:
-            type_hints = typing.get_type_hints(getattr(DataDatabricksNotebookPaths, "recursive").fset)
+            type_hints = typing.get_type_hints(_typecheckingstub__2ee1e9e51d331ff1b81fab74afb59c53bf7a71f0673b0daf04f0038b5e75989f)
             check_type(argname="argument value", value=value, expected_type=type_hints["value"])
         jsii.set(self, "recursive", value)
 
 
 @jsii.data_type(
     jsii_type="@cdktf/provider-databricks.dataDatabricksNotebookPaths.DataDatabricksNotebookPathsConfig",
-    jsii_struct_bases=[cdktf.TerraformMetaArguments],
+    jsii_struct_bases=[_cdktf_9a9027ec.TerraformMetaArguments],
     name_mapping={
         "connection": "connection",
         "count": "count",
@@ -166,19 +169,19 @@ class DataDatabricksNotebookPaths(
         "id": "id",
     },
 )
-class DataDatabricksNotebookPathsConfig(cdktf.TerraformMetaArguments):
+class DataDatabricksNotebookPathsConfig(_cdktf_9a9027ec.TerraformMetaArguments):
     def __init__(
         self,
         *,
-        connection: typing.Optional[typing.Union[typing.Union[cdktf.SSHProvisionerConnection, typing.Dict[str, typing.Any]], typing.Union[cdktf.WinrmProvisionerConnection, typing.Dict[str, typing.Any]]]] = None,
+        connection: typing.Optional[typing.Union[typing.Union[_cdktf_9a9027ec.SSHProvisionerConnection, typing.Dict[builtins.str, typing.Any]], typing.Union[_cdktf_9a9027ec.WinrmProvisionerConnection, typing.Dict[builtins.str, typing.Any]]]] = None,
         count: typing.Optional[jsii.Number] = None,
-        depends_on: typing.Optional[typing.Sequence[cdktf.ITerraformDependable]] = None,
-        for_each: typing.Optional[cdktf.ITerraformIterator] = None,
-        lifecycle: typing.Optional[typing.Union[cdktf.TerraformResourceLifecycle, typing.Dict[str, typing.Any]]] = None,
-        provider: typing.Optional[cdktf.TerraformProvider] = None,
-        provisioners: typing.Optional[typing.Sequence[typing.Union[typing.Union[cdktf.FileProvisioner, typing.Dict[str, typing.Any]], typing.Union[cdktf.LocalExecProvisioner, typing.Dict[str, typing.Any]], typing.Union[cdktf.RemoteExecProvisioner, typing.Dict[str, typing.Any]]]]] = None,
+        depends_on: typing.Optional[typing.Sequence[_cdktf_9a9027ec.ITerraformDependable]] = None,
+        for_each: typing.Optional[_cdktf_9a9027ec.ITerraformIterator] = None,
+        lifecycle: typing.Optional[typing.Union[_cdktf_9a9027ec.TerraformResourceLifecycle, typing.Dict[builtins.str, typing.Any]]] = None,
+        provider: typing.Optional[_cdktf_9a9027ec.TerraformProvider] = None,
+        provisioners: typing.Optional[typing.Sequence[typing.Union[typing.Union[_cdktf_9a9027ec.FileProvisioner, typing.Dict[builtins.str, typing.Any]], typing.Union[_cdktf_9a9027ec.LocalExecProvisioner, typing.Dict[builtins.str, typing.Any]], typing.Union[_cdktf_9a9027ec.RemoteExecProvisioner, typing.Dict[builtins.str, typing.Any]]]]] = None,
         path: builtins.str,
-        recursive: typing.Union[builtins.bool, cdktf.IResolvable],
+        recursive: typing.Union[builtins.bool, _cdktf_9a9027ec.IResolvable],
         id: typing.Optional[builtins.str] = None,
     ) -> None:
         '''
@@ -194,9 +197,9 @@ class DataDatabricksNotebookPathsConfig(cdktf.TerraformMetaArguments):
         :param id: Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/databricks/d/notebook_paths#id DataDatabricksNotebookPaths#id}. Please be aware that the id field is automatically added to all resources in Terraform providers using a Terraform provider SDK version below 2. If you experience problems setting this value it might not be settable. Please take a look at the provider documentation to ensure it should be settable.
         '''
         if isinstance(lifecycle, dict):
-            lifecycle = cdktf.TerraformResourceLifecycle(**lifecycle)
+            lifecycle = _cdktf_9a9027ec.TerraformResourceLifecycle(**lifecycle)
         if __debug__:
-            type_hints = typing.get_type_hints(DataDatabricksNotebookPathsConfig.__init__)
+            type_hints = typing.get_type_hints(_typecheckingstub__e31b3b33a94510e57ddbfc157fc63c1151bcef106f3f8464a70048772b3dda48)
             check_type(argname="argument connection", value=connection, expected_type=type_hints["connection"])
             check_type(argname="argument count", value=count, expected_type=type_hints["count"])
             check_type(argname="argument depends_on", value=depends_on, expected_type=type_hints["depends_on"])
@@ -207,7 +210,7 @@ class DataDatabricksNotebookPathsConfig(cdktf.TerraformMetaArguments):
             check_type(argname="argument path", value=path, expected_type=type_hints["path"])
             check_type(argname="argument recursive", value=recursive, expected_type=type_hints["recursive"])
             check_type(argname="argument id", value=id, expected_type=type_hints["id"])
-        self._values: typing.Dict[str, typing.Any] = {
+        self._values: typing.Dict[builtins.str, typing.Any] = {
             "path": path,
             "recursive": recursive,
         }
@@ -231,12 +234,12 @@ class DataDatabricksNotebookPathsConfig(cdktf.TerraformMetaArguments):
     @builtins.property
     def connection(
         self,
-    ) -> typing.Optional[typing.Union[cdktf.SSHProvisionerConnection, cdktf.WinrmProvisionerConnection]]:
+    ) -> typing.Optional[typing.Union[_cdktf_9a9027ec.SSHProvisionerConnection, _cdktf_9a9027ec.WinrmProvisionerConnection]]:
         '''
         :stability: experimental
         '''
         result = self._values.get("connection")
-        return typing.cast(typing.Optional[typing.Union[cdktf.SSHProvisionerConnection, cdktf.WinrmProvisionerConnection]], result)
+        return typing.cast(typing.Optional[typing.Union[_cdktf_9a9027ec.SSHProvisionerConnection, _cdktf_9a9027ec.WinrmProvisionerConnection]], result)
 
     @builtins.property
     def count(self) -> typing.Optional[jsii.Number]:
@@ -247,46 +250,48 @@ class DataDatabricksNotebookPathsConfig(cdktf.TerraformMetaArguments):
         return typing.cast(typing.Optional[jsii.Number], result)
 
     @builtins.property
-    def depends_on(self) -> typing.Optional[typing.List[cdktf.ITerraformDependable]]:
+    def depends_on(
+        self,
+    ) -> typing.Optional[typing.List[_cdktf_9a9027ec.ITerraformDependable]]:
         '''
         :stability: experimental
         '''
         result = self._values.get("depends_on")
-        return typing.cast(typing.Optional[typing.List[cdktf.ITerraformDependable]], result)
+        return typing.cast(typing.Optional[typing.List[_cdktf_9a9027ec.ITerraformDependable]], result)
 
     @builtins.property
-    def for_each(self) -> typing.Optional[cdktf.ITerraformIterator]:
+    def for_each(self) -> typing.Optional[_cdktf_9a9027ec.ITerraformIterator]:
         '''
         :stability: experimental
         '''
         result = self._values.get("for_each")
-        return typing.cast(typing.Optional[cdktf.ITerraformIterator], result)
+        return typing.cast(typing.Optional[_cdktf_9a9027ec.ITerraformIterator], result)
 
     @builtins.property
-    def lifecycle(self) -> typing.Optional[cdktf.TerraformResourceLifecycle]:
+    def lifecycle(self) -> typing.Optional[_cdktf_9a9027ec.TerraformResourceLifecycle]:
         '''
         :stability: experimental
         '''
         result = self._values.get("lifecycle")
-        return typing.cast(typing.Optional[cdktf.TerraformResourceLifecycle], result)
+        return typing.cast(typing.Optional[_cdktf_9a9027ec.TerraformResourceLifecycle], result)
 
     @builtins.property
-    def provider(self) -> typing.Optional[cdktf.TerraformProvider]:
+    def provider(self) -> typing.Optional[_cdktf_9a9027ec.TerraformProvider]:
         '''
         :stability: experimental
         '''
         result = self._values.get("provider")
-        return typing.cast(typing.Optional[cdktf.TerraformProvider], result)
+        return typing.cast(typing.Optional[_cdktf_9a9027ec.TerraformProvider], result)
 
     @builtins.property
     def provisioners(
         self,
-    ) -> typing.Optional[typing.List[typing.Union[cdktf.FileProvisioner, cdktf.LocalExecProvisioner, cdktf.RemoteExecProvisioner]]]:
+    ) -> typing.Optional[typing.List[typing.Union[_cdktf_9a9027ec.FileProvisioner, _cdktf_9a9027ec.LocalExecProvisioner, _cdktf_9a9027ec.RemoteExecProvisioner]]]:
         '''
         :stability: experimental
         '''
         result = self._values.get("provisioners")
-        return typing.cast(typing.Optional[typing.List[typing.Union[cdktf.FileProvisioner, cdktf.LocalExecProvisioner, cdktf.RemoteExecProvisioner]]], result)
+        return typing.cast(typing.Optional[typing.List[typing.Union[_cdktf_9a9027ec.FileProvisioner, _cdktf_9a9027ec.LocalExecProvisioner, _cdktf_9a9027ec.RemoteExecProvisioner]]], result)
 
     @builtins.property
     def path(self) -> builtins.str:
@@ -296,11 +301,11 @@ class DataDatabricksNotebookPathsConfig(cdktf.TerraformMetaArguments):
         return typing.cast(builtins.str, result)
 
     @builtins.property
-    def recursive(self) -> typing.Union[builtins.bool, cdktf.IResolvable]:
+    def recursive(self) -> typing.Union[builtins.bool, _cdktf_9a9027ec.IResolvable]:
         '''Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/databricks/d/notebook_paths#recursive DataDatabricksNotebookPaths#recursive}.'''
         result = self._values.get("recursive")
         assert result is not None, "Required property 'recursive' is missing"
-        return typing.cast(typing.Union[builtins.bool, cdktf.IResolvable], result)
+        return typing.cast(typing.Union[builtins.bool, _cdktf_9a9027ec.IResolvable], result)
 
     @builtins.property
     def id(self) -> typing.Optional[builtins.str]:
@@ -331,7 +336,7 @@ class DataDatabricksNotebookPathsConfig(cdktf.TerraformMetaArguments):
 )
 class DataDatabricksNotebookPathsNotebookPathList:
     def __init__(self) -> None:
-        self._values: typing.Dict[str, typing.Any] = {}
+        self._values: typing.Dict[builtins.str, typing.Any] = {}
 
     def __eq__(self, rhs: typing.Any) -> builtins.bool:
         return isinstance(rhs, self.__class__) and rhs._values == self._values
@@ -346,13 +351,13 @@ class DataDatabricksNotebookPathsNotebookPathList:
 
 
 class DataDatabricksNotebookPathsNotebookPathListList(
-    cdktf.ComplexList,
+    _cdktf_9a9027ec.ComplexList,
     metaclass=jsii.JSIIMeta,
     jsii_type="@cdktf/provider-databricks.dataDatabricksNotebookPaths.DataDatabricksNotebookPathsNotebookPathListList",
 ):
     def __init__(
         self,
-        terraform_resource: cdktf.IInterpolatingParent,
+        terraform_resource: _cdktf_9a9027ec.IInterpolatingParent,
         terraform_attribute: builtins.str,
         wraps_set: builtins.bool,
     ) -> None:
@@ -362,7 +367,7 @@ class DataDatabricksNotebookPathsNotebookPathListList(
         :param wraps_set: whether the list is wrapping a set (will add tolist() to be able to access an item via an index).
         '''
         if __debug__:
-            type_hints = typing.get_type_hints(DataDatabricksNotebookPathsNotebookPathListList.__init__)
+            type_hints = typing.get_type_hints(_typecheckingstub__06b4ad130af3027668e27055473da95e25213246992760b84260622de7428e02)
             check_type(argname="argument terraform_resource", value=terraform_resource, expected_type=type_hints["terraform_resource"])
             check_type(argname="argument terraform_attribute", value=terraform_attribute, expected_type=type_hints["terraform_attribute"])
             check_type(argname="argument wraps_set", value=wraps_set, expected_type=type_hints["wraps_set"])
@@ -377,7 +382,7 @@ class DataDatabricksNotebookPathsNotebookPathListList(
         :param index: the index of the item to return.
         '''
         if __debug__:
-            type_hints = typing.get_type_hints(DataDatabricksNotebookPathsNotebookPathListList.get)
+            type_hints = typing.get_type_hints(_typecheckingstub__7433f0f7d70f30cd629fb06f35ff70304e83e67b19fc6d8c07e5502c533a3767)
             check_type(argname="argument index", value=index, expected_type=type_hints["index"])
         return typing.cast("DataDatabricksNotebookPathsNotebookPathListOutputReference", jsii.invoke(self, "get", [index]))
 
@@ -390,20 +395,20 @@ class DataDatabricksNotebookPathsNotebookPathListList(
     @_terraform_attribute.setter
     def _terraform_attribute(self, value: builtins.str) -> None:
         if __debug__:
-            type_hints = typing.get_type_hints(getattr(DataDatabricksNotebookPathsNotebookPathListList, "_terraform_attribute").fset)
+            type_hints = typing.get_type_hints(_typecheckingstub__5a7179fcf37e6e22ddf235aee84a17e31414198e181572cdb338922281a529ca)
             check_type(argname="argument value", value=value, expected_type=type_hints["value"])
         jsii.set(self, "terraformAttribute", value)
 
     @builtins.property
     @jsii.member(jsii_name="terraformResource")
-    def _terraform_resource(self) -> cdktf.IInterpolatingParent:
+    def _terraform_resource(self) -> _cdktf_9a9027ec.IInterpolatingParent:
         '''The parent resource.'''
-        return typing.cast(cdktf.IInterpolatingParent, jsii.get(self, "terraformResource"))
+        return typing.cast(_cdktf_9a9027ec.IInterpolatingParent, jsii.get(self, "terraformResource"))
 
     @_terraform_resource.setter
-    def _terraform_resource(self, value: cdktf.IInterpolatingParent) -> None:
+    def _terraform_resource(self, value: _cdktf_9a9027ec.IInterpolatingParent) -> None:
         if __debug__:
-            type_hints = typing.get_type_hints(getattr(DataDatabricksNotebookPathsNotebookPathListList, "_terraform_resource").fset)
+            type_hints = typing.get_type_hints(_typecheckingstub__e395d44210d80102e098562189163b4a45fcf05c1d2daf1917d4167a2db2278e)
             check_type(argname="argument value", value=value, expected_type=type_hints["value"])
         jsii.set(self, "terraformResource", value)
 
@@ -416,19 +421,19 @@ class DataDatabricksNotebookPathsNotebookPathListList(
     @_wraps_set.setter
     def _wraps_set(self, value: builtins.bool) -> None:
         if __debug__:
-            type_hints = typing.get_type_hints(getattr(DataDatabricksNotebookPathsNotebookPathListList, "_wraps_set").fset)
+            type_hints = typing.get_type_hints(_typecheckingstub__1d4d6630321c33fd64add6c4ab469ecf19ef53d782fa2352900e26c945da3bf7)
             check_type(argname="argument value", value=value, expected_type=type_hints["value"])
         jsii.set(self, "wrapsSet", value)
 
 
 class DataDatabricksNotebookPathsNotebookPathListOutputReference(
-    cdktf.ComplexObject,
+    _cdktf_9a9027ec.ComplexObject,
     metaclass=jsii.JSIIMeta,
     jsii_type="@cdktf/provider-databricks.dataDatabricksNotebookPaths.DataDatabricksNotebookPathsNotebookPathListOutputReference",
 ):
     def __init__(
         self,
-        terraform_resource: cdktf.IInterpolatingParent,
+        terraform_resource: _cdktf_9a9027ec.IInterpolatingParent,
         terraform_attribute: builtins.str,
         complex_object_index: jsii.Number,
         complex_object_is_from_set: builtins.bool,
@@ -440,7 +445,7 @@ class DataDatabricksNotebookPathsNotebookPathListOutputReference(
         :param complex_object_is_from_set: whether the list is wrapping a set (will add tolist() to be able to access an item via an index).
         '''
         if __debug__:
-            type_hints = typing.get_type_hints(DataDatabricksNotebookPathsNotebookPathListOutputReference.__init__)
+            type_hints = typing.get_type_hints(_typecheckingstub__46d1e893b5e721c976c042b08103a68f893c4a40d111d4b4676ff93a698a4404)
             check_type(argname="argument terraform_resource", value=terraform_resource, expected_type=type_hints["terraform_resource"])
             check_type(argname="argument terraform_attribute", value=terraform_attribute, expected_type=type_hints["terraform_attribute"])
             check_type(argname="argument complex_object_index", value=complex_object_index, expected_type=type_hints["complex_object_index"])
@@ -470,7 +475,7 @@ class DataDatabricksNotebookPathsNotebookPathListOutputReference(
         value: typing.Optional[DataDatabricksNotebookPathsNotebookPathList],
     ) -> None:
         if __debug__:
-            type_hints = typing.get_type_hints(getattr(DataDatabricksNotebookPathsNotebookPathListOutputReference, "internal_value").fset)
+            type_hints = typing.get_type_hints(_typecheckingstub__551497ab67de5211d5eca28ccdc42e634335952d391955e1351f9f47b2e3f2c3)
             check_type(argname="argument value", value=value, expected_type=type_hints["value"])
         jsii.set(self, "internalValue", value)
 
@@ -484,3 +489,102 @@ __all__ = [
 ]
 
 publication.publish()
+
+def _typecheckingstub__7793b8c43803333b2e9af6a2da8935a777f875a2754bc1e8d00c1a67f78cd7e9(
+    scope: _constructs_77d1e7e8.Construct,
+    id_: builtins.str,
+    *,
+    path: builtins.str,
+    recursive: typing.Union[builtins.bool, _cdktf_9a9027ec.IResolvable],
+    id: typing.Optional[builtins.str] = None,
+    connection: typing.Optional[typing.Union[typing.Union[_cdktf_9a9027ec.SSHProvisionerConnection, typing.Dict[builtins.str, typing.Any]], typing.Union[_cdktf_9a9027ec.WinrmProvisionerConnection, typing.Dict[builtins.str, typing.Any]]]] = None,
+    count: typing.Optional[jsii.Number] = None,
+    depends_on: typing.Optional[typing.Sequence[_cdktf_9a9027ec.ITerraformDependable]] = None,
+    for_each: typing.Optional[_cdktf_9a9027ec.ITerraformIterator] = None,
+    lifecycle: typing.Optional[typing.Union[_cdktf_9a9027ec.TerraformResourceLifecycle, typing.Dict[builtins.str, typing.Any]]] = None,
+    provider: typing.Optional[_cdktf_9a9027ec.TerraformProvider] = None,
+    provisioners: typing.Optional[typing.Sequence[typing.Union[typing.Union[_cdktf_9a9027ec.FileProvisioner, typing.Dict[builtins.str, typing.Any]], typing.Union[_cdktf_9a9027ec.LocalExecProvisioner, typing.Dict[builtins.str, typing.Any]], typing.Union[_cdktf_9a9027ec.RemoteExecProvisioner, typing.Dict[builtins.str, typing.Any]]]]] = None,
+) -> None:
+    """Type checking stubs"""
+    pass
+
+def _typecheckingstub__e0137d7e8221ef72b9f6a440571645f5c2f307647fd5bd37f07f56c374eb5efb(
+    value: builtins.str,
+) -> None:
+    """Type checking stubs"""
+    pass
+
+def _typecheckingstub__5c4a2e0888d95830e098b2c3f6cec118332d4ba2ee1c41d8eb1abca713dbb06f(
+    value: builtins.str,
+) -> None:
+    """Type checking stubs"""
+    pass
+
+def _typecheckingstub__2ee1e9e51d331ff1b81fab74afb59c53bf7a71f0673b0daf04f0038b5e75989f(
+    value: typing.Union[builtins.bool, _cdktf_9a9027ec.IResolvable],
+) -> None:
+    """Type checking stubs"""
+    pass
+
+def _typecheckingstub__e31b3b33a94510e57ddbfc157fc63c1151bcef106f3f8464a70048772b3dda48(
+    *,
+    connection: typing.Optional[typing.Union[typing.Union[_cdktf_9a9027ec.SSHProvisionerConnection, typing.Dict[builtins.str, typing.Any]], typing.Union[_cdktf_9a9027ec.WinrmProvisionerConnection, typing.Dict[builtins.str, typing.Any]]]] = None,
+    count: typing.Optional[jsii.Number] = None,
+    depends_on: typing.Optional[typing.Sequence[_cdktf_9a9027ec.ITerraformDependable]] = None,
+    for_each: typing.Optional[_cdktf_9a9027ec.ITerraformIterator] = None,
+    lifecycle: typing.Optional[typing.Union[_cdktf_9a9027ec.TerraformResourceLifecycle, typing.Dict[builtins.str, typing.Any]]] = None,
+    provider: typing.Optional[_cdktf_9a9027ec.TerraformProvider] = None,
+    provisioners: typing.Optional[typing.Sequence[typing.Union[typing.Union[_cdktf_9a9027ec.FileProvisioner, typing.Dict[builtins.str, typing.Any]], typing.Union[_cdktf_9a9027ec.LocalExecProvisioner, typing.Dict[builtins.str, typing.Any]], typing.Union[_cdktf_9a9027ec.RemoteExecProvisioner, typing.Dict[builtins.str, typing.Any]]]]] = None,
+    path: builtins.str,
+    recursive: typing.Union[builtins.bool, _cdktf_9a9027ec.IResolvable],
+    id: typing.Optional[builtins.str] = None,
+) -> None:
+    """Type checking stubs"""
+    pass
+
+def _typecheckingstub__06b4ad130af3027668e27055473da95e25213246992760b84260622de7428e02(
+    terraform_resource: _cdktf_9a9027ec.IInterpolatingParent,
+    terraform_attribute: builtins.str,
+    wraps_set: builtins.bool,
+) -> None:
+    """Type checking stubs"""
+    pass
+
+def _typecheckingstub__7433f0f7d70f30cd629fb06f35ff70304e83e67b19fc6d8c07e5502c533a3767(
+    index: jsii.Number,
+) -> None:
+    """Type checking stubs"""
+    pass
+
+def _typecheckingstub__5a7179fcf37e6e22ddf235aee84a17e31414198e181572cdb338922281a529ca(
+    value: builtins.str,
+) -> None:
+    """Type checking stubs"""
+    pass
+
+def _typecheckingstub__e395d44210d80102e098562189163b4a45fcf05c1d2daf1917d4167a2db2278e(
+    value: _cdktf_9a9027ec.IInterpolatingParent,
+) -> None:
+    """Type checking stubs"""
+    pass
+
+def _typecheckingstub__1d4d6630321c33fd64add6c4ab469ecf19ef53d782fa2352900e26c945da3bf7(
+    value: builtins.bool,
+) -> None:
+    """Type checking stubs"""
+    pass
+
+def _typecheckingstub__46d1e893b5e721c976c042b08103a68f893c4a40d111d4b4676ff93a698a4404(
+    terraform_resource: _cdktf_9a9027ec.IInterpolatingParent,
+    terraform_attribute: builtins.str,
+    complex_object_index: jsii.Number,
+    complex_object_is_from_set: builtins.bool,
+) -> None:
+    """Type checking stubs"""
+    pass
+
+def _typecheckingstub__551497ab67de5211d5eca28ccdc42e634335952d391955e1351f9f47b2e3f2c3(
+    value: typing.Optional[DataDatabricksNotebookPathsNotebookPathList],
+) -> None:
+    """Type checking stubs"""
+    pass
