@@ -17,12 +17,12 @@ from typeguard import check_type
 
 from .._jsii import *
 
-import cdktf
-import constructs
+import cdktf as _cdktf_9a9027ec
+import constructs as _constructs_77d1e7e8
 
 
 class Library(
-    cdktf.TerraformResource,
+    _cdktf_9a9027ec.TerraformResource,
     metaclass=jsii.JSIIMeta,
     jsii_type="@cdktf/provider-databricks.library.Library",
 ):
@@ -30,24 +30,24 @@ class Library(
 
     def __init__(
         self,
-        scope: constructs.Construct,
+        scope: _constructs_77d1e7e8.Construct,
         id_: builtins.str,
         *,
         cluster_id: builtins.str,
-        cran: typing.Optional[typing.Union["LibraryCran", typing.Dict[str, typing.Any]]] = None,
+        cran: typing.Optional[typing.Union["LibraryCran", typing.Dict[builtins.str, typing.Any]]] = None,
         egg: typing.Optional[builtins.str] = None,
         id: typing.Optional[builtins.str] = None,
         jar: typing.Optional[builtins.str] = None,
-        maven: typing.Optional[typing.Union["LibraryMaven", typing.Dict[str, typing.Any]]] = None,
-        pypi: typing.Optional[typing.Union["LibraryPypi", typing.Dict[str, typing.Any]]] = None,
+        maven: typing.Optional[typing.Union["LibraryMaven", typing.Dict[builtins.str, typing.Any]]] = None,
+        pypi: typing.Optional[typing.Union["LibraryPypi", typing.Dict[builtins.str, typing.Any]]] = None,
         whl: typing.Optional[builtins.str] = None,
-        connection: typing.Optional[typing.Union[typing.Union[cdktf.SSHProvisionerConnection, typing.Dict[str, typing.Any]], typing.Union[cdktf.WinrmProvisionerConnection, typing.Dict[str, typing.Any]]]] = None,
+        connection: typing.Optional[typing.Union[typing.Union[_cdktf_9a9027ec.SSHProvisionerConnection, typing.Dict[builtins.str, typing.Any]], typing.Union[_cdktf_9a9027ec.WinrmProvisionerConnection, typing.Dict[builtins.str, typing.Any]]]] = None,
         count: typing.Optional[jsii.Number] = None,
-        depends_on: typing.Optional[typing.Sequence[cdktf.ITerraformDependable]] = None,
-        for_each: typing.Optional[cdktf.ITerraformIterator] = None,
-        lifecycle: typing.Optional[typing.Union[cdktf.TerraformResourceLifecycle, typing.Dict[str, typing.Any]]] = None,
-        provider: typing.Optional[cdktf.TerraformProvider] = None,
-        provisioners: typing.Optional[typing.Sequence[typing.Union[typing.Union[cdktf.FileProvisioner, typing.Dict[str, typing.Any]], typing.Union[cdktf.LocalExecProvisioner, typing.Dict[str, typing.Any]], typing.Union[cdktf.RemoteExecProvisioner, typing.Dict[str, typing.Any]]]]] = None,
+        depends_on: typing.Optional[typing.Sequence[_cdktf_9a9027ec.ITerraformDependable]] = None,
+        for_each: typing.Optional[_cdktf_9a9027ec.ITerraformIterator] = None,
+        lifecycle: typing.Optional[typing.Union[_cdktf_9a9027ec.TerraformResourceLifecycle, typing.Dict[builtins.str, typing.Any]]] = None,
+        provider: typing.Optional[_cdktf_9a9027ec.TerraformProvider] = None,
+        provisioners: typing.Optional[typing.Sequence[typing.Union[typing.Union[_cdktf_9a9027ec.FileProvisioner, typing.Dict[builtins.str, typing.Any]], typing.Union[_cdktf_9a9027ec.LocalExecProvisioner, typing.Dict[builtins.str, typing.Any]], typing.Union[_cdktf_9a9027ec.RemoteExecProvisioner, typing.Dict[builtins.str, typing.Any]]]]] = None,
     ) -> None:
         '''Create a new {@link https://www.terraform.io/docs/providers/databricks/r/library databricks_library} Resource.
 
@@ -70,7 +70,7 @@ class Library(
         :param provisioners: 
         '''
         if __debug__:
-            type_hints = typing.get_type_hints(Library.__init__)
+            type_hints = typing.get_type_hints(_typecheckingstub__b36fb9c9579abdc533f4a84bf86540f0d0431b9409363235ee6714ce1b5fceb9)
             check_type(argname="argument scope", value=scope, expected_type=type_hints["scope"])
             check_type(argname="argument id_", value=id_, expected_type=type_hints["id_"])
         config = LibraryConfig(
@@ -240,7 +240,7 @@ class Library(
     @cluster_id.setter
     def cluster_id(self, value: builtins.str) -> None:
         if __debug__:
-            type_hints = typing.get_type_hints(getattr(Library, "cluster_id").fset)
+            type_hints = typing.get_type_hints(_typecheckingstub__280bcc59f3dbe171fb95de51b53efae4c9e64bc13027945ab6b08f7a369fee9f)
             check_type(argname="argument value", value=value, expected_type=type_hints["value"])
         jsii.set(self, "clusterId", value)
 
@@ -252,7 +252,7 @@ class Library(
     @egg.setter
     def egg(self, value: builtins.str) -> None:
         if __debug__:
-            type_hints = typing.get_type_hints(getattr(Library, "egg").fset)
+            type_hints = typing.get_type_hints(_typecheckingstub__99a6241909969cf0b4bc69f01ecdcdc7a85adf31a5ac9b0dd5758284ab001a29)
             check_type(argname="argument value", value=value, expected_type=type_hints["value"])
         jsii.set(self, "egg", value)
 
@@ -264,7 +264,7 @@ class Library(
     @id.setter
     def id(self, value: builtins.str) -> None:
         if __debug__:
-            type_hints = typing.get_type_hints(getattr(Library, "id").fset)
+            type_hints = typing.get_type_hints(_typecheckingstub__5f227b1298a0e3329c6dee68761df51da3e6d4f67489be78f15fb6a6440ca58a)
             check_type(argname="argument value", value=value, expected_type=type_hints["value"])
         jsii.set(self, "id", value)
 
@@ -276,7 +276,7 @@ class Library(
     @jar.setter
     def jar(self, value: builtins.str) -> None:
         if __debug__:
-            type_hints = typing.get_type_hints(getattr(Library, "jar").fset)
+            type_hints = typing.get_type_hints(_typecheckingstub__167e6040e68dc7d39bd70bc737a378d2f976aa6d4129cb9888378422c7e72d35)
             check_type(argname="argument value", value=value, expected_type=type_hints["value"])
         jsii.set(self, "jar", value)
 
@@ -288,14 +288,14 @@ class Library(
     @whl.setter
     def whl(self, value: builtins.str) -> None:
         if __debug__:
-            type_hints = typing.get_type_hints(getattr(Library, "whl").fset)
+            type_hints = typing.get_type_hints(_typecheckingstub__1c6bca28056c29c481a9cc356742f4db521c43cb96fc2355a05f7f9afdfa1843)
             check_type(argname="argument value", value=value, expected_type=type_hints["value"])
         jsii.set(self, "whl", value)
 
 
 @jsii.data_type(
     jsii_type="@cdktf/provider-databricks.library.LibraryConfig",
-    jsii_struct_bases=[cdktf.TerraformMetaArguments],
+    jsii_struct_bases=[_cdktf_9a9027ec.TerraformMetaArguments],
     name_mapping={
         "connection": "connection",
         "count": "count",
@@ -314,24 +314,24 @@ class Library(
         "whl": "whl",
     },
 )
-class LibraryConfig(cdktf.TerraformMetaArguments):
+class LibraryConfig(_cdktf_9a9027ec.TerraformMetaArguments):
     def __init__(
         self,
         *,
-        connection: typing.Optional[typing.Union[typing.Union[cdktf.SSHProvisionerConnection, typing.Dict[str, typing.Any]], typing.Union[cdktf.WinrmProvisionerConnection, typing.Dict[str, typing.Any]]]] = None,
+        connection: typing.Optional[typing.Union[typing.Union[_cdktf_9a9027ec.SSHProvisionerConnection, typing.Dict[builtins.str, typing.Any]], typing.Union[_cdktf_9a9027ec.WinrmProvisionerConnection, typing.Dict[builtins.str, typing.Any]]]] = None,
         count: typing.Optional[jsii.Number] = None,
-        depends_on: typing.Optional[typing.Sequence[cdktf.ITerraformDependable]] = None,
-        for_each: typing.Optional[cdktf.ITerraformIterator] = None,
-        lifecycle: typing.Optional[typing.Union[cdktf.TerraformResourceLifecycle, typing.Dict[str, typing.Any]]] = None,
-        provider: typing.Optional[cdktf.TerraformProvider] = None,
-        provisioners: typing.Optional[typing.Sequence[typing.Union[typing.Union[cdktf.FileProvisioner, typing.Dict[str, typing.Any]], typing.Union[cdktf.LocalExecProvisioner, typing.Dict[str, typing.Any]], typing.Union[cdktf.RemoteExecProvisioner, typing.Dict[str, typing.Any]]]]] = None,
+        depends_on: typing.Optional[typing.Sequence[_cdktf_9a9027ec.ITerraformDependable]] = None,
+        for_each: typing.Optional[_cdktf_9a9027ec.ITerraformIterator] = None,
+        lifecycle: typing.Optional[typing.Union[_cdktf_9a9027ec.TerraformResourceLifecycle, typing.Dict[builtins.str, typing.Any]]] = None,
+        provider: typing.Optional[_cdktf_9a9027ec.TerraformProvider] = None,
+        provisioners: typing.Optional[typing.Sequence[typing.Union[typing.Union[_cdktf_9a9027ec.FileProvisioner, typing.Dict[builtins.str, typing.Any]], typing.Union[_cdktf_9a9027ec.LocalExecProvisioner, typing.Dict[builtins.str, typing.Any]], typing.Union[_cdktf_9a9027ec.RemoteExecProvisioner, typing.Dict[builtins.str, typing.Any]]]]] = None,
         cluster_id: builtins.str,
-        cran: typing.Optional[typing.Union["LibraryCran", typing.Dict[str, typing.Any]]] = None,
+        cran: typing.Optional[typing.Union["LibraryCran", typing.Dict[builtins.str, typing.Any]]] = None,
         egg: typing.Optional[builtins.str] = None,
         id: typing.Optional[builtins.str] = None,
         jar: typing.Optional[builtins.str] = None,
-        maven: typing.Optional[typing.Union["LibraryMaven", typing.Dict[str, typing.Any]]] = None,
-        pypi: typing.Optional[typing.Union["LibraryPypi", typing.Dict[str, typing.Any]]] = None,
+        maven: typing.Optional[typing.Union["LibraryMaven", typing.Dict[builtins.str, typing.Any]]] = None,
+        pypi: typing.Optional[typing.Union["LibraryPypi", typing.Dict[builtins.str, typing.Any]]] = None,
         whl: typing.Optional[builtins.str] = None,
     ) -> None:
         '''
@@ -352,7 +352,7 @@ class LibraryConfig(cdktf.TerraformMetaArguments):
         :param whl: Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/databricks/r/library#whl Library#whl}.
         '''
         if isinstance(lifecycle, dict):
-            lifecycle = cdktf.TerraformResourceLifecycle(**lifecycle)
+            lifecycle = _cdktf_9a9027ec.TerraformResourceLifecycle(**lifecycle)
         if isinstance(cran, dict):
             cran = LibraryCran(**cran)
         if isinstance(maven, dict):
@@ -360,7 +360,7 @@ class LibraryConfig(cdktf.TerraformMetaArguments):
         if isinstance(pypi, dict):
             pypi = LibraryPypi(**pypi)
         if __debug__:
-            type_hints = typing.get_type_hints(LibraryConfig.__init__)
+            type_hints = typing.get_type_hints(_typecheckingstub__9efc2bcefbff8944ab39e1065e37bf3145d9fd46cad7156cb2b2b5fd6d11f5ea)
             check_type(argname="argument connection", value=connection, expected_type=type_hints["connection"])
             check_type(argname="argument count", value=count, expected_type=type_hints["count"])
             check_type(argname="argument depends_on", value=depends_on, expected_type=type_hints["depends_on"])
@@ -376,7 +376,7 @@ class LibraryConfig(cdktf.TerraformMetaArguments):
             check_type(argname="argument maven", value=maven, expected_type=type_hints["maven"])
             check_type(argname="argument pypi", value=pypi, expected_type=type_hints["pypi"])
             check_type(argname="argument whl", value=whl, expected_type=type_hints["whl"])
-        self._values: typing.Dict[str, typing.Any] = {
+        self._values: typing.Dict[builtins.str, typing.Any] = {
             "cluster_id": cluster_id,
         }
         if connection is not None:
@@ -411,12 +411,12 @@ class LibraryConfig(cdktf.TerraformMetaArguments):
     @builtins.property
     def connection(
         self,
-    ) -> typing.Optional[typing.Union[cdktf.SSHProvisionerConnection, cdktf.WinrmProvisionerConnection]]:
+    ) -> typing.Optional[typing.Union[_cdktf_9a9027ec.SSHProvisionerConnection, _cdktf_9a9027ec.WinrmProvisionerConnection]]:
         '''
         :stability: experimental
         '''
         result = self._values.get("connection")
-        return typing.cast(typing.Optional[typing.Union[cdktf.SSHProvisionerConnection, cdktf.WinrmProvisionerConnection]], result)
+        return typing.cast(typing.Optional[typing.Union[_cdktf_9a9027ec.SSHProvisionerConnection, _cdktf_9a9027ec.WinrmProvisionerConnection]], result)
 
     @builtins.property
     def count(self) -> typing.Optional[jsii.Number]:
@@ -427,46 +427,48 @@ class LibraryConfig(cdktf.TerraformMetaArguments):
         return typing.cast(typing.Optional[jsii.Number], result)
 
     @builtins.property
-    def depends_on(self) -> typing.Optional[typing.List[cdktf.ITerraformDependable]]:
+    def depends_on(
+        self,
+    ) -> typing.Optional[typing.List[_cdktf_9a9027ec.ITerraformDependable]]:
         '''
         :stability: experimental
         '''
         result = self._values.get("depends_on")
-        return typing.cast(typing.Optional[typing.List[cdktf.ITerraformDependable]], result)
+        return typing.cast(typing.Optional[typing.List[_cdktf_9a9027ec.ITerraformDependable]], result)
 
     @builtins.property
-    def for_each(self) -> typing.Optional[cdktf.ITerraformIterator]:
+    def for_each(self) -> typing.Optional[_cdktf_9a9027ec.ITerraformIterator]:
         '''
         :stability: experimental
         '''
         result = self._values.get("for_each")
-        return typing.cast(typing.Optional[cdktf.ITerraformIterator], result)
+        return typing.cast(typing.Optional[_cdktf_9a9027ec.ITerraformIterator], result)
 
     @builtins.property
-    def lifecycle(self) -> typing.Optional[cdktf.TerraformResourceLifecycle]:
+    def lifecycle(self) -> typing.Optional[_cdktf_9a9027ec.TerraformResourceLifecycle]:
         '''
         :stability: experimental
         '''
         result = self._values.get("lifecycle")
-        return typing.cast(typing.Optional[cdktf.TerraformResourceLifecycle], result)
+        return typing.cast(typing.Optional[_cdktf_9a9027ec.TerraformResourceLifecycle], result)
 
     @builtins.property
-    def provider(self) -> typing.Optional[cdktf.TerraformProvider]:
+    def provider(self) -> typing.Optional[_cdktf_9a9027ec.TerraformProvider]:
         '''
         :stability: experimental
         '''
         result = self._values.get("provider")
-        return typing.cast(typing.Optional[cdktf.TerraformProvider], result)
+        return typing.cast(typing.Optional[_cdktf_9a9027ec.TerraformProvider], result)
 
     @builtins.property
     def provisioners(
         self,
-    ) -> typing.Optional[typing.List[typing.Union[cdktf.FileProvisioner, cdktf.LocalExecProvisioner, cdktf.RemoteExecProvisioner]]]:
+    ) -> typing.Optional[typing.List[typing.Union[_cdktf_9a9027ec.FileProvisioner, _cdktf_9a9027ec.LocalExecProvisioner, _cdktf_9a9027ec.RemoteExecProvisioner]]]:
         '''
         :stability: experimental
         '''
         result = self._values.get("provisioners")
-        return typing.cast(typing.Optional[typing.List[typing.Union[cdktf.FileProvisioner, cdktf.LocalExecProvisioner, cdktf.RemoteExecProvisioner]]], result)
+        return typing.cast(typing.Optional[typing.List[typing.Union[_cdktf_9a9027ec.FileProvisioner, _cdktf_9a9027ec.LocalExecProvisioner, _cdktf_9a9027ec.RemoteExecProvisioner]]], result)
 
     @builtins.property
     def cluster_id(self) -> builtins.str:
@@ -559,10 +561,10 @@ class LibraryCran:
         :param repo: Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/databricks/r/library#repo Library#repo}.
         '''
         if __debug__:
-            type_hints = typing.get_type_hints(LibraryCran.__init__)
+            type_hints = typing.get_type_hints(_typecheckingstub__bb2dd88e49a7a2c492f8cc94d94e24fb8a57d6de2bec99abfc6efc948b54632d)
             check_type(argname="argument package", value=package, expected_type=type_hints["package"])
             check_type(argname="argument repo", value=repo, expected_type=type_hints["repo"])
-        self._values: typing.Dict[str, typing.Any] = {
+        self._values: typing.Dict[builtins.str, typing.Any] = {
             "package": package,
         }
         if repo is not None:
@@ -594,13 +596,13 @@ class LibraryCran:
 
 
 class LibraryCranOutputReference(
-    cdktf.ComplexObject,
+    _cdktf_9a9027ec.ComplexObject,
     metaclass=jsii.JSIIMeta,
     jsii_type="@cdktf/provider-databricks.library.LibraryCranOutputReference",
 ):
     def __init__(
         self,
-        terraform_resource: cdktf.IInterpolatingParent,
+        terraform_resource: _cdktf_9a9027ec.IInterpolatingParent,
         terraform_attribute: builtins.str,
     ) -> None:
         '''
@@ -608,7 +610,7 @@ class LibraryCranOutputReference(
         :param terraform_attribute: The attribute on the parent resource this class is referencing.
         '''
         if __debug__:
-            type_hints = typing.get_type_hints(LibraryCranOutputReference.__init__)
+            type_hints = typing.get_type_hints(_typecheckingstub__f7234e3e90d49897671123de17da06dbbdf36492d3cea35a506abc75c7e909cf)
             check_type(argname="argument terraform_resource", value=terraform_resource, expected_type=type_hints["terraform_resource"])
             check_type(argname="argument terraform_attribute", value=terraform_attribute, expected_type=type_hints["terraform_attribute"])
         jsii.create(self.__class__, self, [terraform_resource, terraform_attribute])
@@ -635,7 +637,7 @@ class LibraryCranOutputReference(
     @package.setter
     def package(self, value: builtins.str) -> None:
         if __debug__:
-            type_hints = typing.get_type_hints(getattr(LibraryCranOutputReference, "package").fset)
+            type_hints = typing.get_type_hints(_typecheckingstub__260d7c0a171dc53a069b5318107de740217030fd6593c65609dcacd81d9f79c4)
             check_type(argname="argument value", value=value, expected_type=type_hints["value"])
         jsii.set(self, "package", value)
 
@@ -647,7 +649,7 @@ class LibraryCranOutputReference(
     @repo.setter
     def repo(self, value: builtins.str) -> None:
         if __debug__:
-            type_hints = typing.get_type_hints(getattr(LibraryCranOutputReference, "repo").fset)
+            type_hints = typing.get_type_hints(_typecheckingstub__198498c92f007ac903cfe6e67bc14a515610781e46afa26c070a76f0c260a6bb)
             check_type(argname="argument value", value=value, expected_type=type_hints["value"])
         jsii.set(self, "repo", value)
 
@@ -659,7 +661,7 @@ class LibraryCranOutputReference(
     @internal_value.setter
     def internal_value(self, value: typing.Optional[LibraryCran]) -> None:
         if __debug__:
-            type_hints = typing.get_type_hints(getattr(LibraryCranOutputReference, "internal_value").fset)
+            type_hints = typing.get_type_hints(_typecheckingstub__6b9c96d5039c6b87936d77eb7a3058a1e841b5ec3363bfb27f649e3382ad620c)
             check_type(argname="argument value", value=value, expected_type=type_hints["value"])
         jsii.set(self, "internalValue", value)
 
@@ -687,11 +689,11 @@ class LibraryMaven:
         :param repo: Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/databricks/r/library#repo Library#repo}.
         '''
         if __debug__:
-            type_hints = typing.get_type_hints(LibraryMaven.__init__)
+            type_hints = typing.get_type_hints(_typecheckingstub__23bcf2170a1c50d6e580f56e86ab07eb1160e0ce5a5bf98719211a3904662494)
             check_type(argname="argument coordinates", value=coordinates, expected_type=type_hints["coordinates"])
             check_type(argname="argument exclusions", value=exclusions, expected_type=type_hints["exclusions"])
             check_type(argname="argument repo", value=repo, expected_type=type_hints["repo"])
-        self._values: typing.Dict[str, typing.Any] = {
+        self._values: typing.Dict[builtins.str, typing.Any] = {
             "coordinates": coordinates,
         }
         if exclusions is not None:
@@ -731,13 +733,13 @@ class LibraryMaven:
 
 
 class LibraryMavenOutputReference(
-    cdktf.ComplexObject,
+    _cdktf_9a9027ec.ComplexObject,
     metaclass=jsii.JSIIMeta,
     jsii_type="@cdktf/provider-databricks.library.LibraryMavenOutputReference",
 ):
     def __init__(
         self,
-        terraform_resource: cdktf.IInterpolatingParent,
+        terraform_resource: _cdktf_9a9027ec.IInterpolatingParent,
         terraform_attribute: builtins.str,
     ) -> None:
         '''
@@ -745,7 +747,7 @@ class LibraryMavenOutputReference(
         :param terraform_attribute: The attribute on the parent resource this class is referencing.
         '''
         if __debug__:
-            type_hints = typing.get_type_hints(LibraryMavenOutputReference.__init__)
+            type_hints = typing.get_type_hints(_typecheckingstub__7dc45815bd7f989be7f806896cbee7af930f15c90e523f4000816bd9a3233ac1)
             check_type(argname="argument terraform_resource", value=terraform_resource, expected_type=type_hints["terraform_resource"])
             check_type(argname="argument terraform_attribute", value=terraform_attribute, expected_type=type_hints["terraform_attribute"])
         jsii.create(self.__class__, self, [terraform_resource, terraform_attribute])
@@ -781,7 +783,7 @@ class LibraryMavenOutputReference(
     @coordinates.setter
     def coordinates(self, value: builtins.str) -> None:
         if __debug__:
-            type_hints = typing.get_type_hints(getattr(LibraryMavenOutputReference, "coordinates").fset)
+            type_hints = typing.get_type_hints(_typecheckingstub__ef07227e509242612d1cb955936a19459cb268c06f98877332de7cfa25cddbbf)
             check_type(argname="argument value", value=value, expected_type=type_hints["value"])
         jsii.set(self, "coordinates", value)
 
@@ -793,7 +795,7 @@ class LibraryMavenOutputReference(
     @exclusions.setter
     def exclusions(self, value: typing.List[builtins.str]) -> None:
         if __debug__:
-            type_hints = typing.get_type_hints(getattr(LibraryMavenOutputReference, "exclusions").fset)
+            type_hints = typing.get_type_hints(_typecheckingstub__dd246eebf3bb52105b2f72e32e2321b535dd02a359cd5f63061c3d09c564442b)
             check_type(argname="argument value", value=value, expected_type=type_hints["value"])
         jsii.set(self, "exclusions", value)
 
@@ -805,7 +807,7 @@ class LibraryMavenOutputReference(
     @repo.setter
     def repo(self, value: builtins.str) -> None:
         if __debug__:
-            type_hints = typing.get_type_hints(getattr(LibraryMavenOutputReference, "repo").fset)
+            type_hints = typing.get_type_hints(_typecheckingstub__8bd29551c744f7dd4f4ded9a9dfb6a81032fe376b9df2ffe77011a63161a72c0)
             check_type(argname="argument value", value=value, expected_type=type_hints["value"])
         jsii.set(self, "repo", value)
 
@@ -817,7 +819,7 @@ class LibraryMavenOutputReference(
     @internal_value.setter
     def internal_value(self, value: typing.Optional[LibraryMaven]) -> None:
         if __debug__:
-            type_hints = typing.get_type_hints(getattr(LibraryMavenOutputReference, "internal_value").fset)
+            type_hints = typing.get_type_hints(_typecheckingstub__680aeb82040d53a43ba576916564f67af43f88bae48aa7f2579d70c7d1694bb1)
             check_type(argname="argument value", value=value, expected_type=type_hints["value"])
         jsii.set(self, "internalValue", value)
 
@@ -839,10 +841,10 @@ class LibraryPypi:
         :param repo: Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/databricks/r/library#repo Library#repo}.
         '''
         if __debug__:
-            type_hints = typing.get_type_hints(LibraryPypi.__init__)
+            type_hints = typing.get_type_hints(_typecheckingstub__4fec956c21e375316999d843c18e2e8871e9ab370c33ddf753d5a322e088a3d0)
             check_type(argname="argument package", value=package, expected_type=type_hints["package"])
             check_type(argname="argument repo", value=repo, expected_type=type_hints["repo"])
-        self._values: typing.Dict[str, typing.Any] = {
+        self._values: typing.Dict[builtins.str, typing.Any] = {
             "package": package,
         }
         if repo is not None:
@@ -874,13 +876,13 @@ class LibraryPypi:
 
 
 class LibraryPypiOutputReference(
-    cdktf.ComplexObject,
+    _cdktf_9a9027ec.ComplexObject,
     metaclass=jsii.JSIIMeta,
     jsii_type="@cdktf/provider-databricks.library.LibraryPypiOutputReference",
 ):
     def __init__(
         self,
-        terraform_resource: cdktf.IInterpolatingParent,
+        terraform_resource: _cdktf_9a9027ec.IInterpolatingParent,
         terraform_attribute: builtins.str,
     ) -> None:
         '''
@@ -888,7 +890,7 @@ class LibraryPypiOutputReference(
         :param terraform_attribute: The attribute on the parent resource this class is referencing.
         '''
         if __debug__:
-            type_hints = typing.get_type_hints(LibraryPypiOutputReference.__init__)
+            type_hints = typing.get_type_hints(_typecheckingstub__39de0cbc90acb0b356f4db6f88ed89bbe9203b1bcd284fbcbcc4bdf75c0f4106)
             check_type(argname="argument terraform_resource", value=terraform_resource, expected_type=type_hints["terraform_resource"])
             check_type(argname="argument terraform_attribute", value=terraform_attribute, expected_type=type_hints["terraform_attribute"])
         jsii.create(self.__class__, self, [terraform_resource, terraform_attribute])
@@ -915,7 +917,7 @@ class LibraryPypiOutputReference(
     @package.setter
     def package(self, value: builtins.str) -> None:
         if __debug__:
-            type_hints = typing.get_type_hints(getattr(LibraryPypiOutputReference, "package").fset)
+            type_hints = typing.get_type_hints(_typecheckingstub__1b44201ce136a603c868a8e725c038c57b6d303d5de493795952610e61a35be1)
             check_type(argname="argument value", value=value, expected_type=type_hints["value"])
         jsii.set(self, "package", value)
 
@@ -927,7 +929,7 @@ class LibraryPypiOutputReference(
     @repo.setter
     def repo(self, value: builtins.str) -> None:
         if __debug__:
-            type_hints = typing.get_type_hints(getattr(LibraryPypiOutputReference, "repo").fset)
+            type_hints = typing.get_type_hints(_typecheckingstub__9e709ccc2a0a7cfe631d52950368e54b3740984aab299394a0fba99bb3f48489)
             check_type(argname="argument value", value=value, expected_type=type_hints["value"])
         jsii.set(self, "repo", value)
 
@@ -939,7 +941,7 @@ class LibraryPypiOutputReference(
     @internal_value.setter
     def internal_value(self, value: typing.Optional[LibraryPypi]) -> None:
         if __debug__:
-            type_hints = typing.get_type_hints(getattr(LibraryPypiOutputReference, "internal_value").fset)
+            type_hints = typing.get_type_hints(_typecheckingstub__fe8d0bdcfd9ce9b21f882b2105d7d014e2d9fa35198f000c1084c657300c5b24)
             check_type(argname="argument value", value=value, expected_type=type_hints["value"])
         jsii.set(self, "internalValue", value)
 
@@ -956,3 +958,183 @@ __all__ = [
 ]
 
 publication.publish()
+
+def _typecheckingstub__b36fb9c9579abdc533f4a84bf86540f0d0431b9409363235ee6714ce1b5fceb9(
+    scope: _constructs_77d1e7e8.Construct,
+    id_: builtins.str,
+    *,
+    cluster_id: builtins.str,
+    cran: typing.Optional[typing.Union[LibraryCran, typing.Dict[builtins.str, typing.Any]]] = None,
+    egg: typing.Optional[builtins.str] = None,
+    id: typing.Optional[builtins.str] = None,
+    jar: typing.Optional[builtins.str] = None,
+    maven: typing.Optional[typing.Union[LibraryMaven, typing.Dict[builtins.str, typing.Any]]] = None,
+    pypi: typing.Optional[typing.Union[LibraryPypi, typing.Dict[builtins.str, typing.Any]]] = None,
+    whl: typing.Optional[builtins.str] = None,
+    connection: typing.Optional[typing.Union[typing.Union[_cdktf_9a9027ec.SSHProvisionerConnection, typing.Dict[builtins.str, typing.Any]], typing.Union[_cdktf_9a9027ec.WinrmProvisionerConnection, typing.Dict[builtins.str, typing.Any]]]] = None,
+    count: typing.Optional[jsii.Number] = None,
+    depends_on: typing.Optional[typing.Sequence[_cdktf_9a9027ec.ITerraformDependable]] = None,
+    for_each: typing.Optional[_cdktf_9a9027ec.ITerraformIterator] = None,
+    lifecycle: typing.Optional[typing.Union[_cdktf_9a9027ec.TerraformResourceLifecycle, typing.Dict[builtins.str, typing.Any]]] = None,
+    provider: typing.Optional[_cdktf_9a9027ec.TerraformProvider] = None,
+    provisioners: typing.Optional[typing.Sequence[typing.Union[typing.Union[_cdktf_9a9027ec.FileProvisioner, typing.Dict[builtins.str, typing.Any]], typing.Union[_cdktf_9a9027ec.LocalExecProvisioner, typing.Dict[builtins.str, typing.Any]], typing.Union[_cdktf_9a9027ec.RemoteExecProvisioner, typing.Dict[builtins.str, typing.Any]]]]] = None,
+) -> None:
+    """Type checking stubs"""
+    pass
+
+def _typecheckingstub__280bcc59f3dbe171fb95de51b53efae4c9e64bc13027945ab6b08f7a369fee9f(
+    value: builtins.str,
+) -> None:
+    """Type checking stubs"""
+    pass
+
+def _typecheckingstub__99a6241909969cf0b4bc69f01ecdcdc7a85adf31a5ac9b0dd5758284ab001a29(
+    value: builtins.str,
+) -> None:
+    """Type checking stubs"""
+    pass
+
+def _typecheckingstub__5f227b1298a0e3329c6dee68761df51da3e6d4f67489be78f15fb6a6440ca58a(
+    value: builtins.str,
+) -> None:
+    """Type checking stubs"""
+    pass
+
+def _typecheckingstub__167e6040e68dc7d39bd70bc737a378d2f976aa6d4129cb9888378422c7e72d35(
+    value: builtins.str,
+) -> None:
+    """Type checking stubs"""
+    pass
+
+def _typecheckingstub__1c6bca28056c29c481a9cc356742f4db521c43cb96fc2355a05f7f9afdfa1843(
+    value: builtins.str,
+) -> None:
+    """Type checking stubs"""
+    pass
+
+def _typecheckingstub__9efc2bcefbff8944ab39e1065e37bf3145d9fd46cad7156cb2b2b5fd6d11f5ea(
+    *,
+    connection: typing.Optional[typing.Union[typing.Union[_cdktf_9a9027ec.SSHProvisionerConnection, typing.Dict[builtins.str, typing.Any]], typing.Union[_cdktf_9a9027ec.WinrmProvisionerConnection, typing.Dict[builtins.str, typing.Any]]]] = None,
+    count: typing.Optional[jsii.Number] = None,
+    depends_on: typing.Optional[typing.Sequence[_cdktf_9a9027ec.ITerraformDependable]] = None,
+    for_each: typing.Optional[_cdktf_9a9027ec.ITerraformIterator] = None,
+    lifecycle: typing.Optional[typing.Union[_cdktf_9a9027ec.TerraformResourceLifecycle, typing.Dict[builtins.str, typing.Any]]] = None,
+    provider: typing.Optional[_cdktf_9a9027ec.TerraformProvider] = None,
+    provisioners: typing.Optional[typing.Sequence[typing.Union[typing.Union[_cdktf_9a9027ec.FileProvisioner, typing.Dict[builtins.str, typing.Any]], typing.Union[_cdktf_9a9027ec.LocalExecProvisioner, typing.Dict[builtins.str, typing.Any]], typing.Union[_cdktf_9a9027ec.RemoteExecProvisioner, typing.Dict[builtins.str, typing.Any]]]]] = None,
+    cluster_id: builtins.str,
+    cran: typing.Optional[typing.Union[LibraryCran, typing.Dict[builtins.str, typing.Any]]] = None,
+    egg: typing.Optional[builtins.str] = None,
+    id: typing.Optional[builtins.str] = None,
+    jar: typing.Optional[builtins.str] = None,
+    maven: typing.Optional[typing.Union[LibraryMaven, typing.Dict[builtins.str, typing.Any]]] = None,
+    pypi: typing.Optional[typing.Union[LibraryPypi, typing.Dict[builtins.str, typing.Any]]] = None,
+    whl: typing.Optional[builtins.str] = None,
+) -> None:
+    """Type checking stubs"""
+    pass
+
+def _typecheckingstub__bb2dd88e49a7a2c492f8cc94d94e24fb8a57d6de2bec99abfc6efc948b54632d(
+    *,
+    package: builtins.str,
+    repo: typing.Optional[builtins.str] = None,
+) -> None:
+    """Type checking stubs"""
+    pass
+
+def _typecheckingstub__f7234e3e90d49897671123de17da06dbbdf36492d3cea35a506abc75c7e909cf(
+    terraform_resource: _cdktf_9a9027ec.IInterpolatingParent,
+    terraform_attribute: builtins.str,
+) -> None:
+    """Type checking stubs"""
+    pass
+
+def _typecheckingstub__260d7c0a171dc53a069b5318107de740217030fd6593c65609dcacd81d9f79c4(
+    value: builtins.str,
+) -> None:
+    """Type checking stubs"""
+    pass
+
+def _typecheckingstub__198498c92f007ac903cfe6e67bc14a515610781e46afa26c070a76f0c260a6bb(
+    value: builtins.str,
+) -> None:
+    """Type checking stubs"""
+    pass
+
+def _typecheckingstub__6b9c96d5039c6b87936d77eb7a3058a1e841b5ec3363bfb27f649e3382ad620c(
+    value: typing.Optional[LibraryCran],
+) -> None:
+    """Type checking stubs"""
+    pass
+
+def _typecheckingstub__23bcf2170a1c50d6e580f56e86ab07eb1160e0ce5a5bf98719211a3904662494(
+    *,
+    coordinates: builtins.str,
+    exclusions: typing.Optional[typing.Sequence[builtins.str]] = None,
+    repo: typing.Optional[builtins.str] = None,
+) -> None:
+    """Type checking stubs"""
+    pass
+
+def _typecheckingstub__7dc45815bd7f989be7f806896cbee7af930f15c90e523f4000816bd9a3233ac1(
+    terraform_resource: _cdktf_9a9027ec.IInterpolatingParent,
+    terraform_attribute: builtins.str,
+) -> None:
+    """Type checking stubs"""
+    pass
+
+def _typecheckingstub__ef07227e509242612d1cb955936a19459cb268c06f98877332de7cfa25cddbbf(
+    value: builtins.str,
+) -> None:
+    """Type checking stubs"""
+    pass
+
+def _typecheckingstub__dd246eebf3bb52105b2f72e32e2321b535dd02a359cd5f63061c3d09c564442b(
+    value: typing.List[builtins.str],
+) -> None:
+    """Type checking stubs"""
+    pass
+
+def _typecheckingstub__8bd29551c744f7dd4f4ded9a9dfb6a81032fe376b9df2ffe77011a63161a72c0(
+    value: builtins.str,
+) -> None:
+    """Type checking stubs"""
+    pass
+
+def _typecheckingstub__680aeb82040d53a43ba576916564f67af43f88bae48aa7f2579d70c7d1694bb1(
+    value: typing.Optional[LibraryMaven],
+) -> None:
+    """Type checking stubs"""
+    pass
+
+def _typecheckingstub__4fec956c21e375316999d843c18e2e8871e9ab370c33ddf753d5a322e088a3d0(
+    *,
+    package: builtins.str,
+    repo: typing.Optional[builtins.str] = None,
+) -> None:
+    """Type checking stubs"""
+    pass
+
+def _typecheckingstub__39de0cbc90acb0b356f4db6f88ed89bbe9203b1bcd284fbcbcc4bdf75c0f4106(
+    terraform_resource: _cdktf_9a9027ec.IInterpolatingParent,
+    terraform_attribute: builtins.str,
+) -> None:
+    """Type checking stubs"""
+    pass
+
+def _typecheckingstub__1b44201ce136a603c868a8e725c038c57b6d303d5de493795952610e61a35be1(
+    value: builtins.str,
+) -> None:
+    """Type checking stubs"""
+    pass
+
+def _typecheckingstub__9e709ccc2a0a7cfe631d52950368e54b3740984aab299394a0fba99bb3f48489(
+    value: builtins.str,
+) -> None:
+    """Type checking stubs"""
+    pass
+
+def _typecheckingstub__fe8d0bdcfd9ce9b21f882b2105d7d014e2d9fa35198f000c1084c657300c5b24(
+    value: typing.Optional[LibraryPypi],
+) -> None:
+    """Type checking stubs"""
+    pass
