@@ -17,12 +17,12 @@ from typeguard import check_type
 
 from .._jsii import *
 
-import cdktf
-import constructs
+import cdktf as _cdktf_9a9027ec
+import constructs as _constructs_77d1e7e8
 
 
 class Metastore(
-    cdktf.TerraformResource,
+    _cdktf_9a9027ec.TerraformResource,
     metaclass=jsii.JSIIMeta,
     jsii_type="@cdktf/provider-databricks.metastore.Metastore",
 ):
@@ -30,7 +30,7 @@ class Metastore(
 
     def __init__(
         self,
-        scope: constructs.Construct,
+        scope: _constructs_77d1e7e8.Construct,
         id_: builtins.str,
         *,
         name: builtins.str,
@@ -42,20 +42,20 @@ class Metastore(
         delta_sharing_organization_name: typing.Optional[builtins.str] = None,
         delta_sharing_recipient_token_lifetime_in_seconds: typing.Optional[jsii.Number] = None,
         delta_sharing_scope: typing.Optional[builtins.str] = None,
-        force_destroy: typing.Optional[typing.Union[builtins.bool, cdktf.IResolvable]] = None,
+        force_destroy: typing.Optional[typing.Union[builtins.bool, _cdktf_9a9027ec.IResolvable]] = None,
         global_metastore_id: typing.Optional[builtins.str] = None,
         id: typing.Optional[builtins.str] = None,
         owner: typing.Optional[builtins.str] = None,
         region: typing.Optional[builtins.str] = None,
         updated_at: typing.Optional[jsii.Number] = None,
         updated_by: typing.Optional[builtins.str] = None,
-        connection: typing.Optional[typing.Union[typing.Union[cdktf.SSHProvisionerConnection, typing.Dict[str, typing.Any]], typing.Union[cdktf.WinrmProvisionerConnection, typing.Dict[str, typing.Any]]]] = None,
+        connection: typing.Optional[typing.Union[typing.Union[_cdktf_9a9027ec.SSHProvisionerConnection, typing.Dict[builtins.str, typing.Any]], typing.Union[_cdktf_9a9027ec.WinrmProvisionerConnection, typing.Dict[builtins.str, typing.Any]]]] = None,
         count: typing.Optional[jsii.Number] = None,
-        depends_on: typing.Optional[typing.Sequence[cdktf.ITerraformDependable]] = None,
-        for_each: typing.Optional[cdktf.ITerraformIterator] = None,
-        lifecycle: typing.Optional[typing.Union[cdktf.TerraformResourceLifecycle, typing.Dict[str, typing.Any]]] = None,
-        provider: typing.Optional[cdktf.TerraformProvider] = None,
-        provisioners: typing.Optional[typing.Sequence[typing.Union[typing.Union[cdktf.FileProvisioner, typing.Dict[str, typing.Any]], typing.Union[cdktf.LocalExecProvisioner, typing.Dict[str, typing.Any]], typing.Union[cdktf.RemoteExecProvisioner, typing.Dict[str, typing.Any]]]]] = None,
+        depends_on: typing.Optional[typing.Sequence[_cdktf_9a9027ec.ITerraformDependable]] = None,
+        for_each: typing.Optional[_cdktf_9a9027ec.ITerraformIterator] = None,
+        lifecycle: typing.Optional[typing.Union[_cdktf_9a9027ec.TerraformResourceLifecycle, typing.Dict[builtins.str, typing.Any]]] = None,
+        provider: typing.Optional[_cdktf_9a9027ec.TerraformProvider] = None,
+        provisioners: typing.Optional[typing.Sequence[typing.Union[typing.Union[_cdktf_9a9027ec.FileProvisioner, typing.Dict[builtins.str, typing.Any]], typing.Union[_cdktf_9a9027ec.LocalExecProvisioner, typing.Dict[builtins.str, typing.Any]], typing.Union[_cdktf_9a9027ec.RemoteExecProvisioner, typing.Dict[builtins.str, typing.Any]]]]] = None,
     ) -> None:
         '''Create a new {@link https://www.terraform.io/docs/providers/databricks/r/metastore databricks_metastore} Resource.
 
@@ -86,7 +86,7 @@ class Metastore(
         :param provisioners: 
         '''
         if __debug__:
-            type_hints = typing.get_type_hints(Metastore.__init__)
+            type_hints = typing.get_type_hints(_typecheckingstub__cd0df927e4f6eddbec08854f51264a361aca007e417a705d8e6dd17d9d3dd366)
             check_type(argname="argument scope", value=scope, expected_type=type_hints["scope"])
             check_type(argname="argument id_", value=id_, expected_type=type_hints["id_"])
         config = MetastoreConfig(
@@ -223,8 +223,8 @@ class Metastore(
     @jsii.member(jsii_name="forceDestroyInput")
     def force_destroy_input(
         self,
-    ) -> typing.Optional[typing.Union[builtins.bool, cdktf.IResolvable]]:
-        return typing.cast(typing.Optional[typing.Union[builtins.bool, cdktf.IResolvable]], jsii.get(self, "forceDestroyInput"))
+    ) -> typing.Optional[typing.Union[builtins.bool, _cdktf_9a9027ec.IResolvable]]:
+        return typing.cast(typing.Optional[typing.Union[builtins.bool, _cdktf_9a9027ec.IResolvable]], jsii.get(self, "forceDestroyInput"))
 
     @builtins.property
     @jsii.member(jsii_name="globalMetastoreIdInput")
@@ -274,7 +274,7 @@ class Metastore(
     @cloud.setter
     def cloud(self, value: builtins.str) -> None:
         if __debug__:
-            type_hints = typing.get_type_hints(getattr(Metastore, "cloud").fset)
+            type_hints = typing.get_type_hints(_typecheckingstub__fc7304ab7bb5b62681f4c5cbb0111ac5ede6579f69fc9cfb794f31afda6bd32b)
             check_type(argname="argument value", value=value, expected_type=type_hints["value"])
         jsii.set(self, "cloud", value)
 
@@ -286,7 +286,7 @@ class Metastore(
     @created_at.setter
     def created_at(self, value: jsii.Number) -> None:
         if __debug__:
-            type_hints = typing.get_type_hints(getattr(Metastore, "created_at").fset)
+            type_hints = typing.get_type_hints(_typecheckingstub__499ebd1e2aba4826bfe89abde91ea612c03af2b8a09fb22566e78cf1e9e7e40b)
             check_type(argname="argument value", value=value, expected_type=type_hints["value"])
         jsii.set(self, "createdAt", value)
 
@@ -298,7 +298,7 @@ class Metastore(
     @created_by.setter
     def created_by(self, value: builtins.str) -> None:
         if __debug__:
-            type_hints = typing.get_type_hints(getattr(Metastore, "created_by").fset)
+            type_hints = typing.get_type_hints(_typecheckingstub__3a239d9e067d620bf9046f46fd5f48e7dd805e52c18803e8b0c3ac6b90724ce6)
             check_type(argname="argument value", value=value, expected_type=type_hints["value"])
         jsii.set(self, "createdBy", value)
 
@@ -310,7 +310,7 @@ class Metastore(
     @default_data_access_config_id.setter
     def default_data_access_config_id(self, value: builtins.str) -> None:
         if __debug__:
-            type_hints = typing.get_type_hints(getattr(Metastore, "default_data_access_config_id").fset)
+            type_hints = typing.get_type_hints(_typecheckingstub__ffc1b428998305f64558a93a839c321b06133180ff32eef2744f4869b245850a)
             check_type(argname="argument value", value=value, expected_type=type_hints["value"])
         jsii.set(self, "defaultDataAccessConfigId", value)
 
@@ -322,7 +322,7 @@ class Metastore(
     @delta_sharing_organization_name.setter
     def delta_sharing_organization_name(self, value: builtins.str) -> None:
         if __debug__:
-            type_hints = typing.get_type_hints(getattr(Metastore, "delta_sharing_organization_name").fset)
+            type_hints = typing.get_type_hints(_typecheckingstub__eae46008b6a20b4329f1b5594b314657f1b88ee89cc3a99e7e471bae675e40d1)
             check_type(argname="argument value", value=value, expected_type=type_hints["value"])
         jsii.set(self, "deltaSharingOrganizationName", value)
 
@@ -337,7 +337,7 @@ class Metastore(
         value: jsii.Number,
     ) -> None:
         if __debug__:
-            type_hints = typing.get_type_hints(getattr(Metastore, "delta_sharing_recipient_token_lifetime_in_seconds").fset)
+            type_hints = typing.get_type_hints(_typecheckingstub__5990c122927373da676211a1063b7cc9a72aa7949c04fa42cd5c13029e12060f)
             check_type(argname="argument value", value=value, expected_type=type_hints["value"])
         jsii.set(self, "deltaSharingRecipientTokenLifetimeInSeconds", value)
 
@@ -349,22 +349,22 @@ class Metastore(
     @delta_sharing_scope.setter
     def delta_sharing_scope(self, value: builtins.str) -> None:
         if __debug__:
-            type_hints = typing.get_type_hints(getattr(Metastore, "delta_sharing_scope").fset)
+            type_hints = typing.get_type_hints(_typecheckingstub__ef33dd455b34a21f6de7780bef11cff0c0baeb5cfd92b1462ddf2863e2ad08e4)
             check_type(argname="argument value", value=value, expected_type=type_hints["value"])
         jsii.set(self, "deltaSharingScope", value)
 
     @builtins.property
     @jsii.member(jsii_name="forceDestroy")
-    def force_destroy(self) -> typing.Union[builtins.bool, cdktf.IResolvable]:
-        return typing.cast(typing.Union[builtins.bool, cdktf.IResolvable], jsii.get(self, "forceDestroy"))
+    def force_destroy(self) -> typing.Union[builtins.bool, _cdktf_9a9027ec.IResolvable]:
+        return typing.cast(typing.Union[builtins.bool, _cdktf_9a9027ec.IResolvable], jsii.get(self, "forceDestroy"))
 
     @force_destroy.setter
     def force_destroy(
         self,
-        value: typing.Union[builtins.bool, cdktf.IResolvable],
+        value: typing.Union[builtins.bool, _cdktf_9a9027ec.IResolvable],
     ) -> None:
         if __debug__:
-            type_hints = typing.get_type_hints(getattr(Metastore, "force_destroy").fset)
+            type_hints = typing.get_type_hints(_typecheckingstub__8671b97cf0e74dab90b774fce0e223b4ca60554ebf76c0e41d09f2d641d47144)
             check_type(argname="argument value", value=value, expected_type=type_hints["value"])
         jsii.set(self, "forceDestroy", value)
 
@@ -376,7 +376,7 @@ class Metastore(
     @global_metastore_id.setter
     def global_metastore_id(self, value: builtins.str) -> None:
         if __debug__:
-            type_hints = typing.get_type_hints(getattr(Metastore, "global_metastore_id").fset)
+            type_hints = typing.get_type_hints(_typecheckingstub__95feb381b2ade7d7efe41b910b29411dc620a1eb9e64a907650f78f4efd99f27)
             check_type(argname="argument value", value=value, expected_type=type_hints["value"])
         jsii.set(self, "globalMetastoreId", value)
 
@@ -388,7 +388,7 @@ class Metastore(
     @id.setter
     def id(self, value: builtins.str) -> None:
         if __debug__:
-            type_hints = typing.get_type_hints(getattr(Metastore, "id").fset)
+            type_hints = typing.get_type_hints(_typecheckingstub__55f2e4c50ed31bfa08ea70ba9d2bfb55c89bf83348508167b9dea4826faa5a89)
             check_type(argname="argument value", value=value, expected_type=type_hints["value"])
         jsii.set(self, "id", value)
 
@@ -400,7 +400,7 @@ class Metastore(
     @name.setter
     def name(self, value: builtins.str) -> None:
         if __debug__:
-            type_hints = typing.get_type_hints(getattr(Metastore, "name").fset)
+            type_hints = typing.get_type_hints(_typecheckingstub__6d8c6f5e33de81d1f32c693227ed824f4176ee0536b702d0e595284921c68027)
             check_type(argname="argument value", value=value, expected_type=type_hints["value"])
         jsii.set(self, "name", value)
 
@@ -412,7 +412,7 @@ class Metastore(
     @owner.setter
     def owner(self, value: builtins.str) -> None:
         if __debug__:
-            type_hints = typing.get_type_hints(getattr(Metastore, "owner").fset)
+            type_hints = typing.get_type_hints(_typecheckingstub__bff8dadf08598b69eca6d5da5e4c6ba264673a9b03dd37f1d4b6f918fb751cf4)
             check_type(argname="argument value", value=value, expected_type=type_hints["value"])
         jsii.set(self, "owner", value)
 
@@ -424,7 +424,7 @@ class Metastore(
     @region.setter
     def region(self, value: builtins.str) -> None:
         if __debug__:
-            type_hints = typing.get_type_hints(getattr(Metastore, "region").fset)
+            type_hints = typing.get_type_hints(_typecheckingstub__92136ba519850550a7491d62e2969b22d95e41d03aef569c7cc0f8833cacf8ea)
             check_type(argname="argument value", value=value, expected_type=type_hints["value"])
         jsii.set(self, "region", value)
 
@@ -436,7 +436,7 @@ class Metastore(
     @storage_root.setter
     def storage_root(self, value: builtins.str) -> None:
         if __debug__:
-            type_hints = typing.get_type_hints(getattr(Metastore, "storage_root").fset)
+            type_hints = typing.get_type_hints(_typecheckingstub__f47845cbca9c727c897da6c393134536d4b0964bbcbd1c4157d0425bf2440d32)
             check_type(argname="argument value", value=value, expected_type=type_hints["value"])
         jsii.set(self, "storageRoot", value)
 
@@ -448,7 +448,7 @@ class Metastore(
     @updated_at.setter
     def updated_at(self, value: jsii.Number) -> None:
         if __debug__:
-            type_hints = typing.get_type_hints(getattr(Metastore, "updated_at").fset)
+            type_hints = typing.get_type_hints(_typecheckingstub__b1ad1837f87df221ac2c0654ba153bf7b635276b7f89e076a3367f1c566c1fb3)
             check_type(argname="argument value", value=value, expected_type=type_hints["value"])
         jsii.set(self, "updatedAt", value)
 
@@ -460,14 +460,14 @@ class Metastore(
     @updated_by.setter
     def updated_by(self, value: builtins.str) -> None:
         if __debug__:
-            type_hints = typing.get_type_hints(getattr(Metastore, "updated_by").fset)
+            type_hints = typing.get_type_hints(_typecheckingstub__19e90ce7e42d6bb1ce86fdc3342edf0cec7beafa4e7f9e0de389b85195e480df)
             check_type(argname="argument value", value=value, expected_type=type_hints["value"])
         jsii.set(self, "updatedBy", value)
 
 
 @jsii.data_type(
     jsii_type="@cdktf/provider-databricks.metastore.MetastoreConfig",
-    jsii_struct_bases=[cdktf.TerraformMetaArguments],
+    jsii_struct_bases=[_cdktf_9a9027ec.TerraformMetaArguments],
     name_mapping={
         "connection": "connection",
         "count": "count",
@@ -494,17 +494,17 @@ class Metastore(
         "updated_by": "updatedBy",
     },
 )
-class MetastoreConfig(cdktf.TerraformMetaArguments):
+class MetastoreConfig(_cdktf_9a9027ec.TerraformMetaArguments):
     def __init__(
         self,
         *,
-        connection: typing.Optional[typing.Union[typing.Union[cdktf.SSHProvisionerConnection, typing.Dict[str, typing.Any]], typing.Union[cdktf.WinrmProvisionerConnection, typing.Dict[str, typing.Any]]]] = None,
+        connection: typing.Optional[typing.Union[typing.Union[_cdktf_9a9027ec.SSHProvisionerConnection, typing.Dict[builtins.str, typing.Any]], typing.Union[_cdktf_9a9027ec.WinrmProvisionerConnection, typing.Dict[builtins.str, typing.Any]]]] = None,
         count: typing.Optional[jsii.Number] = None,
-        depends_on: typing.Optional[typing.Sequence[cdktf.ITerraformDependable]] = None,
-        for_each: typing.Optional[cdktf.ITerraformIterator] = None,
-        lifecycle: typing.Optional[typing.Union[cdktf.TerraformResourceLifecycle, typing.Dict[str, typing.Any]]] = None,
-        provider: typing.Optional[cdktf.TerraformProvider] = None,
-        provisioners: typing.Optional[typing.Sequence[typing.Union[typing.Union[cdktf.FileProvisioner, typing.Dict[str, typing.Any]], typing.Union[cdktf.LocalExecProvisioner, typing.Dict[str, typing.Any]], typing.Union[cdktf.RemoteExecProvisioner, typing.Dict[str, typing.Any]]]]] = None,
+        depends_on: typing.Optional[typing.Sequence[_cdktf_9a9027ec.ITerraformDependable]] = None,
+        for_each: typing.Optional[_cdktf_9a9027ec.ITerraformIterator] = None,
+        lifecycle: typing.Optional[typing.Union[_cdktf_9a9027ec.TerraformResourceLifecycle, typing.Dict[builtins.str, typing.Any]]] = None,
+        provider: typing.Optional[_cdktf_9a9027ec.TerraformProvider] = None,
+        provisioners: typing.Optional[typing.Sequence[typing.Union[typing.Union[_cdktf_9a9027ec.FileProvisioner, typing.Dict[builtins.str, typing.Any]], typing.Union[_cdktf_9a9027ec.LocalExecProvisioner, typing.Dict[builtins.str, typing.Any]], typing.Union[_cdktf_9a9027ec.RemoteExecProvisioner, typing.Dict[builtins.str, typing.Any]]]]] = None,
         name: builtins.str,
         storage_root: builtins.str,
         cloud: typing.Optional[builtins.str] = None,
@@ -514,7 +514,7 @@ class MetastoreConfig(cdktf.TerraformMetaArguments):
         delta_sharing_organization_name: typing.Optional[builtins.str] = None,
         delta_sharing_recipient_token_lifetime_in_seconds: typing.Optional[jsii.Number] = None,
         delta_sharing_scope: typing.Optional[builtins.str] = None,
-        force_destroy: typing.Optional[typing.Union[builtins.bool, cdktf.IResolvable]] = None,
+        force_destroy: typing.Optional[typing.Union[builtins.bool, _cdktf_9a9027ec.IResolvable]] = None,
         global_metastore_id: typing.Optional[builtins.str] = None,
         id: typing.Optional[builtins.str] = None,
         owner: typing.Optional[builtins.str] = None,
@@ -548,9 +548,9 @@ class MetastoreConfig(cdktf.TerraformMetaArguments):
         :param updated_by: Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/databricks/r/metastore#updated_by Metastore#updated_by}.
         '''
         if isinstance(lifecycle, dict):
-            lifecycle = cdktf.TerraformResourceLifecycle(**lifecycle)
+            lifecycle = _cdktf_9a9027ec.TerraformResourceLifecycle(**lifecycle)
         if __debug__:
-            type_hints = typing.get_type_hints(MetastoreConfig.__init__)
+            type_hints = typing.get_type_hints(_typecheckingstub__59c9208fb453358ff13ce46e4765ac29f986e3cdc4be94d1a07a9aff9b2cbc7d)
             check_type(argname="argument connection", value=connection, expected_type=type_hints["connection"])
             check_type(argname="argument count", value=count, expected_type=type_hints["count"])
             check_type(argname="argument depends_on", value=depends_on, expected_type=type_hints["depends_on"])
@@ -574,7 +574,7 @@ class MetastoreConfig(cdktf.TerraformMetaArguments):
             check_type(argname="argument region", value=region, expected_type=type_hints["region"])
             check_type(argname="argument updated_at", value=updated_at, expected_type=type_hints["updated_at"])
             check_type(argname="argument updated_by", value=updated_by, expected_type=type_hints["updated_by"])
-        self._values: typing.Dict[str, typing.Any] = {
+        self._values: typing.Dict[builtins.str, typing.Any] = {
             "name": name,
             "storage_root": storage_root,
         }
@@ -624,12 +624,12 @@ class MetastoreConfig(cdktf.TerraformMetaArguments):
     @builtins.property
     def connection(
         self,
-    ) -> typing.Optional[typing.Union[cdktf.SSHProvisionerConnection, cdktf.WinrmProvisionerConnection]]:
+    ) -> typing.Optional[typing.Union[_cdktf_9a9027ec.SSHProvisionerConnection, _cdktf_9a9027ec.WinrmProvisionerConnection]]:
         '''
         :stability: experimental
         '''
         result = self._values.get("connection")
-        return typing.cast(typing.Optional[typing.Union[cdktf.SSHProvisionerConnection, cdktf.WinrmProvisionerConnection]], result)
+        return typing.cast(typing.Optional[typing.Union[_cdktf_9a9027ec.SSHProvisionerConnection, _cdktf_9a9027ec.WinrmProvisionerConnection]], result)
 
     @builtins.property
     def count(self) -> typing.Optional[jsii.Number]:
@@ -640,46 +640,48 @@ class MetastoreConfig(cdktf.TerraformMetaArguments):
         return typing.cast(typing.Optional[jsii.Number], result)
 
     @builtins.property
-    def depends_on(self) -> typing.Optional[typing.List[cdktf.ITerraformDependable]]:
+    def depends_on(
+        self,
+    ) -> typing.Optional[typing.List[_cdktf_9a9027ec.ITerraformDependable]]:
         '''
         :stability: experimental
         '''
         result = self._values.get("depends_on")
-        return typing.cast(typing.Optional[typing.List[cdktf.ITerraformDependable]], result)
+        return typing.cast(typing.Optional[typing.List[_cdktf_9a9027ec.ITerraformDependable]], result)
 
     @builtins.property
-    def for_each(self) -> typing.Optional[cdktf.ITerraformIterator]:
+    def for_each(self) -> typing.Optional[_cdktf_9a9027ec.ITerraformIterator]:
         '''
         :stability: experimental
         '''
         result = self._values.get("for_each")
-        return typing.cast(typing.Optional[cdktf.ITerraformIterator], result)
+        return typing.cast(typing.Optional[_cdktf_9a9027ec.ITerraformIterator], result)
 
     @builtins.property
-    def lifecycle(self) -> typing.Optional[cdktf.TerraformResourceLifecycle]:
+    def lifecycle(self) -> typing.Optional[_cdktf_9a9027ec.TerraformResourceLifecycle]:
         '''
         :stability: experimental
         '''
         result = self._values.get("lifecycle")
-        return typing.cast(typing.Optional[cdktf.TerraformResourceLifecycle], result)
+        return typing.cast(typing.Optional[_cdktf_9a9027ec.TerraformResourceLifecycle], result)
 
     @builtins.property
-    def provider(self) -> typing.Optional[cdktf.TerraformProvider]:
+    def provider(self) -> typing.Optional[_cdktf_9a9027ec.TerraformProvider]:
         '''
         :stability: experimental
         '''
         result = self._values.get("provider")
-        return typing.cast(typing.Optional[cdktf.TerraformProvider], result)
+        return typing.cast(typing.Optional[_cdktf_9a9027ec.TerraformProvider], result)
 
     @builtins.property
     def provisioners(
         self,
-    ) -> typing.Optional[typing.List[typing.Union[cdktf.FileProvisioner, cdktf.LocalExecProvisioner, cdktf.RemoteExecProvisioner]]]:
+    ) -> typing.Optional[typing.List[typing.Union[_cdktf_9a9027ec.FileProvisioner, _cdktf_9a9027ec.LocalExecProvisioner, _cdktf_9a9027ec.RemoteExecProvisioner]]]:
         '''
         :stability: experimental
         '''
         result = self._values.get("provisioners")
-        return typing.cast(typing.Optional[typing.List[typing.Union[cdktf.FileProvisioner, cdktf.LocalExecProvisioner, cdktf.RemoteExecProvisioner]]], result)
+        return typing.cast(typing.Optional[typing.List[typing.Union[_cdktf_9a9027ec.FileProvisioner, _cdktf_9a9027ec.LocalExecProvisioner, _cdktf_9a9027ec.RemoteExecProvisioner]]], result)
 
     @builtins.property
     def name(self) -> builtins.str:
@@ -742,10 +744,10 @@ class MetastoreConfig(cdktf.TerraformMetaArguments):
     @builtins.property
     def force_destroy(
         self,
-    ) -> typing.Optional[typing.Union[builtins.bool, cdktf.IResolvable]]:
+    ) -> typing.Optional[typing.Union[builtins.bool, _cdktf_9a9027ec.IResolvable]]:
         '''Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/databricks/r/metastore#force_destroy Metastore#force_destroy}.'''
         result = self._values.get("force_destroy")
-        return typing.cast(typing.Optional[typing.Union[builtins.bool, cdktf.IResolvable]], result)
+        return typing.cast(typing.Optional[typing.Union[builtins.bool, _cdktf_9a9027ec.IResolvable]], result)
 
     @builtins.property
     def global_metastore_id(self) -> typing.Optional[builtins.str]:
@@ -805,3 +807,159 @@ __all__ = [
 ]
 
 publication.publish()
+
+def _typecheckingstub__cd0df927e4f6eddbec08854f51264a361aca007e417a705d8e6dd17d9d3dd366(
+    scope: _constructs_77d1e7e8.Construct,
+    id_: builtins.str,
+    *,
+    name: builtins.str,
+    storage_root: builtins.str,
+    cloud: typing.Optional[builtins.str] = None,
+    created_at: typing.Optional[jsii.Number] = None,
+    created_by: typing.Optional[builtins.str] = None,
+    default_data_access_config_id: typing.Optional[builtins.str] = None,
+    delta_sharing_organization_name: typing.Optional[builtins.str] = None,
+    delta_sharing_recipient_token_lifetime_in_seconds: typing.Optional[jsii.Number] = None,
+    delta_sharing_scope: typing.Optional[builtins.str] = None,
+    force_destroy: typing.Optional[typing.Union[builtins.bool, _cdktf_9a9027ec.IResolvable]] = None,
+    global_metastore_id: typing.Optional[builtins.str] = None,
+    id: typing.Optional[builtins.str] = None,
+    owner: typing.Optional[builtins.str] = None,
+    region: typing.Optional[builtins.str] = None,
+    updated_at: typing.Optional[jsii.Number] = None,
+    updated_by: typing.Optional[builtins.str] = None,
+    connection: typing.Optional[typing.Union[typing.Union[_cdktf_9a9027ec.SSHProvisionerConnection, typing.Dict[builtins.str, typing.Any]], typing.Union[_cdktf_9a9027ec.WinrmProvisionerConnection, typing.Dict[builtins.str, typing.Any]]]] = None,
+    count: typing.Optional[jsii.Number] = None,
+    depends_on: typing.Optional[typing.Sequence[_cdktf_9a9027ec.ITerraformDependable]] = None,
+    for_each: typing.Optional[_cdktf_9a9027ec.ITerraformIterator] = None,
+    lifecycle: typing.Optional[typing.Union[_cdktf_9a9027ec.TerraformResourceLifecycle, typing.Dict[builtins.str, typing.Any]]] = None,
+    provider: typing.Optional[_cdktf_9a9027ec.TerraformProvider] = None,
+    provisioners: typing.Optional[typing.Sequence[typing.Union[typing.Union[_cdktf_9a9027ec.FileProvisioner, typing.Dict[builtins.str, typing.Any]], typing.Union[_cdktf_9a9027ec.LocalExecProvisioner, typing.Dict[builtins.str, typing.Any]], typing.Union[_cdktf_9a9027ec.RemoteExecProvisioner, typing.Dict[builtins.str, typing.Any]]]]] = None,
+) -> None:
+    """Type checking stubs"""
+    pass
+
+def _typecheckingstub__fc7304ab7bb5b62681f4c5cbb0111ac5ede6579f69fc9cfb794f31afda6bd32b(
+    value: builtins.str,
+) -> None:
+    """Type checking stubs"""
+    pass
+
+def _typecheckingstub__499ebd1e2aba4826bfe89abde91ea612c03af2b8a09fb22566e78cf1e9e7e40b(
+    value: jsii.Number,
+) -> None:
+    """Type checking stubs"""
+    pass
+
+def _typecheckingstub__3a239d9e067d620bf9046f46fd5f48e7dd805e52c18803e8b0c3ac6b90724ce6(
+    value: builtins.str,
+) -> None:
+    """Type checking stubs"""
+    pass
+
+def _typecheckingstub__ffc1b428998305f64558a93a839c321b06133180ff32eef2744f4869b245850a(
+    value: builtins.str,
+) -> None:
+    """Type checking stubs"""
+    pass
+
+def _typecheckingstub__eae46008b6a20b4329f1b5594b314657f1b88ee89cc3a99e7e471bae675e40d1(
+    value: builtins.str,
+) -> None:
+    """Type checking stubs"""
+    pass
+
+def _typecheckingstub__5990c122927373da676211a1063b7cc9a72aa7949c04fa42cd5c13029e12060f(
+    value: jsii.Number,
+) -> None:
+    """Type checking stubs"""
+    pass
+
+def _typecheckingstub__ef33dd455b34a21f6de7780bef11cff0c0baeb5cfd92b1462ddf2863e2ad08e4(
+    value: builtins.str,
+) -> None:
+    """Type checking stubs"""
+    pass
+
+def _typecheckingstub__8671b97cf0e74dab90b774fce0e223b4ca60554ebf76c0e41d09f2d641d47144(
+    value: typing.Union[builtins.bool, _cdktf_9a9027ec.IResolvable],
+) -> None:
+    """Type checking stubs"""
+    pass
+
+def _typecheckingstub__95feb381b2ade7d7efe41b910b29411dc620a1eb9e64a907650f78f4efd99f27(
+    value: builtins.str,
+) -> None:
+    """Type checking stubs"""
+    pass
+
+def _typecheckingstub__55f2e4c50ed31bfa08ea70ba9d2bfb55c89bf83348508167b9dea4826faa5a89(
+    value: builtins.str,
+) -> None:
+    """Type checking stubs"""
+    pass
+
+def _typecheckingstub__6d8c6f5e33de81d1f32c693227ed824f4176ee0536b702d0e595284921c68027(
+    value: builtins.str,
+) -> None:
+    """Type checking stubs"""
+    pass
+
+def _typecheckingstub__bff8dadf08598b69eca6d5da5e4c6ba264673a9b03dd37f1d4b6f918fb751cf4(
+    value: builtins.str,
+) -> None:
+    """Type checking stubs"""
+    pass
+
+def _typecheckingstub__92136ba519850550a7491d62e2969b22d95e41d03aef569c7cc0f8833cacf8ea(
+    value: builtins.str,
+) -> None:
+    """Type checking stubs"""
+    pass
+
+def _typecheckingstub__f47845cbca9c727c897da6c393134536d4b0964bbcbd1c4157d0425bf2440d32(
+    value: builtins.str,
+) -> None:
+    """Type checking stubs"""
+    pass
+
+def _typecheckingstub__b1ad1837f87df221ac2c0654ba153bf7b635276b7f89e076a3367f1c566c1fb3(
+    value: jsii.Number,
+) -> None:
+    """Type checking stubs"""
+    pass
+
+def _typecheckingstub__19e90ce7e42d6bb1ce86fdc3342edf0cec7beafa4e7f9e0de389b85195e480df(
+    value: builtins.str,
+) -> None:
+    """Type checking stubs"""
+    pass
+
+def _typecheckingstub__59c9208fb453358ff13ce46e4765ac29f986e3cdc4be94d1a07a9aff9b2cbc7d(
+    *,
+    connection: typing.Optional[typing.Union[typing.Union[_cdktf_9a9027ec.SSHProvisionerConnection, typing.Dict[builtins.str, typing.Any]], typing.Union[_cdktf_9a9027ec.WinrmProvisionerConnection, typing.Dict[builtins.str, typing.Any]]]] = None,
+    count: typing.Optional[jsii.Number] = None,
+    depends_on: typing.Optional[typing.Sequence[_cdktf_9a9027ec.ITerraformDependable]] = None,
+    for_each: typing.Optional[_cdktf_9a9027ec.ITerraformIterator] = None,
+    lifecycle: typing.Optional[typing.Union[_cdktf_9a9027ec.TerraformResourceLifecycle, typing.Dict[builtins.str, typing.Any]]] = None,
+    provider: typing.Optional[_cdktf_9a9027ec.TerraformProvider] = None,
+    provisioners: typing.Optional[typing.Sequence[typing.Union[typing.Union[_cdktf_9a9027ec.FileProvisioner, typing.Dict[builtins.str, typing.Any]], typing.Union[_cdktf_9a9027ec.LocalExecProvisioner, typing.Dict[builtins.str, typing.Any]], typing.Union[_cdktf_9a9027ec.RemoteExecProvisioner, typing.Dict[builtins.str, typing.Any]]]]] = None,
+    name: builtins.str,
+    storage_root: builtins.str,
+    cloud: typing.Optional[builtins.str] = None,
+    created_at: typing.Optional[jsii.Number] = None,
+    created_by: typing.Optional[builtins.str] = None,
+    default_data_access_config_id: typing.Optional[builtins.str] = None,
+    delta_sharing_organization_name: typing.Optional[builtins.str] = None,
+    delta_sharing_recipient_token_lifetime_in_seconds: typing.Optional[jsii.Number] = None,
+    delta_sharing_scope: typing.Optional[builtins.str] = None,
+    force_destroy: typing.Optional[typing.Union[builtins.bool, _cdktf_9a9027ec.IResolvable]] = None,
+    global_metastore_id: typing.Optional[builtins.str] = None,
+    id: typing.Optional[builtins.str] = None,
+    owner: typing.Optional[builtins.str] = None,
+    region: typing.Optional[builtins.str] = None,
+    updated_at: typing.Optional[jsii.Number] = None,
+    updated_by: typing.Optional[builtins.str] = None,
+) -> None:
+    """Type checking stubs"""
+    pass
