@@ -17,12 +17,12 @@ from typeguard import check_type
 
 from .._jsii import *
 
-import cdktf
-import constructs
+import cdktf as _cdktf_9a9027ec
+import constructs as _constructs_77d1e7e8
 
 
 class MlflowModel(
-    cdktf.TerraformResource,
+    _cdktf_9a9027ec.TerraformResource,
     metaclass=jsii.JSIIMeta,
     jsii_type="@cdktf/provider-databricks.mlflowModel.MlflowModel",
 ):
@@ -30,7 +30,7 @@ class MlflowModel(
 
     def __init__(
         self,
-        scope: constructs.Construct,
+        scope: _constructs_77d1e7e8.Construct,
         id_: builtins.str,
         *,
         name: builtins.str,
@@ -39,15 +39,15 @@ class MlflowModel(
         id: typing.Optional[builtins.str] = None,
         last_updated_timestamp: typing.Optional[jsii.Number] = None,
         registered_model_id: typing.Optional[builtins.str] = None,
-        tags: typing.Optional[typing.Union[cdktf.IResolvable, typing.Sequence[typing.Union["MlflowModelTags", typing.Dict[str, typing.Any]]]]] = None,
+        tags: typing.Optional[typing.Union[_cdktf_9a9027ec.IResolvable, typing.Sequence[typing.Union["MlflowModelTags", typing.Dict[builtins.str, typing.Any]]]]] = None,
         user_id: typing.Optional[builtins.str] = None,
-        connection: typing.Optional[typing.Union[typing.Union[cdktf.SSHProvisionerConnection, typing.Dict[str, typing.Any]], typing.Union[cdktf.WinrmProvisionerConnection, typing.Dict[str, typing.Any]]]] = None,
+        connection: typing.Optional[typing.Union[typing.Union[_cdktf_9a9027ec.SSHProvisionerConnection, typing.Dict[builtins.str, typing.Any]], typing.Union[_cdktf_9a9027ec.WinrmProvisionerConnection, typing.Dict[builtins.str, typing.Any]]]] = None,
         count: typing.Optional[jsii.Number] = None,
-        depends_on: typing.Optional[typing.Sequence[cdktf.ITerraformDependable]] = None,
-        for_each: typing.Optional[cdktf.ITerraformIterator] = None,
-        lifecycle: typing.Optional[typing.Union[cdktf.TerraformResourceLifecycle, typing.Dict[str, typing.Any]]] = None,
-        provider: typing.Optional[cdktf.TerraformProvider] = None,
-        provisioners: typing.Optional[typing.Sequence[typing.Union[typing.Union[cdktf.FileProvisioner, typing.Dict[str, typing.Any]], typing.Union[cdktf.LocalExecProvisioner, typing.Dict[str, typing.Any]], typing.Union[cdktf.RemoteExecProvisioner, typing.Dict[str, typing.Any]]]]] = None,
+        depends_on: typing.Optional[typing.Sequence[_cdktf_9a9027ec.ITerraformDependable]] = None,
+        for_each: typing.Optional[_cdktf_9a9027ec.ITerraformIterator] = None,
+        lifecycle: typing.Optional[typing.Union[_cdktf_9a9027ec.TerraformResourceLifecycle, typing.Dict[builtins.str, typing.Any]]] = None,
+        provider: typing.Optional[_cdktf_9a9027ec.TerraformProvider] = None,
+        provisioners: typing.Optional[typing.Sequence[typing.Union[typing.Union[_cdktf_9a9027ec.FileProvisioner, typing.Dict[builtins.str, typing.Any]], typing.Union[_cdktf_9a9027ec.LocalExecProvisioner, typing.Dict[builtins.str, typing.Any]], typing.Union[_cdktf_9a9027ec.RemoteExecProvisioner, typing.Dict[builtins.str, typing.Any]]]]] = None,
     ) -> None:
         '''Create a new {@link https://www.terraform.io/docs/providers/databricks/r/mlflow_model databricks_mlflow_model} Resource.
 
@@ -70,7 +70,7 @@ class MlflowModel(
         :param provisioners: 
         '''
         if __debug__:
-            type_hints = typing.get_type_hints(MlflowModel.__init__)
+            type_hints = typing.get_type_hints(_typecheckingstub__bab36b4f3f2418b538ba2c47ade2b43caa4ea7292d9fc94e61a1350214137e6e)
             check_type(argname="argument scope", value=scope, expected_type=type_hints["scope"])
             check_type(argname="argument id_", value=id_, expected_type=type_hints["id_"])
         config = MlflowModelConfig(
@@ -96,13 +96,13 @@ class MlflowModel(
     @jsii.member(jsii_name="putTags")
     def put_tags(
         self,
-        value: typing.Union[cdktf.IResolvable, typing.Sequence[typing.Union["MlflowModelTags", typing.Dict[str, typing.Any]]]],
+        value: typing.Union[_cdktf_9a9027ec.IResolvable, typing.Sequence[typing.Union["MlflowModelTags", typing.Dict[builtins.str, typing.Any]]]],
     ) -> None:
         '''
         :param value: -
         '''
         if __debug__:
-            type_hints = typing.get_type_hints(MlflowModel.put_tags)
+            type_hints = typing.get_type_hints(_typecheckingstub__b7f28d776513880e7d7abef68fa62fa1d18b3c68aa96e42ee1b661b4791ea961)
             check_type(argname="argument value", value=value, expected_type=type_hints["value"])
         return typing.cast(None, jsii.invoke(self, "putTags", [value]))
 
@@ -182,8 +182,8 @@ class MlflowModel(
     @jsii.member(jsii_name="tagsInput")
     def tags_input(
         self,
-    ) -> typing.Optional[typing.Union[cdktf.IResolvable, typing.List["MlflowModelTags"]]]:
-        return typing.cast(typing.Optional[typing.Union[cdktf.IResolvable, typing.List["MlflowModelTags"]]], jsii.get(self, "tagsInput"))
+    ) -> typing.Optional[typing.Union[_cdktf_9a9027ec.IResolvable, typing.List["MlflowModelTags"]]]:
+        return typing.cast(typing.Optional[typing.Union[_cdktf_9a9027ec.IResolvable, typing.List["MlflowModelTags"]]], jsii.get(self, "tagsInput"))
 
     @builtins.property
     @jsii.member(jsii_name="userIdInput")
@@ -198,7 +198,7 @@ class MlflowModel(
     @creation_timestamp.setter
     def creation_timestamp(self, value: jsii.Number) -> None:
         if __debug__:
-            type_hints = typing.get_type_hints(getattr(MlflowModel, "creation_timestamp").fset)
+            type_hints = typing.get_type_hints(_typecheckingstub__0df41ec9b186aed8b85aac2a123fff95f6bad4c1f61c72133c4e6ddd300a3009)
             check_type(argname="argument value", value=value, expected_type=type_hints["value"])
         jsii.set(self, "creationTimestamp", value)
 
@@ -210,7 +210,7 @@ class MlflowModel(
     @description.setter
     def description(self, value: builtins.str) -> None:
         if __debug__:
-            type_hints = typing.get_type_hints(getattr(MlflowModel, "description").fset)
+            type_hints = typing.get_type_hints(_typecheckingstub__d9a8473387bf160042966a31544eee7d4c48f514de1f4c7bfb0bf5b44002faef)
             check_type(argname="argument value", value=value, expected_type=type_hints["value"])
         jsii.set(self, "description", value)
 
@@ -222,7 +222,7 @@ class MlflowModel(
     @id.setter
     def id(self, value: builtins.str) -> None:
         if __debug__:
-            type_hints = typing.get_type_hints(getattr(MlflowModel, "id").fset)
+            type_hints = typing.get_type_hints(_typecheckingstub__84a2a9153865f72de498d1e2e2c3f29c7bc198f8f3905587bd377768a87b55c0)
             check_type(argname="argument value", value=value, expected_type=type_hints["value"])
         jsii.set(self, "id", value)
 
@@ -234,7 +234,7 @@ class MlflowModel(
     @last_updated_timestamp.setter
     def last_updated_timestamp(self, value: jsii.Number) -> None:
         if __debug__:
-            type_hints = typing.get_type_hints(getattr(MlflowModel, "last_updated_timestamp").fset)
+            type_hints = typing.get_type_hints(_typecheckingstub__da1a38ca8cd6822434a3168e44c6f18531768176b24dfc71ee2be02a8303a514)
             check_type(argname="argument value", value=value, expected_type=type_hints["value"])
         jsii.set(self, "lastUpdatedTimestamp", value)
 
@@ -246,7 +246,7 @@ class MlflowModel(
     @name.setter
     def name(self, value: builtins.str) -> None:
         if __debug__:
-            type_hints = typing.get_type_hints(getattr(MlflowModel, "name").fset)
+            type_hints = typing.get_type_hints(_typecheckingstub__0023d526a1cc3af6ea5a53475032aba11efebb81436fea9e84be9c9d0795d3d4)
             check_type(argname="argument value", value=value, expected_type=type_hints["value"])
         jsii.set(self, "name", value)
 
@@ -258,7 +258,7 @@ class MlflowModel(
     @registered_model_id.setter
     def registered_model_id(self, value: builtins.str) -> None:
         if __debug__:
-            type_hints = typing.get_type_hints(getattr(MlflowModel, "registered_model_id").fset)
+            type_hints = typing.get_type_hints(_typecheckingstub__475e47726a64a35fe775f3e9ac95dd7db07449a8100f778ad4dcf0e65a80ac21)
             check_type(argname="argument value", value=value, expected_type=type_hints["value"])
         jsii.set(self, "registeredModelId", value)
 
@@ -270,14 +270,14 @@ class MlflowModel(
     @user_id.setter
     def user_id(self, value: builtins.str) -> None:
         if __debug__:
-            type_hints = typing.get_type_hints(getattr(MlflowModel, "user_id").fset)
+            type_hints = typing.get_type_hints(_typecheckingstub__a641dd97e50785e99f3993aab2ca7f90a3b68e2cf9826b34590ebc06b5594851)
             check_type(argname="argument value", value=value, expected_type=type_hints["value"])
         jsii.set(self, "userId", value)
 
 
 @jsii.data_type(
     jsii_type="@cdktf/provider-databricks.mlflowModel.MlflowModelConfig",
-    jsii_struct_bases=[cdktf.TerraformMetaArguments],
+    jsii_struct_bases=[_cdktf_9a9027ec.TerraformMetaArguments],
     name_mapping={
         "connection": "connection",
         "count": "count",
@@ -296,24 +296,24 @@ class MlflowModel(
         "user_id": "userId",
     },
 )
-class MlflowModelConfig(cdktf.TerraformMetaArguments):
+class MlflowModelConfig(_cdktf_9a9027ec.TerraformMetaArguments):
     def __init__(
         self,
         *,
-        connection: typing.Optional[typing.Union[typing.Union[cdktf.SSHProvisionerConnection, typing.Dict[str, typing.Any]], typing.Union[cdktf.WinrmProvisionerConnection, typing.Dict[str, typing.Any]]]] = None,
+        connection: typing.Optional[typing.Union[typing.Union[_cdktf_9a9027ec.SSHProvisionerConnection, typing.Dict[builtins.str, typing.Any]], typing.Union[_cdktf_9a9027ec.WinrmProvisionerConnection, typing.Dict[builtins.str, typing.Any]]]] = None,
         count: typing.Optional[jsii.Number] = None,
-        depends_on: typing.Optional[typing.Sequence[cdktf.ITerraformDependable]] = None,
-        for_each: typing.Optional[cdktf.ITerraformIterator] = None,
-        lifecycle: typing.Optional[typing.Union[cdktf.TerraformResourceLifecycle, typing.Dict[str, typing.Any]]] = None,
-        provider: typing.Optional[cdktf.TerraformProvider] = None,
-        provisioners: typing.Optional[typing.Sequence[typing.Union[typing.Union[cdktf.FileProvisioner, typing.Dict[str, typing.Any]], typing.Union[cdktf.LocalExecProvisioner, typing.Dict[str, typing.Any]], typing.Union[cdktf.RemoteExecProvisioner, typing.Dict[str, typing.Any]]]]] = None,
+        depends_on: typing.Optional[typing.Sequence[_cdktf_9a9027ec.ITerraformDependable]] = None,
+        for_each: typing.Optional[_cdktf_9a9027ec.ITerraformIterator] = None,
+        lifecycle: typing.Optional[typing.Union[_cdktf_9a9027ec.TerraformResourceLifecycle, typing.Dict[builtins.str, typing.Any]]] = None,
+        provider: typing.Optional[_cdktf_9a9027ec.TerraformProvider] = None,
+        provisioners: typing.Optional[typing.Sequence[typing.Union[typing.Union[_cdktf_9a9027ec.FileProvisioner, typing.Dict[builtins.str, typing.Any]], typing.Union[_cdktf_9a9027ec.LocalExecProvisioner, typing.Dict[builtins.str, typing.Any]], typing.Union[_cdktf_9a9027ec.RemoteExecProvisioner, typing.Dict[builtins.str, typing.Any]]]]] = None,
         name: builtins.str,
         creation_timestamp: typing.Optional[jsii.Number] = None,
         description: typing.Optional[builtins.str] = None,
         id: typing.Optional[builtins.str] = None,
         last_updated_timestamp: typing.Optional[jsii.Number] = None,
         registered_model_id: typing.Optional[builtins.str] = None,
-        tags: typing.Optional[typing.Union[cdktf.IResolvable, typing.Sequence[typing.Union["MlflowModelTags", typing.Dict[str, typing.Any]]]]] = None,
+        tags: typing.Optional[typing.Union[_cdktf_9a9027ec.IResolvable, typing.Sequence[typing.Union["MlflowModelTags", typing.Dict[builtins.str, typing.Any]]]]] = None,
         user_id: typing.Optional[builtins.str] = None,
     ) -> None:
         '''
@@ -334,9 +334,9 @@ class MlflowModelConfig(cdktf.TerraformMetaArguments):
         :param user_id: Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/databricks/r/mlflow_model#user_id MlflowModel#user_id}.
         '''
         if isinstance(lifecycle, dict):
-            lifecycle = cdktf.TerraformResourceLifecycle(**lifecycle)
+            lifecycle = _cdktf_9a9027ec.TerraformResourceLifecycle(**lifecycle)
         if __debug__:
-            type_hints = typing.get_type_hints(MlflowModelConfig.__init__)
+            type_hints = typing.get_type_hints(_typecheckingstub__a28ea3b2e2cc4250ebcc1802f5eb50f8ac5bf05c1cf67e23be325c19d935b8b7)
             check_type(argname="argument connection", value=connection, expected_type=type_hints["connection"])
             check_type(argname="argument count", value=count, expected_type=type_hints["count"])
             check_type(argname="argument depends_on", value=depends_on, expected_type=type_hints["depends_on"])
@@ -352,7 +352,7 @@ class MlflowModelConfig(cdktf.TerraformMetaArguments):
             check_type(argname="argument registered_model_id", value=registered_model_id, expected_type=type_hints["registered_model_id"])
             check_type(argname="argument tags", value=tags, expected_type=type_hints["tags"])
             check_type(argname="argument user_id", value=user_id, expected_type=type_hints["user_id"])
-        self._values: typing.Dict[str, typing.Any] = {
+        self._values: typing.Dict[builtins.str, typing.Any] = {
             "name": name,
         }
         if connection is not None:
@@ -387,12 +387,12 @@ class MlflowModelConfig(cdktf.TerraformMetaArguments):
     @builtins.property
     def connection(
         self,
-    ) -> typing.Optional[typing.Union[cdktf.SSHProvisionerConnection, cdktf.WinrmProvisionerConnection]]:
+    ) -> typing.Optional[typing.Union[_cdktf_9a9027ec.SSHProvisionerConnection, _cdktf_9a9027ec.WinrmProvisionerConnection]]:
         '''
         :stability: experimental
         '''
         result = self._values.get("connection")
-        return typing.cast(typing.Optional[typing.Union[cdktf.SSHProvisionerConnection, cdktf.WinrmProvisionerConnection]], result)
+        return typing.cast(typing.Optional[typing.Union[_cdktf_9a9027ec.SSHProvisionerConnection, _cdktf_9a9027ec.WinrmProvisionerConnection]], result)
 
     @builtins.property
     def count(self) -> typing.Optional[jsii.Number]:
@@ -403,46 +403,48 @@ class MlflowModelConfig(cdktf.TerraformMetaArguments):
         return typing.cast(typing.Optional[jsii.Number], result)
 
     @builtins.property
-    def depends_on(self) -> typing.Optional[typing.List[cdktf.ITerraformDependable]]:
+    def depends_on(
+        self,
+    ) -> typing.Optional[typing.List[_cdktf_9a9027ec.ITerraformDependable]]:
         '''
         :stability: experimental
         '''
         result = self._values.get("depends_on")
-        return typing.cast(typing.Optional[typing.List[cdktf.ITerraformDependable]], result)
+        return typing.cast(typing.Optional[typing.List[_cdktf_9a9027ec.ITerraformDependable]], result)
 
     @builtins.property
-    def for_each(self) -> typing.Optional[cdktf.ITerraformIterator]:
+    def for_each(self) -> typing.Optional[_cdktf_9a9027ec.ITerraformIterator]:
         '''
         :stability: experimental
         '''
         result = self._values.get("for_each")
-        return typing.cast(typing.Optional[cdktf.ITerraformIterator], result)
+        return typing.cast(typing.Optional[_cdktf_9a9027ec.ITerraformIterator], result)
 
     @builtins.property
-    def lifecycle(self) -> typing.Optional[cdktf.TerraformResourceLifecycle]:
+    def lifecycle(self) -> typing.Optional[_cdktf_9a9027ec.TerraformResourceLifecycle]:
         '''
         :stability: experimental
         '''
         result = self._values.get("lifecycle")
-        return typing.cast(typing.Optional[cdktf.TerraformResourceLifecycle], result)
+        return typing.cast(typing.Optional[_cdktf_9a9027ec.TerraformResourceLifecycle], result)
 
     @builtins.property
-    def provider(self) -> typing.Optional[cdktf.TerraformProvider]:
+    def provider(self) -> typing.Optional[_cdktf_9a9027ec.TerraformProvider]:
         '''
         :stability: experimental
         '''
         result = self._values.get("provider")
-        return typing.cast(typing.Optional[cdktf.TerraformProvider], result)
+        return typing.cast(typing.Optional[_cdktf_9a9027ec.TerraformProvider], result)
 
     @builtins.property
     def provisioners(
         self,
-    ) -> typing.Optional[typing.List[typing.Union[cdktf.FileProvisioner, cdktf.LocalExecProvisioner, cdktf.RemoteExecProvisioner]]]:
+    ) -> typing.Optional[typing.List[typing.Union[_cdktf_9a9027ec.FileProvisioner, _cdktf_9a9027ec.LocalExecProvisioner, _cdktf_9a9027ec.RemoteExecProvisioner]]]:
         '''
         :stability: experimental
         '''
         result = self._values.get("provisioners")
-        return typing.cast(typing.Optional[typing.List[typing.Union[cdktf.FileProvisioner, cdktf.LocalExecProvisioner, cdktf.RemoteExecProvisioner]]], result)
+        return typing.cast(typing.Optional[typing.List[typing.Union[_cdktf_9a9027ec.FileProvisioner, _cdktf_9a9027ec.LocalExecProvisioner, _cdktf_9a9027ec.RemoteExecProvisioner]]], result)
 
     @builtins.property
     def name(self) -> builtins.str:
@@ -488,13 +490,13 @@ class MlflowModelConfig(cdktf.TerraformMetaArguments):
     @builtins.property
     def tags(
         self,
-    ) -> typing.Optional[typing.Union[cdktf.IResolvable, typing.List["MlflowModelTags"]]]:
+    ) -> typing.Optional[typing.Union[_cdktf_9a9027ec.IResolvable, typing.List["MlflowModelTags"]]]:
         '''tags block.
 
         Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/databricks/r/mlflow_model#tags MlflowModel#tags}
         '''
         result = self._values.get("tags")
-        return typing.cast(typing.Optional[typing.Union[cdktf.IResolvable, typing.List["MlflowModelTags"]]], result)
+        return typing.cast(typing.Optional[typing.Union[_cdktf_9a9027ec.IResolvable, typing.List["MlflowModelTags"]]], result)
 
     @builtins.property
     def user_id(self) -> typing.Optional[builtins.str]:
@@ -526,10 +528,10 @@ class MlflowModelTags:
         :param value: Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/databricks/r/mlflow_model#value MlflowModel#value}.
         '''
         if __debug__:
-            type_hints = typing.get_type_hints(MlflowModelTags.__init__)
+            type_hints = typing.get_type_hints(_typecheckingstub__35b94db2df78dbadd2c1bf30814533bda7707d1b33cf7bc971fc3977bb0a3839)
             check_type(argname="argument key", value=key, expected_type=type_hints["key"])
             check_type(argname="argument value", value=value, expected_type=type_hints["value"])
-        self._values: typing.Dict[str, typing.Any] = {
+        self._values: typing.Dict[builtins.str, typing.Any] = {
             "key": key,
             "value": value,
         }
@@ -561,13 +563,13 @@ class MlflowModelTags:
 
 
 class MlflowModelTagsList(
-    cdktf.ComplexList,
+    _cdktf_9a9027ec.ComplexList,
     metaclass=jsii.JSIIMeta,
     jsii_type="@cdktf/provider-databricks.mlflowModel.MlflowModelTagsList",
 ):
     def __init__(
         self,
-        terraform_resource: cdktf.IInterpolatingParent,
+        terraform_resource: _cdktf_9a9027ec.IInterpolatingParent,
         terraform_attribute: builtins.str,
         wraps_set: builtins.bool,
     ) -> None:
@@ -577,7 +579,7 @@ class MlflowModelTagsList(
         :param wraps_set: whether the list is wrapping a set (will add tolist() to be able to access an item via an index).
         '''
         if __debug__:
-            type_hints = typing.get_type_hints(MlflowModelTagsList.__init__)
+            type_hints = typing.get_type_hints(_typecheckingstub__ed958ecf318bf30f1511f3924e518becfff7a7ecbf27922429f1fb91193421d2)
             check_type(argname="argument terraform_resource", value=terraform_resource, expected_type=type_hints["terraform_resource"])
             check_type(argname="argument terraform_attribute", value=terraform_attribute, expected_type=type_hints["terraform_attribute"])
             check_type(argname="argument wraps_set", value=wraps_set, expected_type=type_hints["wraps_set"])
@@ -589,7 +591,7 @@ class MlflowModelTagsList(
         :param index: the index of the item to return.
         '''
         if __debug__:
-            type_hints = typing.get_type_hints(MlflowModelTagsList.get)
+            type_hints = typing.get_type_hints(_typecheckingstub__6be78248b1a5f36b0d84c6aaee7f54f69c51316be654dec572225ecc7622acab)
             check_type(argname="argument index", value=index, expected_type=type_hints["index"])
         return typing.cast("MlflowModelTagsOutputReference", jsii.invoke(self, "get", [index]))
 
@@ -602,20 +604,20 @@ class MlflowModelTagsList(
     @_terraform_attribute.setter
     def _terraform_attribute(self, value: builtins.str) -> None:
         if __debug__:
-            type_hints = typing.get_type_hints(getattr(MlflowModelTagsList, "_terraform_attribute").fset)
+            type_hints = typing.get_type_hints(_typecheckingstub__16dd5dcbcc9c3eb126faedaaf2b27c9cbc0291c8d54d0f1ec74bde76d093b397)
             check_type(argname="argument value", value=value, expected_type=type_hints["value"])
         jsii.set(self, "terraformAttribute", value)
 
     @builtins.property
     @jsii.member(jsii_name="terraformResource")
-    def _terraform_resource(self) -> cdktf.IInterpolatingParent:
+    def _terraform_resource(self) -> _cdktf_9a9027ec.IInterpolatingParent:
         '''The parent resource.'''
-        return typing.cast(cdktf.IInterpolatingParent, jsii.get(self, "terraformResource"))
+        return typing.cast(_cdktf_9a9027ec.IInterpolatingParent, jsii.get(self, "terraformResource"))
 
     @_terraform_resource.setter
-    def _terraform_resource(self, value: cdktf.IInterpolatingParent) -> None:
+    def _terraform_resource(self, value: _cdktf_9a9027ec.IInterpolatingParent) -> None:
         if __debug__:
-            type_hints = typing.get_type_hints(getattr(MlflowModelTagsList, "_terraform_resource").fset)
+            type_hints = typing.get_type_hints(_typecheckingstub__1d02570d5de010db60529393d2ed660126d5f070741c4a01d827951660921924)
             check_type(argname="argument value", value=value, expected_type=type_hints["value"])
         jsii.set(self, "terraformResource", value)
 
@@ -628,7 +630,7 @@ class MlflowModelTagsList(
     @_wraps_set.setter
     def _wraps_set(self, value: builtins.bool) -> None:
         if __debug__:
-            type_hints = typing.get_type_hints(getattr(MlflowModelTagsList, "_wraps_set").fset)
+            type_hints = typing.get_type_hints(_typecheckingstub__f0d7ee0bc2823ee818e98c54cb7115173821196c443e73e018ec3f464fcad106)
             check_type(argname="argument value", value=value, expected_type=type_hints["value"])
         jsii.set(self, "wrapsSet", value)
 
@@ -636,28 +638,28 @@ class MlflowModelTagsList(
     @jsii.member(jsii_name="internalValue")
     def internal_value(
         self,
-    ) -> typing.Optional[typing.Union[cdktf.IResolvable, typing.List[MlflowModelTags]]]:
-        return typing.cast(typing.Optional[typing.Union[cdktf.IResolvable, typing.List[MlflowModelTags]]], jsii.get(self, "internalValue"))
+    ) -> typing.Optional[typing.Union[_cdktf_9a9027ec.IResolvable, typing.List[MlflowModelTags]]]:
+        return typing.cast(typing.Optional[typing.Union[_cdktf_9a9027ec.IResolvable, typing.List[MlflowModelTags]]], jsii.get(self, "internalValue"))
 
     @internal_value.setter
     def internal_value(
         self,
-        value: typing.Optional[typing.Union[cdktf.IResolvable, typing.List[MlflowModelTags]]],
+        value: typing.Optional[typing.Union[_cdktf_9a9027ec.IResolvable, typing.List[MlflowModelTags]]],
     ) -> None:
         if __debug__:
-            type_hints = typing.get_type_hints(getattr(MlflowModelTagsList, "internal_value").fset)
+            type_hints = typing.get_type_hints(_typecheckingstub__668435f6d57d52b7aa1a2e9639df1fcb98b685e5ae5b43e03531cd48d12ea7f3)
             check_type(argname="argument value", value=value, expected_type=type_hints["value"])
         jsii.set(self, "internalValue", value)
 
 
 class MlflowModelTagsOutputReference(
-    cdktf.ComplexObject,
+    _cdktf_9a9027ec.ComplexObject,
     metaclass=jsii.JSIIMeta,
     jsii_type="@cdktf/provider-databricks.mlflowModel.MlflowModelTagsOutputReference",
 ):
     def __init__(
         self,
-        terraform_resource: cdktf.IInterpolatingParent,
+        terraform_resource: _cdktf_9a9027ec.IInterpolatingParent,
         terraform_attribute: builtins.str,
         complex_object_index: jsii.Number,
         complex_object_is_from_set: builtins.bool,
@@ -669,7 +671,7 @@ class MlflowModelTagsOutputReference(
         :param complex_object_is_from_set: whether the list is wrapping a set (will add tolist() to be able to access an item via an index).
         '''
         if __debug__:
-            type_hints = typing.get_type_hints(MlflowModelTagsOutputReference.__init__)
+            type_hints = typing.get_type_hints(_typecheckingstub__5aee858f4fb029e269c93ee77b0f217c9c7335881353247fc8968f2be0f3aff5)
             check_type(argname="argument terraform_resource", value=terraform_resource, expected_type=type_hints["terraform_resource"])
             check_type(argname="argument terraform_attribute", value=terraform_attribute, expected_type=type_hints["terraform_attribute"])
             check_type(argname="argument complex_object_index", value=complex_object_index, expected_type=type_hints["complex_object_index"])
@@ -694,7 +696,7 @@ class MlflowModelTagsOutputReference(
     @key.setter
     def key(self, value: builtins.str) -> None:
         if __debug__:
-            type_hints = typing.get_type_hints(getattr(MlflowModelTagsOutputReference, "key").fset)
+            type_hints = typing.get_type_hints(_typecheckingstub__231643bf0e99fd8d03f8a0af3cf71be35b20b97add51d6cc5456d95616b83c00)
             check_type(argname="argument value", value=value, expected_type=type_hints["value"])
         jsii.set(self, "key", value)
 
@@ -706,7 +708,7 @@ class MlflowModelTagsOutputReference(
     @value.setter
     def value(self, value: builtins.str) -> None:
         if __debug__:
-            type_hints = typing.get_type_hints(getattr(MlflowModelTagsOutputReference, "value").fset)
+            type_hints = typing.get_type_hints(_typecheckingstub__1f523c69372dab798c3049f9ac1c926c9349d1eca00393740bc914f5fda9ba2c)
             check_type(argname="argument value", value=value, expected_type=type_hints["value"])
         jsii.set(self, "value", value)
 
@@ -714,16 +716,16 @@ class MlflowModelTagsOutputReference(
     @jsii.member(jsii_name="internalValue")
     def internal_value(
         self,
-    ) -> typing.Optional[typing.Union[MlflowModelTags, cdktf.IResolvable]]:
-        return typing.cast(typing.Optional[typing.Union[MlflowModelTags, cdktf.IResolvable]], jsii.get(self, "internalValue"))
+    ) -> typing.Optional[typing.Union[MlflowModelTags, _cdktf_9a9027ec.IResolvable]]:
+        return typing.cast(typing.Optional[typing.Union[MlflowModelTags, _cdktf_9a9027ec.IResolvable]], jsii.get(self, "internalValue"))
 
     @internal_value.setter
     def internal_value(
         self,
-        value: typing.Optional[typing.Union[MlflowModelTags, cdktf.IResolvable]],
+        value: typing.Optional[typing.Union[MlflowModelTags, _cdktf_9a9027ec.IResolvable]],
     ) -> None:
         if __debug__:
-            type_hints = typing.get_type_hints(getattr(MlflowModelTagsOutputReference, "internal_value").fset)
+            type_hints = typing.get_type_hints(_typecheckingstub__6c7abf425167c7731c8af3581efdaee163cf7e306fec8b257f9bc7ca1957c15e)
             check_type(argname="argument value", value=value, expected_type=type_hints["value"])
         jsii.set(self, "internalValue", value)
 
@@ -737,3 +739,168 @@ __all__ = [
 ]
 
 publication.publish()
+
+def _typecheckingstub__bab36b4f3f2418b538ba2c47ade2b43caa4ea7292d9fc94e61a1350214137e6e(
+    scope: _constructs_77d1e7e8.Construct,
+    id_: builtins.str,
+    *,
+    name: builtins.str,
+    creation_timestamp: typing.Optional[jsii.Number] = None,
+    description: typing.Optional[builtins.str] = None,
+    id: typing.Optional[builtins.str] = None,
+    last_updated_timestamp: typing.Optional[jsii.Number] = None,
+    registered_model_id: typing.Optional[builtins.str] = None,
+    tags: typing.Optional[typing.Union[_cdktf_9a9027ec.IResolvable, typing.Sequence[typing.Union[MlflowModelTags, typing.Dict[builtins.str, typing.Any]]]]] = None,
+    user_id: typing.Optional[builtins.str] = None,
+    connection: typing.Optional[typing.Union[typing.Union[_cdktf_9a9027ec.SSHProvisionerConnection, typing.Dict[builtins.str, typing.Any]], typing.Union[_cdktf_9a9027ec.WinrmProvisionerConnection, typing.Dict[builtins.str, typing.Any]]]] = None,
+    count: typing.Optional[jsii.Number] = None,
+    depends_on: typing.Optional[typing.Sequence[_cdktf_9a9027ec.ITerraformDependable]] = None,
+    for_each: typing.Optional[_cdktf_9a9027ec.ITerraformIterator] = None,
+    lifecycle: typing.Optional[typing.Union[_cdktf_9a9027ec.TerraformResourceLifecycle, typing.Dict[builtins.str, typing.Any]]] = None,
+    provider: typing.Optional[_cdktf_9a9027ec.TerraformProvider] = None,
+    provisioners: typing.Optional[typing.Sequence[typing.Union[typing.Union[_cdktf_9a9027ec.FileProvisioner, typing.Dict[builtins.str, typing.Any]], typing.Union[_cdktf_9a9027ec.LocalExecProvisioner, typing.Dict[builtins.str, typing.Any]], typing.Union[_cdktf_9a9027ec.RemoteExecProvisioner, typing.Dict[builtins.str, typing.Any]]]]] = None,
+) -> None:
+    """Type checking stubs"""
+    pass
+
+def _typecheckingstub__b7f28d776513880e7d7abef68fa62fa1d18b3c68aa96e42ee1b661b4791ea961(
+    value: typing.Union[_cdktf_9a9027ec.IResolvable, typing.Sequence[typing.Union[MlflowModelTags, typing.Dict[builtins.str, typing.Any]]]],
+) -> None:
+    """Type checking stubs"""
+    pass
+
+def _typecheckingstub__0df41ec9b186aed8b85aac2a123fff95f6bad4c1f61c72133c4e6ddd300a3009(
+    value: jsii.Number,
+) -> None:
+    """Type checking stubs"""
+    pass
+
+def _typecheckingstub__d9a8473387bf160042966a31544eee7d4c48f514de1f4c7bfb0bf5b44002faef(
+    value: builtins.str,
+) -> None:
+    """Type checking stubs"""
+    pass
+
+def _typecheckingstub__84a2a9153865f72de498d1e2e2c3f29c7bc198f8f3905587bd377768a87b55c0(
+    value: builtins.str,
+) -> None:
+    """Type checking stubs"""
+    pass
+
+def _typecheckingstub__da1a38ca8cd6822434a3168e44c6f18531768176b24dfc71ee2be02a8303a514(
+    value: jsii.Number,
+) -> None:
+    """Type checking stubs"""
+    pass
+
+def _typecheckingstub__0023d526a1cc3af6ea5a53475032aba11efebb81436fea9e84be9c9d0795d3d4(
+    value: builtins.str,
+) -> None:
+    """Type checking stubs"""
+    pass
+
+def _typecheckingstub__475e47726a64a35fe775f3e9ac95dd7db07449a8100f778ad4dcf0e65a80ac21(
+    value: builtins.str,
+) -> None:
+    """Type checking stubs"""
+    pass
+
+def _typecheckingstub__a641dd97e50785e99f3993aab2ca7f90a3b68e2cf9826b34590ebc06b5594851(
+    value: builtins.str,
+) -> None:
+    """Type checking stubs"""
+    pass
+
+def _typecheckingstub__a28ea3b2e2cc4250ebcc1802f5eb50f8ac5bf05c1cf67e23be325c19d935b8b7(
+    *,
+    connection: typing.Optional[typing.Union[typing.Union[_cdktf_9a9027ec.SSHProvisionerConnection, typing.Dict[builtins.str, typing.Any]], typing.Union[_cdktf_9a9027ec.WinrmProvisionerConnection, typing.Dict[builtins.str, typing.Any]]]] = None,
+    count: typing.Optional[jsii.Number] = None,
+    depends_on: typing.Optional[typing.Sequence[_cdktf_9a9027ec.ITerraformDependable]] = None,
+    for_each: typing.Optional[_cdktf_9a9027ec.ITerraformIterator] = None,
+    lifecycle: typing.Optional[typing.Union[_cdktf_9a9027ec.TerraformResourceLifecycle, typing.Dict[builtins.str, typing.Any]]] = None,
+    provider: typing.Optional[_cdktf_9a9027ec.TerraformProvider] = None,
+    provisioners: typing.Optional[typing.Sequence[typing.Union[typing.Union[_cdktf_9a9027ec.FileProvisioner, typing.Dict[builtins.str, typing.Any]], typing.Union[_cdktf_9a9027ec.LocalExecProvisioner, typing.Dict[builtins.str, typing.Any]], typing.Union[_cdktf_9a9027ec.RemoteExecProvisioner, typing.Dict[builtins.str, typing.Any]]]]] = None,
+    name: builtins.str,
+    creation_timestamp: typing.Optional[jsii.Number] = None,
+    description: typing.Optional[builtins.str] = None,
+    id: typing.Optional[builtins.str] = None,
+    last_updated_timestamp: typing.Optional[jsii.Number] = None,
+    registered_model_id: typing.Optional[builtins.str] = None,
+    tags: typing.Optional[typing.Union[_cdktf_9a9027ec.IResolvable, typing.Sequence[typing.Union[MlflowModelTags, typing.Dict[builtins.str, typing.Any]]]]] = None,
+    user_id: typing.Optional[builtins.str] = None,
+) -> None:
+    """Type checking stubs"""
+    pass
+
+def _typecheckingstub__35b94db2df78dbadd2c1bf30814533bda7707d1b33cf7bc971fc3977bb0a3839(
+    *,
+    key: builtins.str,
+    value: builtins.str,
+) -> None:
+    """Type checking stubs"""
+    pass
+
+def _typecheckingstub__ed958ecf318bf30f1511f3924e518becfff7a7ecbf27922429f1fb91193421d2(
+    terraform_resource: _cdktf_9a9027ec.IInterpolatingParent,
+    terraform_attribute: builtins.str,
+    wraps_set: builtins.bool,
+) -> None:
+    """Type checking stubs"""
+    pass
+
+def _typecheckingstub__6be78248b1a5f36b0d84c6aaee7f54f69c51316be654dec572225ecc7622acab(
+    index: jsii.Number,
+) -> None:
+    """Type checking stubs"""
+    pass
+
+def _typecheckingstub__16dd5dcbcc9c3eb126faedaaf2b27c9cbc0291c8d54d0f1ec74bde76d093b397(
+    value: builtins.str,
+) -> None:
+    """Type checking stubs"""
+    pass
+
+def _typecheckingstub__1d02570d5de010db60529393d2ed660126d5f070741c4a01d827951660921924(
+    value: _cdktf_9a9027ec.IInterpolatingParent,
+) -> None:
+    """Type checking stubs"""
+    pass
+
+def _typecheckingstub__f0d7ee0bc2823ee818e98c54cb7115173821196c443e73e018ec3f464fcad106(
+    value: builtins.bool,
+) -> None:
+    """Type checking stubs"""
+    pass
+
+def _typecheckingstub__668435f6d57d52b7aa1a2e9639df1fcb98b685e5ae5b43e03531cd48d12ea7f3(
+    value: typing.Optional[typing.Union[_cdktf_9a9027ec.IResolvable, typing.List[MlflowModelTags]]],
+) -> None:
+    """Type checking stubs"""
+    pass
+
+def _typecheckingstub__5aee858f4fb029e269c93ee77b0f217c9c7335881353247fc8968f2be0f3aff5(
+    terraform_resource: _cdktf_9a9027ec.IInterpolatingParent,
+    terraform_attribute: builtins.str,
+    complex_object_index: jsii.Number,
+    complex_object_is_from_set: builtins.bool,
+) -> None:
+    """Type checking stubs"""
+    pass
+
+def _typecheckingstub__231643bf0e99fd8d03f8a0af3cf71be35b20b97add51d6cc5456d95616b83c00(
+    value: builtins.str,
+) -> None:
+    """Type checking stubs"""
+    pass
+
+def _typecheckingstub__1f523c69372dab798c3049f9ac1c926c9349d1eca00393740bc914f5fda9ba2c(
+    value: builtins.str,
+) -> None:
+    """Type checking stubs"""
+    pass
+
+def _typecheckingstub__6c7abf425167c7731c8af3581efdaee163cf7e306fec8b257f9bc7ca1957c15e(
+    value: typing.Optional[typing.Union[MlflowModelTags, _cdktf_9a9027ec.IResolvable]],
+) -> None:
+    """Type checking stubs"""
+    pass
