@@ -17,12 +17,12 @@ from typeguard import check_type
 
 from .._jsii import *
 
-import cdktf
-import constructs
+import cdktf as _cdktf_9a9027ec
+import constructs as _constructs_77d1e7e8
 
 
 class MlflowWebhook(
-    cdktf.TerraformResource,
+    _cdktf_9a9027ec.TerraformResource,
     metaclass=jsii.JSIIMeta,
     jsii_type="@cdktf/provider-databricks.mlflowWebhook.MlflowWebhook",
 ):
@@ -30,23 +30,23 @@ class MlflowWebhook(
 
     def __init__(
         self,
-        scope: constructs.Construct,
+        scope: _constructs_77d1e7e8.Construct,
         id_: builtins.str,
         *,
         events: typing.Sequence[builtins.str],
         description: typing.Optional[builtins.str] = None,
-        http_url_spec: typing.Optional[typing.Union["MlflowWebhookHttpUrlSpec", typing.Dict[str, typing.Any]]] = None,
+        http_url_spec: typing.Optional[typing.Union["MlflowWebhookHttpUrlSpec", typing.Dict[builtins.str, typing.Any]]] = None,
         id: typing.Optional[builtins.str] = None,
-        job_spec: typing.Optional[typing.Union["MlflowWebhookJobSpec", typing.Dict[str, typing.Any]]] = None,
+        job_spec: typing.Optional[typing.Union["MlflowWebhookJobSpec", typing.Dict[builtins.str, typing.Any]]] = None,
         model_name: typing.Optional[builtins.str] = None,
         status: typing.Optional[builtins.str] = None,
-        connection: typing.Optional[typing.Union[typing.Union[cdktf.SSHProvisionerConnection, typing.Dict[str, typing.Any]], typing.Union[cdktf.WinrmProvisionerConnection, typing.Dict[str, typing.Any]]]] = None,
+        connection: typing.Optional[typing.Union[typing.Union[_cdktf_9a9027ec.SSHProvisionerConnection, typing.Dict[builtins.str, typing.Any]], typing.Union[_cdktf_9a9027ec.WinrmProvisionerConnection, typing.Dict[builtins.str, typing.Any]]]] = None,
         count: typing.Optional[jsii.Number] = None,
-        depends_on: typing.Optional[typing.Sequence[cdktf.ITerraformDependable]] = None,
-        for_each: typing.Optional[cdktf.ITerraformIterator] = None,
-        lifecycle: typing.Optional[typing.Union[cdktf.TerraformResourceLifecycle, typing.Dict[str, typing.Any]]] = None,
-        provider: typing.Optional[cdktf.TerraformProvider] = None,
-        provisioners: typing.Optional[typing.Sequence[typing.Union[typing.Union[cdktf.FileProvisioner, typing.Dict[str, typing.Any]], typing.Union[cdktf.LocalExecProvisioner, typing.Dict[str, typing.Any]], typing.Union[cdktf.RemoteExecProvisioner, typing.Dict[str, typing.Any]]]]] = None,
+        depends_on: typing.Optional[typing.Sequence[_cdktf_9a9027ec.ITerraformDependable]] = None,
+        for_each: typing.Optional[_cdktf_9a9027ec.ITerraformIterator] = None,
+        lifecycle: typing.Optional[typing.Union[_cdktf_9a9027ec.TerraformResourceLifecycle, typing.Dict[builtins.str, typing.Any]]] = None,
+        provider: typing.Optional[_cdktf_9a9027ec.TerraformProvider] = None,
+        provisioners: typing.Optional[typing.Sequence[typing.Union[typing.Union[_cdktf_9a9027ec.FileProvisioner, typing.Dict[builtins.str, typing.Any]], typing.Union[_cdktf_9a9027ec.LocalExecProvisioner, typing.Dict[builtins.str, typing.Any]], typing.Union[_cdktf_9a9027ec.RemoteExecProvisioner, typing.Dict[builtins.str, typing.Any]]]]] = None,
     ) -> None:
         '''Create a new {@link https://www.terraform.io/docs/providers/databricks/r/mlflow_webhook databricks_mlflow_webhook} Resource.
 
@@ -68,7 +68,7 @@ class MlflowWebhook(
         :param provisioners: 
         '''
         if __debug__:
-            type_hints = typing.get_type_hints(MlflowWebhook.__init__)
+            type_hints = typing.get_type_hints(_typecheckingstub__9f232a4f020f1195c887ea48a25a4b28369976f829ee1e01451e1832008244bc)
             check_type(argname="argument scope", value=scope, expected_type=type_hints["scope"])
             check_type(argname="argument id_", value=id_, expected_type=type_hints["id_"])
         config = MlflowWebhookConfig(
@@ -96,7 +96,7 @@ class MlflowWebhook(
         *,
         url: builtins.str,
         authorization: typing.Optional[builtins.str] = None,
-        enable_ssl_verification: typing.Optional[typing.Union[builtins.bool, cdktf.IResolvable]] = None,
+        enable_ssl_verification: typing.Optional[typing.Union[builtins.bool, _cdktf_9a9027ec.IResolvable]] = None,
         secret: typing.Optional[builtins.str] = None,
     ) -> None:
         '''
@@ -219,7 +219,7 @@ class MlflowWebhook(
     @description.setter
     def description(self, value: builtins.str) -> None:
         if __debug__:
-            type_hints = typing.get_type_hints(getattr(MlflowWebhook, "description").fset)
+            type_hints = typing.get_type_hints(_typecheckingstub__48b43463662ed503311668db84261241402b6d81c6b9556a79171dd2d481e5d1)
             check_type(argname="argument value", value=value, expected_type=type_hints["value"])
         jsii.set(self, "description", value)
 
@@ -231,7 +231,7 @@ class MlflowWebhook(
     @events.setter
     def events(self, value: typing.List[builtins.str]) -> None:
         if __debug__:
-            type_hints = typing.get_type_hints(getattr(MlflowWebhook, "events").fset)
+            type_hints = typing.get_type_hints(_typecheckingstub__63c32a180557655b134c05d93c7f0f19d72f6f7b2da2988e513315fa82eac7f0)
             check_type(argname="argument value", value=value, expected_type=type_hints["value"])
         jsii.set(self, "events", value)
 
@@ -243,7 +243,7 @@ class MlflowWebhook(
     @id.setter
     def id(self, value: builtins.str) -> None:
         if __debug__:
-            type_hints = typing.get_type_hints(getattr(MlflowWebhook, "id").fset)
+            type_hints = typing.get_type_hints(_typecheckingstub__94c3bf0ce0737dd774efb9613d2d61bfc37ebc1669bd3cfe9e2e5344b0c8d76d)
             check_type(argname="argument value", value=value, expected_type=type_hints["value"])
         jsii.set(self, "id", value)
 
@@ -255,7 +255,7 @@ class MlflowWebhook(
     @model_name.setter
     def model_name(self, value: builtins.str) -> None:
         if __debug__:
-            type_hints = typing.get_type_hints(getattr(MlflowWebhook, "model_name").fset)
+            type_hints = typing.get_type_hints(_typecheckingstub__f5b7d444a899f8703e18ab10086ec59edd9423ad6cf755b8da0d6535f92aaf5d)
             check_type(argname="argument value", value=value, expected_type=type_hints["value"])
         jsii.set(self, "modelName", value)
 
@@ -267,14 +267,14 @@ class MlflowWebhook(
     @status.setter
     def status(self, value: builtins.str) -> None:
         if __debug__:
-            type_hints = typing.get_type_hints(getattr(MlflowWebhook, "status").fset)
+            type_hints = typing.get_type_hints(_typecheckingstub__58b1bf03b434e3701697a10976496b400ab39e2b21c03c4ccc5b4da5be5f3102)
             check_type(argname="argument value", value=value, expected_type=type_hints["value"])
         jsii.set(self, "status", value)
 
 
 @jsii.data_type(
     jsii_type="@cdktf/provider-databricks.mlflowWebhook.MlflowWebhookConfig",
-    jsii_struct_bases=[cdktf.TerraformMetaArguments],
+    jsii_struct_bases=[_cdktf_9a9027ec.TerraformMetaArguments],
     name_mapping={
         "connection": "connection",
         "count": "count",
@@ -292,22 +292,22 @@ class MlflowWebhook(
         "status": "status",
     },
 )
-class MlflowWebhookConfig(cdktf.TerraformMetaArguments):
+class MlflowWebhookConfig(_cdktf_9a9027ec.TerraformMetaArguments):
     def __init__(
         self,
         *,
-        connection: typing.Optional[typing.Union[typing.Union[cdktf.SSHProvisionerConnection, typing.Dict[str, typing.Any]], typing.Union[cdktf.WinrmProvisionerConnection, typing.Dict[str, typing.Any]]]] = None,
+        connection: typing.Optional[typing.Union[typing.Union[_cdktf_9a9027ec.SSHProvisionerConnection, typing.Dict[builtins.str, typing.Any]], typing.Union[_cdktf_9a9027ec.WinrmProvisionerConnection, typing.Dict[builtins.str, typing.Any]]]] = None,
         count: typing.Optional[jsii.Number] = None,
-        depends_on: typing.Optional[typing.Sequence[cdktf.ITerraformDependable]] = None,
-        for_each: typing.Optional[cdktf.ITerraformIterator] = None,
-        lifecycle: typing.Optional[typing.Union[cdktf.TerraformResourceLifecycle, typing.Dict[str, typing.Any]]] = None,
-        provider: typing.Optional[cdktf.TerraformProvider] = None,
-        provisioners: typing.Optional[typing.Sequence[typing.Union[typing.Union[cdktf.FileProvisioner, typing.Dict[str, typing.Any]], typing.Union[cdktf.LocalExecProvisioner, typing.Dict[str, typing.Any]], typing.Union[cdktf.RemoteExecProvisioner, typing.Dict[str, typing.Any]]]]] = None,
+        depends_on: typing.Optional[typing.Sequence[_cdktf_9a9027ec.ITerraformDependable]] = None,
+        for_each: typing.Optional[_cdktf_9a9027ec.ITerraformIterator] = None,
+        lifecycle: typing.Optional[typing.Union[_cdktf_9a9027ec.TerraformResourceLifecycle, typing.Dict[builtins.str, typing.Any]]] = None,
+        provider: typing.Optional[_cdktf_9a9027ec.TerraformProvider] = None,
+        provisioners: typing.Optional[typing.Sequence[typing.Union[typing.Union[_cdktf_9a9027ec.FileProvisioner, typing.Dict[builtins.str, typing.Any]], typing.Union[_cdktf_9a9027ec.LocalExecProvisioner, typing.Dict[builtins.str, typing.Any]], typing.Union[_cdktf_9a9027ec.RemoteExecProvisioner, typing.Dict[builtins.str, typing.Any]]]]] = None,
         events: typing.Sequence[builtins.str],
         description: typing.Optional[builtins.str] = None,
-        http_url_spec: typing.Optional[typing.Union["MlflowWebhookHttpUrlSpec", typing.Dict[str, typing.Any]]] = None,
+        http_url_spec: typing.Optional[typing.Union["MlflowWebhookHttpUrlSpec", typing.Dict[builtins.str, typing.Any]]] = None,
         id: typing.Optional[builtins.str] = None,
-        job_spec: typing.Optional[typing.Union["MlflowWebhookJobSpec", typing.Dict[str, typing.Any]]] = None,
+        job_spec: typing.Optional[typing.Union["MlflowWebhookJobSpec", typing.Dict[builtins.str, typing.Any]]] = None,
         model_name: typing.Optional[builtins.str] = None,
         status: typing.Optional[builtins.str] = None,
     ) -> None:
@@ -328,13 +328,13 @@ class MlflowWebhookConfig(cdktf.TerraformMetaArguments):
         :param status: Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/databricks/r/mlflow_webhook#status MlflowWebhook#status}.
         '''
         if isinstance(lifecycle, dict):
-            lifecycle = cdktf.TerraformResourceLifecycle(**lifecycle)
+            lifecycle = _cdktf_9a9027ec.TerraformResourceLifecycle(**lifecycle)
         if isinstance(http_url_spec, dict):
             http_url_spec = MlflowWebhookHttpUrlSpec(**http_url_spec)
         if isinstance(job_spec, dict):
             job_spec = MlflowWebhookJobSpec(**job_spec)
         if __debug__:
-            type_hints = typing.get_type_hints(MlflowWebhookConfig.__init__)
+            type_hints = typing.get_type_hints(_typecheckingstub__e7b0b71ed197d9864a4a5ceda869aa676a61c1e1dc57374e13732c21b7c5f0b6)
             check_type(argname="argument connection", value=connection, expected_type=type_hints["connection"])
             check_type(argname="argument count", value=count, expected_type=type_hints["count"])
             check_type(argname="argument depends_on", value=depends_on, expected_type=type_hints["depends_on"])
@@ -349,7 +349,7 @@ class MlflowWebhookConfig(cdktf.TerraformMetaArguments):
             check_type(argname="argument job_spec", value=job_spec, expected_type=type_hints["job_spec"])
             check_type(argname="argument model_name", value=model_name, expected_type=type_hints["model_name"])
             check_type(argname="argument status", value=status, expected_type=type_hints["status"])
-        self._values: typing.Dict[str, typing.Any] = {
+        self._values: typing.Dict[builtins.str, typing.Any] = {
             "events": events,
         }
         if connection is not None:
@@ -382,12 +382,12 @@ class MlflowWebhookConfig(cdktf.TerraformMetaArguments):
     @builtins.property
     def connection(
         self,
-    ) -> typing.Optional[typing.Union[cdktf.SSHProvisionerConnection, cdktf.WinrmProvisionerConnection]]:
+    ) -> typing.Optional[typing.Union[_cdktf_9a9027ec.SSHProvisionerConnection, _cdktf_9a9027ec.WinrmProvisionerConnection]]:
         '''
         :stability: experimental
         '''
         result = self._values.get("connection")
-        return typing.cast(typing.Optional[typing.Union[cdktf.SSHProvisionerConnection, cdktf.WinrmProvisionerConnection]], result)
+        return typing.cast(typing.Optional[typing.Union[_cdktf_9a9027ec.SSHProvisionerConnection, _cdktf_9a9027ec.WinrmProvisionerConnection]], result)
 
     @builtins.property
     def count(self) -> typing.Optional[jsii.Number]:
@@ -398,46 +398,48 @@ class MlflowWebhookConfig(cdktf.TerraformMetaArguments):
         return typing.cast(typing.Optional[jsii.Number], result)
 
     @builtins.property
-    def depends_on(self) -> typing.Optional[typing.List[cdktf.ITerraformDependable]]:
+    def depends_on(
+        self,
+    ) -> typing.Optional[typing.List[_cdktf_9a9027ec.ITerraformDependable]]:
         '''
         :stability: experimental
         '''
         result = self._values.get("depends_on")
-        return typing.cast(typing.Optional[typing.List[cdktf.ITerraformDependable]], result)
+        return typing.cast(typing.Optional[typing.List[_cdktf_9a9027ec.ITerraformDependable]], result)
 
     @builtins.property
-    def for_each(self) -> typing.Optional[cdktf.ITerraformIterator]:
+    def for_each(self) -> typing.Optional[_cdktf_9a9027ec.ITerraformIterator]:
         '''
         :stability: experimental
         '''
         result = self._values.get("for_each")
-        return typing.cast(typing.Optional[cdktf.ITerraformIterator], result)
+        return typing.cast(typing.Optional[_cdktf_9a9027ec.ITerraformIterator], result)
 
     @builtins.property
-    def lifecycle(self) -> typing.Optional[cdktf.TerraformResourceLifecycle]:
+    def lifecycle(self) -> typing.Optional[_cdktf_9a9027ec.TerraformResourceLifecycle]:
         '''
         :stability: experimental
         '''
         result = self._values.get("lifecycle")
-        return typing.cast(typing.Optional[cdktf.TerraformResourceLifecycle], result)
+        return typing.cast(typing.Optional[_cdktf_9a9027ec.TerraformResourceLifecycle], result)
 
     @builtins.property
-    def provider(self) -> typing.Optional[cdktf.TerraformProvider]:
+    def provider(self) -> typing.Optional[_cdktf_9a9027ec.TerraformProvider]:
         '''
         :stability: experimental
         '''
         result = self._values.get("provider")
-        return typing.cast(typing.Optional[cdktf.TerraformProvider], result)
+        return typing.cast(typing.Optional[_cdktf_9a9027ec.TerraformProvider], result)
 
     @builtins.property
     def provisioners(
         self,
-    ) -> typing.Optional[typing.List[typing.Union[cdktf.FileProvisioner, cdktf.LocalExecProvisioner, cdktf.RemoteExecProvisioner]]]:
+    ) -> typing.Optional[typing.List[typing.Union[_cdktf_9a9027ec.FileProvisioner, _cdktf_9a9027ec.LocalExecProvisioner, _cdktf_9a9027ec.RemoteExecProvisioner]]]:
         '''
         :stability: experimental
         '''
         result = self._values.get("provisioners")
-        return typing.cast(typing.Optional[typing.List[typing.Union[cdktf.FileProvisioner, cdktf.LocalExecProvisioner, cdktf.RemoteExecProvisioner]]], result)
+        return typing.cast(typing.Optional[typing.List[typing.Union[_cdktf_9a9027ec.FileProvisioner, _cdktf_9a9027ec.LocalExecProvisioner, _cdktf_9a9027ec.RemoteExecProvisioner]]], result)
 
     @builtins.property
     def events(self) -> typing.List[builtins.str]:
@@ -520,7 +522,7 @@ class MlflowWebhookHttpUrlSpec:
         *,
         url: builtins.str,
         authorization: typing.Optional[builtins.str] = None,
-        enable_ssl_verification: typing.Optional[typing.Union[builtins.bool, cdktf.IResolvable]] = None,
+        enable_ssl_verification: typing.Optional[typing.Union[builtins.bool, _cdktf_9a9027ec.IResolvable]] = None,
         secret: typing.Optional[builtins.str] = None,
     ) -> None:
         '''
@@ -530,12 +532,12 @@ class MlflowWebhookHttpUrlSpec:
         :param secret: Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/databricks/r/mlflow_webhook#secret MlflowWebhook#secret}.
         '''
         if __debug__:
-            type_hints = typing.get_type_hints(MlflowWebhookHttpUrlSpec.__init__)
+            type_hints = typing.get_type_hints(_typecheckingstub__73a239e169fb7f0e00d840790cbcbd46ce96281dd071886eeb803d5a65aeac7d)
             check_type(argname="argument url", value=url, expected_type=type_hints["url"])
             check_type(argname="argument authorization", value=authorization, expected_type=type_hints["authorization"])
             check_type(argname="argument enable_ssl_verification", value=enable_ssl_verification, expected_type=type_hints["enable_ssl_verification"])
             check_type(argname="argument secret", value=secret, expected_type=type_hints["secret"])
-        self._values: typing.Dict[str, typing.Any] = {
+        self._values: typing.Dict[builtins.str, typing.Any] = {
             "url": url,
         }
         if authorization is not None:
@@ -561,10 +563,10 @@ class MlflowWebhookHttpUrlSpec:
     @builtins.property
     def enable_ssl_verification(
         self,
-    ) -> typing.Optional[typing.Union[builtins.bool, cdktf.IResolvable]]:
+    ) -> typing.Optional[typing.Union[builtins.bool, _cdktf_9a9027ec.IResolvable]]:
         '''Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/databricks/r/mlflow_webhook#enable_ssl_verification MlflowWebhook#enable_ssl_verification}.'''
         result = self._values.get("enable_ssl_verification")
-        return typing.cast(typing.Optional[typing.Union[builtins.bool, cdktf.IResolvable]], result)
+        return typing.cast(typing.Optional[typing.Union[builtins.bool, _cdktf_9a9027ec.IResolvable]], result)
 
     @builtins.property
     def secret(self) -> typing.Optional[builtins.str]:
@@ -585,13 +587,13 @@ class MlflowWebhookHttpUrlSpec:
 
 
 class MlflowWebhookHttpUrlSpecOutputReference(
-    cdktf.ComplexObject,
+    _cdktf_9a9027ec.ComplexObject,
     metaclass=jsii.JSIIMeta,
     jsii_type="@cdktf/provider-databricks.mlflowWebhook.MlflowWebhookHttpUrlSpecOutputReference",
 ):
     def __init__(
         self,
-        terraform_resource: cdktf.IInterpolatingParent,
+        terraform_resource: _cdktf_9a9027ec.IInterpolatingParent,
         terraform_attribute: builtins.str,
     ) -> None:
         '''
@@ -599,7 +601,7 @@ class MlflowWebhookHttpUrlSpecOutputReference(
         :param terraform_attribute: The attribute on the parent resource this class is referencing.
         '''
         if __debug__:
-            type_hints = typing.get_type_hints(MlflowWebhookHttpUrlSpecOutputReference.__init__)
+            type_hints = typing.get_type_hints(_typecheckingstub__3796ac1c2c36ff630d103a0242999976bc71327386fa9dec813a91a2c1ce5ae5)
             check_type(argname="argument terraform_resource", value=terraform_resource, expected_type=type_hints["terraform_resource"])
             check_type(argname="argument terraform_attribute", value=terraform_attribute, expected_type=type_hints["terraform_attribute"])
         jsii.create(self.__class__, self, [terraform_resource, terraform_attribute])
@@ -625,8 +627,8 @@ class MlflowWebhookHttpUrlSpecOutputReference(
     @jsii.member(jsii_name="enableSslVerificationInput")
     def enable_ssl_verification_input(
         self,
-    ) -> typing.Optional[typing.Union[builtins.bool, cdktf.IResolvable]]:
-        return typing.cast(typing.Optional[typing.Union[builtins.bool, cdktf.IResolvable]], jsii.get(self, "enableSslVerificationInput"))
+    ) -> typing.Optional[typing.Union[builtins.bool, _cdktf_9a9027ec.IResolvable]]:
+        return typing.cast(typing.Optional[typing.Union[builtins.bool, _cdktf_9a9027ec.IResolvable]], jsii.get(self, "enableSslVerificationInput"))
 
     @builtins.property
     @jsii.member(jsii_name="secretInput")
@@ -646,22 +648,24 @@ class MlflowWebhookHttpUrlSpecOutputReference(
     @authorization.setter
     def authorization(self, value: builtins.str) -> None:
         if __debug__:
-            type_hints = typing.get_type_hints(getattr(MlflowWebhookHttpUrlSpecOutputReference, "authorization").fset)
+            type_hints = typing.get_type_hints(_typecheckingstub__a39707d04c4f2119265fe4d631974e0acbe776a3364542b5a8c3447ff48cf4cc)
             check_type(argname="argument value", value=value, expected_type=type_hints["value"])
         jsii.set(self, "authorization", value)
 
     @builtins.property
     @jsii.member(jsii_name="enableSslVerification")
-    def enable_ssl_verification(self) -> typing.Union[builtins.bool, cdktf.IResolvable]:
-        return typing.cast(typing.Union[builtins.bool, cdktf.IResolvable], jsii.get(self, "enableSslVerification"))
+    def enable_ssl_verification(
+        self,
+    ) -> typing.Union[builtins.bool, _cdktf_9a9027ec.IResolvable]:
+        return typing.cast(typing.Union[builtins.bool, _cdktf_9a9027ec.IResolvable], jsii.get(self, "enableSslVerification"))
 
     @enable_ssl_verification.setter
     def enable_ssl_verification(
         self,
-        value: typing.Union[builtins.bool, cdktf.IResolvable],
+        value: typing.Union[builtins.bool, _cdktf_9a9027ec.IResolvable],
     ) -> None:
         if __debug__:
-            type_hints = typing.get_type_hints(getattr(MlflowWebhookHttpUrlSpecOutputReference, "enable_ssl_verification").fset)
+            type_hints = typing.get_type_hints(_typecheckingstub__0eb808946f33c2afb900c91311c0ac302049f289ab1d79df1de0e00c17fafabb)
             check_type(argname="argument value", value=value, expected_type=type_hints["value"])
         jsii.set(self, "enableSslVerification", value)
 
@@ -673,7 +677,7 @@ class MlflowWebhookHttpUrlSpecOutputReference(
     @secret.setter
     def secret(self, value: builtins.str) -> None:
         if __debug__:
-            type_hints = typing.get_type_hints(getattr(MlflowWebhookHttpUrlSpecOutputReference, "secret").fset)
+            type_hints = typing.get_type_hints(_typecheckingstub__a9cbc3e9754cac72bb1cbe945d06f56d816966e12ec85f88a1563af1b0614131)
             check_type(argname="argument value", value=value, expected_type=type_hints["value"])
         jsii.set(self, "secret", value)
 
@@ -685,7 +689,7 @@ class MlflowWebhookHttpUrlSpecOutputReference(
     @url.setter
     def url(self, value: builtins.str) -> None:
         if __debug__:
-            type_hints = typing.get_type_hints(getattr(MlflowWebhookHttpUrlSpecOutputReference, "url").fset)
+            type_hints = typing.get_type_hints(_typecheckingstub__98adc656d62c4b9d267d5da5f6d0d884123dc55cc7807143ca895fc3f76c5a35)
             check_type(argname="argument value", value=value, expected_type=type_hints["value"])
         jsii.set(self, "url", value)
 
@@ -697,7 +701,7 @@ class MlflowWebhookHttpUrlSpecOutputReference(
     @internal_value.setter
     def internal_value(self, value: typing.Optional[MlflowWebhookHttpUrlSpec]) -> None:
         if __debug__:
-            type_hints = typing.get_type_hints(getattr(MlflowWebhookHttpUrlSpecOutputReference, "internal_value").fset)
+            type_hints = typing.get_type_hints(_typecheckingstub__7736596d16c52d226e0f37e7444ccecbbf5bf8efe17a249906b6cb43224aacde)
             check_type(argname="argument value", value=value, expected_type=type_hints["value"])
         jsii.set(self, "internalValue", value)
 
@@ -725,11 +729,11 @@ class MlflowWebhookJobSpec:
         :param workspace_url: Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/databricks/r/mlflow_webhook#workspace_url MlflowWebhook#workspace_url}.
         '''
         if __debug__:
-            type_hints = typing.get_type_hints(MlflowWebhookJobSpec.__init__)
+            type_hints = typing.get_type_hints(_typecheckingstub__48c0e74ca8eecb9a366cd5e5f4323f8df5c45c18afffec5ec15d6f059078ceb1)
             check_type(argname="argument access_token", value=access_token, expected_type=type_hints["access_token"])
             check_type(argname="argument job_id", value=job_id, expected_type=type_hints["job_id"])
             check_type(argname="argument workspace_url", value=workspace_url, expected_type=type_hints["workspace_url"])
-        self._values: typing.Dict[str, typing.Any] = {
+        self._values: typing.Dict[builtins.str, typing.Any] = {
             "access_token": access_token,
             "job_id": job_id,
         }
@@ -769,13 +773,13 @@ class MlflowWebhookJobSpec:
 
 
 class MlflowWebhookJobSpecOutputReference(
-    cdktf.ComplexObject,
+    _cdktf_9a9027ec.ComplexObject,
     metaclass=jsii.JSIIMeta,
     jsii_type="@cdktf/provider-databricks.mlflowWebhook.MlflowWebhookJobSpecOutputReference",
 ):
     def __init__(
         self,
-        terraform_resource: cdktf.IInterpolatingParent,
+        terraform_resource: _cdktf_9a9027ec.IInterpolatingParent,
         terraform_attribute: builtins.str,
     ) -> None:
         '''
@@ -783,7 +787,7 @@ class MlflowWebhookJobSpecOutputReference(
         :param terraform_attribute: The attribute on the parent resource this class is referencing.
         '''
         if __debug__:
-            type_hints = typing.get_type_hints(MlflowWebhookJobSpecOutputReference.__init__)
+            type_hints = typing.get_type_hints(_typecheckingstub__f7bf91bc0dea2cfdb27de3cf5d6623c79cf391eb950a7eed025544a412520ae7)
             check_type(argname="argument terraform_resource", value=terraform_resource, expected_type=type_hints["terraform_resource"])
             check_type(argname="argument terraform_attribute", value=terraform_attribute, expected_type=type_hints["terraform_attribute"])
         jsii.create(self.__class__, self, [terraform_resource, terraform_attribute])
@@ -815,7 +819,7 @@ class MlflowWebhookJobSpecOutputReference(
     @access_token.setter
     def access_token(self, value: builtins.str) -> None:
         if __debug__:
-            type_hints = typing.get_type_hints(getattr(MlflowWebhookJobSpecOutputReference, "access_token").fset)
+            type_hints = typing.get_type_hints(_typecheckingstub__7c90598dfb27be0726055a2634f3ac03ebdaf3bfe3c6f48d1f57dd78419fea82)
             check_type(argname="argument value", value=value, expected_type=type_hints["value"])
         jsii.set(self, "accessToken", value)
 
@@ -827,7 +831,7 @@ class MlflowWebhookJobSpecOutputReference(
     @job_id.setter
     def job_id(self, value: builtins.str) -> None:
         if __debug__:
-            type_hints = typing.get_type_hints(getattr(MlflowWebhookJobSpecOutputReference, "job_id").fset)
+            type_hints = typing.get_type_hints(_typecheckingstub__4efa544623d055d2b4e728c06d8d73bbfd2fd78b7cace42684c9a7fec88ebaf3)
             check_type(argname="argument value", value=value, expected_type=type_hints["value"])
         jsii.set(self, "jobId", value)
 
@@ -839,7 +843,7 @@ class MlflowWebhookJobSpecOutputReference(
     @workspace_url.setter
     def workspace_url(self, value: builtins.str) -> None:
         if __debug__:
-            type_hints = typing.get_type_hints(getattr(MlflowWebhookJobSpecOutputReference, "workspace_url").fset)
+            type_hints = typing.get_type_hints(_typecheckingstub__131b36f32a7cb3d95dcf89a59c986d770e469d07dab4a9d52677c40a37d9d553)
             check_type(argname="argument value", value=value, expected_type=type_hints["value"])
         jsii.set(self, "workspaceUrl", value)
 
@@ -851,7 +855,7 @@ class MlflowWebhookJobSpecOutputReference(
     @internal_value.setter
     def internal_value(self, value: typing.Optional[MlflowWebhookJobSpec]) -> None:
         if __debug__:
-            type_hints = typing.get_type_hints(getattr(MlflowWebhookJobSpecOutputReference, "internal_value").fset)
+            type_hints = typing.get_type_hints(_typecheckingstub__5369d89364faa312df7be05bcf2d0f89ac5d841a774adb39b70e4b3e53150a97)
             check_type(argname="argument value", value=value, expected_type=type_hints["value"])
         jsii.set(self, "internalValue", value)
 
@@ -866,3 +870,162 @@ __all__ = [
 ]
 
 publication.publish()
+
+def _typecheckingstub__9f232a4f020f1195c887ea48a25a4b28369976f829ee1e01451e1832008244bc(
+    scope: _constructs_77d1e7e8.Construct,
+    id_: builtins.str,
+    *,
+    events: typing.Sequence[builtins.str],
+    description: typing.Optional[builtins.str] = None,
+    http_url_spec: typing.Optional[typing.Union[MlflowWebhookHttpUrlSpec, typing.Dict[builtins.str, typing.Any]]] = None,
+    id: typing.Optional[builtins.str] = None,
+    job_spec: typing.Optional[typing.Union[MlflowWebhookJobSpec, typing.Dict[builtins.str, typing.Any]]] = None,
+    model_name: typing.Optional[builtins.str] = None,
+    status: typing.Optional[builtins.str] = None,
+    connection: typing.Optional[typing.Union[typing.Union[_cdktf_9a9027ec.SSHProvisionerConnection, typing.Dict[builtins.str, typing.Any]], typing.Union[_cdktf_9a9027ec.WinrmProvisionerConnection, typing.Dict[builtins.str, typing.Any]]]] = None,
+    count: typing.Optional[jsii.Number] = None,
+    depends_on: typing.Optional[typing.Sequence[_cdktf_9a9027ec.ITerraformDependable]] = None,
+    for_each: typing.Optional[_cdktf_9a9027ec.ITerraformIterator] = None,
+    lifecycle: typing.Optional[typing.Union[_cdktf_9a9027ec.TerraformResourceLifecycle, typing.Dict[builtins.str, typing.Any]]] = None,
+    provider: typing.Optional[_cdktf_9a9027ec.TerraformProvider] = None,
+    provisioners: typing.Optional[typing.Sequence[typing.Union[typing.Union[_cdktf_9a9027ec.FileProvisioner, typing.Dict[builtins.str, typing.Any]], typing.Union[_cdktf_9a9027ec.LocalExecProvisioner, typing.Dict[builtins.str, typing.Any]], typing.Union[_cdktf_9a9027ec.RemoteExecProvisioner, typing.Dict[builtins.str, typing.Any]]]]] = None,
+) -> None:
+    """Type checking stubs"""
+    pass
+
+def _typecheckingstub__48b43463662ed503311668db84261241402b6d81c6b9556a79171dd2d481e5d1(
+    value: builtins.str,
+) -> None:
+    """Type checking stubs"""
+    pass
+
+def _typecheckingstub__63c32a180557655b134c05d93c7f0f19d72f6f7b2da2988e513315fa82eac7f0(
+    value: typing.List[builtins.str],
+) -> None:
+    """Type checking stubs"""
+    pass
+
+def _typecheckingstub__94c3bf0ce0737dd774efb9613d2d61bfc37ebc1669bd3cfe9e2e5344b0c8d76d(
+    value: builtins.str,
+) -> None:
+    """Type checking stubs"""
+    pass
+
+def _typecheckingstub__f5b7d444a899f8703e18ab10086ec59edd9423ad6cf755b8da0d6535f92aaf5d(
+    value: builtins.str,
+) -> None:
+    """Type checking stubs"""
+    pass
+
+def _typecheckingstub__58b1bf03b434e3701697a10976496b400ab39e2b21c03c4ccc5b4da5be5f3102(
+    value: builtins.str,
+) -> None:
+    """Type checking stubs"""
+    pass
+
+def _typecheckingstub__e7b0b71ed197d9864a4a5ceda869aa676a61c1e1dc57374e13732c21b7c5f0b6(
+    *,
+    connection: typing.Optional[typing.Union[typing.Union[_cdktf_9a9027ec.SSHProvisionerConnection, typing.Dict[builtins.str, typing.Any]], typing.Union[_cdktf_9a9027ec.WinrmProvisionerConnection, typing.Dict[builtins.str, typing.Any]]]] = None,
+    count: typing.Optional[jsii.Number] = None,
+    depends_on: typing.Optional[typing.Sequence[_cdktf_9a9027ec.ITerraformDependable]] = None,
+    for_each: typing.Optional[_cdktf_9a9027ec.ITerraformIterator] = None,
+    lifecycle: typing.Optional[typing.Union[_cdktf_9a9027ec.TerraformResourceLifecycle, typing.Dict[builtins.str, typing.Any]]] = None,
+    provider: typing.Optional[_cdktf_9a9027ec.TerraformProvider] = None,
+    provisioners: typing.Optional[typing.Sequence[typing.Union[typing.Union[_cdktf_9a9027ec.FileProvisioner, typing.Dict[builtins.str, typing.Any]], typing.Union[_cdktf_9a9027ec.LocalExecProvisioner, typing.Dict[builtins.str, typing.Any]], typing.Union[_cdktf_9a9027ec.RemoteExecProvisioner, typing.Dict[builtins.str, typing.Any]]]]] = None,
+    events: typing.Sequence[builtins.str],
+    description: typing.Optional[builtins.str] = None,
+    http_url_spec: typing.Optional[typing.Union[MlflowWebhookHttpUrlSpec, typing.Dict[builtins.str, typing.Any]]] = None,
+    id: typing.Optional[builtins.str] = None,
+    job_spec: typing.Optional[typing.Union[MlflowWebhookJobSpec, typing.Dict[builtins.str, typing.Any]]] = None,
+    model_name: typing.Optional[builtins.str] = None,
+    status: typing.Optional[builtins.str] = None,
+) -> None:
+    """Type checking stubs"""
+    pass
+
+def _typecheckingstub__73a239e169fb7f0e00d840790cbcbd46ce96281dd071886eeb803d5a65aeac7d(
+    *,
+    url: builtins.str,
+    authorization: typing.Optional[builtins.str] = None,
+    enable_ssl_verification: typing.Optional[typing.Union[builtins.bool, _cdktf_9a9027ec.IResolvable]] = None,
+    secret: typing.Optional[builtins.str] = None,
+) -> None:
+    """Type checking stubs"""
+    pass
+
+def _typecheckingstub__3796ac1c2c36ff630d103a0242999976bc71327386fa9dec813a91a2c1ce5ae5(
+    terraform_resource: _cdktf_9a9027ec.IInterpolatingParent,
+    terraform_attribute: builtins.str,
+) -> None:
+    """Type checking stubs"""
+    pass
+
+def _typecheckingstub__a39707d04c4f2119265fe4d631974e0acbe776a3364542b5a8c3447ff48cf4cc(
+    value: builtins.str,
+) -> None:
+    """Type checking stubs"""
+    pass
+
+def _typecheckingstub__0eb808946f33c2afb900c91311c0ac302049f289ab1d79df1de0e00c17fafabb(
+    value: typing.Union[builtins.bool, _cdktf_9a9027ec.IResolvable],
+) -> None:
+    """Type checking stubs"""
+    pass
+
+def _typecheckingstub__a9cbc3e9754cac72bb1cbe945d06f56d816966e12ec85f88a1563af1b0614131(
+    value: builtins.str,
+) -> None:
+    """Type checking stubs"""
+    pass
+
+def _typecheckingstub__98adc656d62c4b9d267d5da5f6d0d884123dc55cc7807143ca895fc3f76c5a35(
+    value: builtins.str,
+) -> None:
+    """Type checking stubs"""
+    pass
+
+def _typecheckingstub__7736596d16c52d226e0f37e7444ccecbbf5bf8efe17a249906b6cb43224aacde(
+    value: typing.Optional[MlflowWebhookHttpUrlSpec],
+) -> None:
+    """Type checking stubs"""
+    pass
+
+def _typecheckingstub__48c0e74ca8eecb9a366cd5e5f4323f8df5c45c18afffec5ec15d6f059078ceb1(
+    *,
+    access_token: builtins.str,
+    job_id: builtins.str,
+    workspace_url: typing.Optional[builtins.str] = None,
+) -> None:
+    """Type checking stubs"""
+    pass
+
+def _typecheckingstub__f7bf91bc0dea2cfdb27de3cf5d6623c79cf391eb950a7eed025544a412520ae7(
+    terraform_resource: _cdktf_9a9027ec.IInterpolatingParent,
+    terraform_attribute: builtins.str,
+) -> None:
+    """Type checking stubs"""
+    pass
+
+def _typecheckingstub__7c90598dfb27be0726055a2634f3ac03ebdaf3bfe3c6f48d1f57dd78419fea82(
+    value: builtins.str,
+) -> None:
+    """Type checking stubs"""
+    pass
+
+def _typecheckingstub__4efa544623d055d2b4e728c06d8d73bbfd2fd78b7cace42684c9a7fec88ebaf3(
+    value: builtins.str,
+) -> None:
+    """Type checking stubs"""
+    pass
+
+def _typecheckingstub__131b36f32a7cb3d95dcf89a59c986d770e469d07dab4a9d52677c40a37d9d553(
+    value: builtins.str,
+) -> None:
+    """Type checking stubs"""
+    pass
+
+def _typecheckingstub__5369d89364faa312df7be05bcf2d0f89ac5d841a774adb39b70e4b3e53150a97(
+    value: typing.Optional[MlflowWebhookJobSpec],
+) -> None:
+    """Type checking stubs"""
+    pass
