@@ -17,12 +17,12 @@ from typeguard import check_type
 
 from .._jsii import *
 
-import cdktf
-import constructs
+import cdktf as _cdktf_9a9027ec
+import constructs as _constructs_77d1e7e8
 
 
 class MwsLogDelivery(
-    cdktf.TerraformResource,
+    _cdktf_9a9027ec.TerraformResource,
     metaclass=jsii.JSIIMeta,
     jsii_type="@cdktf/provider-databricks.mwsLogDelivery.MwsLogDelivery",
 ):
@@ -30,7 +30,7 @@ class MwsLogDelivery(
 
     def __init__(
         self,
-        scope: constructs.Construct,
+        scope: _constructs_77d1e7e8.Construct,
         id_: builtins.str,
         *,
         account_id: builtins.str,
@@ -45,13 +45,13 @@ class MwsLogDelivery(
         id: typing.Optional[builtins.str] = None,
         status: typing.Optional[builtins.str] = None,
         workspace_ids_filter: typing.Optional[typing.Sequence[jsii.Number]] = None,
-        connection: typing.Optional[typing.Union[typing.Union[cdktf.SSHProvisionerConnection, typing.Dict[str, typing.Any]], typing.Union[cdktf.WinrmProvisionerConnection, typing.Dict[str, typing.Any]]]] = None,
+        connection: typing.Optional[typing.Union[typing.Union[_cdktf_9a9027ec.SSHProvisionerConnection, typing.Dict[builtins.str, typing.Any]], typing.Union[_cdktf_9a9027ec.WinrmProvisionerConnection, typing.Dict[builtins.str, typing.Any]]]] = None,
         count: typing.Optional[jsii.Number] = None,
-        depends_on: typing.Optional[typing.Sequence[cdktf.ITerraformDependable]] = None,
-        for_each: typing.Optional[cdktf.ITerraformIterator] = None,
-        lifecycle: typing.Optional[typing.Union[cdktf.TerraformResourceLifecycle, typing.Dict[str, typing.Any]]] = None,
-        provider: typing.Optional[cdktf.TerraformProvider] = None,
-        provisioners: typing.Optional[typing.Sequence[typing.Union[typing.Union[cdktf.FileProvisioner, typing.Dict[str, typing.Any]], typing.Union[cdktf.LocalExecProvisioner, typing.Dict[str, typing.Any]], typing.Union[cdktf.RemoteExecProvisioner, typing.Dict[str, typing.Any]]]]] = None,
+        depends_on: typing.Optional[typing.Sequence[_cdktf_9a9027ec.ITerraformDependable]] = None,
+        for_each: typing.Optional[_cdktf_9a9027ec.ITerraformIterator] = None,
+        lifecycle: typing.Optional[typing.Union[_cdktf_9a9027ec.TerraformResourceLifecycle, typing.Dict[builtins.str, typing.Any]]] = None,
+        provider: typing.Optional[_cdktf_9a9027ec.TerraformProvider] = None,
+        provisioners: typing.Optional[typing.Sequence[typing.Union[typing.Union[_cdktf_9a9027ec.FileProvisioner, typing.Dict[builtins.str, typing.Any]], typing.Union[_cdktf_9a9027ec.LocalExecProvisioner, typing.Dict[builtins.str, typing.Any]], typing.Union[_cdktf_9a9027ec.RemoteExecProvisioner, typing.Dict[builtins.str, typing.Any]]]]] = None,
     ) -> None:
         '''Create a new {@link https://www.terraform.io/docs/providers/databricks/r/mws_log_delivery databricks_mws_log_delivery} Resource.
 
@@ -78,7 +78,7 @@ class MwsLogDelivery(
         :param provisioners: 
         '''
         if __debug__:
-            type_hints = typing.get_type_hints(MwsLogDelivery.__init__)
+            type_hints = typing.get_type_hints(_typecheckingstub__61f9096be0eeb2b0bdd625a7494845a3964c73744beabd3b7d979093383f19a2)
             check_type(argname="argument scope", value=scope, expected_type=type_hints["scope"])
             check_type(argname="argument id_", value=id_, expected_type=type_hints["id_"])
         config = MwsLogDeliveryConfig(
@@ -210,7 +210,7 @@ class MwsLogDelivery(
     @account_id.setter
     def account_id(self, value: builtins.str) -> None:
         if __debug__:
-            type_hints = typing.get_type_hints(getattr(MwsLogDelivery, "account_id").fset)
+            type_hints = typing.get_type_hints(_typecheckingstub__1aee7d8d71cedc4e14792540650a9da7245d41310633fce28af64c607085c643)
             check_type(argname="argument value", value=value, expected_type=type_hints["value"])
         jsii.set(self, "accountId", value)
 
@@ -222,7 +222,7 @@ class MwsLogDelivery(
     @config_id.setter
     def config_id(self, value: builtins.str) -> None:
         if __debug__:
-            type_hints = typing.get_type_hints(getattr(MwsLogDelivery, "config_id").fset)
+            type_hints = typing.get_type_hints(_typecheckingstub__61d08bf3588cbfb98bccd16577fe9bdcf2b50d2e2839a26329a3c690b3921355)
             check_type(argname="argument value", value=value, expected_type=type_hints["value"])
         jsii.set(self, "configId", value)
 
@@ -234,7 +234,7 @@ class MwsLogDelivery(
     @config_name.setter
     def config_name(self, value: builtins.str) -> None:
         if __debug__:
-            type_hints = typing.get_type_hints(getattr(MwsLogDelivery, "config_name").fset)
+            type_hints = typing.get_type_hints(_typecheckingstub__073de51596cba45182575483cf4dd1ae6ad795223b7573f947331ceff0b0df56)
             check_type(argname="argument value", value=value, expected_type=type_hints["value"])
         jsii.set(self, "configName", value)
 
@@ -246,7 +246,7 @@ class MwsLogDelivery(
     @credentials_id.setter
     def credentials_id(self, value: builtins.str) -> None:
         if __debug__:
-            type_hints = typing.get_type_hints(getattr(MwsLogDelivery, "credentials_id").fset)
+            type_hints = typing.get_type_hints(_typecheckingstub__381cd1c5cb2e0843fe80c320cbcf0bae2cdd3c7d7456169f0bf772dc40aaf8a0)
             check_type(argname="argument value", value=value, expected_type=type_hints["value"])
         jsii.set(self, "credentialsId", value)
 
@@ -258,7 +258,7 @@ class MwsLogDelivery(
     @delivery_path_prefix.setter
     def delivery_path_prefix(self, value: builtins.str) -> None:
         if __debug__:
-            type_hints = typing.get_type_hints(getattr(MwsLogDelivery, "delivery_path_prefix").fset)
+            type_hints = typing.get_type_hints(_typecheckingstub__864859e29f6eed4a4e92a86e96989773f47e87c5e927a4f4ab5f1f59e8f42904)
             check_type(argname="argument value", value=value, expected_type=type_hints["value"])
         jsii.set(self, "deliveryPathPrefix", value)
 
@@ -270,7 +270,7 @@ class MwsLogDelivery(
     @delivery_start_time.setter
     def delivery_start_time(self, value: builtins.str) -> None:
         if __debug__:
-            type_hints = typing.get_type_hints(getattr(MwsLogDelivery, "delivery_start_time").fset)
+            type_hints = typing.get_type_hints(_typecheckingstub__8ca35469f9e987373b59fd745ee3a8fc79dfe53beb3d41b846512d1be1f31e1e)
             check_type(argname="argument value", value=value, expected_type=type_hints["value"])
         jsii.set(self, "deliveryStartTime", value)
 
@@ -282,7 +282,7 @@ class MwsLogDelivery(
     @id.setter
     def id(self, value: builtins.str) -> None:
         if __debug__:
-            type_hints = typing.get_type_hints(getattr(MwsLogDelivery, "id").fset)
+            type_hints = typing.get_type_hints(_typecheckingstub__655e97f23f09fb485fee0e9506b0f69ce34cbae46d655cd45b5913766b2f1a9b)
             check_type(argname="argument value", value=value, expected_type=type_hints["value"])
         jsii.set(self, "id", value)
 
@@ -294,7 +294,7 @@ class MwsLogDelivery(
     @log_type.setter
     def log_type(self, value: builtins.str) -> None:
         if __debug__:
-            type_hints = typing.get_type_hints(getattr(MwsLogDelivery, "log_type").fset)
+            type_hints = typing.get_type_hints(_typecheckingstub__80faf8c8c47fecdbe8a283f70ab673582655ba932ea43b08ce407fce0a703651)
             check_type(argname="argument value", value=value, expected_type=type_hints["value"])
         jsii.set(self, "logType", value)
 
@@ -306,7 +306,7 @@ class MwsLogDelivery(
     @output_format.setter
     def output_format(self, value: builtins.str) -> None:
         if __debug__:
-            type_hints = typing.get_type_hints(getattr(MwsLogDelivery, "output_format").fset)
+            type_hints = typing.get_type_hints(_typecheckingstub__edb5defd56dcb05acf9f8b432b480d233cf743f4fd044d4f7053ad344e962849)
             check_type(argname="argument value", value=value, expected_type=type_hints["value"])
         jsii.set(self, "outputFormat", value)
 
@@ -318,7 +318,7 @@ class MwsLogDelivery(
     @status.setter
     def status(self, value: builtins.str) -> None:
         if __debug__:
-            type_hints = typing.get_type_hints(getattr(MwsLogDelivery, "status").fset)
+            type_hints = typing.get_type_hints(_typecheckingstub__eff77d2411ff53f91226fed9118c27ea9bedbf68273cced6b07af7ab1a3da2c6)
             check_type(argname="argument value", value=value, expected_type=type_hints["value"])
         jsii.set(self, "status", value)
 
@@ -330,7 +330,7 @@ class MwsLogDelivery(
     @storage_configuration_id.setter
     def storage_configuration_id(self, value: builtins.str) -> None:
         if __debug__:
-            type_hints = typing.get_type_hints(getattr(MwsLogDelivery, "storage_configuration_id").fset)
+            type_hints = typing.get_type_hints(_typecheckingstub__b8f63a1d7c7fed78756241e224b18c501b33df1dbe42df0d19746ab63ddbc157)
             check_type(argname="argument value", value=value, expected_type=type_hints["value"])
         jsii.set(self, "storageConfigurationId", value)
 
@@ -342,14 +342,14 @@ class MwsLogDelivery(
     @workspace_ids_filter.setter
     def workspace_ids_filter(self, value: typing.List[jsii.Number]) -> None:
         if __debug__:
-            type_hints = typing.get_type_hints(getattr(MwsLogDelivery, "workspace_ids_filter").fset)
+            type_hints = typing.get_type_hints(_typecheckingstub__4bf833c8fba70aeca68edfb214125ef3d7d181c6a3c07eb2531adfbef4f65064)
             check_type(argname="argument value", value=value, expected_type=type_hints["value"])
         jsii.set(self, "workspaceIdsFilter", value)
 
 
 @jsii.data_type(
     jsii_type="@cdktf/provider-databricks.mwsLogDelivery.MwsLogDeliveryConfig",
-    jsii_struct_bases=[cdktf.TerraformMetaArguments],
+    jsii_struct_bases=[_cdktf_9a9027ec.TerraformMetaArguments],
     name_mapping={
         "connection": "connection",
         "count": "count",
@@ -372,17 +372,17 @@ class MwsLogDelivery(
         "workspace_ids_filter": "workspaceIdsFilter",
     },
 )
-class MwsLogDeliveryConfig(cdktf.TerraformMetaArguments):
+class MwsLogDeliveryConfig(_cdktf_9a9027ec.TerraformMetaArguments):
     def __init__(
         self,
         *,
-        connection: typing.Optional[typing.Union[typing.Union[cdktf.SSHProvisionerConnection, typing.Dict[str, typing.Any]], typing.Union[cdktf.WinrmProvisionerConnection, typing.Dict[str, typing.Any]]]] = None,
+        connection: typing.Optional[typing.Union[typing.Union[_cdktf_9a9027ec.SSHProvisionerConnection, typing.Dict[builtins.str, typing.Any]], typing.Union[_cdktf_9a9027ec.WinrmProvisionerConnection, typing.Dict[builtins.str, typing.Any]]]] = None,
         count: typing.Optional[jsii.Number] = None,
-        depends_on: typing.Optional[typing.Sequence[cdktf.ITerraformDependable]] = None,
-        for_each: typing.Optional[cdktf.ITerraformIterator] = None,
-        lifecycle: typing.Optional[typing.Union[cdktf.TerraformResourceLifecycle, typing.Dict[str, typing.Any]]] = None,
-        provider: typing.Optional[cdktf.TerraformProvider] = None,
-        provisioners: typing.Optional[typing.Sequence[typing.Union[typing.Union[cdktf.FileProvisioner, typing.Dict[str, typing.Any]], typing.Union[cdktf.LocalExecProvisioner, typing.Dict[str, typing.Any]], typing.Union[cdktf.RemoteExecProvisioner, typing.Dict[str, typing.Any]]]]] = None,
+        depends_on: typing.Optional[typing.Sequence[_cdktf_9a9027ec.ITerraformDependable]] = None,
+        for_each: typing.Optional[_cdktf_9a9027ec.ITerraformIterator] = None,
+        lifecycle: typing.Optional[typing.Union[_cdktf_9a9027ec.TerraformResourceLifecycle, typing.Dict[builtins.str, typing.Any]]] = None,
+        provider: typing.Optional[_cdktf_9a9027ec.TerraformProvider] = None,
+        provisioners: typing.Optional[typing.Sequence[typing.Union[typing.Union[_cdktf_9a9027ec.FileProvisioner, typing.Dict[builtins.str, typing.Any]], typing.Union[_cdktf_9a9027ec.LocalExecProvisioner, typing.Dict[builtins.str, typing.Any]], typing.Union[_cdktf_9a9027ec.RemoteExecProvisioner, typing.Dict[builtins.str, typing.Any]]]]] = None,
         account_id: builtins.str,
         credentials_id: builtins.str,
         log_type: builtins.str,
@@ -418,9 +418,9 @@ class MwsLogDeliveryConfig(cdktf.TerraformMetaArguments):
         :param workspace_ids_filter: Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/databricks/r/mws_log_delivery#workspace_ids_filter MwsLogDelivery#workspace_ids_filter}.
         '''
         if isinstance(lifecycle, dict):
-            lifecycle = cdktf.TerraformResourceLifecycle(**lifecycle)
+            lifecycle = _cdktf_9a9027ec.TerraformResourceLifecycle(**lifecycle)
         if __debug__:
-            type_hints = typing.get_type_hints(MwsLogDeliveryConfig.__init__)
+            type_hints = typing.get_type_hints(_typecheckingstub__552e6089cca1109e76474d0890d0bc2c14a8a9e3eccde36f753a298cd7b3efc7)
             check_type(argname="argument connection", value=connection, expected_type=type_hints["connection"])
             check_type(argname="argument count", value=count, expected_type=type_hints["count"])
             check_type(argname="argument depends_on", value=depends_on, expected_type=type_hints["depends_on"])
@@ -440,7 +440,7 @@ class MwsLogDeliveryConfig(cdktf.TerraformMetaArguments):
             check_type(argname="argument id", value=id, expected_type=type_hints["id"])
             check_type(argname="argument status", value=status, expected_type=type_hints["status"])
             check_type(argname="argument workspace_ids_filter", value=workspace_ids_filter, expected_type=type_hints["workspace_ids_filter"])
-        self._values: typing.Dict[str, typing.Any] = {
+        self._values: typing.Dict[builtins.str, typing.Any] = {
             "account_id": account_id,
             "credentials_id": credentials_id,
             "log_type": log_type,
@@ -479,12 +479,12 @@ class MwsLogDeliveryConfig(cdktf.TerraformMetaArguments):
     @builtins.property
     def connection(
         self,
-    ) -> typing.Optional[typing.Union[cdktf.SSHProvisionerConnection, cdktf.WinrmProvisionerConnection]]:
+    ) -> typing.Optional[typing.Union[_cdktf_9a9027ec.SSHProvisionerConnection, _cdktf_9a9027ec.WinrmProvisionerConnection]]:
         '''
         :stability: experimental
         '''
         result = self._values.get("connection")
-        return typing.cast(typing.Optional[typing.Union[cdktf.SSHProvisionerConnection, cdktf.WinrmProvisionerConnection]], result)
+        return typing.cast(typing.Optional[typing.Union[_cdktf_9a9027ec.SSHProvisionerConnection, _cdktf_9a9027ec.WinrmProvisionerConnection]], result)
 
     @builtins.property
     def count(self) -> typing.Optional[jsii.Number]:
@@ -495,46 +495,48 @@ class MwsLogDeliveryConfig(cdktf.TerraformMetaArguments):
         return typing.cast(typing.Optional[jsii.Number], result)
 
     @builtins.property
-    def depends_on(self) -> typing.Optional[typing.List[cdktf.ITerraformDependable]]:
+    def depends_on(
+        self,
+    ) -> typing.Optional[typing.List[_cdktf_9a9027ec.ITerraformDependable]]:
         '''
         :stability: experimental
         '''
         result = self._values.get("depends_on")
-        return typing.cast(typing.Optional[typing.List[cdktf.ITerraformDependable]], result)
+        return typing.cast(typing.Optional[typing.List[_cdktf_9a9027ec.ITerraformDependable]], result)
 
     @builtins.property
-    def for_each(self) -> typing.Optional[cdktf.ITerraformIterator]:
+    def for_each(self) -> typing.Optional[_cdktf_9a9027ec.ITerraformIterator]:
         '''
         :stability: experimental
         '''
         result = self._values.get("for_each")
-        return typing.cast(typing.Optional[cdktf.ITerraformIterator], result)
+        return typing.cast(typing.Optional[_cdktf_9a9027ec.ITerraformIterator], result)
 
     @builtins.property
-    def lifecycle(self) -> typing.Optional[cdktf.TerraformResourceLifecycle]:
+    def lifecycle(self) -> typing.Optional[_cdktf_9a9027ec.TerraformResourceLifecycle]:
         '''
         :stability: experimental
         '''
         result = self._values.get("lifecycle")
-        return typing.cast(typing.Optional[cdktf.TerraformResourceLifecycle], result)
+        return typing.cast(typing.Optional[_cdktf_9a9027ec.TerraformResourceLifecycle], result)
 
     @builtins.property
-    def provider(self) -> typing.Optional[cdktf.TerraformProvider]:
+    def provider(self) -> typing.Optional[_cdktf_9a9027ec.TerraformProvider]:
         '''
         :stability: experimental
         '''
         result = self._values.get("provider")
-        return typing.cast(typing.Optional[cdktf.TerraformProvider], result)
+        return typing.cast(typing.Optional[_cdktf_9a9027ec.TerraformProvider], result)
 
     @builtins.property
     def provisioners(
         self,
-    ) -> typing.Optional[typing.List[typing.Union[cdktf.FileProvisioner, cdktf.LocalExecProvisioner, cdktf.RemoteExecProvisioner]]]:
+    ) -> typing.Optional[typing.List[typing.Union[_cdktf_9a9027ec.FileProvisioner, _cdktf_9a9027ec.LocalExecProvisioner, _cdktf_9a9027ec.RemoteExecProvisioner]]]:
         '''
         :stability: experimental
         '''
         result = self._values.get("provisioners")
-        return typing.cast(typing.Optional[typing.List[typing.Union[cdktf.FileProvisioner, cdktf.LocalExecProvisioner, cdktf.RemoteExecProvisioner]]], result)
+        return typing.cast(typing.Optional[typing.List[typing.Union[_cdktf_9a9027ec.FileProvisioner, _cdktf_9a9027ec.LocalExecProvisioner, _cdktf_9a9027ec.RemoteExecProvisioner]]], result)
 
     @builtins.property
     def account_id(self) -> builtins.str:
@@ -635,3 +637,127 @@ __all__ = [
 ]
 
 publication.publish()
+
+def _typecheckingstub__61f9096be0eeb2b0bdd625a7494845a3964c73744beabd3b7d979093383f19a2(
+    scope: _constructs_77d1e7e8.Construct,
+    id_: builtins.str,
+    *,
+    account_id: builtins.str,
+    credentials_id: builtins.str,
+    log_type: builtins.str,
+    output_format: builtins.str,
+    storage_configuration_id: builtins.str,
+    config_id: typing.Optional[builtins.str] = None,
+    config_name: typing.Optional[builtins.str] = None,
+    delivery_path_prefix: typing.Optional[builtins.str] = None,
+    delivery_start_time: typing.Optional[builtins.str] = None,
+    id: typing.Optional[builtins.str] = None,
+    status: typing.Optional[builtins.str] = None,
+    workspace_ids_filter: typing.Optional[typing.Sequence[jsii.Number]] = None,
+    connection: typing.Optional[typing.Union[typing.Union[_cdktf_9a9027ec.SSHProvisionerConnection, typing.Dict[builtins.str, typing.Any]], typing.Union[_cdktf_9a9027ec.WinrmProvisionerConnection, typing.Dict[builtins.str, typing.Any]]]] = None,
+    count: typing.Optional[jsii.Number] = None,
+    depends_on: typing.Optional[typing.Sequence[_cdktf_9a9027ec.ITerraformDependable]] = None,
+    for_each: typing.Optional[_cdktf_9a9027ec.ITerraformIterator] = None,
+    lifecycle: typing.Optional[typing.Union[_cdktf_9a9027ec.TerraformResourceLifecycle, typing.Dict[builtins.str, typing.Any]]] = None,
+    provider: typing.Optional[_cdktf_9a9027ec.TerraformProvider] = None,
+    provisioners: typing.Optional[typing.Sequence[typing.Union[typing.Union[_cdktf_9a9027ec.FileProvisioner, typing.Dict[builtins.str, typing.Any]], typing.Union[_cdktf_9a9027ec.LocalExecProvisioner, typing.Dict[builtins.str, typing.Any]], typing.Union[_cdktf_9a9027ec.RemoteExecProvisioner, typing.Dict[builtins.str, typing.Any]]]]] = None,
+) -> None:
+    """Type checking stubs"""
+    pass
+
+def _typecheckingstub__1aee7d8d71cedc4e14792540650a9da7245d41310633fce28af64c607085c643(
+    value: builtins.str,
+) -> None:
+    """Type checking stubs"""
+    pass
+
+def _typecheckingstub__61d08bf3588cbfb98bccd16577fe9bdcf2b50d2e2839a26329a3c690b3921355(
+    value: builtins.str,
+) -> None:
+    """Type checking stubs"""
+    pass
+
+def _typecheckingstub__073de51596cba45182575483cf4dd1ae6ad795223b7573f947331ceff0b0df56(
+    value: builtins.str,
+) -> None:
+    """Type checking stubs"""
+    pass
+
+def _typecheckingstub__381cd1c5cb2e0843fe80c320cbcf0bae2cdd3c7d7456169f0bf772dc40aaf8a0(
+    value: builtins.str,
+) -> None:
+    """Type checking stubs"""
+    pass
+
+def _typecheckingstub__864859e29f6eed4a4e92a86e96989773f47e87c5e927a4f4ab5f1f59e8f42904(
+    value: builtins.str,
+) -> None:
+    """Type checking stubs"""
+    pass
+
+def _typecheckingstub__8ca35469f9e987373b59fd745ee3a8fc79dfe53beb3d41b846512d1be1f31e1e(
+    value: builtins.str,
+) -> None:
+    """Type checking stubs"""
+    pass
+
+def _typecheckingstub__655e97f23f09fb485fee0e9506b0f69ce34cbae46d655cd45b5913766b2f1a9b(
+    value: builtins.str,
+) -> None:
+    """Type checking stubs"""
+    pass
+
+def _typecheckingstub__80faf8c8c47fecdbe8a283f70ab673582655ba932ea43b08ce407fce0a703651(
+    value: builtins.str,
+) -> None:
+    """Type checking stubs"""
+    pass
+
+def _typecheckingstub__edb5defd56dcb05acf9f8b432b480d233cf743f4fd044d4f7053ad344e962849(
+    value: builtins.str,
+) -> None:
+    """Type checking stubs"""
+    pass
+
+def _typecheckingstub__eff77d2411ff53f91226fed9118c27ea9bedbf68273cced6b07af7ab1a3da2c6(
+    value: builtins.str,
+) -> None:
+    """Type checking stubs"""
+    pass
+
+def _typecheckingstub__b8f63a1d7c7fed78756241e224b18c501b33df1dbe42df0d19746ab63ddbc157(
+    value: builtins.str,
+) -> None:
+    """Type checking stubs"""
+    pass
+
+def _typecheckingstub__4bf833c8fba70aeca68edfb214125ef3d7d181c6a3c07eb2531adfbef4f65064(
+    value: typing.List[jsii.Number],
+) -> None:
+    """Type checking stubs"""
+    pass
+
+def _typecheckingstub__552e6089cca1109e76474d0890d0bc2c14a8a9e3eccde36f753a298cd7b3efc7(
+    *,
+    connection: typing.Optional[typing.Union[typing.Union[_cdktf_9a9027ec.SSHProvisionerConnection, typing.Dict[builtins.str, typing.Any]], typing.Union[_cdktf_9a9027ec.WinrmProvisionerConnection, typing.Dict[builtins.str, typing.Any]]]] = None,
+    count: typing.Optional[jsii.Number] = None,
+    depends_on: typing.Optional[typing.Sequence[_cdktf_9a9027ec.ITerraformDependable]] = None,
+    for_each: typing.Optional[_cdktf_9a9027ec.ITerraformIterator] = None,
+    lifecycle: typing.Optional[typing.Union[_cdktf_9a9027ec.TerraformResourceLifecycle, typing.Dict[builtins.str, typing.Any]]] = None,
+    provider: typing.Optional[_cdktf_9a9027ec.TerraformProvider] = None,
+    provisioners: typing.Optional[typing.Sequence[typing.Union[typing.Union[_cdktf_9a9027ec.FileProvisioner, typing.Dict[builtins.str, typing.Any]], typing.Union[_cdktf_9a9027ec.LocalExecProvisioner, typing.Dict[builtins.str, typing.Any]], typing.Union[_cdktf_9a9027ec.RemoteExecProvisioner, typing.Dict[builtins.str, typing.Any]]]]] = None,
+    account_id: builtins.str,
+    credentials_id: builtins.str,
+    log_type: builtins.str,
+    output_format: builtins.str,
+    storage_configuration_id: builtins.str,
+    config_id: typing.Optional[builtins.str] = None,
+    config_name: typing.Optional[builtins.str] = None,
+    delivery_path_prefix: typing.Optional[builtins.str] = None,
+    delivery_start_time: typing.Optional[builtins.str] = None,
+    id: typing.Optional[builtins.str] = None,
+    status: typing.Optional[builtins.str] = None,
+    workspace_ids_filter: typing.Optional[typing.Sequence[jsii.Number]] = None,
+) -> None:
+    """Type checking stubs"""
+    pass
