@@ -17,12 +17,12 @@ from typeguard import check_type
 
 from .._jsii import *
 
-import cdktf
-import constructs
+import cdktf as _cdktf_9a9027ec
+import constructs as _constructs_77d1e7e8
 
 
 class MwsPrivateAccessSettings(
-    cdktf.TerraformResource,
+    _cdktf_9a9027ec.TerraformResource,
     metaclass=jsii.JSIIMeta,
     jsii_type="@cdktf/provider-databricks.mwsPrivateAccessSettings.MwsPrivateAccessSettings",
 ):
@@ -30,7 +30,7 @@ class MwsPrivateAccessSettings(
 
     def __init__(
         self,
-        scope: constructs.Construct,
+        scope: _constructs_77d1e7e8.Construct,
         id_: builtins.str,
         *,
         private_access_settings_name: builtins.str,
@@ -40,15 +40,15 @@ class MwsPrivateAccessSettings(
         id: typing.Optional[builtins.str] = None,
         private_access_level: typing.Optional[builtins.str] = None,
         private_access_settings_id: typing.Optional[builtins.str] = None,
-        public_access_enabled: typing.Optional[typing.Union[builtins.bool, cdktf.IResolvable]] = None,
+        public_access_enabled: typing.Optional[typing.Union[builtins.bool, _cdktf_9a9027ec.IResolvable]] = None,
         status: typing.Optional[builtins.str] = None,
-        connection: typing.Optional[typing.Union[typing.Union[cdktf.SSHProvisionerConnection, typing.Dict[str, typing.Any]], typing.Union[cdktf.WinrmProvisionerConnection, typing.Dict[str, typing.Any]]]] = None,
+        connection: typing.Optional[typing.Union[typing.Union[_cdktf_9a9027ec.SSHProvisionerConnection, typing.Dict[builtins.str, typing.Any]], typing.Union[_cdktf_9a9027ec.WinrmProvisionerConnection, typing.Dict[builtins.str, typing.Any]]]] = None,
         count: typing.Optional[jsii.Number] = None,
-        depends_on: typing.Optional[typing.Sequence[cdktf.ITerraformDependable]] = None,
-        for_each: typing.Optional[cdktf.ITerraformIterator] = None,
-        lifecycle: typing.Optional[typing.Union[cdktf.TerraformResourceLifecycle, typing.Dict[str, typing.Any]]] = None,
-        provider: typing.Optional[cdktf.TerraformProvider] = None,
-        provisioners: typing.Optional[typing.Sequence[typing.Union[typing.Union[cdktf.FileProvisioner, typing.Dict[str, typing.Any]], typing.Union[cdktf.LocalExecProvisioner, typing.Dict[str, typing.Any]], typing.Union[cdktf.RemoteExecProvisioner, typing.Dict[str, typing.Any]]]]] = None,
+        depends_on: typing.Optional[typing.Sequence[_cdktf_9a9027ec.ITerraformDependable]] = None,
+        for_each: typing.Optional[_cdktf_9a9027ec.ITerraformIterator] = None,
+        lifecycle: typing.Optional[typing.Union[_cdktf_9a9027ec.TerraformResourceLifecycle, typing.Dict[builtins.str, typing.Any]]] = None,
+        provider: typing.Optional[_cdktf_9a9027ec.TerraformProvider] = None,
+        provisioners: typing.Optional[typing.Sequence[typing.Union[typing.Union[_cdktf_9a9027ec.FileProvisioner, typing.Dict[builtins.str, typing.Any]], typing.Union[_cdktf_9a9027ec.LocalExecProvisioner, typing.Dict[builtins.str, typing.Any]], typing.Union[_cdktf_9a9027ec.RemoteExecProvisioner, typing.Dict[builtins.str, typing.Any]]]]] = None,
     ) -> None:
         '''Create a new {@link https://www.terraform.io/docs/providers/databricks/r/mws_private_access_settings databricks_mws_private_access_settings} Resource.
 
@@ -72,7 +72,7 @@ class MwsPrivateAccessSettings(
         :param provisioners: 
         '''
         if __debug__:
-            type_hints = typing.get_type_hints(MwsPrivateAccessSettings.__init__)
+            type_hints = typing.get_type_hints(_typecheckingstub__558ab876614b55c196d9e855a124e5f40876121e80f87098ab57f22a021af624)
             check_type(argname="argument scope", value=scope, expected_type=type_hints["scope"])
             check_type(argname="argument id_", value=id_, expected_type=type_hints["id_"])
         config = MwsPrivateAccessSettingsConfig(
@@ -169,8 +169,8 @@ class MwsPrivateAccessSettings(
     @jsii.member(jsii_name="publicAccessEnabledInput")
     def public_access_enabled_input(
         self,
-    ) -> typing.Optional[typing.Union[builtins.bool, cdktf.IResolvable]]:
-        return typing.cast(typing.Optional[typing.Union[builtins.bool, cdktf.IResolvable]], jsii.get(self, "publicAccessEnabledInput"))
+    ) -> typing.Optional[typing.Union[builtins.bool, _cdktf_9a9027ec.IResolvable]]:
+        return typing.cast(typing.Optional[typing.Union[builtins.bool, _cdktf_9a9027ec.IResolvable]], jsii.get(self, "publicAccessEnabledInput"))
 
     @builtins.property
     @jsii.member(jsii_name="regionInput")
@@ -190,7 +190,7 @@ class MwsPrivateAccessSettings(
     @account_id.setter
     def account_id(self, value: builtins.str) -> None:
         if __debug__:
-            type_hints = typing.get_type_hints(getattr(MwsPrivateAccessSettings, "account_id").fset)
+            type_hints = typing.get_type_hints(_typecheckingstub__8284effc666787f6af44fcebf8fafb576d81d13c2ca23da22559ae6058cb996f)
             check_type(argname="argument value", value=value, expected_type=type_hints["value"])
         jsii.set(self, "accountId", value)
 
@@ -202,7 +202,7 @@ class MwsPrivateAccessSettings(
     @allowed_vpc_endpoint_ids.setter
     def allowed_vpc_endpoint_ids(self, value: typing.List[builtins.str]) -> None:
         if __debug__:
-            type_hints = typing.get_type_hints(getattr(MwsPrivateAccessSettings, "allowed_vpc_endpoint_ids").fset)
+            type_hints = typing.get_type_hints(_typecheckingstub__7a813e1726b30473fc8b6f16aae0d265230aa847c7c56e3dfcfe855c60b08800)
             check_type(argname="argument value", value=value, expected_type=type_hints["value"])
         jsii.set(self, "allowedVpcEndpointIds", value)
 
@@ -214,7 +214,7 @@ class MwsPrivateAccessSettings(
     @id.setter
     def id(self, value: builtins.str) -> None:
         if __debug__:
-            type_hints = typing.get_type_hints(getattr(MwsPrivateAccessSettings, "id").fset)
+            type_hints = typing.get_type_hints(_typecheckingstub__f0899d416577f510977d6a3dc194cb46a2023237f794e518f1cbc14032de57af)
             check_type(argname="argument value", value=value, expected_type=type_hints["value"])
         jsii.set(self, "id", value)
 
@@ -226,7 +226,7 @@ class MwsPrivateAccessSettings(
     @private_access_level.setter
     def private_access_level(self, value: builtins.str) -> None:
         if __debug__:
-            type_hints = typing.get_type_hints(getattr(MwsPrivateAccessSettings, "private_access_level").fset)
+            type_hints = typing.get_type_hints(_typecheckingstub__98953684de89f348e7eac3613d0c1af130cf2f60b0b80e7041082138e9fb294e)
             check_type(argname="argument value", value=value, expected_type=type_hints["value"])
         jsii.set(self, "privateAccessLevel", value)
 
@@ -238,7 +238,7 @@ class MwsPrivateAccessSettings(
     @private_access_settings_id.setter
     def private_access_settings_id(self, value: builtins.str) -> None:
         if __debug__:
-            type_hints = typing.get_type_hints(getattr(MwsPrivateAccessSettings, "private_access_settings_id").fset)
+            type_hints = typing.get_type_hints(_typecheckingstub__920fdaf95f350734436b14ecfaacb1cab02c99739fdef01745ed3253e6bf1606)
             check_type(argname="argument value", value=value, expected_type=type_hints["value"])
         jsii.set(self, "privateAccessSettingsId", value)
 
@@ -250,22 +250,24 @@ class MwsPrivateAccessSettings(
     @private_access_settings_name.setter
     def private_access_settings_name(self, value: builtins.str) -> None:
         if __debug__:
-            type_hints = typing.get_type_hints(getattr(MwsPrivateAccessSettings, "private_access_settings_name").fset)
+            type_hints = typing.get_type_hints(_typecheckingstub__80da4c31e1f81c065f332d1170f70e8442aee77e4c88e902e671dffb831cfbae)
             check_type(argname="argument value", value=value, expected_type=type_hints["value"])
         jsii.set(self, "privateAccessSettingsName", value)
 
     @builtins.property
     @jsii.member(jsii_name="publicAccessEnabled")
-    def public_access_enabled(self) -> typing.Union[builtins.bool, cdktf.IResolvable]:
-        return typing.cast(typing.Union[builtins.bool, cdktf.IResolvable], jsii.get(self, "publicAccessEnabled"))
+    def public_access_enabled(
+        self,
+    ) -> typing.Union[builtins.bool, _cdktf_9a9027ec.IResolvable]:
+        return typing.cast(typing.Union[builtins.bool, _cdktf_9a9027ec.IResolvable], jsii.get(self, "publicAccessEnabled"))
 
     @public_access_enabled.setter
     def public_access_enabled(
         self,
-        value: typing.Union[builtins.bool, cdktf.IResolvable],
+        value: typing.Union[builtins.bool, _cdktf_9a9027ec.IResolvable],
     ) -> None:
         if __debug__:
-            type_hints = typing.get_type_hints(getattr(MwsPrivateAccessSettings, "public_access_enabled").fset)
+            type_hints = typing.get_type_hints(_typecheckingstub__4bd4345512052629135e981729d5da0179d05f4e227a172699ac25c28faa239e)
             check_type(argname="argument value", value=value, expected_type=type_hints["value"])
         jsii.set(self, "publicAccessEnabled", value)
 
@@ -277,7 +279,7 @@ class MwsPrivateAccessSettings(
     @region.setter
     def region(self, value: builtins.str) -> None:
         if __debug__:
-            type_hints = typing.get_type_hints(getattr(MwsPrivateAccessSettings, "region").fset)
+            type_hints = typing.get_type_hints(_typecheckingstub__e899360f788adf42ca2b1e41dfa27f29d939a322dcb7396b09c63be8c3ef2908)
             check_type(argname="argument value", value=value, expected_type=type_hints["value"])
         jsii.set(self, "region", value)
 
@@ -289,14 +291,14 @@ class MwsPrivateAccessSettings(
     @status.setter
     def status(self, value: builtins.str) -> None:
         if __debug__:
-            type_hints = typing.get_type_hints(getattr(MwsPrivateAccessSettings, "status").fset)
+            type_hints = typing.get_type_hints(_typecheckingstub__b06a164b7e7d06b390ce9976dc10b6fddb249a5ae2645b888856556afc45c3ee)
             check_type(argname="argument value", value=value, expected_type=type_hints["value"])
         jsii.set(self, "status", value)
 
 
 @jsii.data_type(
     jsii_type="@cdktf/provider-databricks.mwsPrivateAccessSettings.MwsPrivateAccessSettingsConfig",
-    jsii_struct_bases=[cdktf.TerraformMetaArguments],
+    jsii_struct_bases=[_cdktf_9a9027ec.TerraformMetaArguments],
     name_mapping={
         "connection": "connection",
         "count": "count",
@@ -316,17 +318,17 @@ class MwsPrivateAccessSettings(
         "status": "status",
     },
 )
-class MwsPrivateAccessSettingsConfig(cdktf.TerraformMetaArguments):
+class MwsPrivateAccessSettingsConfig(_cdktf_9a9027ec.TerraformMetaArguments):
     def __init__(
         self,
         *,
-        connection: typing.Optional[typing.Union[typing.Union[cdktf.SSHProvisionerConnection, typing.Dict[str, typing.Any]], typing.Union[cdktf.WinrmProvisionerConnection, typing.Dict[str, typing.Any]]]] = None,
+        connection: typing.Optional[typing.Union[typing.Union[_cdktf_9a9027ec.SSHProvisionerConnection, typing.Dict[builtins.str, typing.Any]], typing.Union[_cdktf_9a9027ec.WinrmProvisionerConnection, typing.Dict[builtins.str, typing.Any]]]] = None,
         count: typing.Optional[jsii.Number] = None,
-        depends_on: typing.Optional[typing.Sequence[cdktf.ITerraformDependable]] = None,
-        for_each: typing.Optional[cdktf.ITerraformIterator] = None,
-        lifecycle: typing.Optional[typing.Union[cdktf.TerraformResourceLifecycle, typing.Dict[str, typing.Any]]] = None,
-        provider: typing.Optional[cdktf.TerraformProvider] = None,
-        provisioners: typing.Optional[typing.Sequence[typing.Union[typing.Union[cdktf.FileProvisioner, typing.Dict[str, typing.Any]], typing.Union[cdktf.LocalExecProvisioner, typing.Dict[str, typing.Any]], typing.Union[cdktf.RemoteExecProvisioner, typing.Dict[str, typing.Any]]]]] = None,
+        depends_on: typing.Optional[typing.Sequence[_cdktf_9a9027ec.ITerraformDependable]] = None,
+        for_each: typing.Optional[_cdktf_9a9027ec.ITerraformIterator] = None,
+        lifecycle: typing.Optional[typing.Union[_cdktf_9a9027ec.TerraformResourceLifecycle, typing.Dict[builtins.str, typing.Any]]] = None,
+        provider: typing.Optional[_cdktf_9a9027ec.TerraformProvider] = None,
+        provisioners: typing.Optional[typing.Sequence[typing.Union[typing.Union[_cdktf_9a9027ec.FileProvisioner, typing.Dict[builtins.str, typing.Any]], typing.Union[_cdktf_9a9027ec.LocalExecProvisioner, typing.Dict[builtins.str, typing.Any]], typing.Union[_cdktf_9a9027ec.RemoteExecProvisioner, typing.Dict[builtins.str, typing.Any]]]]] = None,
         private_access_settings_name: builtins.str,
         region: builtins.str,
         account_id: typing.Optional[builtins.str] = None,
@@ -334,7 +336,7 @@ class MwsPrivateAccessSettingsConfig(cdktf.TerraformMetaArguments):
         id: typing.Optional[builtins.str] = None,
         private_access_level: typing.Optional[builtins.str] = None,
         private_access_settings_id: typing.Optional[builtins.str] = None,
-        public_access_enabled: typing.Optional[typing.Union[builtins.bool, cdktf.IResolvable]] = None,
+        public_access_enabled: typing.Optional[typing.Union[builtins.bool, _cdktf_9a9027ec.IResolvable]] = None,
         status: typing.Optional[builtins.str] = None,
     ) -> None:
         '''
@@ -356,9 +358,9 @@ class MwsPrivateAccessSettingsConfig(cdktf.TerraformMetaArguments):
         :param status: Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/databricks/r/mws_private_access_settings#status MwsPrivateAccessSettings#status}.
         '''
         if isinstance(lifecycle, dict):
-            lifecycle = cdktf.TerraformResourceLifecycle(**lifecycle)
+            lifecycle = _cdktf_9a9027ec.TerraformResourceLifecycle(**lifecycle)
         if __debug__:
-            type_hints = typing.get_type_hints(MwsPrivateAccessSettingsConfig.__init__)
+            type_hints = typing.get_type_hints(_typecheckingstub__9994497deaf05a87f82ba61f9aa725b5cf171bdfc7d65b9576228f4bb8d6a3f0)
             check_type(argname="argument connection", value=connection, expected_type=type_hints["connection"])
             check_type(argname="argument count", value=count, expected_type=type_hints["count"])
             check_type(argname="argument depends_on", value=depends_on, expected_type=type_hints["depends_on"])
@@ -375,7 +377,7 @@ class MwsPrivateAccessSettingsConfig(cdktf.TerraformMetaArguments):
             check_type(argname="argument private_access_settings_id", value=private_access_settings_id, expected_type=type_hints["private_access_settings_id"])
             check_type(argname="argument public_access_enabled", value=public_access_enabled, expected_type=type_hints["public_access_enabled"])
             check_type(argname="argument status", value=status, expected_type=type_hints["status"])
-        self._values: typing.Dict[str, typing.Any] = {
+        self._values: typing.Dict[builtins.str, typing.Any] = {
             "private_access_settings_name": private_access_settings_name,
             "region": region,
         }
@@ -411,12 +413,12 @@ class MwsPrivateAccessSettingsConfig(cdktf.TerraformMetaArguments):
     @builtins.property
     def connection(
         self,
-    ) -> typing.Optional[typing.Union[cdktf.SSHProvisionerConnection, cdktf.WinrmProvisionerConnection]]:
+    ) -> typing.Optional[typing.Union[_cdktf_9a9027ec.SSHProvisionerConnection, _cdktf_9a9027ec.WinrmProvisionerConnection]]:
         '''
         :stability: experimental
         '''
         result = self._values.get("connection")
-        return typing.cast(typing.Optional[typing.Union[cdktf.SSHProvisionerConnection, cdktf.WinrmProvisionerConnection]], result)
+        return typing.cast(typing.Optional[typing.Union[_cdktf_9a9027ec.SSHProvisionerConnection, _cdktf_9a9027ec.WinrmProvisionerConnection]], result)
 
     @builtins.property
     def count(self) -> typing.Optional[jsii.Number]:
@@ -427,46 +429,48 @@ class MwsPrivateAccessSettingsConfig(cdktf.TerraformMetaArguments):
         return typing.cast(typing.Optional[jsii.Number], result)
 
     @builtins.property
-    def depends_on(self) -> typing.Optional[typing.List[cdktf.ITerraformDependable]]:
+    def depends_on(
+        self,
+    ) -> typing.Optional[typing.List[_cdktf_9a9027ec.ITerraformDependable]]:
         '''
         :stability: experimental
         '''
         result = self._values.get("depends_on")
-        return typing.cast(typing.Optional[typing.List[cdktf.ITerraformDependable]], result)
+        return typing.cast(typing.Optional[typing.List[_cdktf_9a9027ec.ITerraformDependable]], result)
 
     @builtins.property
-    def for_each(self) -> typing.Optional[cdktf.ITerraformIterator]:
+    def for_each(self) -> typing.Optional[_cdktf_9a9027ec.ITerraformIterator]:
         '''
         :stability: experimental
         '''
         result = self._values.get("for_each")
-        return typing.cast(typing.Optional[cdktf.ITerraformIterator], result)
+        return typing.cast(typing.Optional[_cdktf_9a9027ec.ITerraformIterator], result)
 
     @builtins.property
-    def lifecycle(self) -> typing.Optional[cdktf.TerraformResourceLifecycle]:
+    def lifecycle(self) -> typing.Optional[_cdktf_9a9027ec.TerraformResourceLifecycle]:
         '''
         :stability: experimental
         '''
         result = self._values.get("lifecycle")
-        return typing.cast(typing.Optional[cdktf.TerraformResourceLifecycle], result)
+        return typing.cast(typing.Optional[_cdktf_9a9027ec.TerraformResourceLifecycle], result)
 
     @builtins.property
-    def provider(self) -> typing.Optional[cdktf.TerraformProvider]:
+    def provider(self) -> typing.Optional[_cdktf_9a9027ec.TerraformProvider]:
         '''
         :stability: experimental
         '''
         result = self._values.get("provider")
-        return typing.cast(typing.Optional[cdktf.TerraformProvider], result)
+        return typing.cast(typing.Optional[_cdktf_9a9027ec.TerraformProvider], result)
 
     @builtins.property
     def provisioners(
         self,
-    ) -> typing.Optional[typing.List[typing.Union[cdktf.FileProvisioner, cdktf.LocalExecProvisioner, cdktf.RemoteExecProvisioner]]]:
+    ) -> typing.Optional[typing.List[typing.Union[_cdktf_9a9027ec.FileProvisioner, _cdktf_9a9027ec.LocalExecProvisioner, _cdktf_9a9027ec.RemoteExecProvisioner]]]:
         '''
         :stability: experimental
         '''
         result = self._values.get("provisioners")
-        return typing.cast(typing.Optional[typing.List[typing.Union[cdktf.FileProvisioner, cdktf.LocalExecProvisioner, cdktf.RemoteExecProvisioner]]], result)
+        return typing.cast(typing.Optional[typing.List[typing.Union[_cdktf_9a9027ec.FileProvisioner, _cdktf_9a9027ec.LocalExecProvisioner, _cdktf_9a9027ec.RemoteExecProvisioner]]], result)
 
     @builtins.property
     def private_access_settings_name(self) -> builtins.str:
@@ -519,10 +523,10 @@ class MwsPrivateAccessSettingsConfig(cdktf.TerraformMetaArguments):
     @builtins.property
     def public_access_enabled(
         self,
-    ) -> typing.Optional[typing.Union[builtins.bool, cdktf.IResolvable]]:
+    ) -> typing.Optional[typing.Union[builtins.bool, _cdktf_9a9027ec.IResolvable]]:
         '''Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/databricks/r/mws_private_access_settings#public_access_enabled MwsPrivateAccessSettings#public_access_enabled}.'''
         result = self._values.get("public_access_enabled")
-        return typing.cast(typing.Optional[typing.Union[builtins.bool, cdktf.IResolvable]], result)
+        return typing.cast(typing.Optional[typing.Union[builtins.bool, _cdktf_9a9027ec.IResolvable]], result)
 
     @builtins.property
     def status(self) -> typing.Optional[builtins.str]:
@@ -548,3 +552,103 @@ __all__ = [
 ]
 
 publication.publish()
+
+def _typecheckingstub__558ab876614b55c196d9e855a124e5f40876121e80f87098ab57f22a021af624(
+    scope: _constructs_77d1e7e8.Construct,
+    id_: builtins.str,
+    *,
+    private_access_settings_name: builtins.str,
+    region: builtins.str,
+    account_id: typing.Optional[builtins.str] = None,
+    allowed_vpc_endpoint_ids: typing.Optional[typing.Sequence[builtins.str]] = None,
+    id: typing.Optional[builtins.str] = None,
+    private_access_level: typing.Optional[builtins.str] = None,
+    private_access_settings_id: typing.Optional[builtins.str] = None,
+    public_access_enabled: typing.Optional[typing.Union[builtins.bool, _cdktf_9a9027ec.IResolvable]] = None,
+    status: typing.Optional[builtins.str] = None,
+    connection: typing.Optional[typing.Union[typing.Union[_cdktf_9a9027ec.SSHProvisionerConnection, typing.Dict[builtins.str, typing.Any]], typing.Union[_cdktf_9a9027ec.WinrmProvisionerConnection, typing.Dict[builtins.str, typing.Any]]]] = None,
+    count: typing.Optional[jsii.Number] = None,
+    depends_on: typing.Optional[typing.Sequence[_cdktf_9a9027ec.ITerraformDependable]] = None,
+    for_each: typing.Optional[_cdktf_9a9027ec.ITerraformIterator] = None,
+    lifecycle: typing.Optional[typing.Union[_cdktf_9a9027ec.TerraformResourceLifecycle, typing.Dict[builtins.str, typing.Any]]] = None,
+    provider: typing.Optional[_cdktf_9a9027ec.TerraformProvider] = None,
+    provisioners: typing.Optional[typing.Sequence[typing.Union[typing.Union[_cdktf_9a9027ec.FileProvisioner, typing.Dict[builtins.str, typing.Any]], typing.Union[_cdktf_9a9027ec.LocalExecProvisioner, typing.Dict[builtins.str, typing.Any]], typing.Union[_cdktf_9a9027ec.RemoteExecProvisioner, typing.Dict[builtins.str, typing.Any]]]]] = None,
+) -> None:
+    """Type checking stubs"""
+    pass
+
+def _typecheckingstub__8284effc666787f6af44fcebf8fafb576d81d13c2ca23da22559ae6058cb996f(
+    value: builtins.str,
+) -> None:
+    """Type checking stubs"""
+    pass
+
+def _typecheckingstub__7a813e1726b30473fc8b6f16aae0d265230aa847c7c56e3dfcfe855c60b08800(
+    value: typing.List[builtins.str],
+) -> None:
+    """Type checking stubs"""
+    pass
+
+def _typecheckingstub__f0899d416577f510977d6a3dc194cb46a2023237f794e518f1cbc14032de57af(
+    value: builtins.str,
+) -> None:
+    """Type checking stubs"""
+    pass
+
+def _typecheckingstub__98953684de89f348e7eac3613d0c1af130cf2f60b0b80e7041082138e9fb294e(
+    value: builtins.str,
+) -> None:
+    """Type checking stubs"""
+    pass
+
+def _typecheckingstub__920fdaf95f350734436b14ecfaacb1cab02c99739fdef01745ed3253e6bf1606(
+    value: builtins.str,
+) -> None:
+    """Type checking stubs"""
+    pass
+
+def _typecheckingstub__80da4c31e1f81c065f332d1170f70e8442aee77e4c88e902e671dffb831cfbae(
+    value: builtins.str,
+) -> None:
+    """Type checking stubs"""
+    pass
+
+def _typecheckingstub__4bd4345512052629135e981729d5da0179d05f4e227a172699ac25c28faa239e(
+    value: typing.Union[builtins.bool, _cdktf_9a9027ec.IResolvable],
+) -> None:
+    """Type checking stubs"""
+    pass
+
+def _typecheckingstub__e899360f788adf42ca2b1e41dfa27f29d939a322dcb7396b09c63be8c3ef2908(
+    value: builtins.str,
+) -> None:
+    """Type checking stubs"""
+    pass
+
+def _typecheckingstub__b06a164b7e7d06b390ce9976dc10b6fddb249a5ae2645b888856556afc45c3ee(
+    value: builtins.str,
+) -> None:
+    """Type checking stubs"""
+    pass
+
+def _typecheckingstub__9994497deaf05a87f82ba61f9aa725b5cf171bdfc7d65b9576228f4bb8d6a3f0(
+    *,
+    connection: typing.Optional[typing.Union[typing.Union[_cdktf_9a9027ec.SSHProvisionerConnection, typing.Dict[builtins.str, typing.Any]], typing.Union[_cdktf_9a9027ec.WinrmProvisionerConnection, typing.Dict[builtins.str, typing.Any]]]] = None,
+    count: typing.Optional[jsii.Number] = None,
+    depends_on: typing.Optional[typing.Sequence[_cdktf_9a9027ec.ITerraformDependable]] = None,
+    for_each: typing.Optional[_cdktf_9a9027ec.ITerraformIterator] = None,
+    lifecycle: typing.Optional[typing.Union[_cdktf_9a9027ec.TerraformResourceLifecycle, typing.Dict[builtins.str, typing.Any]]] = None,
+    provider: typing.Optional[_cdktf_9a9027ec.TerraformProvider] = None,
+    provisioners: typing.Optional[typing.Sequence[typing.Union[typing.Union[_cdktf_9a9027ec.FileProvisioner, typing.Dict[builtins.str, typing.Any]], typing.Union[_cdktf_9a9027ec.LocalExecProvisioner, typing.Dict[builtins.str, typing.Any]], typing.Union[_cdktf_9a9027ec.RemoteExecProvisioner, typing.Dict[builtins.str, typing.Any]]]]] = None,
+    private_access_settings_name: builtins.str,
+    region: builtins.str,
+    account_id: typing.Optional[builtins.str] = None,
+    allowed_vpc_endpoint_ids: typing.Optional[typing.Sequence[builtins.str]] = None,
+    id: typing.Optional[builtins.str] = None,
+    private_access_level: typing.Optional[builtins.str] = None,
+    private_access_settings_id: typing.Optional[builtins.str] = None,
+    public_access_enabled: typing.Optional[typing.Union[builtins.bool, _cdktf_9a9027ec.IResolvable]] = None,
+    status: typing.Optional[builtins.str] = None,
+) -> None:
+    """Type checking stubs"""
+    pass
