@@ -17,12 +17,12 @@ from typeguard import check_type
 
 from .._jsii import *
 
-import cdktf
-import constructs
+import cdktf as _cdktf_9a9027ec
+import constructs as _constructs_77d1e7e8
 
 
 class Notebook(
-    cdktf.TerraformResource,
+    _cdktf_9a9027ec.TerraformResource,
     metaclass=jsii.JSIIMeta,
     jsii_type="@cdktf/provider-databricks.notebook.Notebook",
 ):
@@ -30,7 +30,7 @@ class Notebook(
 
     def __init__(
         self,
-        scope: constructs.Construct,
+        scope: _constructs_77d1e7e8.Construct,
         id_: builtins.str,
         *,
         path: builtins.str,
@@ -42,13 +42,13 @@ class Notebook(
         object_id: typing.Optional[jsii.Number] = None,
         object_type: typing.Optional[builtins.str] = None,
         source: typing.Optional[builtins.str] = None,
-        connection: typing.Optional[typing.Union[typing.Union[cdktf.SSHProvisionerConnection, typing.Dict[str, typing.Any]], typing.Union[cdktf.WinrmProvisionerConnection, typing.Dict[str, typing.Any]]]] = None,
+        connection: typing.Optional[typing.Union[typing.Union[_cdktf_9a9027ec.SSHProvisionerConnection, typing.Dict[builtins.str, typing.Any]], typing.Union[_cdktf_9a9027ec.WinrmProvisionerConnection, typing.Dict[builtins.str, typing.Any]]]] = None,
         count: typing.Optional[jsii.Number] = None,
-        depends_on: typing.Optional[typing.Sequence[cdktf.ITerraformDependable]] = None,
-        for_each: typing.Optional[cdktf.ITerraformIterator] = None,
-        lifecycle: typing.Optional[typing.Union[cdktf.TerraformResourceLifecycle, typing.Dict[str, typing.Any]]] = None,
-        provider: typing.Optional[cdktf.TerraformProvider] = None,
-        provisioners: typing.Optional[typing.Sequence[typing.Union[typing.Union[cdktf.FileProvisioner, typing.Dict[str, typing.Any]], typing.Union[cdktf.LocalExecProvisioner, typing.Dict[str, typing.Any]], typing.Union[cdktf.RemoteExecProvisioner, typing.Dict[str, typing.Any]]]]] = None,
+        depends_on: typing.Optional[typing.Sequence[_cdktf_9a9027ec.ITerraformDependable]] = None,
+        for_each: typing.Optional[_cdktf_9a9027ec.ITerraformIterator] = None,
+        lifecycle: typing.Optional[typing.Union[_cdktf_9a9027ec.TerraformResourceLifecycle, typing.Dict[builtins.str, typing.Any]]] = None,
+        provider: typing.Optional[_cdktf_9a9027ec.TerraformProvider] = None,
+        provisioners: typing.Optional[typing.Sequence[typing.Union[typing.Union[_cdktf_9a9027ec.FileProvisioner, typing.Dict[builtins.str, typing.Any]], typing.Union[_cdktf_9a9027ec.LocalExecProvisioner, typing.Dict[builtins.str, typing.Any]], typing.Union[_cdktf_9a9027ec.RemoteExecProvisioner, typing.Dict[builtins.str, typing.Any]]]]] = None,
     ) -> None:
         '''Create a new {@link https://www.terraform.io/docs/providers/databricks/r/notebook databricks_notebook} Resource.
 
@@ -72,7 +72,7 @@ class Notebook(
         :param provisioners: 
         '''
         if __debug__:
-            type_hints = typing.get_type_hints(Notebook.__init__)
+            type_hints = typing.get_type_hints(_typecheckingstub__df1bf7b2f1702fd3911b4035b9ab7d2bf9f405d25a700b8c831b7b8d22ffde40)
             check_type(argname="argument scope", value=scope, expected_type=type_hints["scope"])
             check_type(argname="argument id_", value=id_, expected_type=type_hints["id_"])
         config = NotebookConfig(
@@ -195,7 +195,7 @@ class Notebook(
     @content_base64.setter
     def content_base64(self, value: builtins.str) -> None:
         if __debug__:
-            type_hints = typing.get_type_hints(getattr(Notebook, "content_base64").fset)
+            type_hints = typing.get_type_hints(_typecheckingstub__42c6cef0c574e405fd6663d3c78cb0db35c3cf3235cdf3d16b7cf4fa41858a57)
             check_type(argname="argument value", value=value, expected_type=type_hints["value"])
         jsii.set(self, "contentBase64", value)
 
@@ -207,7 +207,7 @@ class Notebook(
     @format.setter
     def format(self, value: builtins.str) -> None:
         if __debug__:
-            type_hints = typing.get_type_hints(getattr(Notebook, "format").fset)
+            type_hints = typing.get_type_hints(_typecheckingstub__e089553bcc8a52f47c7787b6ddbb2572f9f2eecee4208adde88915a070d74cae)
             check_type(argname="argument value", value=value, expected_type=type_hints["value"])
         jsii.set(self, "format", value)
 
@@ -219,7 +219,7 @@ class Notebook(
     @id.setter
     def id(self, value: builtins.str) -> None:
         if __debug__:
-            type_hints = typing.get_type_hints(getattr(Notebook, "id").fset)
+            type_hints = typing.get_type_hints(_typecheckingstub__7bf2acc63b601bedee3699fdfafe970b9331b0e830c58700e75ce5298532f9cc)
             check_type(argname="argument value", value=value, expected_type=type_hints["value"])
         jsii.set(self, "id", value)
 
@@ -231,7 +231,7 @@ class Notebook(
     @language.setter
     def language(self, value: builtins.str) -> None:
         if __debug__:
-            type_hints = typing.get_type_hints(getattr(Notebook, "language").fset)
+            type_hints = typing.get_type_hints(_typecheckingstub__f74d0f71bb0180959799cb1e35a5c5024f1c42ed4ef8167f03c2aa5303296eec)
             check_type(argname="argument value", value=value, expected_type=type_hints["value"])
         jsii.set(self, "language", value)
 
@@ -243,7 +243,7 @@ class Notebook(
     @md5.setter
     def md5(self, value: builtins.str) -> None:
         if __debug__:
-            type_hints = typing.get_type_hints(getattr(Notebook, "md5").fset)
+            type_hints = typing.get_type_hints(_typecheckingstub__9c78dde3ef8979e2379f0c943fab4bb9fd41f6ab6282e7ac6cd8a459e724677a)
             check_type(argname="argument value", value=value, expected_type=type_hints["value"])
         jsii.set(self, "md5", value)
 
@@ -255,7 +255,7 @@ class Notebook(
     @object_id.setter
     def object_id(self, value: jsii.Number) -> None:
         if __debug__:
-            type_hints = typing.get_type_hints(getattr(Notebook, "object_id").fset)
+            type_hints = typing.get_type_hints(_typecheckingstub__2d1ac3512105a6cba47f46d0ea8b22b2686421903a439672699c7c8b01c2abc1)
             check_type(argname="argument value", value=value, expected_type=type_hints["value"])
         jsii.set(self, "objectId", value)
 
@@ -267,7 +267,7 @@ class Notebook(
     @object_type.setter
     def object_type(self, value: builtins.str) -> None:
         if __debug__:
-            type_hints = typing.get_type_hints(getattr(Notebook, "object_type").fset)
+            type_hints = typing.get_type_hints(_typecheckingstub__8f35db953befa1eb5299baf417a63b8599eaaea7ce8972fb117ce86f8c3ee9da)
             check_type(argname="argument value", value=value, expected_type=type_hints["value"])
         jsii.set(self, "objectType", value)
 
@@ -279,7 +279,7 @@ class Notebook(
     @path.setter
     def path(self, value: builtins.str) -> None:
         if __debug__:
-            type_hints = typing.get_type_hints(getattr(Notebook, "path").fset)
+            type_hints = typing.get_type_hints(_typecheckingstub__edbb8e9e193b37cc1283fc33882913e20d0be0345b014c98753d2056efe22568)
             check_type(argname="argument value", value=value, expected_type=type_hints["value"])
         jsii.set(self, "path", value)
 
@@ -291,14 +291,14 @@ class Notebook(
     @source.setter
     def source(self, value: builtins.str) -> None:
         if __debug__:
-            type_hints = typing.get_type_hints(getattr(Notebook, "source").fset)
+            type_hints = typing.get_type_hints(_typecheckingstub__5c221249ff2765a8e6f74bc5869bfee3d642646ecf25ea9cb9404a2d954f0683)
             check_type(argname="argument value", value=value, expected_type=type_hints["value"])
         jsii.set(self, "source", value)
 
 
 @jsii.data_type(
     jsii_type="@cdktf/provider-databricks.notebook.NotebookConfig",
-    jsii_struct_bases=[cdktf.TerraformMetaArguments],
+    jsii_struct_bases=[_cdktf_9a9027ec.TerraformMetaArguments],
     name_mapping={
         "connection": "connection",
         "count": "count",
@@ -318,17 +318,17 @@ class Notebook(
         "source": "source",
     },
 )
-class NotebookConfig(cdktf.TerraformMetaArguments):
+class NotebookConfig(_cdktf_9a9027ec.TerraformMetaArguments):
     def __init__(
         self,
         *,
-        connection: typing.Optional[typing.Union[typing.Union[cdktf.SSHProvisionerConnection, typing.Dict[str, typing.Any]], typing.Union[cdktf.WinrmProvisionerConnection, typing.Dict[str, typing.Any]]]] = None,
+        connection: typing.Optional[typing.Union[typing.Union[_cdktf_9a9027ec.SSHProvisionerConnection, typing.Dict[builtins.str, typing.Any]], typing.Union[_cdktf_9a9027ec.WinrmProvisionerConnection, typing.Dict[builtins.str, typing.Any]]]] = None,
         count: typing.Optional[jsii.Number] = None,
-        depends_on: typing.Optional[typing.Sequence[cdktf.ITerraformDependable]] = None,
-        for_each: typing.Optional[cdktf.ITerraformIterator] = None,
-        lifecycle: typing.Optional[typing.Union[cdktf.TerraformResourceLifecycle, typing.Dict[str, typing.Any]]] = None,
-        provider: typing.Optional[cdktf.TerraformProvider] = None,
-        provisioners: typing.Optional[typing.Sequence[typing.Union[typing.Union[cdktf.FileProvisioner, typing.Dict[str, typing.Any]], typing.Union[cdktf.LocalExecProvisioner, typing.Dict[str, typing.Any]], typing.Union[cdktf.RemoteExecProvisioner, typing.Dict[str, typing.Any]]]]] = None,
+        depends_on: typing.Optional[typing.Sequence[_cdktf_9a9027ec.ITerraformDependable]] = None,
+        for_each: typing.Optional[_cdktf_9a9027ec.ITerraformIterator] = None,
+        lifecycle: typing.Optional[typing.Union[_cdktf_9a9027ec.TerraformResourceLifecycle, typing.Dict[builtins.str, typing.Any]]] = None,
+        provider: typing.Optional[_cdktf_9a9027ec.TerraformProvider] = None,
+        provisioners: typing.Optional[typing.Sequence[typing.Union[typing.Union[_cdktf_9a9027ec.FileProvisioner, typing.Dict[builtins.str, typing.Any]], typing.Union[_cdktf_9a9027ec.LocalExecProvisioner, typing.Dict[builtins.str, typing.Any]], typing.Union[_cdktf_9a9027ec.RemoteExecProvisioner, typing.Dict[builtins.str, typing.Any]]]]] = None,
         path: builtins.str,
         content_base64: typing.Optional[builtins.str] = None,
         format: typing.Optional[builtins.str] = None,
@@ -358,9 +358,9 @@ class NotebookConfig(cdktf.TerraformMetaArguments):
         :param source: Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/databricks/r/notebook#source Notebook#source}.
         '''
         if isinstance(lifecycle, dict):
-            lifecycle = cdktf.TerraformResourceLifecycle(**lifecycle)
+            lifecycle = _cdktf_9a9027ec.TerraformResourceLifecycle(**lifecycle)
         if __debug__:
-            type_hints = typing.get_type_hints(NotebookConfig.__init__)
+            type_hints = typing.get_type_hints(_typecheckingstub__8433e0de625b8cdd7af72860d8e18ac94b513440a8e56ff43b927e9da0c98992)
             check_type(argname="argument connection", value=connection, expected_type=type_hints["connection"])
             check_type(argname="argument count", value=count, expected_type=type_hints["count"])
             check_type(argname="argument depends_on", value=depends_on, expected_type=type_hints["depends_on"])
@@ -377,7 +377,7 @@ class NotebookConfig(cdktf.TerraformMetaArguments):
             check_type(argname="argument object_id", value=object_id, expected_type=type_hints["object_id"])
             check_type(argname="argument object_type", value=object_type, expected_type=type_hints["object_type"])
             check_type(argname="argument source", value=source, expected_type=type_hints["source"])
-        self._values: typing.Dict[str, typing.Any] = {
+        self._values: typing.Dict[builtins.str, typing.Any] = {
             "path": path,
         }
         if connection is not None:
@@ -414,12 +414,12 @@ class NotebookConfig(cdktf.TerraformMetaArguments):
     @builtins.property
     def connection(
         self,
-    ) -> typing.Optional[typing.Union[cdktf.SSHProvisionerConnection, cdktf.WinrmProvisionerConnection]]:
+    ) -> typing.Optional[typing.Union[_cdktf_9a9027ec.SSHProvisionerConnection, _cdktf_9a9027ec.WinrmProvisionerConnection]]:
         '''
         :stability: experimental
         '''
         result = self._values.get("connection")
-        return typing.cast(typing.Optional[typing.Union[cdktf.SSHProvisionerConnection, cdktf.WinrmProvisionerConnection]], result)
+        return typing.cast(typing.Optional[typing.Union[_cdktf_9a9027ec.SSHProvisionerConnection, _cdktf_9a9027ec.WinrmProvisionerConnection]], result)
 
     @builtins.property
     def count(self) -> typing.Optional[jsii.Number]:
@@ -430,46 +430,48 @@ class NotebookConfig(cdktf.TerraformMetaArguments):
         return typing.cast(typing.Optional[jsii.Number], result)
 
     @builtins.property
-    def depends_on(self) -> typing.Optional[typing.List[cdktf.ITerraformDependable]]:
+    def depends_on(
+        self,
+    ) -> typing.Optional[typing.List[_cdktf_9a9027ec.ITerraformDependable]]:
         '''
         :stability: experimental
         '''
         result = self._values.get("depends_on")
-        return typing.cast(typing.Optional[typing.List[cdktf.ITerraformDependable]], result)
+        return typing.cast(typing.Optional[typing.List[_cdktf_9a9027ec.ITerraformDependable]], result)
 
     @builtins.property
-    def for_each(self) -> typing.Optional[cdktf.ITerraformIterator]:
+    def for_each(self) -> typing.Optional[_cdktf_9a9027ec.ITerraformIterator]:
         '''
         :stability: experimental
         '''
         result = self._values.get("for_each")
-        return typing.cast(typing.Optional[cdktf.ITerraformIterator], result)
+        return typing.cast(typing.Optional[_cdktf_9a9027ec.ITerraformIterator], result)
 
     @builtins.property
-    def lifecycle(self) -> typing.Optional[cdktf.TerraformResourceLifecycle]:
+    def lifecycle(self) -> typing.Optional[_cdktf_9a9027ec.TerraformResourceLifecycle]:
         '''
         :stability: experimental
         '''
         result = self._values.get("lifecycle")
-        return typing.cast(typing.Optional[cdktf.TerraformResourceLifecycle], result)
+        return typing.cast(typing.Optional[_cdktf_9a9027ec.TerraformResourceLifecycle], result)
 
     @builtins.property
-    def provider(self) -> typing.Optional[cdktf.TerraformProvider]:
+    def provider(self) -> typing.Optional[_cdktf_9a9027ec.TerraformProvider]:
         '''
         :stability: experimental
         '''
         result = self._values.get("provider")
-        return typing.cast(typing.Optional[cdktf.TerraformProvider], result)
+        return typing.cast(typing.Optional[_cdktf_9a9027ec.TerraformProvider], result)
 
     @builtins.property
     def provisioners(
         self,
-    ) -> typing.Optional[typing.List[typing.Union[cdktf.FileProvisioner, cdktf.LocalExecProvisioner, cdktf.RemoteExecProvisioner]]]:
+    ) -> typing.Optional[typing.List[typing.Union[_cdktf_9a9027ec.FileProvisioner, _cdktf_9a9027ec.LocalExecProvisioner, _cdktf_9a9027ec.RemoteExecProvisioner]]]:
         '''
         :stability: experimental
         '''
         result = self._values.get("provisioners")
-        return typing.cast(typing.Optional[typing.List[typing.Union[cdktf.FileProvisioner, cdktf.LocalExecProvisioner, cdktf.RemoteExecProvisioner]]], result)
+        return typing.cast(typing.Optional[typing.List[typing.Union[_cdktf_9a9027ec.FileProvisioner, _cdktf_9a9027ec.LocalExecProvisioner, _cdktf_9a9027ec.RemoteExecProvisioner]]], result)
 
     @builtins.property
     def path(self) -> builtins.str:
@@ -548,3 +550,103 @@ __all__ = [
 ]
 
 publication.publish()
+
+def _typecheckingstub__df1bf7b2f1702fd3911b4035b9ab7d2bf9f405d25a700b8c831b7b8d22ffde40(
+    scope: _constructs_77d1e7e8.Construct,
+    id_: builtins.str,
+    *,
+    path: builtins.str,
+    content_base64: typing.Optional[builtins.str] = None,
+    format: typing.Optional[builtins.str] = None,
+    id: typing.Optional[builtins.str] = None,
+    language: typing.Optional[builtins.str] = None,
+    md5: typing.Optional[builtins.str] = None,
+    object_id: typing.Optional[jsii.Number] = None,
+    object_type: typing.Optional[builtins.str] = None,
+    source: typing.Optional[builtins.str] = None,
+    connection: typing.Optional[typing.Union[typing.Union[_cdktf_9a9027ec.SSHProvisionerConnection, typing.Dict[builtins.str, typing.Any]], typing.Union[_cdktf_9a9027ec.WinrmProvisionerConnection, typing.Dict[builtins.str, typing.Any]]]] = None,
+    count: typing.Optional[jsii.Number] = None,
+    depends_on: typing.Optional[typing.Sequence[_cdktf_9a9027ec.ITerraformDependable]] = None,
+    for_each: typing.Optional[_cdktf_9a9027ec.ITerraformIterator] = None,
+    lifecycle: typing.Optional[typing.Union[_cdktf_9a9027ec.TerraformResourceLifecycle, typing.Dict[builtins.str, typing.Any]]] = None,
+    provider: typing.Optional[_cdktf_9a9027ec.TerraformProvider] = None,
+    provisioners: typing.Optional[typing.Sequence[typing.Union[typing.Union[_cdktf_9a9027ec.FileProvisioner, typing.Dict[builtins.str, typing.Any]], typing.Union[_cdktf_9a9027ec.LocalExecProvisioner, typing.Dict[builtins.str, typing.Any]], typing.Union[_cdktf_9a9027ec.RemoteExecProvisioner, typing.Dict[builtins.str, typing.Any]]]]] = None,
+) -> None:
+    """Type checking stubs"""
+    pass
+
+def _typecheckingstub__42c6cef0c574e405fd6663d3c78cb0db35c3cf3235cdf3d16b7cf4fa41858a57(
+    value: builtins.str,
+) -> None:
+    """Type checking stubs"""
+    pass
+
+def _typecheckingstub__e089553bcc8a52f47c7787b6ddbb2572f9f2eecee4208adde88915a070d74cae(
+    value: builtins.str,
+) -> None:
+    """Type checking stubs"""
+    pass
+
+def _typecheckingstub__7bf2acc63b601bedee3699fdfafe970b9331b0e830c58700e75ce5298532f9cc(
+    value: builtins.str,
+) -> None:
+    """Type checking stubs"""
+    pass
+
+def _typecheckingstub__f74d0f71bb0180959799cb1e35a5c5024f1c42ed4ef8167f03c2aa5303296eec(
+    value: builtins.str,
+) -> None:
+    """Type checking stubs"""
+    pass
+
+def _typecheckingstub__9c78dde3ef8979e2379f0c943fab4bb9fd41f6ab6282e7ac6cd8a459e724677a(
+    value: builtins.str,
+) -> None:
+    """Type checking stubs"""
+    pass
+
+def _typecheckingstub__2d1ac3512105a6cba47f46d0ea8b22b2686421903a439672699c7c8b01c2abc1(
+    value: jsii.Number,
+) -> None:
+    """Type checking stubs"""
+    pass
+
+def _typecheckingstub__8f35db953befa1eb5299baf417a63b8599eaaea7ce8972fb117ce86f8c3ee9da(
+    value: builtins.str,
+) -> None:
+    """Type checking stubs"""
+    pass
+
+def _typecheckingstub__edbb8e9e193b37cc1283fc33882913e20d0be0345b014c98753d2056efe22568(
+    value: builtins.str,
+) -> None:
+    """Type checking stubs"""
+    pass
+
+def _typecheckingstub__5c221249ff2765a8e6f74bc5869bfee3d642646ecf25ea9cb9404a2d954f0683(
+    value: builtins.str,
+) -> None:
+    """Type checking stubs"""
+    pass
+
+def _typecheckingstub__8433e0de625b8cdd7af72860d8e18ac94b513440a8e56ff43b927e9da0c98992(
+    *,
+    connection: typing.Optional[typing.Union[typing.Union[_cdktf_9a9027ec.SSHProvisionerConnection, typing.Dict[builtins.str, typing.Any]], typing.Union[_cdktf_9a9027ec.WinrmProvisionerConnection, typing.Dict[builtins.str, typing.Any]]]] = None,
+    count: typing.Optional[jsii.Number] = None,
+    depends_on: typing.Optional[typing.Sequence[_cdktf_9a9027ec.ITerraformDependable]] = None,
+    for_each: typing.Optional[_cdktf_9a9027ec.ITerraformIterator] = None,
+    lifecycle: typing.Optional[typing.Union[_cdktf_9a9027ec.TerraformResourceLifecycle, typing.Dict[builtins.str, typing.Any]]] = None,
+    provider: typing.Optional[_cdktf_9a9027ec.TerraformProvider] = None,
+    provisioners: typing.Optional[typing.Sequence[typing.Union[typing.Union[_cdktf_9a9027ec.FileProvisioner, typing.Dict[builtins.str, typing.Any]], typing.Union[_cdktf_9a9027ec.LocalExecProvisioner, typing.Dict[builtins.str, typing.Any]], typing.Union[_cdktf_9a9027ec.RemoteExecProvisioner, typing.Dict[builtins.str, typing.Any]]]]] = None,
+    path: builtins.str,
+    content_base64: typing.Optional[builtins.str] = None,
+    format: typing.Optional[builtins.str] = None,
+    id: typing.Optional[builtins.str] = None,
+    language: typing.Optional[builtins.str] = None,
+    md5: typing.Optional[builtins.str] = None,
+    object_id: typing.Optional[jsii.Number] = None,
+    object_type: typing.Optional[builtins.str] = None,
+    source: typing.Optional[builtins.str] = None,
+) -> None:
+    """Type checking stubs"""
+    pass
