@@ -17,12 +17,12 @@ from typeguard import check_type
 
 from .._jsii import *
 
-import cdktf
-import constructs
+import cdktf as _cdktf_9a9027ec
+import constructs as _constructs_77d1e7e8
 
 
 class Repo(
-    cdktf.TerraformResource,
+    _cdktf_9a9027ec.TerraformResource,
     metaclass=jsii.JSIIMeta,
     jsii_type="@cdktf/provider-databricks.repo.Repo",
 ):
@@ -30,7 +30,7 @@ class Repo(
 
     def __init__(
         self,
-        scope: constructs.Construct,
+        scope: _constructs_77d1e7e8.Construct,
         id_: builtins.str,
         *,
         url: builtins.str,
@@ -39,14 +39,15 @@ class Repo(
         git_provider: typing.Optional[builtins.str] = None,
         id: typing.Optional[builtins.str] = None,
         path: typing.Optional[builtins.str] = None,
+        sparse_checkout: typing.Optional[typing.Union["RepoSparseCheckout", typing.Dict[builtins.str, typing.Any]]] = None,
         tag: typing.Optional[builtins.str] = None,
-        connection: typing.Optional[typing.Union[typing.Union[cdktf.SSHProvisionerConnection, typing.Dict[str, typing.Any]], typing.Union[cdktf.WinrmProvisionerConnection, typing.Dict[str, typing.Any]]]] = None,
+        connection: typing.Optional[typing.Union[typing.Union[_cdktf_9a9027ec.SSHProvisionerConnection, typing.Dict[builtins.str, typing.Any]], typing.Union[_cdktf_9a9027ec.WinrmProvisionerConnection, typing.Dict[builtins.str, typing.Any]]]] = None,
         count: typing.Optional[jsii.Number] = None,
-        depends_on: typing.Optional[typing.Sequence[cdktf.ITerraformDependable]] = None,
-        for_each: typing.Optional[cdktf.ITerraformIterator] = None,
-        lifecycle: typing.Optional[typing.Union[cdktf.TerraformResourceLifecycle, typing.Dict[str, typing.Any]]] = None,
-        provider: typing.Optional[cdktf.TerraformProvider] = None,
-        provisioners: typing.Optional[typing.Sequence[typing.Union[typing.Union[cdktf.FileProvisioner, typing.Dict[str, typing.Any]], typing.Union[cdktf.LocalExecProvisioner, typing.Dict[str, typing.Any]], typing.Union[cdktf.RemoteExecProvisioner, typing.Dict[str, typing.Any]]]]] = None,
+        depends_on: typing.Optional[typing.Sequence[_cdktf_9a9027ec.ITerraformDependable]] = None,
+        for_each: typing.Optional[_cdktf_9a9027ec.ITerraformIterator] = None,
+        lifecycle: typing.Optional[typing.Union[_cdktf_9a9027ec.TerraformResourceLifecycle, typing.Dict[builtins.str, typing.Any]]] = None,
+        provider: typing.Optional[_cdktf_9a9027ec.TerraformProvider] = None,
+        provisioners: typing.Optional[typing.Sequence[typing.Union[typing.Union[_cdktf_9a9027ec.FileProvisioner, typing.Dict[builtins.str, typing.Any]], typing.Union[_cdktf_9a9027ec.LocalExecProvisioner, typing.Dict[builtins.str, typing.Any]], typing.Union[_cdktf_9a9027ec.RemoteExecProvisioner, typing.Dict[builtins.str, typing.Any]]]]] = None,
     ) -> None:
         '''Create a new {@link https://www.terraform.io/docs/providers/databricks/r/repo databricks_repo} Resource.
 
@@ -58,6 +59,7 @@ class Repo(
         :param git_provider: Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/databricks/r/repo#git_provider Repo#git_provider}.
         :param id: Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/databricks/r/repo#id Repo#id}. Please be aware that the id field is automatically added to all resources in Terraform providers using a Terraform provider SDK version below 2. If you experience problems setting this value it might not be settable. Please take a look at the provider documentation to ensure it should be settable.
         :param path: Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/databricks/r/repo#path Repo#path}.
+        :param sparse_checkout: sparse_checkout block. Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/databricks/r/repo#sparse_checkout Repo#sparse_checkout}
         :param tag: Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/databricks/r/repo#tag Repo#tag}.
         :param connection: 
         :param count: 
@@ -68,7 +70,7 @@ class Repo(
         :param provisioners: 
         '''
         if __debug__:
-            type_hints = typing.get_type_hints(Repo.__init__)
+            type_hints = typing.get_type_hints(_typecheckingstub__5636969ec1650aa6d44c6ef955faa7e208b06690e92f127f614d5c3a8353a5b4)
             check_type(argname="argument scope", value=scope, expected_type=type_hints["scope"])
             check_type(argname="argument id_", value=id_, expected_type=type_hints["id_"])
         config = RepoConfig(
@@ -78,6 +80,7 @@ class Repo(
             git_provider=git_provider,
             id=id,
             path=path,
+            sparse_checkout=sparse_checkout,
             tag=tag,
             connection=connection,
             count=count,
@@ -90,6 +93,15 @@ class Repo(
 
         jsii.create(self.__class__, self, [scope, id_, config])
 
+    @jsii.member(jsii_name="putSparseCheckout")
+    def put_sparse_checkout(self, *, patterns: typing.Sequence[builtins.str]) -> None:
+        '''
+        :param patterns: Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/databricks/r/repo#patterns Repo#patterns}.
+        '''
+        value = RepoSparseCheckout(patterns=patterns)
+
+        return typing.cast(None, jsii.invoke(self, "putSparseCheckout", [value]))
+
     @jsii.member(jsii_name="resetBranch")
     def reset_branch(self) -> None:
         return typing.cast(None, jsii.invoke(self, "resetBranch", []))
@@ -110,6 +122,10 @@ class Repo(
     def reset_path(self) -> None:
         return typing.cast(None, jsii.invoke(self, "resetPath", []))
 
+    @jsii.member(jsii_name="resetSparseCheckout")
+    def reset_sparse_checkout(self) -> None:
+        return typing.cast(None, jsii.invoke(self, "resetSparseCheckout", []))
+
     @jsii.member(jsii_name="resetTag")
     def reset_tag(self) -> None:
         return typing.cast(None, jsii.invoke(self, "resetTag", []))
@@ -123,6 +139,11 @@ class Repo(
     def TF_RESOURCE_TYPE(cls) -> builtins.str:
         return typing.cast(builtins.str, jsii.sget(cls, "tfResourceType"))
 
+    @builtins.property
+    @jsii.member(jsii_name="sparseCheckout")
+    def sparse_checkout(self) -> "RepoSparseCheckoutOutputReference":
+        return typing.cast("RepoSparseCheckoutOutputReference", jsii.get(self, "sparseCheckout"))
+
     @builtins.property
     @jsii.member(jsii_name="branchInput")
     def branch_input(self) -> typing.Optional[builtins.str]:
@@ -148,6 +169,11 @@ class Repo(
     def path_input(self) -> typing.Optional[builtins.str]:
         return typing.cast(typing.Optional[builtins.str], jsii.get(self, "pathInput"))
 
+    @builtins.property
+    @jsii.member(jsii_name="sparseCheckoutInput")
+    def sparse_checkout_input(self) -> typing.Optional["RepoSparseCheckout"]:
+        return typing.cast(typing.Optional["RepoSparseCheckout"], jsii.get(self, "sparseCheckoutInput"))
+
     @builtins.property
     @jsii.member(jsii_name="tagInput")
     def tag_input(self) -> typing.Optional[builtins.str]:
@@ -166,7 +192,7 @@ class Repo(
     @branch.setter
     def branch(self, value: builtins.str) -> None:
         if __debug__:
-            type_hints = typing.get_type_hints(getattr(Repo, "branch").fset)
+            type_hints = typing.get_type_hints(_typecheckingstub__a3c567793d308090d743de31e92d1fe78c7306aadfa002a67e12553a337b7cdf)
             check_type(argname="argument value", value=value, expected_type=type_hints["value"])
         jsii.set(self, "branch", value)
 
@@ -178,7 +204,7 @@ class Repo(
     @commit_hash.setter
     def commit_hash(self, value: builtins.str) -> None:
         if __debug__:
-            type_hints = typing.get_type_hints(getattr(Repo, "commit_hash").fset)
+            type_hints = typing.get_type_hints(_typecheckingstub__1543c746b5ccb530eea07256b52b210f64968e5d8a13df5b850e789137e5bb9a)
             check_type(argname="argument value", value=value, expected_type=type_hints["value"])
         jsii.set(self, "commitHash", value)
 
@@ -190,7 +216,7 @@ class Repo(
     @git_provider.setter
     def git_provider(self, value: builtins.str) -> None:
         if __debug__:
-            type_hints = typing.get_type_hints(getattr(Repo, "git_provider").fset)
+            type_hints = typing.get_type_hints(_typecheckingstub__3e9d801bfa65ab1a57b4d0a2717bc4055193af4b67ad8cd8318c1f1435f0df54)
             check_type(argname="argument value", value=value, expected_type=type_hints["value"])
         jsii.set(self, "gitProvider", value)
 
@@ -202,7 +228,7 @@ class Repo(
     @id.setter
     def id(self, value: builtins.str) -> None:
         if __debug__:
-            type_hints = typing.get_type_hints(getattr(Repo, "id").fset)
+            type_hints = typing.get_type_hints(_typecheckingstub__0bf8cc715fdbcecda194b55ec47cc00ad84b8fa0ab27242c7284553b6a3c20c8)
             check_type(argname="argument value", value=value, expected_type=type_hints["value"])
         jsii.set(self, "id", value)
 
@@ -214,7 +240,7 @@ class Repo(
     @path.setter
     def path(self, value: builtins.str) -> None:
         if __debug__:
-            type_hints = typing.get_type_hints(getattr(Repo, "path").fset)
+            type_hints = typing.get_type_hints(_typecheckingstub__8ce369e4e556b975ae8b94e2dc4fe58afec6f7662d04c408fd9dddafb13ac5a3)
             check_type(argname="argument value", value=value, expected_type=type_hints["value"])
         jsii.set(self, "path", value)
 
@@ -226,7 +252,7 @@ class Repo(
     @tag.setter
     def tag(self, value: builtins.str) -> None:
         if __debug__:
-            type_hints = typing.get_type_hints(getattr(Repo, "tag").fset)
+            type_hints = typing.get_type_hints(_typecheckingstub__f58f3c5389caea48d2ae000054c482de1a5378d9b638cd60d08a1c984f38438d)
             check_type(argname="argument value", value=value, expected_type=type_hints["value"])
         jsii.set(self, "tag", value)
 
@@ -238,14 +264,14 @@ class Repo(
     @url.setter
     def url(self, value: builtins.str) -> None:
         if __debug__:
-            type_hints = typing.get_type_hints(getattr(Repo, "url").fset)
+            type_hints = typing.get_type_hints(_typecheckingstub__5f41e1f7fb70a0af4ea02e301627c5fc4dca6d7a11e4a847c57a74ff70ae49a9)
             check_type(argname="argument value", value=value, expected_type=type_hints["value"])
         jsii.set(self, "url", value)
 
 
 @jsii.data_type(
     jsii_type="@cdktf/provider-databricks.repo.RepoConfig",
-    jsii_struct_bases=[cdktf.TerraformMetaArguments],
+    jsii_struct_bases=[_cdktf_9a9027ec.TerraformMetaArguments],
     name_mapping={
         "connection": "connection",
         "count": "count",
@@ -260,26 +286,28 @@ class Repo(
         "git_provider": "gitProvider",
         "id": "id",
         "path": "path",
+        "sparse_checkout": "sparseCheckout",
         "tag": "tag",
     },
 )
-class RepoConfig(cdktf.TerraformMetaArguments):
+class RepoConfig(_cdktf_9a9027ec.TerraformMetaArguments):
     def __init__(
         self,
         *,
-        connection: typing.Optional[typing.Union[typing.Union[cdktf.SSHProvisionerConnection, typing.Dict[str, typing.Any]], typing.Union[cdktf.WinrmProvisionerConnection, typing.Dict[str, typing.Any]]]] = None,
+        connection: typing.Optional[typing.Union[typing.Union[_cdktf_9a9027ec.SSHProvisionerConnection, typing.Dict[builtins.str, typing.Any]], typing.Union[_cdktf_9a9027ec.WinrmProvisionerConnection, typing.Dict[builtins.str, typing.Any]]]] = None,
         count: typing.Optional[jsii.Number] = None,
-        depends_on: typing.Optional[typing.Sequence[cdktf.ITerraformDependable]] = None,
-        for_each: typing.Optional[cdktf.ITerraformIterator] = None,
-        lifecycle: typing.Optional[typing.Union[cdktf.TerraformResourceLifecycle, typing.Dict[str, typing.Any]]] = None,
-        provider: typing.Optional[cdktf.TerraformProvider] = None,
-        provisioners: typing.Optional[typing.Sequence[typing.Union[typing.Union[cdktf.FileProvisioner, typing.Dict[str, typing.Any]], typing.Union[cdktf.LocalExecProvisioner, typing.Dict[str, typing.Any]], typing.Union[cdktf.RemoteExecProvisioner, typing.Dict[str, typing.Any]]]]] = None,
+        depends_on: typing.Optional[typing.Sequence[_cdktf_9a9027ec.ITerraformDependable]] = None,
+        for_each: typing.Optional[_cdktf_9a9027ec.ITerraformIterator] = None,
+        lifecycle: typing.Optional[typing.Union[_cdktf_9a9027ec.TerraformResourceLifecycle, typing.Dict[builtins.str, typing.Any]]] = None,
+        provider: typing.Optional[_cdktf_9a9027ec.TerraformProvider] = None,
+        provisioners: typing.Optional[typing.Sequence[typing.Union[typing.Union[_cdktf_9a9027ec.FileProvisioner, typing.Dict[builtins.str, typing.Any]], typing.Union[_cdktf_9a9027ec.LocalExecProvisioner, typing.Dict[builtins.str, typing.Any]], typing.Union[_cdktf_9a9027ec.RemoteExecProvisioner, typing.Dict[builtins.str, typing.Any]]]]] = None,
         url: builtins.str,
         branch: typing.Optional[builtins.str] = None,
         commit_hash: typing.Optional[builtins.str] = None,
         git_provider: typing.Optional[builtins.str] = None,
         id: typing.Optional[builtins.str] = None,
         path: typing.Optional[builtins.str] = None,
+        sparse_checkout: typing.Optional[typing.Union["RepoSparseCheckout", typing.Dict[builtins.str, typing.Any]]] = None,
         tag: typing.Optional[builtins.str] = None,
     ) -> None:
         '''
@@ -296,12 +324,15 @@ class RepoConfig(cdktf.TerraformMetaArguments):
         :param git_provider: Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/databricks/r/repo#git_provider Repo#git_provider}.
         :param id: Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/databricks/r/repo#id Repo#id}. Please be aware that the id field is automatically added to all resources in Terraform providers using a Terraform provider SDK version below 2. If you experience problems setting this value it might not be settable. Please take a look at the provider documentation to ensure it should be settable.
         :param path: Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/databricks/r/repo#path Repo#path}.
+        :param sparse_checkout: sparse_checkout block. Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/databricks/r/repo#sparse_checkout Repo#sparse_checkout}
         :param tag: Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/databricks/r/repo#tag Repo#tag}.
         '''
         if isinstance(lifecycle, dict):
-            lifecycle = cdktf.TerraformResourceLifecycle(**lifecycle)
+            lifecycle = _cdktf_9a9027ec.TerraformResourceLifecycle(**lifecycle)
+        if isinstance(sparse_checkout, dict):
+            sparse_checkout = RepoSparseCheckout(**sparse_checkout)
         if __debug__:
-            type_hints = typing.get_type_hints(RepoConfig.__init__)
+            type_hints = typing.get_type_hints(_typecheckingstub__31f7e7a613a905cd019e9d144690ee96290034ff01018f454ac3b8dec1acc785)
             check_type(argname="argument connection", value=connection, expected_type=type_hints["connection"])
             check_type(argname="argument count", value=count, expected_type=type_hints["count"])
             check_type(argname="argument depends_on", value=depends_on, expected_type=type_hints["depends_on"])
@@ -315,8 +346,9 @@ class RepoConfig(cdktf.TerraformMetaArguments):
             check_type(argname="argument git_provider", value=git_provider, expected_type=type_hints["git_provider"])
             check_type(argname="argument id", value=id, expected_type=type_hints["id"])
             check_type(argname="argument path", value=path, expected_type=type_hints["path"])
+            check_type(argname="argument sparse_checkout", value=sparse_checkout, expected_type=type_hints["sparse_checkout"])
             check_type(argname="argument tag", value=tag, expected_type=type_hints["tag"])
-        self._values: typing.Dict[str, typing.Any] = {
+        self._values: typing.Dict[builtins.str, typing.Any] = {
             "url": url,
         }
         if connection is not None:
@@ -343,18 +375,20 @@ class RepoConfig(cdktf.TerraformMetaArguments):
             self._values["id"] = id
         if path is not None:
             self._values["path"] = path
+        if sparse_checkout is not None:
+            self._values["sparse_checkout"] = sparse_checkout
         if tag is not None:
             self._values["tag"] = tag
 
     @builtins.property
     def connection(
         self,
-    ) -> typing.Optional[typing.Union[cdktf.SSHProvisionerConnection, cdktf.WinrmProvisionerConnection]]:
+    ) -> typing.Optional[typing.Union[_cdktf_9a9027ec.SSHProvisionerConnection, _cdktf_9a9027ec.WinrmProvisionerConnection]]:
         '''
         :stability: experimental
         '''
         result = self._values.get("connection")
-        return typing.cast(typing.Optional[typing.Union[cdktf.SSHProvisionerConnection, cdktf.WinrmProvisionerConnection]], result)
+        return typing.cast(typing.Optional[typing.Union[_cdktf_9a9027ec.SSHProvisionerConnection, _cdktf_9a9027ec.WinrmProvisionerConnection]], result)
 
     @builtins.property
     def count(self) -> typing.Optional[jsii.Number]:
@@ -365,46 +399,48 @@ class RepoConfig(cdktf.TerraformMetaArguments):
         return typing.cast(typing.Optional[jsii.Number], result)
 
     @builtins.property
-    def depends_on(self) -> typing.Optional[typing.List[cdktf.ITerraformDependable]]:
+    def depends_on(
+        self,
+    ) -> typing.Optional[typing.List[_cdktf_9a9027ec.ITerraformDependable]]:
         '''
         :stability: experimental
         '''
         result = self._values.get("depends_on")
-        return typing.cast(typing.Optional[typing.List[cdktf.ITerraformDependable]], result)
+        return typing.cast(typing.Optional[typing.List[_cdktf_9a9027ec.ITerraformDependable]], result)
 
     @builtins.property
-    def for_each(self) -> typing.Optional[cdktf.ITerraformIterator]:
+    def for_each(self) -> typing.Optional[_cdktf_9a9027ec.ITerraformIterator]:
         '''
         :stability: experimental
         '''
         result = self._values.get("for_each")
-        return typing.cast(typing.Optional[cdktf.ITerraformIterator], result)
+        return typing.cast(typing.Optional[_cdktf_9a9027ec.ITerraformIterator], result)
 
     @builtins.property
-    def lifecycle(self) -> typing.Optional[cdktf.TerraformResourceLifecycle]:
+    def lifecycle(self) -> typing.Optional[_cdktf_9a9027ec.TerraformResourceLifecycle]:
         '''
         :stability: experimental
         '''
         result = self._values.get("lifecycle")
-        return typing.cast(typing.Optional[cdktf.TerraformResourceLifecycle], result)
+        return typing.cast(typing.Optional[_cdktf_9a9027ec.TerraformResourceLifecycle], result)
 
     @builtins.property
-    def provider(self) -> typing.Optional[cdktf.TerraformProvider]:
+    def provider(self) -> typing.Optional[_cdktf_9a9027ec.TerraformProvider]:
         '''
         :stability: experimental
         '''
         result = self._values.get("provider")
-        return typing.cast(typing.Optional[cdktf.TerraformProvider], result)
+        return typing.cast(typing.Optional[_cdktf_9a9027ec.TerraformProvider], result)
 
     @builtins.property
     def provisioners(
         self,
-    ) -> typing.Optional[typing.List[typing.Union[cdktf.FileProvisioner, cdktf.LocalExecProvisioner, cdktf.RemoteExecProvisioner]]]:
+    ) -> typing.Optional[typing.List[typing.Union[_cdktf_9a9027ec.FileProvisioner, _cdktf_9a9027ec.LocalExecProvisioner, _cdktf_9a9027ec.RemoteExecProvisioner]]]:
         '''
         :stability: experimental
         '''
         result = self._values.get("provisioners")
-        return typing.cast(typing.Optional[typing.List[typing.Union[cdktf.FileProvisioner, cdktf.LocalExecProvisioner, cdktf.RemoteExecProvisioner]]], result)
+        return typing.cast(typing.Optional[typing.List[typing.Union[_cdktf_9a9027ec.FileProvisioner, _cdktf_9a9027ec.LocalExecProvisioner, _cdktf_9a9027ec.RemoteExecProvisioner]]], result)
 
     @builtins.property
     def url(self) -> builtins.str:
@@ -447,6 +483,15 @@ class RepoConfig(cdktf.TerraformMetaArguments):
         result = self._values.get("path")
         return typing.cast(typing.Optional[builtins.str], result)
 
+    @builtins.property
+    def sparse_checkout(self) -> typing.Optional["RepoSparseCheckout"]:
+        '''sparse_checkout block.
+
+        Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/databricks/r/repo#sparse_checkout Repo#sparse_checkout}
+        '''
+        result = self._values.get("sparse_checkout")
+        return typing.cast(typing.Optional["RepoSparseCheckout"], result)
+
     @builtins.property
     def tag(self) -> typing.Optional[builtins.str]:
         '''Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/databricks/r/repo#tag Repo#tag}.'''
@@ -465,9 +510,209 @@ class RepoConfig(cdktf.TerraformMetaArguments):
         )
 
 
+@jsii.data_type(
+    jsii_type="@cdktf/provider-databricks.repo.RepoSparseCheckout",
+    jsii_struct_bases=[],
+    name_mapping={"patterns": "patterns"},
+)
+class RepoSparseCheckout:
+    def __init__(self, *, patterns: typing.Sequence[builtins.str]) -> None:
+        '''
+        :param patterns: Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/databricks/r/repo#patterns Repo#patterns}.
+        '''
+        if __debug__:
+            type_hints = typing.get_type_hints(_typecheckingstub__606578d25ad3e66ac041a449a63915e68219508c5e1ac375c05272ab46400143)
+            check_type(argname="argument patterns", value=patterns, expected_type=type_hints["patterns"])
+        self._values: typing.Dict[builtins.str, typing.Any] = {
+            "patterns": patterns,
+        }
+
+    @builtins.property
+    def patterns(self) -> typing.List[builtins.str]:
+        '''Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/databricks/r/repo#patterns Repo#patterns}.'''
+        result = self._values.get("patterns")
+        assert result is not None, "Required property 'patterns' is missing"
+        return typing.cast(typing.List[builtins.str], result)
+
+    def __eq__(self, rhs: typing.Any) -> builtins.bool:
+        return isinstance(rhs, self.__class__) and rhs._values == self._values
+
+    def __ne__(self, rhs: typing.Any) -> builtins.bool:
+        return not (rhs == self)
+
+    def __repr__(self) -> str:
+        return "RepoSparseCheckout(%s)" % ", ".join(
+            k + "=" + repr(v) for k, v in self._values.items()
+        )
+
+
+class RepoSparseCheckoutOutputReference(
+    _cdktf_9a9027ec.ComplexObject,
+    metaclass=jsii.JSIIMeta,
+    jsii_type="@cdktf/provider-databricks.repo.RepoSparseCheckoutOutputReference",
+):
+    def __init__(
+        self,
+        terraform_resource: _cdktf_9a9027ec.IInterpolatingParent,
+        terraform_attribute: builtins.str,
+    ) -> None:
+        '''
+        :param terraform_resource: The parent resource.
+        :param terraform_attribute: The attribute on the parent resource this class is referencing.
+        '''
+        if __debug__:
+            type_hints = typing.get_type_hints(_typecheckingstub__3f2054c59a5af1a255b781bfbe0f472ad74a9c35425efa6a65effd7d581dd42d)
+            check_type(argname="argument terraform_resource", value=terraform_resource, expected_type=type_hints["terraform_resource"])
+            check_type(argname="argument terraform_attribute", value=terraform_attribute, expected_type=type_hints["terraform_attribute"])
+        jsii.create(self.__class__, self, [terraform_resource, terraform_attribute])
+
+    @builtins.property
+    @jsii.member(jsii_name="patternsInput")
+    def patterns_input(self) -> typing.Optional[typing.List[builtins.str]]:
+        return typing.cast(typing.Optional[typing.List[builtins.str]], jsii.get(self, "patternsInput"))
+
+    @builtins.property
+    @jsii.member(jsii_name="patterns")
+    def patterns(self) -> typing.List[builtins.str]:
+        return typing.cast(typing.List[builtins.str], jsii.get(self, "patterns"))
+
+    @patterns.setter
+    def patterns(self, value: typing.List[builtins.str]) -> None:
+        if __debug__:
+            type_hints = typing.get_type_hints(_typecheckingstub__55409da951f6f4731a2f56cfdcee7a8fd912b20344b0c412e6fb3425bc27c3d6)
+            check_type(argname="argument value", value=value, expected_type=type_hints["value"])
+        jsii.set(self, "patterns", value)
+
+    @builtins.property
+    @jsii.member(jsii_name="internalValue")
+    def internal_value(self) -> typing.Optional[RepoSparseCheckout]:
+        return typing.cast(typing.Optional[RepoSparseCheckout], jsii.get(self, "internalValue"))
+
+    @internal_value.setter
+    def internal_value(self, value: typing.Optional[RepoSparseCheckout]) -> None:
+        if __debug__:
+            type_hints = typing.get_type_hints(_typecheckingstub__9dbd3bf2cb275bd25ce71a7a04597591fbda16bce9d74023da85688d84ad919f)
+            check_type(argname="argument value", value=value, expected_type=type_hints["value"])
+        jsii.set(self, "internalValue", value)
+
+
 __all__ = [
     "Repo",
     "RepoConfig",
+    "RepoSparseCheckout",
+    "RepoSparseCheckoutOutputReference",
 ]
 
 publication.publish()
+
+def _typecheckingstub__5636969ec1650aa6d44c6ef955faa7e208b06690e92f127f614d5c3a8353a5b4(
+    scope: _constructs_77d1e7e8.Construct,
+    id_: builtins.str,
+    *,
+    url: builtins.str,
+    branch: typing.Optional[builtins.str] = None,
+    commit_hash: typing.Optional[builtins.str] = None,
+    git_provider: typing.Optional[builtins.str] = None,
+    id: typing.Optional[builtins.str] = None,
+    path: typing.Optional[builtins.str] = None,
+    sparse_checkout: typing.Optional[typing.Union[RepoSparseCheckout, typing.Dict[builtins.str, typing.Any]]] = None,
+    tag: typing.Optional[builtins.str] = None,
+    connection: typing.Optional[typing.Union[typing.Union[_cdktf_9a9027ec.SSHProvisionerConnection, typing.Dict[builtins.str, typing.Any]], typing.Union[_cdktf_9a9027ec.WinrmProvisionerConnection, typing.Dict[builtins.str, typing.Any]]]] = None,
+    count: typing.Optional[jsii.Number] = None,
+    depends_on: typing.Optional[typing.Sequence[_cdktf_9a9027ec.ITerraformDependable]] = None,
+    for_each: typing.Optional[_cdktf_9a9027ec.ITerraformIterator] = None,
+    lifecycle: typing.Optional[typing.Union[_cdktf_9a9027ec.TerraformResourceLifecycle, typing.Dict[builtins.str, typing.Any]]] = None,
+    provider: typing.Optional[_cdktf_9a9027ec.TerraformProvider] = None,
+    provisioners: typing.Optional[typing.Sequence[typing.Union[typing.Union[_cdktf_9a9027ec.FileProvisioner, typing.Dict[builtins.str, typing.Any]], typing.Union[_cdktf_9a9027ec.LocalExecProvisioner, typing.Dict[builtins.str, typing.Any]], typing.Union[_cdktf_9a9027ec.RemoteExecProvisioner, typing.Dict[builtins.str, typing.Any]]]]] = None,
+) -> None:
+    """Type checking stubs"""
+    pass
+
+def _typecheckingstub__a3c567793d308090d743de31e92d1fe78c7306aadfa002a67e12553a337b7cdf(
+    value: builtins.str,
+) -> None:
+    """Type checking stubs"""
+    pass
+
+def _typecheckingstub__1543c746b5ccb530eea07256b52b210f64968e5d8a13df5b850e789137e5bb9a(
+    value: builtins.str,
+) -> None:
+    """Type checking stubs"""
+    pass
+
+def _typecheckingstub__3e9d801bfa65ab1a57b4d0a2717bc4055193af4b67ad8cd8318c1f1435f0df54(
+    value: builtins.str,
+) -> None:
+    """Type checking stubs"""
+    pass
+
+def _typecheckingstub__0bf8cc715fdbcecda194b55ec47cc00ad84b8fa0ab27242c7284553b6a3c20c8(
+    value: builtins.str,
+) -> None:
+    """Type checking stubs"""
+    pass
+
+def _typecheckingstub__8ce369e4e556b975ae8b94e2dc4fe58afec6f7662d04c408fd9dddafb13ac5a3(
+    value: builtins.str,
+) -> None:
+    """Type checking stubs"""
+    pass
+
+def _typecheckingstub__f58f3c5389caea48d2ae000054c482de1a5378d9b638cd60d08a1c984f38438d(
+    value: builtins.str,
+) -> None:
+    """Type checking stubs"""
+    pass
+
+def _typecheckingstub__5f41e1f7fb70a0af4ea02e301627c5fc4dca6d7a11e4a847c57a74ff70ae49a9(
+    value: builtins.str,
+) -> None:
+    """Type checking stubs"""
+    pass
+
+def _typecheckingstub__31f7e7a613a905cd019e9d144690ee96290034ff01018f454ac3b8dec1acc785(
+    *,
+    connection: typing.Optional[typing.Union[typing.Union[_cdktf_9a9027ec.SSHProvisionerConnection, typing.Dict[builtins.str, typing.Any]], typing.Union[_cdktf_9a9027ec.WinrmProvisionerConnection, typing.Dict[builtins.str, typing.Any]]]] = None,
+    count: typing.Optional[jsii.Number] = None,
+    depends_on: typing.Optional[typing.Sequence[_cdktf_9a9027ec.ITerraformDependable]] = None,
+    for_each: typing.Optional[_cdktf_9a9027ec.ITerraformIterator] = None,
+    lifecycle: typing.Optional[typing.Union[_cdktf_9a9027ec.TerraformResourceLifecycle, typing.Dict[builtins.str, typing.Any]]] = None,
+    provider: typing.Optional[_cdktf_9a9027ec.TerraformProvider] = None,
+    provisioners: typing.Optional[typing.Sequence[typing.Union[typing.Union[_cdktf_9a9027ec.FileProvisioner, typing.Dict[builtins.str, typing.Any]], typing.Union[_cdktf_9a9027ec.LocalExecProvisioner, typing.Dict[builtins.str, typing.Any]], typing.Union[_cdktf_9a9027ec.RemoteExecProvisioner, typing.Dict[builtins.str, typing.Any]]]]] = None,
+    url: builtins.str,
+    branch: typing.Optional[builtins.str] = None,
+    commit_hash: typing.Optional[builtins.str] = None,
+    git_provider: typing.Optional[builtins.str] = None,
+    id: typing.Optional[builtins.str] = None,
+    path: typing.Optional[builtins.str] = None,
+    sparse_checkout: typing.Optional[typing.Union[RepoSparseCheckout, typing.Dict[builtins.str, typing.Any]]] = None,
+    tag: typing.Optional[builtins.str] = None,
+) -> None:
+    """Type checking stubs"""
+    pass
+
+def _typecheckingstub__606578d25ad3e66ac041a449a63915e68219508c5e1ac375c05272ab46400143(
+    *,
+    patterns: typing.Sequence[builtins.str],
+) -> None:
+    """Type checking stubs"""
+    pass
+
+def _typecheckingstub__3f2054c59a5af1a255b781bfbe0f472ad74a9c35425efa6a65effd7d581dd42d(
+    terraform_resource: _cdktf_9a9027ec.IInterpolatingParent,
+    terraform_attribute: builtins.str,
+) -> None:
+    """Type checking stubs"""
+    pass
+
+def _typecheckingstub__55409da951f6f4731a2f56cfdcee7a8fd912b20344b0c412e6fb3425bc27c3d6(
+    value: typing.List[builtins.str],
+) -> None:
+    """Type checking stubs"""
+    pass
+
+def _typecheckingstub__9dbd3bf2cb275bd25ce71a7a04597591fbda16bce9d74023da85688d84ad919f(
+    value: typing.Optional[RepoSparseCheckout],
+) -> None:
+    """Type checking stubs"""
+    pass
