@@ -17,12 +17,12 @@ from typeguard import check_type
 
 from .._jsii import *
 
-import cdktf
-import constructs
+import cdktf as _cdktf_9a9027ec
+import constructs as _constructs_77d1e7e8
 
 
 class Schema(
-    cdktf.TerraformResource,
+    _cdktf_9a9027ec.TerraformResource,
     metaclass=jsii.JSIIMeta,
     jsii_type="@cdktf/provider-databricks.schema.Schema",
 ):
@@ -30,24 +30,25 @@ class Schema(
 
     def __init__(
         self,
-        scope: constructs.Construct,
+        scope: _constructs_77d1e7e8.Construct,
         id_: builtins.str,
         *,
         catalog_name: builtins.str,
         name: builtins.str,
         comment: typing.Optional[builtins.str] = None,
-        force_destroy: typing.Optional[typing.Union[builtins.bool, cdktf.IResolvable]] = None,
+        force_destroy: typing.Optional[typing.Union[builtins.bool, _cdktf_9a9027ec.IResolvable]] = None,
         id: typing.Optional[builtins.str] = None,
         metastore_id: typing.Optional[builtins.str] = None,
         owner: typing.Optional[builtins.str] = None,
         properties: typing.Optional[typing.Mapping[builtins.str, builtins.str]] = None,
-        connection: typing.Optional[typing.Union[typing.Union[cdktf.SSHProvisionerConnection, typing.Dict[str, typing.Any]], typing.Union[cdktf.WinrmProvisionerConnection, typing.Dict[str, typing.Any]]]] = None,
+        storage_root: typing.Optional[builtins.str] = None,
+        connection: typing.Optional[typing.Union[typing.Union[_cdktf_9a9027ec.SSHProvisionerConnection, typing.Dict[builtins.str, typing.Any]], typing.Union[_cdktf_9a9027ec.WinrmProvisionerConnection, typing.Dict[builtins.str, typing.Any]]]] = None,
         count: typing.Optional[jsii.Number] = None,
-        depends_on: typing.Optional[typing.Sequence[cdktf.ITerraformDependable]] = None,
-        for_each: typing.Optional[cdktf.ITerraformIterator] = None,
-        lifecycle: typing.Optional[typing.Union[cdktf.TerraformResourceLifecycle, typing.Dict[str, typing.Any]]] = None,
-        provider: typing.Optional[cdktf.TerraformProvider] = None,
-        provisioners: typing.Optional[typing.Sequence[typing.Union[typing.Union[cdktf.FileProvisioner, typing.Dict[str, typing.Any]], typing.Union[cdktf.LocalExecProvisioner, typing.Dict[str, typing.Any]], typing.Union[cdktf.RemoteExecProvisioner, typing.Dict[str, typing.Any]]]]] = None,
+        depends_on: typing.Optional[typing.Sequence[_cdktf_9a9027ec.ITerraformDependable]] = None,
+        for_each: typing.Optional[_cdktf_9a9027ec.ITerraformIterator] = None,
+        lifecycle: typing.Optional[typing.Union[_cdktf_9a9027ec.TerraformResourceLifecycle, typing.Dict[builtins.str, typing.Any]]] = None,
+        provider: typing.Optional[_cdktf_9a9027ec.TerraformProvider] = None,
+        provisioners: typing.Optional[typing.Sequence[typing.Union[typing.Union[_cdktf_9a9027ec.FileProvisioner, typing.Dict[builtins.str, typing.Any]], typing.Union[_cdktf_9a9027ec.LocalExecProvisioner, typing.Dict[builtins.str, typing.Any]], typing.Union[_cdktf_9a9027ec.RemoteExecProvisioner, typing.Dict[builtins.str, typing.Any]]]]] = None,
     ) -> None:
         '''Create a new {@link https://www.terraform.io/docs/providers/databricks/r/schema databricks_schema} Resource.
 
@@ -61,6 +62,7 @@ class Schema(
         :param metastore_id: Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/databricks/r/schema#metastore_id Schema#metastore_id}.
         :param owner: Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/databricks/r/schema#owner Schema#owner}.
         :param properties: Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/databricks/r/schema#properties Schema#properties}.
+        :param storage_root: Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/databricks/r/schema#storage_root Schema#storage_root}.
         :param connection: 
         :param count: 
         :param depends_on: 
@@ -70,7 +72,7 @@ class Schema(
         :param provisioners: 
         '''
         if __debug__:
-            type_hints = typing.get_type_hints(Schema.__init__)
+            type_hints = typing.get_type_hints(_typecheckingstub__c1b0ac46bec88de0273015c68134e4b6de3e9a83552e0b5f6aaeaebf8d6456b5)
             check_type(argname="argument scope", value=scope, expected_type=type_hints["scope"])
             check_type(argname="argument id_", value=id_, expected_type=type_hints["id_"])
         config = SchemaConfig(
@@ -82,6 +84,7 @@ class Schema(
             metastore_id=metastore_id,
             owner=owner,
             properties=properties,
+            storage_root=storage_root,
             connection=connection,
             count=count,
             depends_on=depends_on,
@@ -117,6 +120,10 @@ class Schema(
     def reset_properties(self) -> None:
         return typing.cast(None, jsii.invoke(self, "resetProperties", []))
 
+    @jsii.member(jsii_name="resetStorageRoot")
+    def reset_storage_root(self) -> None:
+        return typing.cast(None, jsii.invoke(self, "resetStorageRoot", []))
+
     @jsii.member(jsii_name="synthesizeAttributes")
     def _synthesize_attributes(self) -> typing.Mapping[builtins.str, typing.Any]:
         return typing.cast(typing.Mapping[builtins.str, typing.Any], jsii.invoke(self, "synthesizeAttributes", []))
@@ -140,8 +147,8 @@ class Schema(
     @jsii.member(jsii_name="forceDestroyInput")
     def force_destroy_input(
         self,
-    ) -> typing.Optional[typing.Union[builtins.bool, cdktf.IResolvable]]:
-        return typing.cast(typing.Optional[typing.Union[builtins.bool, cdktf.IResolvable]], jsii.get(self, "forceDestroyInput"))
+    ) -> typing.Optional[typing.Union[builtins.bool, _cdktf_9a9027ec.IResolvable]]:
+        return typing.cast(typing.Optional[typing.Union[builtins.bool, _cdktf_9a9027ec.IResolvable]], jsii.get(self, "forceDestroyInput"))
 
     @builtins.property
     @jsii.member(jsii_name="idInput")
@@ -170,6 +177,11 @@ class Schema(
     ) -> typing.Optional[typing.Mapping[builtins.str, builtins.str]]:
         return typing.cast(typing.Optional[typing.Mapping[builtins.str, builtins.str]], jsii.get(self, "propertiesInput"))
 
+    @builtins.property
+    @jsii.member(jsii_name="storageRootInput")
+    def storage_root_input(self) -> typing.Optional[builtins.str]:
+        return typing.cast(typing.Optional[builtins.str], jsii.get(self, "storageRootInput"))
+
     @builtins.property
     @jsii.member(jsii_name="catalogName")
     def catalog_name(self) -> builtins.str:
@@ -178,7 +190,7 @@ class Schema(
     @catalog_name.setter
     def catalog_name(self, value: builtins.str) -> None:
         if __debug__:
-            type_hints = typing.get_type_hints(getattr(Schema, "catalog_name").fset)
+            type_hints = typing.get_type_hints(_typecheckingstub__15fa9f50b9bae65d26c88a79513294bcc9d60e62d6fd0d39b13875e1a8220f18)
             check_type(argname="argument value", value=value, expected_type=type_hints["value"])
         jsii.set(self, "catalogName", value)
 
@@ -190,22 +202,22 @@ class Schema(
     @comment.setter
     def comment(self, value: builtins.str) -> None:
         if __debug__:
-            type_hints = typing.get_type_hints(getattr(Schema, "comment").fset)
+            type_hints = typing.get_type_hints(_typecheckingstub__73301c1e6cab5fbc59195de29ecdc411ecb9a8ccc789a5f01dfb32f105b8d5aa)
             check_type(argname="argument value", value=value, expected_type=type_hints["value"])
         jsii.set(self, "comment", value)
 
     @builtins.property
     @jsii.member(jsii_name="forceDestroy")
-    def force_destroy(self) -> typing.Union[builtins.bool, cdktf.IResolvable]:
-        return typing.cast(typing.Union[builtins.bool, cdktf.IResolvable], jsii.get(self, "forceDestroy"))
+    def force_destroy(self) -> typing.Union[builtins.bool, _cdktf_9a9027ec.IResolvable]:
+        return typing.cast(typing.Union[builtins.bool, _cdktf_9a9027ec.IResolvable], jsii.get(self, "forceDestroy"))
 
     @force_destroy.setter
     def force_destroy(
         self,
-        value: typing.Union[builtins.bool, cdktf.IResolvable],
+        value: typing.Union[builtins.bool, _cdktf_9a9027ec.IResolvable],
     ) -> None:
         if __debug__:
-            type_hints = typing.get_type_hints(getattr(Schema, "force_destroy").fset)
+            type_hints = typing.get_type_hints(_typecheckingstub__7a2ed0f0a0c16fc771fe38040ff7d6f60f5f614ea209e558f8534d4e3bcb6c08)
             check_type(argname="argument value", value=value, expected_type=type_hints["value"])
         jsii.set(self, "forceDestroy", value)
 
@@ -217,7 +229,7 @@ class Schema(
     @id.setter
     def id(self, value: builtins.str) -> None:
         if __debug__:
-            type_hints = typing.get_type_hints(getattr(Schema, "id").fset)
+            type_hints = typing.get_type_hints(_typecheckingstub__513e8d7a5b405d6e20fbdc966fe1414292182e4401885d56b8c6114155d8c7d6)
             check_type(argname="argument value", value=value, expected_type=type_hints["value"])
         jsii.set(self, "id", value)
 
@@ -229,7 +241,7 @@ class Schema(
     @metastore_id.setter
     def metastore_id(self, value: builtins.str) -> None:
         if __debug__:
-            type_hints = typing.get_type_hints(getattr(Schema, "metastore_id").fset)
+            type_hints = typing.get_type_hints(_typecheckingstub__99b609d5de122a78deaf722ba1911d26d430bfb44f957a512a4278c93889bd45)
             check_type(argname="argument value", value=value, expected_type=type_hints["value"])
         jsii.set(self, "metastoreId", value)
 
@@ -241,7 +253,7 @@ class Schema(
     @name.setter
     def name(self, value: builtins.str) -> None:
         if __debug__:
-            type_hints = typing.get_type_hints(getattr(Schema, "name").fset)
+            type_hints = typing.get_type_hints(_typecheckingstub__77fac3d7fb1a80976536a4ca10fbb80bb5f7e374214c9a8c2dd0807da15836d3)
             check_type(argname="argument value", value=value, expected_type=type_hints["value"])
         jsii.set(self, "name", value)
 
@@ -253,7 +265,7 @@ class Schema(
     @owner.setter
     def owner(self, value: builtins.str) -> None:
         if __debug__:
-            type_hints = typing.get_type_hints(getattr(Schema, "owner").fset)
+            type_hints = typing.get_type_hints(_typecheckingstub__38c26ab420d233b782cf57f6afeac46c0fc2ed1b723d520439beca5546be05bc)
             check_type(argname="argument value", value=value, expected_type=type_hints["value"])
         jsii.set(self, "owner", value)
 
@@ -265,14 +277,26 @@ class Schema(
     @properties.setter
     def properties(self, value: typing.Mapping[builtins.str, builtins.str]) -> None:
         if __debug__:
-            type_hints = typing.get_type_hints(getattr(Schema, "properties").fset)
+            type_hints = typing.get_type_hints(_typecheckingstub__71913a536de82977d600ea2a2587a738611abf746c42e598cbfa430ef8e4494f)
             check_type(argname="argument value", value=value, expected_type=type_hints["value"])
         jsii.set(self, "properties", value)
 
+    @builtins.property
+    @jsii.member(jsii_name="storageRoot")
+    def storage_root(self) -> builtins.str:
+        return typing.cast(builtins.str, jsii.get(self, "storageRoot"))
+
+    @storage_root.setter
+    def storage_root(self, value: builtins.str) -> None:
+        if __debug__:
+            type_hints = typing.get_type_hints(_typecheckingstub__762f046d2fd2946eddb44d83a0102d26d9dd5ae346f5fe25c91fa7a7827a20fd)
+            check_type(argname="argument value", value=value, expected_type=type_hints["value"])
+        jsii.set(self, "storageRoot", value)
+
 
 @jsii.data_type(
     jsii_type="@cdktf/provider-databricks.schema.SchemaConfig",
-    jsii_struct_bases=[cdktf.TerraformMetaArguments],
+    jsii_struct_bases=[_cdktf_9a9027ec.TerraformMetaArguments],
     name_mapping={
         "connection": "connection",
         "count": "count",
@@ -289,27 +313,29 @@ class Schema(
         "metastore_id": "metastoreId",
         "owner": "owner",
         "properties": "properties",
+        "storage_root": "storageRoot",
     },
 )
-class SchemaConfig(cdktf.TerraformMetaArguments):
+class SchemaConfig(_cdktf_9a9027ec.TerraformMetaArguments):
     def __init__(
         self,
         *,
-        connection: typing.Optional[typing.Union[typing.Union[cdktf.SSHProvisionerConnection, typing.Dict[str, typing.Any]], typing.Union[cdktf.WinrmProvisionerConnection, typing.Dict[str, typing.Any]]]] = None,
+        connection: typing.Optional[typing.Union[typing.Union[_cdktf_9a9027ec.SSHProvisionerConnection, typing.Dict[builtins.str, typing.Any]], typing.Union[_cdktf_9a9027ec.WinrmProvisionerConnection, typing.Dict[builtins.str, typing.Any]]]] = None,
         count: typing.Optional[jsii.Number] = None,
-        depends_on: typing.Optional[typing.Sequence[cdktf.ITerraformDependable]] = None,
-        for_each: typing.Optional[cdktf.ITerraformIterator] = None,
-        lifecycle: typing.Optional[typing.Union[cdktf.TerraformResourceLifecycle, typing.Dict[str, typing.Any]]] = None,
-        provider: typing.Optional[cdktf.TerraformProvider] = None,
-        provisioners: typing.Optional[typing.Sequence[typing.Union[typing.Union[cdktf.FileProvisioner, typing.Dict[str, typing.Any]], typing.Union[cdktf.LocalExecProvisioner, typing.Dict[str, typing.Any]], typing.Union[cdktf.RemoteExecProvisioner, typing.Dict[str, typing.Any]]]]] = None,
+        depends_on: typing.Optional[typing.Sequence[_cdktf_9a9027ec.ITerraformDependable]] = None,
+        for_each: typing.Optional[_cdktf_9a9027ec.ITerraformIterator] = None,
+        lifecycle: typing.Optional[typing.Union[_cdktf_9a9027ec.TerraformResourceLifecycle, typing.Dict[builtins.str, typing.Any]]] = None,
+        provider: typing.Optional[_cdktf_9a9027ec.TerraformProvider] = None,
+        provisioners: typing.Optional[typing.Sequence[typing.Union[typing.Union[_cdktf_9a9027ec.FileProvisioner, typing.Dict[builtins.str, typing.Any]], typing.Union[_cdktf_9a9027ec.LocalExecProvisioner, typing.Dict[builtins.str, typing.Any]], typing.Union[_cdktf_9a9027ec.RemoteExecProvisioner, typing.Dict[builtins.str, typing.Any]]]]] = None,
         catalog_name: builtins.str,
         name: builtins.str,
         comment: typing.Optional[builtins.str] = None,
-        force_destroy: typing.Optional[typing.Union[builtins.bool, cdktf.IResolvable]] = None,
+        force_destroy: typing.Optional[typing.Union[builtins.bool, _cdktf_9a9027ec.IResolvable]] = None,
         id: typing.Optional[builtins.str] = None,
         metastore_id: typing.Optional[builtins.str] = None,
         owner: typing.Optional[builtins.str] = None,
         properties: typing.Optional[typing.Mapping[builtins.str, builtins.str]] = None,
+        storage_root: typing.Optional[builtins.str] = None,
     ) -> None:
         '''
         :param connection: 
@@ -327,11 +353,12 @@ class SchemaConfig(cdktf.TerraformMetaArguments):
         :param metastore_id: Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/databricks/r/schema#metastore_id Schema#metastore_id}.
         :param owner: Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/databricks/r/schema#owner Schema#owner}.
         :param properties: Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/databricks/r/schema#properties Schema#properties}.
+        :param storage_root: Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/databricks/r/schema#storage_root Schema#storage_root}.
         '''
         if isinstance(lifecycle, dict):
-            lifecycle = cdktf.TerraformResourceLifecycle(**lifecycle)
+            lifecycle = _cdktf_9a9027ec.TerraformResourceLifecycle(**lifecycle)
         if __debug__:
-            type_hints = typing.get_type_hints(SchemaConfig.__init__)
+            type_hints = typing.get_type_hints(_typecheckingstub__71b4bc89cdd0d11b153ace5889ca53f8688918837b4c362d5f0da6061436c020)
             check_type(argname="argument connection", value=connection, expected_type=type_hints["connection"])
             check_type(argname="argument count", value=count, expected_type=type_hints["count"])
             check_type(argname="argument depends_on", value=depends_on, expected_type=type_hints["depends_on"])
@@ -347,7 +374,8 @@ class SchemaConfig(cdktf.TerraformMetaArguments):
             check_type(argname="argument metastore_id", value=metastore_id, expected_type=type_hints["metastore_id"])
             check_type(argname="argument owner", value=owner, expected_type=type_hints["owner"])
             check_type(argname="argument properties", value=properties, expected_type=type_hints["properties"])
-        self._values: typing.Dict[str, typing.Any] = {
+            check_type(argname="argument storage_root", value=storage_root, expected_type=type_hints["storage_root"])
+        self._values: typing.Dict[builtins.str, typing.Any] = {
             "catalog_name": catalog_name,
             "name": name,
         }
@@ -377,16 +405,18 @@ class SchemaConfig(cdktf.TerraformMetaArguments):
             self._values["owner"] = owner
         if properties is not None:
             self._values["properties"] = properties
+        if storage_root is not None:
+            self._values["storage_root"] = storage_root
 
     @builtins.property
     def connection(
         self,
-    ) -> typing.Optional[typing.Union[cdktf.SSHProvisionerConnection, cdktf.WinrmProvisionerConnection]]:
+    ) -> typing.Optional[typing.Union[_cdktf_9a9027ec.SSHProvisionerConnection, _cdktf_9a9027ec.WinrmProvisionerConnection]]:
         '''
         :stability: experimental
         '''
         result = self._values.get("connection")
-        return typing.cast(typing.Optional[typing.Union[cdktf.SSHProvisionerConnection, cdktf.WinrmProvisionerConnection]], result)
+        return typing.cast(typing.Optional[typing.Union[_cdktf_9a9027ec.SSHProvisionerConnection, _cdktf_9a9027ec.WinrmProvisionerConnection]], result)
 
     @builtins.property
     def count(self) -> typing.Optional[jsii.Number]:
@@ -397,46 +427,48 @@ class SchemaConfig(cdktf.TerraformMetaArguments):
         return typing.cast(typing.Optional[jsii.Number], result)
 
     @builtins.property
-    def depends_on(self) -> typing.Optional[typing.List[cdktf.ITerraformDependable]]:
+    def depends_on(
+        self,
+    ) -> typing.Optional[typing.List[_cdktf_9a9027ec.ITerraformDependable]]:
         '''
         :stability: experimental
         '''
         result = self._values.get("depends_on")
-        return typing.cast(typing.Optional[typing.List[cdktf.ITerraformDependable]], result)
+        return typing.cast(typing.Optional[typing.List[_cdktf_9a9027ec.ITerraformDependable]], result)
 
     @builtins.property
-    def for_each(self) -> typing.Optional[cdktf.ITerraformIterator]:
+    def for_each(self) -> typing.Optional[_cdktf_9a9027ec.ITerraformIterator]:
         '''
         :stability: experimental
         '''
         result = self._values.get("for_each")
-        return typing.cast(typing.Optional[cdktf.ITerraformIterator], result)
+        return typing.cast(typing.Optional[_cdktf_9a9027ec.ITerraformIterator], result)
 
     @builtins.property
-    def lifecycle(self) -> typing.Optional[cdktf.TerraformResourceLifecycle]:
+    def lifecycle(self) -> typing.Optional[_cdktf_9a9027ec.TerraformResourceLifecycle]:
         '''
         :stability: experimental
         '''
         result = self._values.get("lifecycle")
-        return typing.cast(typing.Optional[cdktf.TerraformResourceLifecycle], result)
+        return typing.cast(typing.Optional[_cdktf_9a9027ec.TerraformResourceLifecycle], result)
 
     @builtins.property
-    def provider(self) -> typing.Optional[cdktf.TerraformProvider]:
+    def provider(self) -> typing.Optional[_cdktf_9a9027ec.TerraformProvider]:
         '''
         :stability: experimental
         '''
         result = self._values.get("provider")
-        return typing.cast(typing.Optional[cdktf.TerraformProvider], result)
+        return typing.cast(typing.Optional[_cdktf_9a9027ec.TerraformProvider], result)
 
     @builtins.property
     def provisioners(
         self,
-    ) -> typing.Optional[typing.List[typing.Union[cdktf.FileProvisioner, cdktf.LocalExecProvisioner, cdktf.RemoteExecProvisioner]]]:
+    ) -> typing.Optional[typing.List[typing.Union[_cdktf_9a9027ec.FileProvisioner, _cdktf_9a9027ec.LocalExecProvisioner, _cdktf_9a9027ec.RemoteExecProvisioner]]]:
         '''
         :stability: experimental
         '''
         result = self._values.get("provisioners")
-        return typing.cast(typing.Optional[typing.List[typing.Union[cdktf.FileProvisioner, cdktf.LocalExecProvisioner, cdktf.RemoteExecProvisioner]]], result)
+        return typing.cast(typing.Optional[typing.List[typing.Union[_cdktf_9a9027ec.FileProvisioner, _cdktf_9a9027ec.LocalExecProvisioner, _cdktf_9a9027ec.RemoteExecProvisioner]]], result)
 
     @builtins.property
     def catalog_name(self) -> builtins.str:
@@ -461,10 +493,10 @@ class SchemaConfig(cdktf.TerraformMetaArguments):
     @builtins.property
     def force_destroy(
         self,
-    ) -> typing.Optional[typing.Union[builtins.bool, cdktf.IResolvable]]:
+    ) -> typing.Optional[typing.Union[builtins.bool, _cdktf_9a9027ec.IResolvable]]:
         '''Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/databricks/r/schema#force_destroy Schema#force_destroy}.'''
         result = self._values.get("force_destroy")
-        return typing.cast(typing.Optional[typing.Union[builtins.bool, cdktf.IResolvable]], result)
+        return typing.cast(typing.Optional[typing.Union[builtins.bool, _cdktf_9a9027ec.IResolvable]], result)
 
     @builtins.property
     def id(self) -> typing.Optional[builtins.str]:
@@ -494,6 +526,12 @@ class SchemaConfig(cdktf.TerraformMetaArguments):
         result = self._values.get("properties")
         return typing.cast(typing.Optional[typing.Mapping[builtins.str, builtins.str]], result)
 
+    @builtins.property
+    def storage_root(self) -> typing.Optional[builtins.str]:
+        '''Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/databricks/r/schema#storage_root Schema#storage_root}.'''
+        result = self._values.get("storage_root")
+        return typing.cast(typing.Optional[builtins.str], result)
+
     def __eq__(self, rhs: typing.Any) -> builtins.bool:
         return isinstance(rhs, self.__class__) and rhs._values == self._values
 
@@ -512,3 +550,103 @@ __all__ = [
 ]
 
 publication.publish()
+
+def _typecheckingstub__c1b0ac46bec88de0273015c68134e4b6de3e9a83552e0b5f6aaeaebf8d6456b5(
+    scope: _constructs_77d1e7e8.Construct,
+    id_: builtins.str,
+    *,
+    catalog_name: builtins.str,
+    name: builtins.str,
+    comment: typing.Optional[builtins.str] = None,
+    force_destroy: typing.Optional[typing.Union[builtins.bool, _cdktf_9a9027ec.IResolvable]] = None,
+    id: typing.Optional[builtins.str] = None,
+    metastore_id: typing.Optional[builtins.str] = None,
+    owner: typing.Optional[builtins.str] = None,
+    properties: typing.Optional[typing.Mapping[builtins.str, builtins.str]] = None,
+    storage_root: typing.Optional[builtins.str] = None,
+    connection: typing.Optional[typing.Union[typing.Union[_cdktf_9a9027ec.SSHProvisionerConnection, typing.Dict[builtins.str, typing.Any]], typing.Union[_cdktf_9a9027ec.WinrmProvisionerConnection, typing.Dict[builtins.str, typing.Any]]]] = None,
+    count: typing.Optional[jsii.Number] = None,
+    depends_on: typing.Optional[typing.Sequence[_cdktf_9a9027ec.ITerraformDependable]] = None,
+    for_each: typing.Optional[_cdktf_9a9027ec.ITerraformIterator] = None,
+    lifecycle: typing.Optional[typing.Union[_cdktf_9a9027ec.TerraformResourceLifecycle, typing.Dict[builtins.str, typing.Any]]] = None,
+    provider: typing.Optional[_cdktf_9a9027ec.TerraformProvider] = None,
+    provisioners: typing.Optional[typing.Sequence[typing.Union[typing.Union[_cdktf_9a9027ec.FileProvisioner, typing.Dict[builtins.str, typing.Any]], typing.Union[_cdktf_9a9027ec.LocalExecProvisioner, typing.Dict[builtins.str, typing.Any]], typing.Union[_cdktf_9a9027ec.RemoteExecProvisioner, typing.Dict[builtins.str, typing.Any]]]]] = None,
+) -> None:
+    """Type checking stubs"""
+    pass
+
+def _typecheckingstub__15fa9f50b9bae65d26c88a79513294bcc9d60e62d6fd0d39b13875e1a8220f18(
+    value: builtins.str,
+) -> None:
+    """Type checking stubs"""
+    pass
+
+def _typecheckingstub__73301c1e6cab5fbc59195de29ecdc411ecb9a8ccc789a5f01dfb32f105b8d5aa(
+    value: builtins.str,
+) -> None:
+    """Type checking stubs"""
+    pass
+
+def _typecheckingstub__7a2ed0f0a0c16fc771fe38040ff7d6f60f5f614ea209e558f8534d4e3bcb6c08(
+    value: typing.Union[builtins.bool, _cdktf_9a9027ec.IResolvable],
+) -> None:
+    """Type checking stubs"""
+    pass
+
+def _typecheckingstub__513e8d7a5b405d6e20fbdc966fe1414292182e4401885d56b8c6114155d8c7d6(
+    value: builtins.str,
+) -> None:
+    """Type checking stubs"""
+    pass
+
+def _typecheckingstub__99b609d5de122a78deaf722ba1911d26d430bfb44f957a512a4278c93889bd45(
+    value: builtins.str,
+) -> None:
+    """Type checking stubs"""
+    pass
+
+def _typecheckingstub__77fac3d7fb1a80976536a4ca10fbb80bb5f7e374214c9a8c2dd0807da15836d3(
+    value: builtins.str,
+) -> None:
+    """Type checking stubs"""
+    pass
+
+def _typecheckingstub__38c26ab420d233b782cf57f6afeac46c0fc2ed1b723d520439beca5546be05bc(
+    value: builtins.str,
+) -> None:
+    """Type checking stubs"""
+    pass
+
+def _typecheckingstub__71913a536de82977d600ea2a2587a738611abf746c42e598cbfa430ef8e4494f(
+    value: typing.Mapping[builtins.str, builtins.str],
+) -> None:
+    """Type checking stubs"""
+    pass
+
+def _typecheckingstub__762f046d2fd2946eddb44d83a0102d26d9dd5ae346f5fe25c91fa7a7827a20fd(
+    value: builtins.str,
+) -> None:
+    """Type checking stubs"""
+    pass
+
+def _typecheckingstub__71b4bc89cdd0d11b153ace5889ca53f8688918837b4c362d5f0da6061436c020(
+    *,
+    connection: typing.Optional[typing.Union[typing.Union[_cdktf_9a9027ec.SSHProvisionerConnection, typing.Dict[builtins.str, typing.Any]], typing.Union[_cdktf_9a9027ec.WinrmProvisionerConnection, typing.Dict[builtins.str, typing.Any]]]] = None,
+    count: typing.Optional[jsii.Number] = None,
+    depends_on: typing.Optional[typing.Sequence[_cdktf_9a9027ec.ITerraformDependable]] = None,
+    for_each: typing.Optional[_cdktf_9a9027ec.ITerraformIterator] = None,
+    lifecycle: typing.Optional[typing.Union[_cdktf_9a9027ec.TerraformResourceLifecycle, typing.Dict[builtins.str, typing.Any]]] = None,
+    provider: typing.Optional[_cdktf_9a9027ec.TerraformProvider] = None,
+    provisioners: typing.Optional[typing.Sequence[typing.Union[typing.Union[_cdktf_9a9027ec.FileProvisioner, typing.Dict[builtins.str, typing.Any]], typing.Union[_cdktf_9a9027ec.LocalExecProvisioner, typing.Dict[builtins.str, typing.Any]], typing.Union[_cdktf_9a9027ec.RemoteExecProvisioner, typing.Dict[builtins.str, typing.Any]]]]] = None,
+    catalog_name: builtins.str,
+    name: builtins.str,
+    comment: typing.Optional[builtins.str] = None,
+    force_destroy: typing.Optional[typing.Union[builtins.bool, _cdktf_9a9027ec.IResolvable]] = None,
+    id: typing.Optional[builtins.str] = None,
+    metastore_id: typing.Optional[builtins.str] = None,
+    owner: typing.Optional[builtins.str] = None,
+    properties: typing.Optional[typing.Mapping[builtins.str, builtins.str]] = None,
+    storage_root: typing.Optional[builtins.str] = None,
+) -> None:
+    """Type checking stubs"""
+    pass
